///
// @file gpiAPI.h
// @brief header file generate from sapp_gpi.kra
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef _SAPP_GPI_KRA_
#define _SAPP_GPI_KRA_

#ifdef C_SYNTAX
#define KC_EXPAND_RECIPE
#endif // C_SYNTAX

#ifndef KC_EXPAND_RECIPE

//////////////////////////////////////////////////////////////////
// *** define declaration that is not for recipe users *** //
//////////////////////////////////////////////////////////////////

#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// Initialize
#define GPI_API_INIT 0
#define GPI_Init() \
  EAPI_SendEvent(EAPI_TASKID_GPI,GPI_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
#define GPI_API_SET_NOTIFY_PORT 256
#define GPI_SetNotifyPort(mode,port,state,notify_event_id) \
  EAPI_SendEvent(EAPI_TASKID_GPI,GPI_API_SET_NOTIFY_PORT,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,mode,EAPI_VTYPE_U8,port,EAPI_VTYPE_U8,state,EAPI_VTYPE_U8,notify_event_id)
#define GPI_API_CHECK_INTERVAL 257
#define GPI_SetCheckGpiInterval(interval) \
  EAPI_SendEvent(EAPI_TASKID_GPI,GPI_API_CHECK_INTERVAL,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U32,interval)
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 通知するGPI番号
#define NOTIFY_GPI1 1
#define NOTIFY_GPI2 2
#define NOTIFY_GPI3 3
// 通知するGPI状態
#define NOTIFY_GPI_L 1
#define NOTIFY_GPI_H 2
// GPI通知を有効化/無効化
#define NOTIFY_GPI_ENABLE 1
#define NOTIFY_GPI_DISABLE 0

#else

//////////////////////////////////////////////////////////////////
// *** define declaration for recipe users *** //
//////////////////////////////////////////////////////////////////
#include "taskid.h"
#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// Initialize
#define GPI_API_INIT 0
func sys_api_GPI_Init() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_GPI,GPI_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define GPI_Init() sys_api_GPI_Init()
#define GPI_API_SET_NOTIFY_PORT 256
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_GPI_SetNotifyPort(uint8 mode, uint8 port, uint8 state, uint8 notify_event_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,mode);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,port);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,state);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,notify_event_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_GPI,GPI_API_SET_NOTIFY_PORT,EAPI_SYNC_RESULT,1000));
}
#define GPI_SetNotifyPort(mode,port,state,notify_event_id) sys_api_GPI_SetNotifyPort(mode,port,state,notify_event_id)
#endif // YIELD_TO_BASIC_INFOROMATION
#define GPI_API_CHECK_INTERVAL 257
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_GPI_SetCheckGpiInterval(uint32 interval) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,interval);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_GPI,GPI_API_CHECK_INTERVAL,EAPI_SYNC_RESULT,1000));
}
#define GPI_SetCheckGpiInterval(interval) sys_api_GPI_SetCheckGpiInterval(interval)
#endif // YIELD_TO_BASIC_INFOROMATION
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 通知するGPI番号
#define NOTIFY_GPI1 1
#define NOTIFY_GPI2 2
#define NOTIFY_GPI3 3
// 通知するGPI状態
#define NOTIFY_GPI_L 1
#define NOTIFY_GPI_H 2
// GPI通知を有効化/無効化
#define NOTIFY_GPI_ENABLE 1
#define NOTIFY_GPI_DISABLE 0

#endif

#endif
