///
// @file kcSystemAPI.h
// @brief header file generate from sdev_kcsystem.kra
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef _SDEV_KCSYSTEM_KRA_
#define _SDEV_KCSYSTEM_KRA_

#ifdef C_SYNTAX
#define KC_EXPAND_RECIPE
#endif // C_SYNTAX

#ifndef KC_EXPAND_RECIPE

//////////////////////////////////////////////////////////////////
// *** define declaration that is not for recipe users *** //
//////////////////////////////////////////////////////////////////

#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define KCS_API_INIT 0
#define KCS_Init() \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// 工程コマンド実行要求
#define KCS_API_REQ_INSPECTION 256
#define KCS_RequestInspection(message_id,cmd) \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_API_REQ_INSPECTION,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,message_id,EAPI_VTYPE_U32,cmd)
// 温度表示要求
#define KCS_API_REQ_TEMPINFO 257
#define KCS_RequestTemp() \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_API_REQ_TEMPINFO,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// デバイス状態通知
#define KCS_API_NOTIFY_INSPECTION 258
#define KCS_NotifyInspection(cmd) \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_API_NOTIFY_INSPECTION,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,cmd)
// 停止準備完了通知
#define KCS_API_READY_SHUTDOWN 259
#define KCS_NotifyReadyShutdown() \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_API_READY_SHUTDOWN,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// FOTA タイマタイムアウトイベント
#define KCS_NOTIFY_FOTA_TIMEOUT 260
#define KCS_NotifyFotaTimeout(message_id) \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_NOTIFY_FOTA_TIMEOUT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,message_id)
// FOTA アラームイベント
#define KCS_NOTIFY_FOTA_ALARM 261
#define KCS_NotifyFotaAlarm() \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_NOTIFY_FOTA_ALARM,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// スタンバイ実行
#define KCS_API_SHUTDOWN 262
#define KCS_Shutdown() \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_API_SHUTDOWN,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// RCP_OTA実行
#define KCS_NOTIFY_RCP_OTA_START 263
#define KCS_NotifyRcpOtaStart() \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_NOTIFY_RCP_OTA_START,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// RCP_OTA タイマタイムアウトイベント
#define KCS_NOTIFY_RCP_OTA_TIMEOUT 264
#define KCS_NotifyRcpOtaTimeout(message_id) \
  EAPI_SendEvent(EAPI_TASKID_KCS,KCS_NOTIFY_RCP_OTA_TIMEOUT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,message_id)
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// デバイス状態コマンド(cmd)
#define KCS_POWER_ON 0
#define KCS_POWER_OFF 1
#define KCS_AUTOFOTA_START 2
#define KCS_AUTOFOTA_END 3
// RecipeOTA 返答値(ex_result)
#define KCS_RCPOTA_RESULT_NO_ERROR 0
#define KCS_RCPOTA_RESULT_ERR_INVALID_URL 1
#define KCS_RCPOTA_RESULT_ERR_CANNOT_START 2
// RecipeOTA Event返答値(resp_code)
#define KCS_RCPOTA_RESP_OK 0
#define KCS_RCPOTA_RESP_ERR 1
#define KCS_RCPOTA_RESP_NO_UPDATE 2
#define KCS_RCPOTA_RESP_SUSPEND 3
#define KCS_RCPOTA_RESP_RESUME 4

#else

//////////////////////////////////////////////////////////////////
// *** define declaration for recipe users *** //
//////////////////////////////////////////////////////////////////
#include "taskid.h"
#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define KCS_API_INIT 0
func sys_api_KCS_Init() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_Init() sys_api_KCS_Init()
// 工程コマンド実行要求
#define KCS_API_REQ_INSPECTION 256
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_KCS_RequestInspection(uint8 message_id, uint32 cmd) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,message_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,cmd);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_API_REQ_INSPECTION,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_RequestInspection(message_id,cmd) sys_api_KCS_RequestInspection(message_id,cmd)
#endif // YIELD_TO_BASIC_INFOROMATION
// 温度表示要求
#define KCS_API_REQ_TEMPINFO 257
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_KCS_RequestTemp() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_API_REQ_TEMPINFO,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_RequestTemp() sys_api_KCS_RequestTemp()
#endif // YIELD_TO_BASIC_INFOROMATION
// デバイス状態通知
#define KCS_API_NOTIFY_INSPECTION 258
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_KCS_NotifyInspection(uint8 cmd) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,cmd);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_API_NOTIFY_INSPECTION,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_NotifyInspection(cmd) sys_api_KCS_NotifyInspection(cmd)
#endif // YIELD_TO_BASIC_INFOROMATION
// 停止準備完了通知
#define KCS_API_READY_SHUTDOWN 259
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_KCS_NotifyReadyShutdown() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_API_READY_SHUTDOWN,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_NotifyReadyShutdown() sys_api_KCS_NotifyReadyShutdown()
#endif // YIELD_TO_BASIC_INFOROMATION
// FOTA タイマタイムアウトイベント
#define KCS_NOTIFY_FOTA_TIMEOUT 260
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_KCS_NotifyFotaTimeout(uint8 message_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,message_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_NOTIFY_FOTA_TIMEOUT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_NotifyFotaTimeout(message_id) sys_api_KCS_NotifyFotaTimeout(message_id)
#endif // YIELD_TO_BASIC_INFOROMATION
// FOTA アラームイベント
#define KCS_NOTIFY_FOTA_ALARM 261
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_KCS_NotifyFotaAlarm() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_NOTIFY_FOTA_ALARM,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_NotifyFotaAlarm() sys_api_KCS_NotifyFotaAlarm()
#endif // YIELD_TO_BASIC_INFOROMATION
// スタンバイ実行
#define KCS_API_SHUTDOWN 262
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_KCS_Shutdown() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_API_SHUTDOWN,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_Shutdown() sys_api_KCS_Shutdown()
#endif // YIELD_TO_BASIC_INFOROMATION
// RCP_OTA実行
#define KCS_NOTIFY_RCP_OTA_START 263
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_KCS_NotifyRcpOtaStart() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_NOTIFY_RCP_OTA_START,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_NotifyRcpOtaStart() sys_api_KCS_NotifyRcpOtaStart()
#endif // YIELD_TO_BASIC_INFOROMATION
// RCP_OTA タイマタイムアウトイベント
#define KCS_NOTIFY_RCP_OTA_TIMEOUT 264
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_KCS_NotifyRcpOtaTimeout(uint8 message_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,message_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_KCS,KCS_NOTIFY_RCP_OTA_TIMEOUT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define KCS_NotifyRcpOtaTimeout(message_id) sys_api_KCS_NotifyRcpOtaTimeout(message_id)
#endif // YIELD_TO_BASIC_INFOROMATION
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// デバイス状態コマンド(cmd)
#define KCS_POWER_ON 0
#define KCS_POWER_OFF 1
#define KCS_AUTOFOTA_START 2
#define KCS_AUTOFOTA_END 3
// RecipeOTA 返答値(ex_result)
#define KCS_RCPOTA_RESULT_NO_ERROR 0
#define KCS_RCPOTA_RESULT_ERR_INVALID_URL 1
#define KCS_RCPOTA_RESULT_ERR_CANNOT_START 2
// RecipeOTA Event返答値(resp_code)
#define KCS_RCPOTA_RESP_OK 0
#define KCS_RCPOTA_RESP_ERR 1
#define KCS_RCPOTA_RESP_NO_UPDATE 2
#define KCS_RCPOTA_RESP_SUSPEND 3
#define KCS_RCPOTA_RESP_RESUME 4

#endif

#endif
