///
// @file ledAPI.h
// @brief header file generate from sapp_led.kra
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef _SAPP_LED_KRA_
#define _SAPP_LED_KRA_

#ifdef C_SYNTAX
#define KC_EXPAND_RECIPE
#endif // C_SYNTAX

#ifndef KC_EXPAND_RECIPE

//////////////////////////////////////////////////////////////////
// *** define declaration that is not for recipe users *** //
//////////////////////////////////////////////////////////////////

#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define LED_API_INIT 0
#define LED_Init() \
  EAPI_SendEvent(EAPI_TASKID_LED,LED_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
#define LED_API_DO_BOOTUP 256
#define LED_DoBootup(mode,event_id) \
  EAPI_SendEvent(EAPI_TASKID_LED,LED_API_DO_BOOTUP,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,mode,EAPI_VTYPE_U8,event_id)
#define LED_API_DO_SHUTDOWN 257
#define LED_DoShutdown(event_id) \
  EAPI_SendEvent(EAPI_TASKID_LED,LED_API_DO_SHUTDOWN,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,event_id)
#define LED_API_DO_ERROR 258
#define LED_DoError(sw) \
  EAPI_SendEvent(EAPI_TASKID_LED,LED_API_DO_ERROR,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,sw)
#define LED_API_DO_FWUPDATE 259
#define LED_DoFWupdate(sw) \
  EAPI_SendEvent(EAPI_TASKID_LED,LED_API_DO_FWUPDATE,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,sw)
#define LED_API_DO_LIGHTUP_U 260
#define LED_DoLightup(color,time) \
  EAPI_SendEvent(EAPI_TASKID_LED,LED_API_DO_LIGHTUP_U,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,color,EAPI_VTYPE_U32,time)
#define LED_API_DO_BLINK_U 261
#define LED_DoBlink(color,count,interval) \
  EAPI_SendEvent(EAPI_TASKID_LED,LED_API_DO_BLINK_U,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,color,EAPI_VTYPE_U16,count,EAPI_VTYPE_U32,interval)
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 動作モード(mode)
#define LED_UPMODE_KCSYSTEM 0
#define LED_UPMODE_INSPECTION 1
// 動作指定(sw)
#define LED_START 1
#define LED_STOP 0
// 色指定(color)
#define LED_COLOR_RED 0
#define LED_COLOR_GREEN 1
#define LED_COLOR_ORANGE 2
#define LED_COLOR_STOP 3
// 間隔(interval)
#define LED_INTERVAL_LOW 1000
#define LED_INTERVAL_HIGH 500
// 間隔変換マクロ(秒指定)
#define LED_INTERVAL_LOW_REQ(x) (x*1000/2/LED_INTERVAL_LOW)
#define LED_INTERVAL_HIGH_REQ(x) (x*1000/2/LED_INTERVAL_HIGH)

#else

//////////////////////////////////////////////////////////////////
// *** define declaration for recipe users *** //
//////////////////////////////////////////////////////////////////
#include "taskid.h"
#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define LED_API_INIT 0
func sys_api_LED_Init() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_LED,LED_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define LED_Init() sys_api_LED_Init()
#define LED_API_DO_BOOTUP 256
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_LED_DoBootup(uint8 mode, uint8 event_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,mode);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,event_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_LED,LED_API_DO_BOOTUP,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define LED_DoBootup(mode,event_id) sys_api_LED_DoBootup(mode,event_id)
#endif // YIELD_TO_BASIC_INFOROMATION
#define LED_API_DO_SHUTDOWN 257
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_LED_DoShutdown(uint8 event_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,event_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_LED,LED_API_DO_SHUTDOWN,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define LED_DoShutdown(event_id) sys_api_LED_DoShutdown(event_id)
#endif // YIELD_TO_BASIC_INFOROMATION
#define LED_API_DO_ERROR 258
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_LED_DoError(uint8 sw) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,sw);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_LED,LED_API_DO_ERROR,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define LED_DoError(sw) sys_api_LED_DoError(sw)
#endif // YIELD_TO_BASIC_INFOROMATION
#define LED_API_DO_FWUPDATE 259
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_LED_DoFWupdate(uint8 sw) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,sw);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_LED,LED_API_DO_FWUPDATE,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define LED_DoFWupdate(sw) sys_api_LED_DoFWupdate(sw)
#endif // YIELD_TO_BASIC_INFOROMATION
#define LED_API_DO_LIGHTUP_U 260
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_LED_DoLightup(uint8 color, uint32 time) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,color);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,time);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_LED,LED_API_DO_LIGHTUP_U,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define LED_DoLightup(color,time) sys_api_LED_DoLightup(color,time)
#endif // YIELD_TO_BASIC_INFOROMATION
#define LED_API_DO_BLINK_U 261
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_LED_DoBlink(uint8 color, uint16 count, uint32 interval) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,color);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,count);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,interval);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_LED,LED_API_DO_BLINK_U,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define LED_DoBlink(color,count,interval) sys_api_LED_DoBlink(color,count,interval)
#endif // YIELD_TO_BASIC_INFOROMATION
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 動作モード(mode)
#define LED_UPMODE_KCSYSTEM 0
#define LED_UPMODE_INSPECTION 1
// 動作指定(sw)
#define LED_START 1
#define LED_STOP 0
// 色指定(color)
#define LED_COLOR_RED 0
#define LED_COLOR_GREEN 1
#define LED_COLOR_ORANGE 2
#define LED_COLOR_STOP 3
// 間隔(interval)
#define LED_INTERVAL_LOW 1000
#define LED_INTERVAL_HIGH 500
// 間隔変換マクロ(秒指定)
#define LED_INTERVAL_LOW_REQ(x) (x*1000/2/LED_INTERVAL_LOW)
#define LED_INTERVAL_HIGH_REQ(x) (x*1000/2/LED_INTERVAL_HIGH)

#endif

#endif
