///
// @file olcAPI.h
// @brief header file generate from sapp_oled.kra
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef _SAPP_OLED_KRA_
#define _SAPP_OLED_KRA_

#ifdef C_SYNTAX
#define KC_EXPAND_RECIPE
#endif // C_SYNTAX

#ifndef KC_EXPAND_RECIPE

//////////////////////////////////////////////////////////////////
// *** define declaration that is not for recipe users *** //
//////////////////////////////////////////////////////////////////

#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define OLC_API_INIT 0
#define OLC_Init() \
  EAPI_SendEvent(EAPI_TASKID_OLC,OLC_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// ピクト表示(id=OLC_PICT_*)
#define OLC_API_DISP_PICT 256
#define OLC_DisplayPict(id) \
  EAPI_SendEvent(EAPI_TASKID_OLC,OLC_API_DISP_PICT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,id)
// 文字表示(id=OLC_CHAR_*)
#define OLC_API_DISP_CHAR 257
#define OLC_DisplayChar(id,line,offset,char) \
  EAPI_SendEvent(EAPI_TASKID_OLC,OLC_API_DISP_CHAR,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,id,EAPI_VTYPE_U8,line,EAPI_VTYPE_U8,offset,EAPI_VTYPE_STR,char)
// パターン表示(id=OLC_FREE_*)
#define OLC_API_DISP_FREE 258
#define OLC_DisplayFree(id,line,data0,data1,data2,data3,size) \
  EAPI_SendEvent(EAPI_TASKID_OLC,OLC_API_DISP_FREE,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,id,EAPI_VTYPE_U8,line,EAPI_VTYPE_U32,data0,EAPI_VTYPE_U32,data1,EAPI_VTYPE_U32,data2,EAPI_VTYPE_U32,data3,EAPI_VTYPE_U8,size)
// パネル表示
#define OLC_API_DISP_PANEL 259
#define OLC_DisplayPanel(id) \
  EAPI_SendEvent(EAPI_TASKID_OLC,OLC_API_DISP_PANEL,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,id)
// 状態変更通知
#define OLC_API_CHANGE_STATUS 260
#define OLC_ChangeStatus(event,task) \
  EAPI_SendEvent(EAPI_TASKID_OLC,OLC_API_CHANGE_STATUS,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,event,EAPI_VTYPE_I8,task)
// エラーコード通知
#define OLC_API_SET_ERROR_CODE 261
#define OLC_SetErrCode(flag,errcd) \
  EAPI_SendEvent(EAPI_TASKID_OLC,OLC_API_SET_ERROR_CODE,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,flag,EAPI_VTYPE_STR,errcd)
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 画面表示指定
#define OLC_PICT_STATE 1
#define OLC_PICT_SET 2
// 文字表示指示
#define OLC_CHAR_FORCE 1
#define OLC_CHAR_USER 2
// 文字表示の列指定
#define OLC_CHAR_LINE1 0
#define OLC_CHAR_LINE2 18
// パターン表示指示
#define OLC_FREE_FORCE 1
#define OLC_FREE_USER 2
// パネル表示
#define OLC_PANEL_CLEAR 0
#define OLC_PANEL_WAKEUP 1
#define OLC_PANEL_HELLO 2
#define OLC_PANEL_GOODBYE 3
#define OLC_PANEL_UPDATING 4
// 通知デバイス種別
#define OLC_DEVICE_MODEM 0
#define OLC_DEVICE_GNSS 1
#define OLC_DEVICE_BLE 2
#define OLC_DEVICE_UVC 3
#define OLC_DEVICE_SERIAL 4
#define OLC_DEVICE_SENSOR 5
// 通知ステータス種別
#define OLC_EVENT_POWER_OFF 0
#define OLC_EVENT_POWER_ON 1
#define OLC_EVENT_SEND_START 2
#define OLC_EVENT_SEND 3
#define OLC_EVENT_SEND_TERM 4
#define OLC_EVENT_RECV 5
// エラーコード
#define OLC_ERRCD_CLEAR 0
#define OLC_ERRCD_SET 1
// 文字表示情報クリア
#define OLC_StartChar(a) OLC_DisplayChar(a,0xff,0xff,"")
#define OLC_StartFree(a) OLC_DisplayFree(a,0xff,0,0,0,0,0)

#else

//////////////////////////////////////////////////////////////////
// *** define declaration for recipe users *** //
//////////////////////////////////////////////////////////////////
#include "taskid.h"
#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define OLC_API_INIT 0
func sys_api_OLC_Init() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLC,OLC_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define OLC_Init() sys_api_OLC_Init()
// ピクト表示(id=OLC_PICT_*)
#define OLC_API_DISP_PICT 256
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLC_DisplayPict(uint8 id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLC,OLC_API_DISP_PICT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define OLC_DisplayPict(id) sys_api_OLC_DisplayPict(id)
#endif // YIELD_TO_BASIC_INFOROMATION
// 文字表示(id=OLC_CHAR_*)
#define OLC_API_DISP_CHAR 257
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLC_DisplayChar(uint8 id, uint8 line, uint8 offset, str char[32]) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,line);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,offset);
  rcplib_TASK_SetArg(EAPI_VTYPE_STR,char);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLC,OLC_API_DISP_CHAR,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define OLC_DisplayChar(id,line,offset,char) sys_api_OLC_DisplayChar(id,line,offset,char)
#endif // YIELD_TO_BASIC_INFOROMATION
// パターン表示(id=OLC_FREE_*)
#define OLC_API_DISP_FREE 258
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLC_DisplayFree(uint8 id, uint8 line, uint32 data0, uint32 data1, uint32 data2, uint32 data3, uint8 size) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,line);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,data0);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,data1);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,data2);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,data3);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,size);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLC,OLC_API_DISP_FREE,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define OLC_DisplayFree(id,line,data0,data1,data2,data3,size) sys_api_OLC_DisplayFree(id,line,data0,data1,data2,data3,size)
#endif // YIELD_TO_BASIC_INFOROMATION
// パネル表示
#define OLC_API_DISP_PANEL 259
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLC_DisplayPanel(uint8 id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLC,OLC_API_DISP_PANEL,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define OLC_DisplayPanel(id) sys_api_OLC_DisplayPanel(id)
#endif // YIELD_TO_BASIC_INFOROMATION
// 状態変更通知
#define OLC_API_CHANGE_STATUS 260
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLC_ChangeStatus(uint8 event, int8 task) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,event);
  rcplib_TASK_SetArg(EAPI_VTYPE_I8,task);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLC,OLC_API_CHANGE_STATUS,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define OLC_ChangeStatus(event,task) sys_api_OLC_ChangeStatus(event,task)
#endif // YIELD_TO_BASIC_INFOROMATION
// エラーコード通知
#define OLC_API_SET_ERROR_CODE 261
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLC_SetErrCode(uint8 flag, str errcd[32]) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,flag);
  rcplib_TASK_SetArg(EAPI_VTYPE_STR,errcd);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLC,OLC_API_SET_ERROR_CODE,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define OLC_SetErrCode(flag,errcd) sys_api_OLC_SetErrCode(flag,errcd)
#endif // YIELD_TO_BASIC_INFOROMATION
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 画面表示指定
#define OLC_PICT_STATE 1
#define OLC_PICT_SET 2
// 文字表示指示
#define OLC_CHAR_FORCE 1
#define OLC_CHAR_USER 2
// 文字表示の列指定
#define OLC_CHAR_LINE1 0
#define OLC_CHAR_LINE2 18
// パターン表示指示
#define OLC_FREE_FORCE 1
#define OLC_FREE_USER 2
// パネル表示
#define OLC_PANEL_CLEAR 0
#define OLC_PANEL_WAKEUP 1
#define OLC_PANEL_HELLO 2
#define OLC_PANEL_GOODBYE 3
#define OLC_PANEL_UPDATING 4
// 通知デバイス種別
#define OLC_DEVICE_MODEM 0
#define OLC_DEVICE_GNSS 1
#define OLC_DEVICE_BLE 2
#define OLC_DEVICE_UVC 3
#define OLC_DEVICE_SERIAL 4
#define OLC_DEVICE_SENSOR 5
// 通知ステータス種別
#define OLC_EVENT_POWER_OFF 0
#define OLC_EVENT_POWER_ON 1
#define OLC_EVENT_SEND_START 2
#define OLC_EVENT_SEND 3
#define OLC_EVENT_SEND_TERM 4
#define OLC_EVENT_RECV 5
// エラーコード
#define OLC_ERRCD_CLEAR 0
#define OLC_ERRCD_SET 1
// 文字表示情報クリア
#define OLC_StartChar(a) OLC_DisplayChar(a,0xff,0xff,"")
#define OLC_StartFree(a) OLC_DisplayFree(a,0xff,0,0,0,0,0)

#endif

#endif
