///
// @file oledAPI.h
// @brief header file generate from sdev_oled.kra
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef _SDEV_OLED_KRA_
#define _SDEV_OLED_KRA_

#ifdef C_SYNTAX
#define KC_EXPAND_RECIPE
#endif // C_SYNTAX

#ifndef KC_EXPAND_RECIPE

//////////////////////////////////////////////////////////////////
// *** define declaration that is not for recipe users *** //
//////////////////////////////////////////////////////////////////

#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define OLED_API_INIT 0
#define OLED_Init() \
  EAPI_SendEvent(EAPI_TASKID_OLED,OLED_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// 電源ON/OFF
#define OLED_API_POWER 256
#define OLED_Power(sw) \
  EAPI_SendEvent(EAPI_TASKID_OLED,OLED_API_POWER,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,sw)
// 状態表示
#define OLED_API_DISPLAY_STATE 257
#define OLED_DisplayState(_sync,_timeout,radio,battery,gnss,ble,uvc,serial,time) \
  EAPI_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_STATE,_sync,_timeout,EAPI_VTYPE_U8,radio,EAPI_VTYPE_U8,battery,EAPI_VTYPE_U8,gnss,EAPI_VTYPE_U8,ble,EAPI_VTYPE_U8,uvc,EAPI_VTYPE_U8,serial,EAPI_VTYPE_U64,time)
// 設定確認表示
#define OLED_API_DISPLAY_SET 258
#define OLED_DisplaySet(_sync,_timeout,gnss,ble_r,uvc,serial_r,serial_s,ble_s,sensor,modem,errcd) \
  EAPI_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_SET,_sync,_timeout,EAPI_VTYPE_U8,gnss,EAPI_VTYPE_U8,ble_r,EAPI_VTYPE_U8,uvc,EAPI_VTYPE_U8,serial_r,EAPI_VTYPE_U8,serial_s,EAPI_VTYPE_U8,ble_s,EAPI_VTYPE_U8,sensor,EAPI_VTYPE_U8,modem,EAPI_VTYPE_STR,errcd)
// 文字表示
#define OLED_API_DISPLAY_CHAR 259
#define OLED_DisplayChar(line,offset,data) \
  EAPI_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_CHAR,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,line,EAPI_VTYPE_U8,offset,EAPI_VTYPE_STR,data)
// 任意パターン表示
#define OLED_API_DISPLAY_FREE 260
#define OLED_DisplayFree(line,offset,data0,data1,data2,data3,size) \
  EAPI_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_FREE,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,line,EAPI_VTYPE_U8,offset,EAPI_VTYPE_U32,data0,EAPI_VTYPE_U32,data1,EAPI_VTYPE_U32,data2,EAPI_VTYPE_U32,data3,EAPI_VTYPE_U8,size)
// 全画面表示
#define OLED_API_DISPLAY_WHITE_BLACK 261
#define OLED_DisplayWhiteBlack(pattern) \
  EAPI_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_WHITE_BLACK,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,pattern)
// 24h/AMPM表記変更
#define OLED_API_DISPLAY_TIME_NOTATION_CHANGE 262
#define OLED_DisplayTimeNotationChange(ampm_flg) \
  EAPI_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_TIME_NOTATION_CHANGE,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,ampm_flg)
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 割り込み通知
#define UNSYNC_EVENT_UPDATING_DISP_TIMER 1
// sw値
#define OLED_POWER_ON 1
#define OLED_POWER_OFF 0
// White Black値
#define OLED_DISP_ALL_WHITE 0
#define OLED_DISP_ALL_BLACK 1
#define OLED_DISP_FRAME 2
#define OLED_DISP_KYOCERA 3
#define OLED_DISP_HELLO 4
#define OLED_DISP_GOODBYE 5
#define OLED_DISP_UPDATING 0x10
#define OLED_DISP_UPDATING_C1 0x11
#define OLED_DISP_UPDATING_C2 0x12
#define OLED_DISP_UPDATING_C3 0x13
#define OLED_DISP_UPDATING_C4 0x14
// 時刻表記
#define OLED_DISP_TIME_NOTATION_24H 0
#define OLED_DISP_TIME_NOTATION_AMPM 1
// OLED APIエラー
#define OLED_ERR_UNKNOWN 1
#define OLED_ERR_OUT_OF_RANGE 2
#define OLED_ERR_OVERFLOW 3

#else

//////////////////////////////////////////////////////////////////
// *** define declaration for recipe users *** //
//////////////////////////////////////////////////////////////////
#include "taskid.h"
#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define OLED_API_INIT 0
func sys_api_OLED_Init() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLED,OLED_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define OLED_Init() sys_api_OLED_Init()
// 電源ON/OFF
#define OLED_API_POWER 256
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLED_Power(uint8 sw) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,sw);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLED,OLED_API_POWER,EAPI_SYNC_RESULT,1000));
}
#define OLED_Power(sw) sys_api_OLED_Power(sw)
#endif // YIELD_TO_BASIC_INFOROMATION
// 状態表示
#define OLED_API_DISPLAY_STATE 257
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLED_DisplayState(uint8 sync,int32 timeout,uint8 radio, uint8 battery, uint8 gnss, uint8 ble, uint8 uvc, uint8 serial, uint64 time) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,radio);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,battery);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,gnss);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,ble);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,uvc);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,serial);
  rcplib_TASK_SetArg(EAPI_VTYPE_U64,time);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_STATE,sync,timeout));
}
#define OLED_DisplayState(_sync,_timeout,radio,battery,gnss,ble,uvc,serial,time) sys_api_OLED_DisplayState(_sync,_timeout,radio,battery,gnss,ble,uvc,serial,time)
#endif // YIELD_TO_BASIC_INFOROMATION
// 設定確認表示
#define OLED_API_DISPLAY_SET 258
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLED_DisplaySet(uint8 sync,int32 timeout,uint8 gnss, uint8 ble_r, uint8 uvc, uint8 serial_r, uint8 serial_s, uint8 ble_s, uint8 sensor, uint8 modem, str errcd[32]) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,gnss);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,ble_r);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,uvc);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,serial_r);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,serial_s);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,ble_s);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,sensor);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,modem);
  rcplib_TASK_SetArg(EAPI_VTYPE_STR,errcd);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_SET,sync,timeout));
}
#define OLED_DisplaySet(_sync,_timeout,gnss,ble_r,uvc,serial_r,serial_s,ble_s,sensor,modem,errcd) sys_api_OLED_DisplaySet(_sync,_timeout,gnss,ble_r,uvc,serial_r,serial_s,ble_s,sensor,modem,errcd)
#endif // YIELD_TO_BASIC_INFOROMATION
// 文字表示
#define OLED_API_DISPLAY_CHAR 259
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLED_DisplayChar(uint8 line, uint8 offset, str data[32]) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,line);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,offset);
  rcplib_TASK_SetArg(EAPI_VTYPE_STR,data);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_CHAR,EAPI_SYNC_RESULT,1000));
}
#define OLED_DisplayChar(line,offset,data) sys_api_OLED_DisplayChar(line,offset,data)
#endif // YIELD_TO_BASIC_INFOROMATION
// 任意パターン表示
#define OLED_API_DISPLAY_FREE 260
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLED_DisplayFree(uint8 line, uint8 offset, uint32 data0, uint32 data1, uint32 data2, uint32 data3, uint8 size) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,line);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,offset);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,data0);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,data1);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,data2);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,data3);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,size);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_FREE,EAPI_SYNC_RESULT,1000));
}
#define OLED_DisplayFree(line,offset,data0,data1,data2,data3,size) sys_api_OLED_DisplayFree(line,offset,data0,data1,data2,data3,size)
#endif // YIELD_TO_BASIC_INFOROMATION
// 全画面表示
#define OLED_API_DISPLAY_WHITE_BLACK 261
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLED_DisplayWhiteBlack(uint8 pattern) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,pattern);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_WHITE_BLACK,EAPI_SYNC_RESULT,1000));
}
#define OLED_DisplayWhiteBlack(pattern) sys_api_OLED_DisplayWhiteBlack(pattern)
#endif // YIELD_TO_BASIC_INFOROMATION
// 24h/AMPM表記変更
#define OLED_API_DISPLAY_TIME_NOTATION_CHANGE 262
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_OLED_DisplayTimeNotationChange(uint8 ampm_flg) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,ampm_flg);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_OLED,OLED_API_DISPLAY_TIME_NOTATION_CHANGE,EAPI_SYNC_RESULT,1000));
}
#define OLED_DisplayTimeNotationChange(ampm_flg) sys_api_OLED_DisplayTimeNotationChange(ampm_flg)
#endif // YIELD_TO_BASIC_INFOROMATION
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 割り込み通知
#define UNSYNC_EVENT_UPDATING_DISP_TIMER 1
// sw値
#define OLED_POWER_ON 1
#define OLED_POWER_OFF 0
// White Black値
#define OLED_DISP_ALL_WHITE 0
#define OLED_DISP_ALL_BLACK 1
#define OLED_DISP_FRAME 2
#define OLED_DISP_KYOCERA 3
#define OLED_DISP_HELLO 4
#define OLED_DISP_GOODBYE 5
#define OLED_DISP_UPDATING 0x10
#define OLED_DISP_UPDATING_C1 0x11
#define OLED_DISP_UPDATING_C2 0x12
#define OLED_DISP_UPDATING_C3 0x13
#define OLED_DISP_UPDATING_C4 0x14
// 時刻表記
#define OLED_DISP_TIME_NOTATION_24H 0
#define OLED_DISP_TIME_NOTATION_AMPM 1
// OLED APIエラー
#define OLED_ERR_UNKNOWN 1
#define OLED_ERR_OUT_OF_RANGE 2
#define OLED_ERR_OVERFLOW 3

#endif

#endif
