///
// @file msa_base.h
// @brief header file for modem sub application
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef __MSA_BASE_H__
#define __MSA_BASE_H__

#ifdef C_SYNTAX
#include "basicInformation.h"
#endif // C_SYNTAX
#include "eventLib.h"
#include "logAPI.h"
#include "flashLib.h"
#include "bufferLib.h"
#include "cmd_str.h"
#include "modemMgrTask.h"
#include "msa_param.h"
#include "sappModemAPI.h"
#include "msa_send_id_01_func.h"
#include "msa_send_id_02_func.h"
#include "msa_send_id_03_func.h"
#include "msa_send_id_04_func.h"
#include "msa_send_id_05_func.h"
#include "msa_send_id_06_func.h"
#include "msa_send_id_07_func.h"
#include "msa_send_id_08_func.h"

//////////////////////////////////////////////////////////////////
// main function //
//////////////////////////////////////////////////////////////////
func sappModem_init(uint8 send_id, uint8 rcv_event_id) {
    uint8 ret;
    ret = EAPI_NO_ERROR;
    
    // <sapp_modem非利用時のビルドWarning回避処理(実質無意味な処理)>
    l_retain = l_retain;
    l_session = l_session;

    // <通知先イベントIDの記憶>
    l_rcv_event_id = rcv_event_id;

    // <送信ID毎の設定値更新>
    sappModem_setOwnPatameter(send_id);

    // <送信ID毎の設定処理実行>
    if (send_id == 1) {
        ret = sappModem_01_init();
    } else if (send_id == 2) {
        ret = sappModem_02_init();
    } else if (send_id == 3) {
        ret = sappModem_03_init();
    } else if (send_id == 4) {
        ret = sappModem_04_init();
    } else if (send_id == 5) {
        ret = sappModem_05_init();
    } else if (send_id == 6) {
        ret = sappModem_06_init();
    } else if (send_id == 7) {
        ret = sappModem_07_init();
    } else if (send_id == 8) {
        ret = sappModem_08_init();
    } else {
        ret = MSA_SID_API_ERR_OUT_OF_RANGE;
    }

    return(ret);
}
func sappModem_send_data(uint8 next_conn_send_id, uint8 curr_conn_send_id, uint8 keep_conn_send_id) {

    uint16 send_success_num;
    uint8 new_curr_conn_send_id;
    send_success_num = 0;

    // ＜必要に応じて現在の接続のSocket切断＞
    new_curr_conn_send_id = sappModem_disconnect_session_if_need(next_conn_send_id, curr_conn_send_id);

    // <送信ID毎の設定値更新>
    sappModem_setOwnPatameter(next_conn_send_id);
    
    // 予め指定したプロトコルの送信処理を実行
    send_success_num = sappModem_send_data_protocol(next_conn_send_id, new_curr_conn_send_id, keep_conn_send_id);
    
    return(send_success_num);
}
func sappModem_send_camera_image(uint8 next_conn_send_id, uint16 mov_target, uint8 curr_conn_send_id, uint8 keep_conn_send_id) {

    uint16 send_success_num;
    uint8 new_curr_conn_send_id;
    send_success_num = 0;

    // ＜必要に応じて現在の接続のSocket切断＞
    new_curr_conn_send_id = sappModem_disconnect_session_if_need(next_conn_send_id, curr_conn_send_id);

    // <送信ID毎の設定値更新>
    sappModem_setOwnPatameter(next_conn_send_id);

    // 送信対象とする動画バッファをセット
    l_databuf_id = MMG_MOVIE_BUF_ID;
    l_mov_target = mov_target;
    
    // 予め指定したプロトコルの送信処理を実行
    send_success_num = sappModem_send_data_protocol(next_conn_send_id, new_curr_conn_send_id, keep_conn_send_id);

    return(send_success_num);
}
func sappModem_re_connect(uint8 send_id) {

    uint16 re_connect_res;
    re_connect_res = 0;

    // <送信ID毎の設定値更新>
    sappModem_setOwnPatameter(send_id);
    
    // 予め指定したプロトコルの再接続処理を実行
    re_connect_res = sappModem_re_connect_protocol();
    
    return(re_connect_res);
}
//////////////////////////////////////////////////////////////////
// sub function //
//////////////////////////////////////////////////////////////////
// 送信ID毎の設定値更新
func sappModem_setOwnPatameter(uint8 send_id) {
    if (send_id == 1) {
        sappModem_01_setMyParameter();
    } else if (send_id == 2) {
        sappModem_02_setMyParameter();
    } else if (send_id == 3) {
        sappModem_03_setMyParameter();
    } else if (send_id == 4) {
        sappModem_04_setMyParameter();
    } else if (send_id == 5) {
        sappModem_05_setMyParameter();
    } else if (send_id == 6) {
        sappModem_06_setMyParameter();
    } else if (send_id == 7) {
        sappModem_07_setMyParameter();
    } else if (send_id == 8) {
        sappModem_08_setMyParameter();
    }
    return(0);
}
#ifdef MODEM_SETTING_USE_SOCKET
// ソケット通信全般の初期化処理
func sappModem_socket_init(uint8 exe_set_param, uint8 exe_set_recv) {
    // ソケット通信全般の初期化処理
    sappModem_socket_setting(exe_set_param, exe_set_recv);
    return(0);
}
#endif // MODEM_SETTING_USE_SOCKET

#ifdef MODEM_SETTING_USE_HTTP
// HTTP通信全般の初期化処理
func sappModem_http_init(uint8 exe_set_param, uint8 exe_set_recv, uint8 exe_set_http_param) {
    uint8 ex_result;

    // ソケット通信全般の初期化処理
    sappModem_socket_setting(exe_set_param, exe_set_recv);
    // HTTPパラメータ設定実行
    if (exe_set_http_param == EXE_SET_HTTP_PARAM) {
        if(MMG_SetConnectParamHTTP(l_timeout, l_sync, ex_result, l_send_id, l_http_url_str, l_http_header_str, l_http_method) != 0) {
            rcplib_FORMAT_String(l_str_log_out, "MMG_SetConnectParamHTTP Error!! send_id:%d", l_send_id);
            rcplib_LOG_Print(l_str_log_out); // USBログ出力
        }
    }
    return(0);
}
#endif // MODEM_SETTING_USE_HTTP
#ifdef MODEM_SETTING_USE_MQTT
// MQTT通信全般の初期化処理
func sappModem_mqtt_init(uint8 exe_set_param, uint8 exe_set_recv, uint8 exe_set_mqtt_param, uint8 exe_set_mqtt_subscribe) {
    uint8 ex_result;

    // ソケット通信全般の初期化処理
    sappModem_socket_setting(exe_set_param, exe_set_recv);
    // MQTTパラメータ設定実行
    if (exe_set_mqtt_param == EXE_SET_MQTT_PARAM) {
        if(MMG_SetConnectParamMQTT(l_timeout, l_sync, ex_result, l_mq_cid, l_mq_clean, l_mq_keep_alive, l_mq_client_id,
            l_mq_user_name, l_mq_user_pass, l_mq_will_qos, l_mq_will_retain, l_mq_will_topic_name, l_mq_will_payload) != 0) {
            rcplib_FORMAT_String(l_str_log_out, "MMG_SetConnectParamMQTT Error!! send_id:%d", l_send_id);
            rcplib_LOG_Print(l_str_log_out);
        }
    }
    // MQTT Subscribe設定実行
    if (exe_set_mqtt_subscribe == EXE_SET_MQTT_SUBSCRIBE) {
        if(MMG_SetSubscriveParamMQTT(l_timeout, l_sync, ex_result, l_mq_cid, l_mq_sid, l_mq_sub_qos, l_mq_sub_topic_name, l_rcv_databuf_id, l_rcv_event_id) != 0) {
            rcplib_FORMAT_String(l_str_log_out, "MMG_SetSubscriveParamMQTT Error!! send_id:%d", l_send_id);
            rcplib_LOG_Print(l_str_log_out);
        }
    }
    return(0);
}
#endif // MODEM_SETTING_USE_MQTT

// 異なるセッション接続中のセッション切断処理
func sappModem_disconnect_session_if_need(uint8 next_conn_send_id, uint8 curr_conn_send_id) {
    uint8 conn_send_id;
    conn_send_id = curr_conn_send_id;
    if ((curr_conn_send_id != 0) && (curr_conn_send_id != next_conn_send_id)) {
        // 現在別の送信IDで接続中なのでSocket切断実行し、次はSocket接続要求から実行する
        sappModem_setOwnPatameter(curr_conn_send_id);
        sappModem_socket_disconnect();
        rcplib_FORMAT_String(l_str_log_out, "sappModem_disconnect_session_if_need Disconnected. send_id:%d", curr_conn_send_id);
        // 現在接続中の送信ID更新
        conn_send_id = 0;
    }
    return (conn_send_id);
}
// プロトコルごとのデータ送信処理
func sappModem_send_data_protocol(uint8 next_conn_send_id, uint8 curr_conn_send_id, uint8 keep_conn_send_id) {
    uint8 req_connect;
    uint8 req_disconnect;
#ifdef MODEM_SETTING_USE_MQTT
    uint8 req_mqtt_connect;
    uint8 req_mqtt_disconnect;
#endif // MODEM_SETTING_USE_MQTT
    uint16 send_success_num;
    send_success_num = 0;

    // ＜次の接続処理の必要性を判断＞
    if ((curr_conn_send_id != 0) && (curr_conn_send_id != next_conn_send_id)) {
        // 現在同一の送信IDで接続中なので、そのままSocket接続要求せずに実行する
        req_connect = NOT_CONNECT;
#ifdef MODEM_SETTING_USE_MQTT
        req_mqtt_connect = NOT_MQTT_CONNECT;
#endif // MODEM_SETTING_USE_MQTT
    } else {
        // それ以外の場合は通常の接続処理から実行する
        req_connect = EXE_CONNECT;
#ifdef MODEM_SETTING_USE_MQTT
        req_mqtt_connect = EXE_MQTT_CONNECT;
#endif // MODEM_SETTING_USE_MQTT
    }

    // ＜現在の接続のSocket切断と、次の接続処理の必要性を判断＞
    if (next_conn_send_id == keep_conn_send_id) {
        // 接続継続対象の送信IDなので、送信後の切断処理は実行しない
        req_disconnect = NOT_DISCONNECT;
#ifdef MODEM_SETTING_USE_MQTT
        req_mqtt_disconnect = NOT_MQTT_DISCONNECT;
#endif // MODEM_SETTING_USE_MQTT
    } else {
        // 接続継続対象の送信IDではないので、送信後の切断処理を実行する
        req_disconnect = EXE_DISCONNECT;
#ifdef MODEM_SETTING_USE_MQTT
        req_mqtt_disconnect = EXE_MQTT_DISCONNECT;
#endif // MODEM_SETTING_USE_MQTT
    }

    // ＜各プロトコルの送信処理＞
#ifdef MODEM_SETTING_USE_SOCKET
    if (l_protocol == MMG_PROTOCOL_UDP || l_protocol == MMG_PROTOCOL_TCP || l_protocol == MMG_PROTOCOL_TLS) {
        send_success_num = sappModem_socket_send(req_connect, EXE_SEND, req_disconnect);
    }
#endif // MODEM_SETTING_USE_SOCKET

#ifdef MODEM_SETTING_USE_HTTP
    // HTTP通知用変数クリア
    l_http_send_success_num = 0;
    l_http_resp_code = 0;
    l_http_recv_buf_id = 0;

    if (l_protocol == MMG_PROTOCOL_HTTP || l_protocol == MMG_PROTOCOL_HTTPS || 
            l_protocol == MMG_PROTOCOL_S3_STORAGE_HTTPS || l_protocol == MMG_PROTOCOL_AZURE_STORAGE_REST_HTTPS || 
            l_protocol == MMG_PROTOCOL_AZURE_IOT_SASTOKEN_HTTPS || l_protocol == MMG_PROTOCOL_GCP_IOT_ES256_HTTPS) {
        send_success_num = sappModem_http_send(req_connect, EXE_SEND, req_disconnect);
    }
#endif // MODEM_SETTING_USE_HTTP

#ifdef MODEM_SETTING_USE_MQTT
    if (l_protocol == MMG_PROTOCOL_MQTT || l_protocol == MMG_PROTOCOL_MQTTS || 
            l_protocol == MMG_PROTOCOL_AZURE_IOT_SASTOKEN_MQTTS || l_protocol == MMG_PROTOCOL_GCP_IOT_ES256_MQTTS) {
        send_success_num = sappModem_mqtt_send(req_connect, req_mqtt_connect, EXE_SEND, req_mqtt_disconnect, req_disconnect);
    }
#endif // MODEM_SETTING_USE_MQTT
    return(send_success_num);
}

// プロトコルごとの再接続処理
func sappModem_re_connect_protocol() {

    uint16 re_connect_res;
    re_connect_res = 0;
    
    // ＜各プロトコルの送信処理＞
#ifdef MODEM_SETTING_USE_SOCKET
    if (l_protocol == MMG_PROTOCOL_UDP || l_protocol == MMG_PROTOCOL_TCP || l_protocol == MMG_PROTOCOL_TLS) {
        re_connect_res = sappModem_socket_send(EXE_CONNECT, NOT_SEND, NOT_DISCONNECT);
    }
#endif // MODEM_SETTING_USE_SOCKET

#ifdef MODEM_SETTING_USE_HTTP
    if (l_protocol == MMG_PROTOCOL_HTTP || l_protocol == MMG_PROTOCOL_HTTPS || 
            l_protocol == MMG_PROTOCOL_S3_STORAGE_HTTPS || l_protocol == MMG_PROTOCOL_AZURE_STORAGE_REST_HTTPS || 
            l_protocol == MMG_PROTOCOL_AZURE_IOT_SASTOKEN_HTTPS || l_protocol == MMG_PROTOCOL_GCP_IOT_ES256_HTTPS) {
        re_connect_res = sappModem_http_send(EXE_CONNECT, NOT_SEND, NOT_DISCONNECT);
    }
#endif // MODEM_SETTING_USE_HTTP

#ifdef MODEM_SETTING_USE_MQTT
    if (l_protocol == MMG_PROTOCOL_MQTT || l_protocol == MMG_PROTOCOL_MQTTS || 
            l_protocol == MMG_PROTOCOL_AZURE_IOT_SASTOKEN_MQTTS || l_protocol == MMG_PROTOCOL_GCP_IOT_ES256_MQTTS) {
        re_connect_res = sappModem_mqtt_send(EXE_CONNECT, EXE_MQTT_CONNECT, NOT_SEND, NOT_MQTT_DISCONNECT, NOT_DISCONNECT);
    }
#endif // MODEM_SETTING_USE_MQTT
    return(re_connect_res);
}

#ifdef MODEM_SETTING_USE_SOCKET
// ソケット送信
func sappModem_socket_send(uint8 exe_connect, uint8 exe_send, uint8 exe_disconnect) {
    int32 ret;
    uint8 ex_result;
    uint16 send_success_num;
    ret = 0;
    send_success_num = 0;
    if (exe_connect == EXE_CONNECT) {
        // Socket接続実行
        ret = sappModem_socket_connect();
    }
    // エラー未発生の場合のみ送信処理を実行する
    if (ret == 0) {
        if (exe_send == EXE_SEND) {
            // burstサイズを調整してから送信処理実行
            rcpfunc_lte_burst_send_num_round(l_databuf_id);
            ret = MMG_SendSOCKET(l_timeout, l_sync, ex_result, l_send_id, l_databuf_id, l_mov_target, l_burst, l_session, l_retain, send_success_num);
            if(ret != 0) {
                // ソケット送信失敗時のログ出力
                rcplib_FORMAT_String(l_str_log_out, "MMG_SendSOCKET Error!! ex_res:%d", ex_result);
                rcplib_LOG_Print(l_str_log_out);
                
                if (ex_result > MMG_WARN_END) {
                    // ソケット送信失敗時は、ソケット切断処理を実行(Warningに対しては実行しない)
                    ret = MMG_ConnectSOCKET(l_timeout, l_sync, ex_result, l_send_id, MMG_SOCKET_CLOSE);
                    rcplib_LOG_Print("Socket Close");
                }
            }
        } else if (exe_disconnect == NOT_DISCONNECT) {
            // ソケット再接続命令の場合は、return値は再接続成功の意味で返す
            send_success_num = 1;
        }
    }
    if (exe_disconnect == EXE_DISCONNECT) {
        // Socket切断実行
        sappModem_socket_disconnect();
    }
    return(send_success_num);
}
#endif // MODEM_SETTING_USE_SOCKET

#ifdef MODEM_SETTING_USE_HTTP
// HTTP送信
func sappModem_http_send(uint8 exe_connect, uint8 exe_send, uint8 exe_disconnect) {
    int32 ret;
    str str_log_tmp[LOGAPI_OUT_MAX];
    uint8 ex_result;
    uint16 v_rspcode; uint8 v_buff_id; uint16 v_send_num;
    ret = 0;
    v_send_num = 0;
    if (exe_connect == EXE_CONNECT) {
        // Socket接続実行
        ret = sappModem_socket_connect();
    }
    // エラー未発生の場合のみ送信処理を実行する
    if (ret == 0) {
        if (exe_send == EXE_SEND) {
            // burstサイズを調整してから送信処理実行
            rcpfunc_lte_burst_send_num_round(l_databuf_id);
            ret = MMG_SendHTTP(l_timeout, l_sync, ex_result, l_send_id, l_databuf_id, l_mov_target, l_burst, l_session, l_retain, v_rspcode, v_buff_id, v_send_num);
            if(ret != 0) {
                rcplib_FORMAT_String(l_str_log_out, "MMG_SendHTTP SEND Error!! send_id:%d", l_send_id);
                rcplib_FORMAT_String(str_log_tmp, " ex_res:%d", ex_result);
                rcplib_STR_Cat(l_str_log_out, str_log_tmp);
                rcplib_LOG_Print(l_str_log_out); // USBログ出力
                if (ex_result > MMG_WARN_END) {
                    // 送信失敗の場合はSocket切断実行
                    ret = MMG_ConnectSOCKET(l_timeout, l_sync, ex_result, l_send_id, MMG_SOCKET_CLOSE);
                    rcplib_LOG_Print("Socket Close");
                }
            } else {
                rcplib_FORMAT_String(l_str_log_out, "MMG_SendHTTP success. send_id:%d", l_send_id);
                rcplib_FORMAT_String(str_log_tmp, " rspcode:%d", v_rspcode);
                rcplib_STR_Cat(l_str_log_out, str_log_tmp);
                rcplib_LOG_Print(l_str_log_out); // USBログ出力
                rcplib_FORMAT_String(l_str_log_out, "buff_id:%d", v_buff_id);
                rcplib_FORMAT_String(str_log_tmp, " send_success_num:%d", v_send_num);
                rcplib_STR_Cat(l_str_log_out, str_log_tmp);
                rcplib_LOG_Print(l_str_log_out); // USBログ出力
            }
            if (v_send_num > 0) {
                // HTTP通知用変数を更新
                l_http_send_success_num = v_send_num;
                l_http_resp_code = v_rspcode;
                l_http_recv_buf_id = v_buff_id;
            }
        } else if (exe_disconnect == NOT_DISCONNECT) {
            // ソケット再接続命令の場合は、return値は再接続成功の意味で返す
            v_send_num = 1;
        }
    }
    if (exe_disconnect == EXE_DISCONNECT) {
        // Socket切断実行
        sappModem_socket_disconnect();
    }

    return(v_send_num);
}
#endif // MODEM_SETTING_USE_HTTP

#ifdef MODEM_SETTING_USE_MQTT
// MQTT送信
func sappModem_mqtt_send(uint8 exe_connect, uint8 exe_mq_connect, uint8 exe_send, uint8 exe_mq_disconnect, uint8 exe_disconnect) {
    uint32 ret;
    str str_log_tmp[LOGAPI_OUT_MAX];
    uint8 ex_result;
    uint16 v_send_num;
    ret = 0;
    v_send_num = 0;
    if (exe_connect == EXE_CONNECT) {
        // Socket接続実行
        ret = sappModem_socket_connect();
    }
    // エラー未発生の場合のみMQTT処理を実行する
    if (ret == 0) {
        if (exe_mq_connect == EXE_MQTT_CONNECT) {
            ret = MMG_ConnectMQTT(l_timeout, l_sync, ex_result, l_send_id, l_mq_cid, MMG_MQTT_OPEN);
            if(ret != 0) {
                rcplib_FORMAT_String(l_str_log_out, "MMG_ConnectMQTT OPEN Error!! send_id:%d", l_send_id);
                rcplib_FORMAT_String(str_log_tmp, " ex_res:%d", ex_result);
                rcplib_STR_Cat(l_str_log_out, str_log_tmp);
                rcplib_LOG_Print(l_str_log_out); // USBログ出力
                if (ex_result > MMG_WARN_END) {
                    // 送信失敗の場合はSocket切断実行
                    MMG_ConnectSOCKET(l_timeout, l_sync, ex_result, l_send_id, MMG_SOCKET_CLOSE);
                    rcplib_LOG_Print("Socket Close");
                }
            }
        }
        // エラー未発生の場合のみMQTT送信処理を実行する
        if (ret == 0) {
            if (exe_send == EXE_SEND) {
                // burstサイズを調整してから送信処理実行
                rcpfunc_lte_burst_send_num_round(l_databuf_id);
                ret = MMG_SendMQTT(l_timeout, l_sync, ex_result, l_send_id, l_mq_cid, l_mq_pub_qos, l_mq_pub_retain, l_mq_pub_topic_name,
                                l_databuf_id, l_mov_target, l_burst, l_session, l_retain, v_send_num);
                if(ret != 0) {
                    rcplib_FORMAT_String(l_str_log_out, "MMG_SendMQTT Error!! send_id:%d", l_send_id);
                    rcplib_FORMAT_String(str_log_tmp, " ex_res:%d", ex_result);
                    rcplib_STR_Cat(l_str_log_out, str_log_tmp);
                    rcplib_LOG_Print(l_str_log_out); // USBログ出力
                    if (ex_result > MMG_WARN_END) {
                        // 送信失敗の場合はSocket切断実行
                        ret = MMG_ConnectSOCKET(l_timeout, l_sync, ex_result, l_send_id, MMG_SOCKET_CLOSE);
                        rcplib_LOG_Print("Socket Close");
                    }
                }
            } else if (exe_mq_disconnect == NOT_MQTT_DISCONNECT && exe_disconnect == NOT_DISCONNECT) {
                // ソケット&MQTT再接続命令の場合は、return値は再接続成功の意味で返す
                v_send_num = 1;
            }
            if (exe_mq_disconnect == EXE_MQTT_DISCONNECT) {
                ret = MMG_ConnectMQTT(l_timeout, l_sync, ex_result, l_send_id, l_mq_cid, MMG_MQTT_CLOSE);
                if(ret != 0) {
                    rcplib_FORMAT_String(l_str_log_out, "MMG_ConnectMQTT CLOSE Error!! send_id:%d", l_send_id);
                    rcplib_FORMAT_String(str_log_tmp, " ex_res:%d", ex_result);
                    rcplib_STR_Cat(l_str_log_out, str_log_tmp);
                    rcplib_LOG_Print(l_str_log_out); // USBログ出力
                }
            }
        }
    }
    if (exe_disconnect == EXE_DISCONNECT) {
        // Socket切断実行
        sappModem_socket_disconnect();
    }
    return(v_send_num);
}
#endif // MODEM_SETTING_USE_MQTT

// ソケット接続設定
func sappModem_socket_setting(uint8 exe_set_param, uint8 exe_set_recv) {
    uint8 ex_result;
    
    // 基本設定実行
    if (exe_set_param == EXE_SET_PARAM) {
        if(MMG_SetConnectParam(l_timeout, l_sync, ex_result, l_send_id, l_hostname, l_port, l_protocol, l_sni, l_auth_mode, l_auth_index, l_use_usb) != 0) {
            rcplib_FORMAT_String(l_str_log_out, "MMG_SetConnectParam Error!! send_id:%d", l_send_id);
            rcplib_LOG_Print(l_str_log_out);
        }
    }
    // データ受信設定実行
    if (exe_set_recv == EXE_SET_RECV) {
        if(MMG_SetReceiveParam(l_timeout, l_sync, ex_result, l_send_id, l_rcv_databuf_id, l_rcv_event_id) != 0) {
            rcplib_FORMAT_String(l_str_log_out, "MMG_SetReceiveParam Error!! send_id:%d", l_send_id);
            rcplib_LOG_Print(l_str_log_out);
        }
    }
    return(0);
}
// ソケット接続
func sappModem_socket_connect() {
    int32 ret;
    uint8 ex_result;
    ret = MMG_ConnectSOCKET(l_timeout, l_sync, ex_result, l_send_id, MMG_SOCKET_OPEN);
    if(ret != 0) {
        // ソケット接続失敗時のログ出力
        rcplib_FORMAT_String(l_str_log_out, "MMG_ConnectSOCKET OPEN Error!! ex_res:%d", ex_result);
        rcplib_LOG_Print(l_str_log_out);
        if (ex_result > MMG_WARN_END) {
            // ソケット接続失敗時は、ソケット切断処理を実行(既にソケット接続中などのWarningに対しては実行しない)
            ret = MMG_ConnectSOCKET(l_timeout, l_sync, ex_result, l_send_id, MMG_SOCKET_CLOSE);
            rcplib_LOG_Print("Socket Close");
            ret = MMG_ConnectSOCKET(l_timeout, l_sync, ex_result, l_send_id, MMG_SOCKET_OPEN);
            rcplib_LOG_Print("Socket Re-Open");
            if(ret != 0) {
                MMG_ConnectSOCKET(l_timeout, l_sync, ex_result, l_send_id, MMG_SOCKET_CLOSE);
                rcplib_LOG_Print("Socket Re-Close");
            }
        }
    }
    return(ret);
}
// ソケット切断
func sappModem_socket_disconnect() {
    int32 ret;
    uint8 ex_result;
    ret = MMG_ConnectSOCKET(l_timeout, l_sync, ex_result, l_send_id, MMG_SOCKET_CLOSE);
    if (ret != 0) {
        // ソケット切断失敗時のログ出力
        rcplib_FORMAT_String(l_str_log_out, "MMG_ConnectSOCKET CLOSE Error!!  ex_res:%d", ex_result);
        rcplib_LOG_Print(l_str_log_out);
    }
    return(0);
}
// burst送信数の調整処理
func rcpfunc_lte_burst_send_num_round(uint8 send_buf_id) {
    uint16 valid_data_num;
    if (send_buf_id != MMG_MOVIE_BUF_ID) {
        valid_data_num = rcplib_FIFOBUF_GetEntryNumber(send_buf_id);
        if (valid_data_num < l_burst) {
            l_burst = valid_data_num;
        }
    }
    return(0);
}
#ifdef MODEM_SETTING_USE_AUTH
// 認証情報関連のデータの変換
func rcpfunc_auth_convert(str add_auth_content[TLS_AUTH_INFO_MAX]) {
    rcplib_FORMAT_Binary(l_bin_auth_info, l_auth_info_ofs, EAPI_VTYPE_STR, rcplib_STR_Len(add_auth_content), add_auth_content);
    l_bin_auth_info[l_auth_info_ofs + rcplib_STR_Len(add_auth_content)]  = 13;
    l_bin_auth_info[l_auth_info_ofs + rcplib_STR_Len(add_auth_content) + 1]  = 10;
    l_auth_info_ofs = l_auth_info_ofs + rcplib_STR_Len(add_auth_content);
    l_auth_info_ofs = l_auth_info_ofs + 2;

    return(0);
}
// 認証情報関連の初期化
func rcpfunc_auth_init() {
    uint16 bin_count;
    l_auth_info_ofs = 0;
    bin_count = 0;
    while(bin_count < TLS_AUTH_INFO_MAX) {
        l_bin_auth_info[bin_count] = 0;
        bin_count = bin_count + 1;
    }

    return(0);
}
#endif // MODEM_SETTING_USE_AUTH
#ifdef MODEM_SETTING_USE_HTTP
// HTTP header関連初期化
func rcpfunc_http_header_init() {
    uint16 bin_count;
    l_http_header_ofs = 0;
    // rcplib_STR_SetString(l_str_http_header, "");
    bin_count = 0;
    while(bin_count < MMG_HEADER_MAX) {
        l_bin_http_header[bin_count] = 0;
        bin_count = bin_count + 1;
    }

    return(0);
}
// HTTP headerデータの変換
func rcpfunc_http_header_convert(str add_header_content[MMG_HEADER_MAX]) {
    rcplib_FORMAT_Binary(l_bin_http_header, l_http_header_ofs, EAPI_VTYPE_STR, rcplib_STR_Len(add_header_content), add_header_content);
    l_bin_http_header[l_http_header_ofs + rcplib_STR_Len(add_header_content)]  = 13;
    l_bin_http_header[l_http_header_ofs + rcplib_STR_Len(add_header_content) + 1]  = 10;
    l_http_header_ofs = l_http_header_ofs + rcplib_STR_Len(add_header_content);
    l_http_header_ofs = l_http_header_ofs + 2;

    return(0);
}
#endif // MODEM_SETTING_USE_HTTP

#ifdef MODEM_SETTING_USE_OTHER_AUTH
// クラウド認証用の不揮発アイテムの更新が必要であれば書き込み実行する関数(strデータ用)
func update_cloud_nv_str(uint8 send_id, uint32 data_nv_id, uint32 size_nv_id, str expected_str[OTHER_AUTH_INFO_MAX]) {
    uint16 nv_size; // 読み出した認証情報のサイズを格納する変数
    uint8 nv_value[OTHER_AUTH_INFO_MAX]; // 不揮発アイテム読み出し&書き込み用変数
    str str_nv_value[OTHER_AUTH_INFO_MAX]; // 不揮発アイテム読み出し用文字列変数
    uint8 nv_need_to_write; // NV書き込みフラグ

    nv_need_to_write = 0; // 書き込みフラグクリア
    // クラウド認証用の不揮発アイテムのデータサイズを読み出す
    rcplib_NV_Read(size_nv_id, send_id, nv_value);
    rcplib_FORMAT_Value(nv_size, nv_value, 0, EAPI_VTYPE_U16, 1);
    if (nv_size > OTHER_AUTH_INFO_MAX) {
        // サイズが適正範囲外の場合、不揮発アイテム書き込みの必要あり
        nv_need_to_write = 1; // 書き込みフラグセット
    } else {
        // サイズが適正範囲であれば、認証鍵用の不揮発アイテムのデータを読み出す
        rcplib_NV_Read(data_nv_id, send_id, nv_value);
        rcplib_FORMAT_Value(str_nv_value, nv_value, 0, EAPI_VTYPE_STR, nv_size);
        // クラウド認証用の不揮発アイテムが期待値と完全一致するか確認
        if (str_nv_value != expected_str) {
            nv_need_to_write = 1; // 書き込みフラグセット
        }
    }
    // 期待値と違った場合は不揮発領域に書き込む
    if (nv_need_to_write) {
        rcplib_FORMAT_Binary(nv_value, 0, EAPI_VTYPE_U16, 1, rcplib_STR_Len(expected_str)); // 書き込み用データ作成
        rcplib_NV_Write(size_nv_id, send_id, nv_value, 2); // 認証鍵のサイズを書き込む
        rcplib_FORMAT_Binary(nv_value, 0, EAPI_VTYPE_STR, rcplib_STR_Len(expected_str) + 1, expected_str); // 書き込み用データ作成
        rcplib_NV_Write(data_nv_id, send_id, nv_value, rcplib_STR_Len(expected_str) + 1); // 認証鍵を書き込む
        rcplib_FORMAT_String(l_str_log_out, "send_id %d item is different. NV write.", send_id);
        rcplib_LOG_Print(l_str_log_out); // USBログ出力
    } else {
        rcplib_FORMAT_String(l_str_log_out, "send_id %d item is same.", send_id);
        rcplib_LOG_Print(l_str_log_out); // USBログ出力
    }

    return(nv_need_to_write);
}
#endif // MODEM_SETTING_USE_OTHER_AUTH

#ifdef MODEM_SETTING_USE_OTHER_AUTH_BIN_NV
// クラウド認証用の不揮発アイテムの更新が必要であれば書き込み実行する関数(uint8配列用)
func update_cloud_nv_bin(uint8 send_id, uint32 data_nv_id, uint32 size_nv_id, uint8 expected_bin[], uint16 expected_size) {
    uint16 nv_size; // 読み出した認証情報のサイズを格納する変数
    uint8 nv_value[OTHER_AUTH_INFO_MAX]; // 不揮発アイテム読み出し&書き込み用変数
    uint8 nv_need_to_write; // 不揮発アイテム書き込みフラグ
    uint16 nv_check_cnt; // 不揮発アイテム確認用カウント変数

    nv_need_to_write = 0; // 書き込みフラグクリア
    // クラウド認証用の不揮発アイテムのデータサイズを読み出す
    rcplib_NV_Read(size_nv_id, send_id, nv_value);
    rcplib_FORMAT_Value(nv_size, nv_value, 0, EAPI_VTYPE_U16, 1);
    if (nv_size != expected_size) {
        // サイズが適正範囲外の場合、不揮発アイテム書き込みの必要あり
            nv_need_to_write = 1; // 書き込みフラグセット
    } else {
        // サイズが適正範囲であれば、認証鍵用の不揮発アイテムのデータを読み出す
        rcplib_NV_Read(data_nv_id, send_id, nv_value);
        // クラウド認証用の不揮発アイテムが期待値と完全一致するか確認
        nv_check_cnt = 0;
        while (nv_check_cnt < nv_size) {
            if (nv_value[nv_check_cnt] != expected_bin[nv_check_cnt]) {
                nv_need_to_write = 1; // 書き込みフラグセット
                break;
            }
            nv_check_cnt = nv_check_cnt + 1;
        }
    }
    // 期待値と違った場合は不揮発領域に書き込む
    if (nv_need_to_write) {
        rcplib_FORMAT_Binary(nv_value, 0, EAPI_VTYPE_U16, 1, expected_size); // 書き込み用データ作成
        rcplib_NV_Write(size_nv_id, send_id, nv_value, 2); // 認証鍵のサイズを書き込む
        rcplib_FORMAT_Binary(nv_value, 0, EAPI_VTYPE_U8, expected_size, expected_bin); // 書き込み用データ作成
        rcplib_NV_Write(data_nv_id, send_id, nv_value, expected_size); // 認証鍵を書き込む
        rcplib_FORMAT_String(l_str_log_out, "send_id %d item is different. NV write.", send_id);
        rcplib_LOG_Print(l_str_log_out); // USBログ出力
    } else {
        rcplib_FORMAT_String(l_str_log_out, "send_id %d item is same.", send_id);
        rcplib_LOG_Print(l_str_log_out); // USBログ出力
    }

    return(nv_need_to_write);
}
#endif // MODEM_SETTING_USE_OTHER_AUTH_BIN_NV
#endif
