///
// @file sapp_modem_param.h
// @brief header file for parameter of modem sub application
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef __SAPP_MODEM_PARAM_H__
#define __SAPP_MODEM_PARAM_H__

#ifdef C_SYNTAX
#include "basicInformation.h"
#endif // C_SYNTAX
#include "msa_send_id_01_config.h"
#include "msa_send_id_02_config.h"
#include "msa_send_id_03_config.h"
#include "msa_send_id_04_config.h"
#include "msa_send_id_05_config.h"
#include "msa_send_id_06_config.h"
#include "msa_send_id_07_config.h"
#include "msa_send_id_08_config.h"

//////////////////////////////////////////////////////////////////
// basic define (本項の設定値は変更しないでください) //
//////////////////////////////////////////////////////////////////
// <内部関数用設定値>
// Socketパラメータ設定
#define NOT_SET_PARAM 0
#define EXE_SET_PARAM 1
// Socket受信事前設定
#define NOT_SET_RECV 0
#define EXE_SET_RECV 1
// Socket接続設定
#define NOT_CONNECT 0
#define EXE_CONNECT 1
// Socket送信設定
#define NOT_SEND 0
#define EXE_SEND 1
// Socket切断設定
#define NOT_DISCONNECT 0
#define EXE_DISCONNECT 1

#ifdef MODEM_SETTING_USE_HTTP
// HTTPパラメータ設定
#define NOT_SET_HTTP_PARAM 0
#define EXE_SET_HTTP_PARAM 1
#endif // MODEM_SETTING_USE_HTTP

#ifdef MODEM_SETTING_USE_MQTT
// MQTTパラメータ設定
#define NOT_SET_MQTT_PARAM 0
#define EXE_SET_MQTT_PARAM 1
// MQTT Subscribe設定
#define NOT_SET_MQTT_SUBSCRIBE 0
#define EXE_SET_MQTT_SUBSCRIBE 1
// MQTT接続設定
#define NOT_MQTT_CONNECT 0
#define EXE_MQTT_CONNECT 1
// MQTT切断設定
#define NOT_MQTT_DISCONNECT 0
#define EXE_MQTT_DISCONNECT 1
#endif // MODEM_SETTING_USE_MQTT

#ifdef MODEM_SETTING_USE_AUTH
// <認証情報基本値>
// 証明書情報最大値
#define TLS_AUTH_INFO_MAX 5120
#endif // MODEM_SETTING_USE_AUTH

// <その他認証情報基本値>
// その他認証に利用する鍵の最大値
#define OTHER_AUTH_INFO_MAX 384

// 未使用の送信IDのFIFOバッファ定義
#ifndef FIFO_BUF_LTE_SEND_01_DATA_SIZE
#define FIFO_BUF_LTE_SEND_01_DATA_SIZE 0
#endif // FIFO_BUF_LTE_SEND_01_DATA_SIZE
#ifndef FIFO_BUF_LTE_RECV_01_DATA_SIZE
#define FIFO_BUF_LTE_RECV_01_DATA_SIZE 0
#endif // FIFO_BUF_LTE_RECV_01_DATA_SIZE
#ifndef FIFO_BUF_LTE_SEND_02_DATA_SIZE
#define FIFO_BUF_LTE_SEND_02_DATA_SIZE 0
#endif // FIFO_BUF_LTE_SEND_02_DATA_SIZE
#ifndef FIFO_BUF_LTE_RECV_02_DATA_SIZE
#define FIFO_BUF_LTE_RECV_02_DATA_SIZE 0
#endif // FIFO_BUF_LTE_RECV_02_DATA_SIZE
#ifndef FIFO_BUF_LTE_SEND_03_DATA_SIZE
#define FIFO_BUF_LTE_SEND_03_DATA_SIZE 0
#endif // FIFO_BUF_LTE_SEND_03_DATA_SIZE
#ifndef FIFO_BUF_LTE_RECV_03_DATA_SIZE
#define FIFO_BUF_LTE_RECV_03_DATA_SIZE 0
#endif // FIFO_BUF_LTE_RECV_03_DATA_SIZE
#ifndef FIFO_BUF_LTE_SEND_04_DATA_SIZE
#define FIFO_BUF_LTE_SEND_04_DATA_SIZE 0
#endif // FIFO_BUF_LTE_SEND_04_DATA_SIZE
#ifndef FIFO_BUF_LTE_RECV_04_DATA_SIZE
#define FIFO_BUF_LTE_RECV_04_DATA_SIZE 0
#endif // FIFO_BUF_LTE_RECV_04_DATA_SIZE
#ifndef FIFO_BUF_LTE_SEND_05_DATA_SIZE
#define FIFO_BUF_LTE_SEND_05_DATA_SIZE 0
#endif // FIFO_BUF_LTE_SEND_05_DATA_SIZE
#ifndef FIFO_BUF_LTE_RECV_05_DATA_SIZE
#define FIFO_BUF_LTE_RECV_05_DATA_SIZE 0
#endif // FIFO_BUF_LTE_RECV_05_DATA_SIZE
#ifndef FIFO_BUF_LTE_SEND_06_DATA_SIZE
#define FIFO_BUF_LTE_SEND_06_DATA_SIZE 0
#endif // FIFO_BUF_LTE_SEND_06_DATA_SIZE
#ifndef FIFO_BUF_LTE_RECV_06_DATA_SIZE
#define FIFO_BUF_LTE_RECV_06_DATA_SIZE 0
#endif // FIFO_BUF_LTE_RECV_06_DATA_SIZE
#ifndef FIFO_BUF_LTE_SEND_07_DATA_SIZE
#define FIFO_BUF_LTE_SEND_07_DATA_SIZE 0
#endif // FIFO_BUF_LTE_SEND_07_DATA_SIZE
#ifndef FIFO_BUF_LTE_RECV_07_DATA_SIZE
#define FIFO_BUF_LTE_RECV_07_DATA_SIZE 0
#endif // FIFO_BUF_LTE_RECV_07_DATA_SIZE
#ifndef FIFO_BUF_LTE_SEND_08_DATA_SIZE
#define FIFO_BUF_LTE_SEND_08_DATA_SIZE 0
#endif // FIFO_BUF_LTE_SEND_08_DATA_SIZE
#ifndef FIFO_BUF_LTE_RECV_08_DATA_SIZE
#define FIFO_BUF_LTE_RECV_08_DATA_SIZE 0
#endif // FIFO_BUF_LTE_RECV_08_DATA_SIZE

//////////////////////////////////////////////////////////////////
// basic global variable (本項の設定値は変更しないでください) //
//////////////////////////////////////////////////////////////////
// <送信パラメータグローバル変数>
// Base
int32 l_timeout; uint8 l_sync;
uint8 l_send_id; str l_hostname[MMG_HOST_NAME_MAX]; uint16 l_port; uint8 l_protocol;
uint8 l_sni; uint8 l_auth_mode; uint8 l_auth_index; uint8 l_use_usb;
uint8 l_rcv_databuf_id; uint8 l_rcv_event_id;
uint8 l_databuf_id; uint16 l_burst; uint8 l_session; uint8 l_retain;
uint16 l_mov_target;

str l_str_log_out[LOGAPI_OUT_MAX]; // Log出力用変数

#ifdef MODEM_SETTING_USE_HTTP
// HTTP
str l_http_header_str[MMG_HEADER_MAX];
str l_http_url_str[MMG_URL_MAX];
uint8 l_http_method;
// HTTPワーク
uint8 l_bin_http_header[MMG_HEADER_MAX]; // HTTPヘッダuint8配列変数
uint16 l_http_header_ofs; // HTTPヘッダ作成時のオフセット管理変数
// HTTP通知用
uint16 l_http_send_success_num;
uint16 l_http_resp_code;
uint8 l_http_recv_buf_id;
#endif // MODEM_SETTING_USE_HTTP

#ifdef MODEM_SETTING_USE_MQTT
// MQTT
uint8 l_mq_cid; uint8 l_mq_clean; uint16 l_mq_keep_alive;
str l_mq_client_id[MMG_MQTT_CLIENT_ID_MAX]; str l_mq_user_name[MMG_MQTT_USER_NAME_MAX]; str l_mq_user_pass[MMG_MQTT_USER_PASS_MAX];
uint8 l_mq_will_qos; uint8 l_mq_will_retain; str l_mq_will_topic_name[MMG_MQTT_WILL_TOPIC_MAX]; str l_mq_will_payload[MMG_MQTT_WILL_PAYLOAD_MAX];
uint8 l_mq_pub_qos; uint8 l_mq_pub_retain; str l_mq_pub_topic_name[MMG_MQTT_PUB_TOPIC_MAX];
uint8 l_mq_sid; uint8 l_mq_sub_qos; str l_mq_sub_topic_name[MMG_MQTT_SUB_TOPIC_MAX];
#endif // MODEM_SETTING_USE_MQTT

#ifdef MODEM_SETTING_USE_AUTH
// <TLS認証ワーク関連のグローバル変数>
uint8 l_bin_auth_info[TLS_AUTH_INFO_MAX]; // TLS認証情報のuint8配列変数
uint16 l_auth_info_ofs; // TLS認証情報作成時のオフセット管理変数
#endif // MODEM_SETTING_USE_AUTH

#endif
