///
// @file msa_send_id_01_config.h
// @brief header file for send_id_01_setting of modem sub application
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef __MSA_SEND_ID_01_CONFIG_H__
#define __MSA_SEND_ID_01_CONFIG_H__

#ifdef C_SYNTAX
#include "basicInformation.h"
#endif // C_SYNTAX
#include "eventLib.h"
#include "logAPI.h"
#include "flashLib.h"
#include "bufferLib.h"
#include "cmd_str.h"
#include "modemMgrTask.h"
#include "sappModemAPI.h"
#include "msa_config_udp.h"
#include "msa_config_tcp.h"
#include "msa_config_http.h"
#include "msa_config_https_without_cli_cert.h"
#include "msa_config_https_with_cli_cert.h"
#include "msa_config_mqtt.h"
#include "msa_config_mqtts_without_cli_cert.h"
#include "msa_config_mqtts_with_cli_cert.h"
#include "msa_config_s3_storage_https.h"
#include "msa_config_azure_storage_rest_https.h"
#include "msa_config_azure_iot_sas_token_https.h"
#include "msa_config_azure_iot_sas_token_mqtts.h"
#include "msa_config_gcp_iot_es256_https.h"
#include "msa_config_gcp_iot_es256_mqtts.h"

//////////////////////////////////////////////////////////////////
// sapp_modem.krsの利用方法 //
//////////////////////////////////////////////////////////////////
#define MSA_CONFIG_01_NOT_USE

#ifdef MSA_CONFIG_01_USE_UDP
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_UDP
#ifdef MSA_CONFIG_01_USE_TCP
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_TCP
#ifdef MSA_CONFIG_01_USE_HTTP
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_HTTP
#ifdef MSA_CONFIG_01_USE_MQTT
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_MQTT
#ifdef MSA_CONFIG_01_USE_HTTPS
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_HTTPS
#ifdef MSA_CONFIG_01_USE_HTTPS_WITH_CLI_CERT
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_HTTPS_WITH_CLI_CERT
#ifdef MSA_CONFIG_01_USE_MQTTS
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_MQTTS
#ifdef MSA_CONFIG_01_USE_MQTTS_WITH_CLI_CERT
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_MQTTS_WITH_CLI_CERT
#ifdef MSA_CONFIG_01_USE_S3_STORAGE_HTTPS
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_S3_STORAGE_HTTPS
#ifdef MSA_CONFIG_01_USE_AZURE_STORAGE_REST_HTTPS
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_AZURE_STORAGE_REST_HTTPS
#ifdef MSA_CONFIG_01_USE_AZURE_IOT_SASTOKEN_HTTPS
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_AZURE_IOT_SASTOKEN_HTTPS
#ifdef MSA_CONFIG_01_USE_GCP_IOT_ES256_HTTPS
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_GCP_IOT_ES256_HTTPS
#ifdef MSA_CONFIG_01_USE_AZURE_IOT_SASTOKEN_MQTTS
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_AZURE_IOT_SASTOKEN_MQTTS
#ifdef MSA_CONFIG_01_USE_GCP_IOT_ES256_MQTTS
#undef MSA_CONFIG_01_NOT_USE
#endif // MSA_CONFIG_01_USE_GCP_IOT_ES256_MQTTS

#ifndef MSA_CONFIG_01_NOT_USE
//////////////////////////////////////////////////////////////////
// basic setting (本項の設定値は変更禁止) //
//////////////////////////////////////////////////////////////////

#ifdef MSA_CONFIG_01_USE_UDP
#define MODEM_SETTING_USE_SOCKET
#define MODEM_SETTING_01_USE_SOCKET
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_UDP // UDP通信を利用する
#endif // MSA_CONFIG_01_USE_UDP
#ifdef MSA_CONFIG_01_USE_TCP
#define MODEM_SETTING_USE_SOCKET
#define MODEM_SETTING_01_USE_SOCKET
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_TCP // TCP通信を利用する
#endif // MSA_CONFIG_01_USE_TCP
#ifdef MSA_CONFIG_01_USE_HTTP
#define MODEM_SETTING_USE_HTTP
#define MODEM_SETTING_01_USE_HTTP
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_HTTP // HTTP通信を利用する
#endif // MSA_CONFIG_01_USE_HTTP
#ifdef MSA_CONFIG_01_USE_MQTT
#define MODEM_SETTING_USE_MQTT
#define MODEM_SETTING_01_USE_MQTT
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_MQTT // MQTT通信を利用する
#endif // MSA_CONFIG_01_USE_MQTT
#ifdef MSA_CONFIG_01_USE_HTTPS
#define MODEM_SETTING_USE_HTTP
#define MODEM_SETTING_USE_AUTH
#define MODEM_SETTING_01_USE_HTTP
#define MODEM_SETTING_01_USE_AUTH
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_HTTPS // HTTPS通信を利用する
#define MODEM_SETTING_01_AUTH_MODE          MMG_AUTH_SRV       // TLS認証方式(CA証明あり)
#endif // MSA_CONFIG_01_USE_HTTP
#ifdef MSA_CONFIG_01_USE_HTTPS_WITH_CLI_CERT
#define MODEM_SETTING_USE_HTTP
#define MODEM_SETTING_USE_AUTH
#define MODEM_SETTING_USE_AUTH_CLI
#define MODEM_SETTING_01_USE_HTTP
#define MODEM_SETTING_01_USE_AUTH
#define MODEM_SETTING_01_USE_AUTH_CLI
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_HTTPS // HTTPS通信を利用する
#define MODEM_SETTING_01_AUTH_MODE          MMG_AUTH_SRVCLI    // TLS認証方式(クライアント証明あり)
#endif // MSA_CONFIG_01_USE_HTTP
#ifdef MSA_CONFIG_01_USE_MQTTS_WITH_CLI_CERT
#define MODEM_SETTING_USE_MQTT
#define MODEM_SETTING_USE_AUTH
#define MODEM_SETTING_USE_AUTH_CLI
#define MODEM_SETTING_01_USE_MQTT
#define MODEM_SETTING_01_USE_AUTH
#define MODEM_SETTING_01_USE_AUTH_CLI
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_MQTTS // MQTTS通信を利用する
#define MODEM_SETTING_01_AUTH_MODE          MMG_AUTH_SRVCLI    // TLS認証方式(クライアント証明あり)
#endif // MSA_CONFIG_01_USE_HTTP
#ifdef MSA_CONFIG_01_USE_S3_STORAGE_HTTPS
#define MODEM_SETTING_USE_HTTP
#define MODEM_SETTING_USE_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH1
#define MODEM_SETTING_USE_OTHER_AUTH2
#define MODEM_SETTING_USE_OTHER_AUTH3
#define MODEM_SETTING_01_USE_HTTP
#define MODEM_SETTING_01_USE_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH1
#define MODEM_SETTING_01_USE_OTHER_AUTH2
#define MODEM_SETTING_01_USE_OTHER_AUTH3
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_S3_STORAGE_HTTPS // S3互換のストレージ向けHTTPS通信を利用する
#define MODEM_SETTING_01_AUTH_MODE          MMG_AUTH_SRV                  // TLS認証方式(CA証明あり)
#endif // MSA_CONFIG_01_USE_S3_STORAGE_HTTPS
#ifdef MSA_CONFIG_01_USE_AZURE_STORAGE_REST_HTTPS
#define MODEM_SETTING_USE_HTTP
#define MODEM_SETTING_USE_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH1
#define MODEM_SETTING_01_USE_HTTP
#define MODEM_SETTING_01_USE_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH1
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_AZURE_STORAGE_REST_HTTPS // Azure Blob Storage向けHTTPS通信を利用する
#define MODEM_SETTING_01_AUTH_MODE          MMG_AUTH_SRV                          // TLS認証方式(CA証明あり)
#endif // MSA_CONFIG_01_USE_AZURE_STORAGE_REST_HTTPS
#ifdef MSA_CONFIG_01_USE_AZURE_IOT_SASTOKEN_HTTPS
#define MODEM_SETTING_USE_HTTP
#define MODEM_SETTING_USE_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH1
#define MODEM_SETTING_USE_OTHER_AUTH3
#define MODEM_SETTING_01_USE_HTTP
#define MODEM_SETTING_01_USE_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH1
#define MODEM_SETTING_01_USE_OTHER_AUTH3
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_AZURE_IOT_SASTOKEN_HTTPS // Azure IoT Hub向けHTTPS通信を利用する
#define MODEM_SETTING_01_AUTH_MODE          MMG_AUTH_SRV                          // TLS認証方式(CA証明あり)
#endif // MSA_CONFIG_01_USE_AZURE_IOT_SASTOKEN_HTTPS
#ifdef MSA_CONFIG_01_USE_GCP_IOT_ES256_HTTPS
#define MODEM_SETTING_USE_HTTP
#define MODEM_SETTING_USE_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH_BIN_NV
#define MODEM_SETTING_USE_OTHER_AUTH_BIN_1
#define MODEM_SETTING_01_USE_HTTP
#define MODEM_SETTING_01_USE_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH_BIN_NV
#define MODEM_SETTING_01_USE_OTHER_AUTH_BIN_1
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_GCP_IOT_ES256_HTTPS // GCP IoT Core向けHTTPS通信を利用する
#define MODEM_SETTING_01_AUTH_MODE          MMG_AUTH_SRV                     // TLS認証方式(CA証明あり)
#define MODEM_SETTING_01_USE_OTHER_AUTH_B1_SIZE 32
#endif // MSA_CONFIG_01_USE_GCP_IOT_ES256_HTTPS
#ifdef MSA_CONFIG_01_USE_AZURE_IOT_SASTOKEN_MQTTS
#define MODEM_SETTING_USE_MQTT
#define MODEM_SETTING_USE_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH1
#define MODEM_SETTING_USE_OTHER_AUTH2
#define MODEM_SETTING_USE_OTHER_AUTH3
#define MODEM_SETTING_01_USE_MQTT
#define MODEM_SETTING_01_USE_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH1
#define MODEM_SETTING_01_USE_OTHER_AUTH2
#define MODEM_SETTING_01_USE_OTHER_AUTH3
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_AZURE_IOT_SASTOKEN_MQTTS // Azure IoT Hub向けMQTTS通信を利用する
#define MODEM_SETTING_01_AUTH_MODE          MMG_AUTH_SRV                          // TLS認証方式(CA証明あり)
#endif // MSA_CONFIG_01_USE_AZURE_IOT_SASTOKEN_MQTTS
#ifdef MSA_CONFIG_01_USE_GCP_IOT_ES256_MQTTS
#define MODEM_SETTING_USE_MQTT
#define MODEM_SETTING_USE_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH
#define MODEM_SETTING_USE_OTHER_AUTH2
#define MODEM_SETTING_USE_OTHER_AUTH_BIN_NV
#define MODEM_SETTING_USE_OTHER_AUTH_BIN_1
#define MODEM_SETTING_01_USE_MQTT
#define MODEM_SETTING_01_USE_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH
#define MODEM_SETTING_01_USE_OTHER_AUTH2
#define MODEM_SETTING_01_USE_OTHER_AUTH_BIN_NV
#define MODEM_SETTING_01_USE_OTHER_AUTH_BIN_1
#define MODEM_SETTING_01_CONN_PROTOCOL      MMG_PROTOCOL_GCP_IOT_ES256_MQTTS // GCP IoT Core向けMQTTS通信を利用する
#define MODEM_SETTING_01_AUTH_MODE          MMG_AUTH_SRV                     // TLS認証方式(CA証明あり)
#define MODEM_SETTING_01_USE_OTHER_AUTH_B1_SIZE 32
#endif // MSA_CONFIG_01_USE_GCP_IOT_ES256_MQTTS

#endif // MSA_CONFIG_01_NOT_USE

#endif
