﻿///
// @file msa_send_id_05_func.h
// @brief header file for send_id_05_functions of modem sub application
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef __MSA_SEND_ID_05_FUNC_H__
#define __MSA_SEND_ID_05_FUNC_H__

#ifdef C_SYNTAX
#include "basicInformation.h"
#endif // C_SYNTAX
#include "eventLib.h"
#include "logAPI.h"
#include "flashLib.h"
#include "bufferLib.h"
#include "cmd_str.h"
#include "modemMgrTask.h"
#include "sappModemAPI.h"
#include "msa_param.h"

//////////////////////////////////////////////////////////////////
// basic define (本項の設定値は変更しないでください) //
//////////////////////////////////////////////////////////////////
#ifdef MSA_CONFIG_05_USE_S3_STORAGE_HTTPS
// 認証系設定値(S3互換のストレージ向け認証情報)
#define MODEM_SETTING_05_CLOUD_KEY             MSA_CONFIG_05_S3_STR_SCRT_KEY
#define MODEM_SETTING_05_ACCESS_INFO           MSA_CONFIG_05_S3_STR_ACCS_KEY
#define MODEM_SETTING_05_OTHER_INFO            MSA_CONFIG_05_S3_STR_REGION
#endif // MSA_CONFIG_05_USE_S3_STORAGE_HTTPS

#ifdef MSA_CONFIG_05_USE_AZURE_STORAGE_REST_HTTPS
// 認証系設定値(Azure Blob Storage向け認証情報)
#define MODEM_SETTING_05_CLOUD_KEY             MSA_CONFIG_05_AZR_STR_SCRT_KEY
#endif // MSA_CONFIG_05_USE_AZURE_STORAGE_REST_HTTPS

#ifdef MSA_CONFIG_05_USE_AZURE_IOT_SASTOKEN_HTTPS
// 認証系設定値(Azure IoT Core向け認証情報)
#define MODEM_SETTING_05_CLOUD_KEY             MSA_CONFIG_05_AZR_IOT_SCRT_KEY
#define MODEM_SETTING_05_OTHER_INFO            MSA_CONFIG_05_AZR_IOT_SKN
#endif // MSA_CONFIG_05_USE_AZURE_IOT_SASTOKEN_HTTPS

#ifdef MSA_CONFIG_05_USE_GCP_IOT_ES256_HTTPS
// 認証系設定値(GCP IoT Core向け認証情報)
#define MODEM_SETTING_05_CLOUD_SCRT_KEY01_04   MSA_CONFIG_05_GCP_IOT_SCRT_KEY01_04
#define MODEM_SETTING_05_CLOUD_SCRT_KEY05_08   MSA_CONFIG_05_GCP_IOT_SCRT_KEY05_08
#define MODEM_SETTING_05_CLOUD_SCRT_KEY09_12   MSA_CONFIG_05_GCP_IOT_SCRT_KEY09_12
#define MODEM_SETTING_05_CLOUD_SCRT_KEY13_16   MSA_CONFIG_05_GCP_IOT_SCRT_KEY13_16
#define MODEM_SETTING_05_CLOUD_SCRT_KEY17_20   MSA_CONFIG_05_GCP_IOT_SCRT_KEY17_20
#define MODEM_SETTING_05_CLOUD_SCRT_KEY21_24   MSA_CONFIG_05_GCP_IOT_SCRT_KEY21_24
#define MODEM_SETTING_05_CLOUD_SCRT_KEY25_28   MSA_CONFIG_05_GCP_IOT_SCRT_KEY25_28
#define MODEM_SETTING_05_CLOUD_SCRT_KEY29_32   MSA_CONFIG_05_GCP_IOT_SCRT_KEY29_32
#endif // MSA_CONFIG_05_USE_GCP_IOT_ES256_HTTPS

#ifdef MSA_CONFIG_05_USE_AZURE_IOT_SASTOKEN_MQTTS
// 認証系設定値(Azure IoT Core向け認証情報)
#define MODEM_SETTING_05_CLOUD_KEY             MSA_CONFIG_05_AZR_IOT_SCRT_KEY
#define MODEM_SETTING_05_ACCESS_INFO           MSA_CONFIG_05_AZR_IOT_SIGN_EXP
#define MODEM_SETTING_05_OTHER_INFO            MSA_CONFIG_05_AZR_IOT_SKN
#endif // MSA_CONFIG_05_USE_AZURE_IOT_SASTOKEN_MQTTS

#ifdef MSA_CONFIG_05_USE_GCP_IOT_ES256_MQTTS
// 認証系設定値(GCP IoT Core向け認証情報)
#define MODEM_SETTING_05_CLOUD_SCRT_KEY01_04   MSA_CONFIG_05_GCP_IOT_SCRT_KEY01_04
#define MODEM_SETTING_05_CLOUD_SCRT_KEY05_08   MSA_CONFIG_05_GCP_IOT_SCRT_KEY05_08
#define MODEM_SETTING_05_CLOUD_SCRT_KEY09_12   MSA_CONFIG_05_GCP_IOT_SCRT_KEY09_12
#define MODEM_SETTING_05_CLOUD_SCRT_KEY13_16   MSA_CONFIG_05_GCP_IOT_SCRT_KEY13_16
#define MODEM_SETTING_05_CLOUD_SCRT_KEY17_20   MSA_CONFIG_05_GCP_IOT_SCRT_KEY17_20
#define MODEM_SETTING_05_CLOUD_SCRT_KEY21_24   MSA_CONFIG_05_GCP_IOT_SCRT_KEY21_24
#define MODEM_SETTING_05_CLOUD_SCRT_KEY25_28   MSA_CONFIG_05_GCP_IOT_SCRT_KEY25_28
#define MODEM_SETTING_05_CLOUD_SCRT_KEY29_32   MSA_CONFIG_05_GCP_IOT_SCRT_KEY29_32
#define MODEM_SETTING_05_ACCESS_INFO           MSA_CONFIG_05_GCP_IOT_SIGN_EXP
#endif // MSA_CONFIG_05_USE_GCP_IOT_ES256_MQTTS

//////////////////////////////////////////////////////////////////
// main function //
//////////////////////////////////////////////////////////////////
func sappModem_05_setMyParameter() {

#ifndef MSA_CONFIG_05_NOT_USE
    // データ通信基本設定
    // ソケット通信設定
    l_send_id = MSA_CONFIG_05_SEND_ID; rcplib_STR_SetString(l_hostname, MSA_CONFIG_05_CONN_HOSTNAME);
    l_port = MSA_CONFIG_05_CONN_PORT; l_protocol = MODEM_SETTING_05_CONN_PROTOCOL;
    l_rcv_databuf_id = FIFO_BUF_LTE_RECV_05_ID; l_databuf_id = FIFO_BUF_LTE_SEND_05_ID;
    l_use_usb = MSA_CONFIG_05_USE_USB;
    // 基本設定
    l_timeout = MSA_CONFIG_05_API_TIMEOUT; l_sync = EAPI_SYNC_RESULT;
#ifdef MODEM_SETTING_05_USE_AUTH
    // TLS設定
    l_sni = MSA_CONFIG_05_TLS_SNI; l_auth_mode = MODEM_SETTING_05_AUTH_MODE; l_auth_index = MSA_CONFIG_05_AUTH_ID;
#endif // MODEM_SETTING_05_USE_AUTH
    // 送信設定
    l_burst = MSA_CONFIG_05_SEND_BURST; l_session = MMG_SESSION_CONNECT; l_retain = MSA_CONFIG_05_DATA_RETAIN;
    // 画像送信設定
    l_mov_target = 0;
#ifdef MODEM_SETTING_05_USE_HTTP
    // HTTP設定
    rcplib_STR_SetString(l_http_url_str, MSA_CONFIG_05_HTTP_URL);
    rcpfunc_http_header_init();
    if (MSA_CONFIG_05_HTTP_HEADER1 != "") {
        rcpfunc_http_header_convert(MSA_CONFIG_05_HTTP_HEADER1);
    }
    if (MSA_CONFIG_05_HTTP_HEADER2 != "") {
        rcpfunc_http_header_convert(MSA_CONFIG_05_HTTP_HEADER2);
    }
    if (MSA_CONFIG_05_HTTP_HEADER3 != "") {
        rcpfunc_http_header_convert(MSA_CONFIG_05_HTTP_HEADER3);
    }
    rcplib_FORMAT_Value(l_http_header_str, l_bin_http_header, 0, EAPI_VTYPE_STR, MMG_HEADER_MAX);
    l_http_method = MSA_CONFIG_05_HTTP_METHOD;
#endif // MODEM_SETTING_05_USE_HTTP
#ifdef MODEM_SETTING_05_USE_MQTT
// MQTT設定
    l_mq_cid = MSA_CONFIG_05_MQTT_CID; l_mq_clean = MSA_CONFIG_05_MQTT_CLEAN; l_mq_keep_alive = MSA_CONFIG_05_MQTT_KEEP_ALIVE;
    rcplib_STR_SetString(l_mq_client_id, MSA_CONFIG_05_MQTT_CLIENT_ID);
    rcplib_STR_SetString(l_mq_user_name, MSA_CONFIG_05_MQTT_USER_NAME); rcplib_STR_SetString(l_mq_user_pass, MSA_CONFIG_05_MQTT_USER_PASS);
    // Will設定
    l_mq_will_qos = MSA_CONFIG_05_MQTT_WILL_QOS; l_mq_will_retain = MSA_CONFIG_05_MQTT_WILL_RETAIN;
    rcplib_STR_SetString(l_mq_will_topic_name, MSA_CONFIG_05_MQTT_WILL_TOPIC_NAME); rcplib_STR_SetString(l_mq_will_payload, MSA_CONFIG_05_MQTT_WILL_PAYLOAD);
    // Publish設定
    l_mq_pub_qos = MSA_CONFIG_05_MQTT_PUB_QOS; l_mq_pub_retain = MSA_CONFIG_05_MQTT_PUB_RETAIN;
    rcplib_STR_SetString(l_mq_pub_topic_name, MSA_CONFIG_05_MQTT_PUB_TOPIC_NAME);
#ifdef MSA_CONFIG_05_USE_MQTT_SUB
    // Subscribe設定
    l_mq_sid = MSA_CONFIG_05_MQTT_SUB_SID; l_mq_sub_qos = MSA_CONFIG_05_MQTT_SUB_QOS;
    rcplib_STR_SetString(l_mq_sub_topic_name, MSA_CONFIG_05_MQTT_SUB_TOPIC_NAME);
#endif // MSA_CONFIG_05_USE_MQTT_SUB
#endif // MODEM_SETTING_05_USE_MQTT

#endif // MSA_CONFIG_05_NOT_USE

}
func sappModem_05_init() {
    uint8 ret;
    ret = EAPI_NO_ERROR;

#ifndef MSA_CONFIG_05_NOT_USE
    // <データ送信バッファと受信バッファの定義>
    // データ送信用(全体サイズFIFO_BUF_LTE_SEND_05_DATA_SIZE[Byte], 深さFIFO_BUF_LTE_SEND_05_DEPTH_MAX)
    if(rcplib_FIFOBUF_Create(FIFO_BUF_LTE_SEND_05_ID, FIFO_BUF_LTE_SEND_05_DATA_SIZE, FIFO_BUF_LTE_SEND_05_DEPTH_MAX, FIFO_BUF_LTE_SEND_05_OVERWRITE) != 0) {
        ret = MSA_SID_API_ERR_SBUF_CREATE;
        rcplib_LOG_Print("FIFO_BUF_LTE_SEND_05_ID FIFOBUF_Create Error!!");
    }
    // データ受信用(全体サイズFIFO_BUF_LTE_RECV_05_DATA_SIZE[Byte], 深さFIFO_BUF_LTE_RECV_05_DEPTH_MAX)
    if(rcplib_FIFOBUF_Create(FIFO_BUF_LTE_RECV_05_ID, FIFO_BUF_LTE_RECV_05_DATA_SIZE, FIFO_BUF_LTE_RECV_05_DEPTH_MAX, FIFO_BUF_LTE_RECV_05_OVERWRITE) != 0) {
        ret = MSA_SID_API_ERR_RBUF_CREATE;
        rcplib_LOG_Print("FIFO_BUF_LTE_RECV_05_ID FIFOBUF_Create Error!!");
    }

#ifndef MSA_CONFIG_05_USE_AUTH_NV
#ifdef MODEM_SETTING_05_USE_AUTH
    // <クラウド通信認証関連>
    // 認証情報関連の初期設定を実行
    sappModem_05_auth_init(MSA_CONFIG_05_AUTH_ID);
#endif // MODEM_SETTING_05_USE_AUTH
#endif // MSA_CONFIG_05_USE_AUTH_NV

#ifdef MODEM_SETTING_05_USE_OTHER_AUTH
// 認証情報関連の初期設定
    sappModem_05_other_auth_init();
#endif // MODEM_SETTING_05_USE_OTHER_AUTH
    // <クラウド通信プロトコル関連>
#ifdef MODEM_SETTING_05_USE_SOCKET
    // Socket通信関連の各種通信設定を実行
    sappModem_socket_init(EXE_SET_PARAM, EXE_SET_RECV);
#endif // MODEM_SETTING_05_USE_SOCKET
#ifdef MODEM_SETTING_05_USE_HTTP
    // HTTP通信関連の各種通信設定を実行
    sappModem_http_init(EXE_SET_PARAM, EXE_SET_RECV, EXE_SET_HTTP_PARAM);
#endif // MODEM_SETTING_05_USE_HTTP
#ifdef MODEM_SETTING_05_USE_MQTT
    // MQTT通信関連の各種通信設定を実行
#ifdef MSA_CONFIG_05_USE_MQTT_SUB
    sappModem_mqtt_init(EXE_SET_PARAM, EXE_SET_RECV, EXE_SET_MQTT_PARAM, EXE_SET_MQTT_SUBSCRIBE);
#else // MSA_CONFIG_05_USE_MQTT_SUB
    sappModem_mqtt_init(EXE_SET_PARAM, EXE_SET_RECV, EXE_SET_MQTT_PARAM, NOT_SET_MQTT_SUBSCRIBE);
#endif // MSA_CONFIG_05_USE_MQTT_SUB
#endif // MODEM_SETTING_05_USE_HTTP

#else  // MSA_CONFIG_05_NOT_USE
    ret = MSA_SID_API_ERR_NO_CONFIG;
#endif // MSA_CONFIG_05_NOT_USE
    return(ret);
}
//////////////////////////////////////////////////////////////////
// sub function //
//////////////////////////////////////////////////////////////////
#ifndef MSA_CONFIG_05_USE_AUTH_NV
#ifdef MODEM_SETTING_05_USE_AUTH
// 認証情報関連の初期設定
func sappModem_05_auth_init(uint8 auth_index) {
    uint8 ret;
    ret = EAPI_NO_ERROR;

    // ＜TLS認証情報＞
    // TLSサーバー証明書準備
    rcpfunc_auth_init();
    rcpfunc_auth_convert(MSA_CONFIG_05_CA_CERT_HEADER);
    rcpfunc_auth_convert(MSA_CONFIG_05_CA_CERT_BODY);
    rcpfunc_auth_convert(MSA_CONFIG_05_CA_CERT_FOOTER);
    ret = MMG_SetCertificate(auth_index, MMG_AUTH_KIND_CACERT, l_bin_auth_info, l_auth_info_ofs - 1);

#ifdef MODEM_SETTING_05_USE_AUTH_CLI
    // エラー未発生の場合のみ次の処理を実行する
    if (ret == EAPI_NO_ERROR) {
        // TLSクライアント証明書準備
        rcpfunc_auth_init();
        rcpfunc_auth_convert(MSA_CONFIG_05_CLIENT_CERT_HEADER);
        rcpfunc_auth_convert(MSA_CONFIG_05_CLIENT_CERT_BODY);
        rcpfunc_auth_convert(MSA_CONFIG_05_CLIENT_CERT_FOOTER);
        ret = MMG_SetCertificate(auth_index, MMG_AUTH_KIND_CLIENTCERT, l_bin_auth_info, l_auth_info_ofs - 1);
    }

    // エラー未発生の場合のみ次の処理を実行する
    if (ret == EAPI_NO_ERROR) {
        // TLS秘密鍵準備
        rcpfunc_auth_init();
        rcpfunc_auth_convert(MSA_CONFIG_05_CLIENT_KEY_HEADER);
        rcpfunc_auth_convert(MSA_CONFIG_05_CLIENT_KEY_BODY);
        rcpfunc_auth_convert(MSA_CONFIG_05_CLIENT_KEY_FOOTER);
        ret = MMG_SetCertificate(auth_index, MMG_AUTH_KIND_CLIENTKEY, l_bin_auth_info, l_auth_info_ofs - 1);
    }
#endif // MODEM_SETTING_05_USE_AUTH_CLI
    if (ret != EAPI_NO_ERROR) {
        // エラー発生時のログ出力
        rcplib_LOG_Print("sappModem_05_auth_init MMG_SetCertificate Error!!");
    }

    return(ret);
}
#endif // MODEM_SETTING_05_USE_AUTH
#endif // MSA_CONFIG_05_USE_AUTH_NV

#ifdef MODEM_SETTING_05_USE_OTHER_AUTH
// 認証情報関連の初期設定
func sappModem_05_other_auth_init() {
    uint8 sync_flg; // 不揮発アイテムの同期フラグ
    sync_flg = 0;

    // ＜各種クラウドサービス向け認証情報の設定＞
#ifdef MODEM_SETTING_05_USE_OTHER_AUTH1
    // 認証鍵用の不揮発アイテムが期待値と違う場合は書き込む
    sync_flg = sync_flg + update_cloud_nv_str(MSA_CONFIG_05_SEND_ID, NV_RW_USER_CLOUD_KEY, NV_RW_USER_CLOUD_KEY_SIZE, MODEM_SETTING_05_CLOUD_KEY);
#endif // MODEM_SETTING_05_USE_OTHER_AUTH1
#ifdef MODEM_SETTING_05_USE_OTHER_AUTH_BIN_1
    uint8 bin_key1[MODEM_SETTING_05_USE_OTHER_AUTH_B1_SIZE]; // 秘密鍵設定用配列変数
    // 認証鍵情報をuint8配列にセット
    rcplib_FORMAT_Binary(bin_key1, 0, EAPI_VTYPE_U32, 1, MODEM_SETTING_05_CLOUD_SCRT_KEY01_04);
    rcplib_FORMAT_Binary(bin_key1, 4, EAPI_VTYPE_U32, 1, MODEM_SETTING_05_CLOUD_SCRT_KEY05_08);
    rcplib_FORMAT_Binary(bin_key1, 8, EAPI_VTYPE_U32, 1, MODEM_SETTING_05_CLOUD_SCRT_KEY09_12);
    rcplib_FORMAT_Binary(bin_key1, 12, EAPI_VTYPE_U32, 1, MODEM_SETTING_05_CLOUD_SCRT_KEY13_16);
    rcplib_FORMAT_Binary(bin_key1, 16, EAPI_VTYPE_U32, 1, MODEM_SETTING_05_CLOUD_SCRT_KEY17_20);
    rcplib_FORMAT_Binary(bin_key1, 20, EAPI_VTYPE_U32, 1, MODEM_SETTING_05_CLOUD_SCRT_KEY21_24);
    rcplib_FORMAT_Binary(bin_key1, 24, EAPI_VTYPE_U32, 1, MODEM_SETTING_05_CLOUD_SCRT_KEY25_28);
    rcplib_FORMAT_Binary(bin_key1, 28, EAPI_VTYPE_U32, 1, MODEM_SETTING_05_CLOUD_SCRT_KEY29_32);
    // 認証鍵用の不揮発アイテムが期待値と違う場合は書き込む
    sync_flg = sync_flg + update_cloud_nv_bin(MSA_CONFIG_05_SEND_ID, NV_RW_USER_CLOUD_KEY, NV_RW_USER_CLOUD_KEY_SIZE, bin_key1, MODEM_SETTING_05_USE_OTHER_AUTH_B1_SIZE);

#endif // MODEM_SETTING_05_USE_OTHER_AUTH_BIN_1
#ifdef MODEM_SETTING_05_USE_OTHER_AUTH2
    // 認証アクセスキー用の不揮発アイテムが期待値と違う場合は書き込む
    sync_flg = sync_flg + update_cloud_nv_str(MSA_CONFIG_05_SEND_ID, NV_RW_USER_CLOUD_ACCESS_INFO, NV_RW_USER_CLOUD_ACCESS_INFO_SIZE, MODEM_SETTING_05_ACCESS_INFO);
#endif // MODEM_SETTING_05_USE_OTHER_AUTH2
#ifdef MODEM_SETTING_05_USE_OTHER_AUTH3
    // 認証に使うリージョン用の不揮発アイテムが期待値と違う場合は書き込む
    sync_flg = sync_flg + update_cloud_nv_str(MSA_CONFIG_05_SEND_ID, NV_RW_USER_CLOUD_OTHER_INFO, NV_RW_USER_CLOUD_OTHER_INFO_SIZE, MODEM_SETTING_05_OTHER_INFO);
#endif // MODEM_SETTING_05_USE_OTHER_AUTH3

    // ＜不揮発アイテムの同期処理＞
    if (sync_flg) {
        // 一つでも更新した不揮発アイテムがあれば、ミラー領域から実体の不揮発領域に全て書き込む
        rcplib_NV_Sync();
        rcplib_LOG_Print("NV sync done!"); // USBログ出力
    }

    return(0);
}
#endif // MODEM_SETTING_05_USE_OTHER_AUTH

#endif
