///
// @file sappModemAPI.h
// @brief header file generate from sapp_modem.kra
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef _SAPP_MODEM_KRA_
#define _SAPP_MODEM_KRA_

#ifdef C_SYNTAX
#define KC_EXPAND_RECIPE
#endif // C_SYNTAX

#ifndef KC_EXPAND_RECIPE

//////////////////////////////////////////////////////////////////
// *** define declaration that is not for recipe users *** //
//////////////////////////////////////////////////////////////////

#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// Initialize
#define MSA_EVENT_UNSYNC_INIT 0
#define MSA_Init() \
  EAPI_SendEvent(EAPI_TASKID_MODEM_SAPP,MSA_EVENT_UNSYNC_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// Set LTE send id
#define MSA_EVENT_SYNC_SET_LTE_SEND_ID 256
#define MSA_SetLteSendId(send_id,recv_mode,send_res_event_id,recv_data_event_id) \
  EAPI_SendEvent(EAPI_TASKID_MODEM_SAPP,MSA_EVENT_SYNC_SET_LTE_SEND_ID,EAPI_SYNC_RESULT,60000,EAPI_VTYPE_U8,send_id,EAPI_VTYPE_U8,recv_mode,EAPI_VTYPE_U8,send_res_event_id,EAPI_VTYPE_U8,recv_data_event_id)
// Send USB camera image
#define MSA_EVENT_UNSYNC_SEND_CAMERA_IMAGE 257
#define MSA_SendCameraImage(send_id,mov_target) \
  EAPI_SendEvent(EAPI_TASKID_MODEM_SAPP,MSA_EVENT_UNSYNC_SEND_CAMERA_IMAGE,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,send_id,EAPI_VTYPE_U16,mov_target)
// Set always connect send id
#define MSA_EVENT_UNSYNC_SET_ALWAYS_CONNECT 258
#define MSA_SetAlwaysConnect(event_id,send_id,regist) \
  EAPI_SendEvent(EAPI_TASKID_MODEM_SAPP,MSA_EVENT_UNSYNC_SET_ALWAYS_CONNECT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,event_id,EAPI_VTYPE_U8,send_id,EAPI_VTYPE_U8,regist)
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// LTE送信ID
#define MSA_SEND_ID_01_LTE 1
#define MSA_SEND_ID_02_LTE 2
#define MSA_SEND_ID_03_LTE 3
#define MSA_SEND_ID_04_LTE 4
#define MSA_SEND_ID_05_LTE 5
#define MSA_SEND_ID_06_LTE 6
#define MSA_SEND_ID_07_LTE 7
#define MSA_SEND_ID_08_LTE 8
// LTE送受信用FIOバッファ指定
#define MSA_LTE_SEND_FIFO_BUF_BASE 16
#define MSA_LTE_RECV_FIFO_BUF_BASE 24
#define MSA_FIFO_BUF_01_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+0
#define MSA_FIFO_BUF_01_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+0
#define MSA_FIFO_BUF_02_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+1
#define MSA_FIFO_BUF_02_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+1
#define MSA_FIFO_BUF_03_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+2
#define MSA_FIFO_BUF_03_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+2
#define MSA_FIFO_BUF_04_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+3
#define MSA_FIFO_BUF_04_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+3
#define MSA_FIFO_BUF_05_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+4
#define MSA_FIFO_BUF_05_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+4
#define MSA_FIFO_BUF_06_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+5
#define MSA_FIFO_BUF_06_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+5
#define MSA_FIFO_BUF_07_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+6
#define MSA_FIFO_BUF_07_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+6
#define MSA_FIFO_BUF_08_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+7
#define MSA_FIFO_BUF_08_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+7
// LTE送信ID登録APIの有効化設定
#define MSA_SID_API_UNREGISTERED 0
#define MSA_SID_API_REGISTERED 1
// LTE送信ID登録APIのデータ受信登録なしの設定ち
#define MSA_SID_API_RECEIVE_DISABLE 0 // 送信のみの利用(送信結果通知もデータ受信も不要の場合)
#define MSA_SID_API_RECEIVE_RESULT_ENABLE 1 // 送信と送信結果通知の利用(データ受信は不要の場合)
#define MSA_SID_API_RECEIVE_DATA_ENABLE 2 // 送信とデータ受信の利用(送信結果通知は不要の場合)
#define MSA_SID_API_RECEIVE_ALL_ENABLE 3 // 送信と送信結果通知とデータ受信の利用
// LTE送信ID登録APIのエラーコード
#define MSA_SID_API_ERR_NO_CONFIG 100 // プロトコル設定が無い(NOT_USEを指定している)
#define MSA_SID_API_ERR_OUT_OF_RANGE 101 // 設定値が範囲外
#define MSA_SID_API_ERR_ALREADY_SET 102 // 登録済みの送信ID指定
#define MSA_SID_API_ERR_SBUF_CREATE 103 // 送信バッファの作成失敗
#define MSA_SID_API_ERR_RBUF_CREATE 104 // 受信バッファの作成失敗
#define MSA_SID_API_ERR_NO_RECEPTION 105 // 圏外により送信せず
#define MSA_SID_API_ERR_LTE_SEND_FAIL 106 // LTEデータ送信成功数0
// 登録/解除の設定値
#define MSA_ALWAYS_CONN_UNREGIST 0
#define MSA_ALWAYS_CONN_REGIST 1

#else

//////////////////////////////////////////////////////////////////
// *** define declaration for recipe users *** //
//////////////////////////////////////////////////////////////////
#include "taskid.h"
#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// Initialize
#define MSA_EVENT_UNSYNC_INIT 0
func sys_api_MSA_Init() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_MODEM_SAPP,MSA_EVENT_UNSYNC_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define MSA_Init() sys_api_MSA_Init()
// Set LTE send id
#define MSA_EVENT_SYNC_SET_LTE_SEND_ID 256
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_MSA_SetLteSendId(uint8 send_id, uint8 recv_mode, uint8 send_res_event_id, uint8 recv_data_event_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,send_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,recv_mode);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,send_res_event_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,recv_data_event_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_MODEM_SAPP,MSA_EVENT_SYNC_SET_LTE_SEND_ID,EAPI_SYNC_RESULT,60000));
}
#define MSA_SetLteSendId(send_id,recv_mode,send_res_event_id,recv_data_event_id) sys_api_MSA_SetLteSendId(send_id,recv_mode,send_res_event_id,recv_data_event_id)
#endif // YIELD_TO_BASIC_INFOROMATION
// Send USB camera image
#define MSA_EVENT_UNSYNC_SEND_CAMERA_IMAGE 257
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_MSA_SendCameraImage(uint8 send_id, uint16 mov_target) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,send_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,mov_target);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_MODEM_SAPP,MSA_EVENT_UNSYNC_SEND_CAMERA_IMAGE,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define MSA_SendCameraImage(send_id,mov_target) sys_api_MSA_SendCameraImage(send_id,mov_target)
#endif // YIELD_TO_BASIC_INFOROMATION
// Set always connect send id
#define MSA_EVENT_UNSYNC_SET_ALWAYS_CONNECT 258
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_MSA_SetAlwaysConnect(uint8 event_id, uint8 send_id, uint8 regist) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,event_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,send_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,regist);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_MODEM_SAPP,MSA_EVENT_UNSYNC_SET_ALWAYS_CONNECT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define MSA_SetAlwaysConnect(event_id,send_id,regist) sys_api_MSA_SetAlwaysConnect(event_id,send_id,regist)
#endif // YIELD_TO_BASIC_INFOROMATION
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// LTE送信ID
#define MSA_SEND_ID_01_LTE 1
#define MSA_SEND_ID_02_LTE 2
#define MSA_SEND_ID_03_LTE 3
#define MSA_SEND_ID_04_LTE 4
#define MSA_SEND_ID_05_LTE 5
#define MSA_SEND_ID_06_LTE 6
#define MSA_SEND_ID_07_LTE 7
#define MSA_SEND_ID_08_LTE 8
// LTE送受信用FIOバッファ指定
#define MSA_LTE_SEND_FIFO_BUF_BASE 16
#define MSA_LTE_RECV_FIFO_BUF_BASE 24
#define MSA_FIFO_BUF_01_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+0
#define MSA_FIFO_BUF_01_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+0
#define MSA_FIFO_BUF_02_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+1
#define MSA_FIFO_BUF_02_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+1
#define MSA_FIFO_BUF_03_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+2
#define MSA_FIFO_BUF_03_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+2
#define MSA_FIFO_BUF_04_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+3
#define MSA_FIFO_BUF_04_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+3
#define MSA_FIFO_BUF_05_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+4
#define MSA_FIFO_BUF_05_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+4
#define MSA_FIFO_BUF_06_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+5
#define MSA_FIFO_BUF_06_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+5
#define MSA_FIFO_BUF_07_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+6
#define MSA_FIFO_BUF_07_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+6
#define MSA_FIFO_BUF_08_LTE_SEND MSA_LTE_SEND_FIFO_BUF_BASE+7
#define MSA_FIFO_BUF_08_LTE_RECV MSA_LTE_RECV_FIFO_BUF_BASE+7
// LTE送信ID登録APIの有効化設定
#define MSA_SID_API_UNREGISTERED 0
#define MSA_SID_API_REGISTERED 1
// LTE送信ID登録APIのデータ受信登録なしの設定ち
#define MSA_SID_API_RECEIVE_DISABLE 0 // 送信のみの利用(送信結果通知もデータ受信も不要の場合)
#define MSA_SID_API_RECEIVE_RESULT_ENABLE 1 // 送信と送信結果通知の利用(データ受信は不要の場合)
#define MSA_SID_API_RECEIVE_DATA_ENABLE 2 // 送信とデータ受信の利用(送信結果通知は不要の場合)
#define MSA_SID_API_RECEIVE_ALL_ENABLE 3 // 送信と送信結果通知とデータ受信の利用
// LTE送信ID登録APIのエラーコード
#define MSA_SID_API_ERR_NO_CONFIG 100 // プロトコル設定が無い(NOT_USEを指定している)
#define MSA_SID_API_ERR_OUT_OF_RANGE 101 // 設定値が範囲外
#define MSA_SID_API_ERR_ALREADY_SET 102 // 登録済みの送信ID指定
#define MSA_SID_API_ERR_SBUF_CREATE 103 // 送信バッファの作成失敗
#define MSA_SID_API_ERR_RBUF_CREATE 104 // 受信バッファの作成失敗
#define MSA_SID_API_ERR_NO_RECEPTION 105 // 圏外により送信せず
#define MSA_SID_API_ERR_LTE_SEND_FAIL 106 // LTEデータ送信成功数0
// 登録/解除の設定値
#define MSA_ALWAYS_CONN_UNREGIST 0
#define MSA_ALWAYS_CONN_REGIST 1

#endif

#endif
