///
// @file serialAPI.h
// @brief header file generate from sapp_serial.kra
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef _SAPP_SERIAL_KRA_
#define _SAPP_SERIAL_KRA_

#ifdef C_SYNTAX
#define KC_EXPAND_RECIPE
#endif // C_SYNTAX

#ifndef KC_EXPAND_RECIPE

//////////////////////////////////////////////////////////////////
// *** define declaration that is not for recipe users *** //
//////////////////////////////////////////////////////////////////

#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define SIO_API_INIT 0
#define SIO_Init() \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// データ受信イベント通知指定
#define SIO_API_REGIST 256
#define SIO_Regist(device_id,sw,event_id) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_REGIST,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,sw,EAPI_VTYPE_U8,event_id)
#define SIO_API_SET_SEPARATE_MODE_CODE 257
#define SIO_SetSeparateModeCode(device_id,code) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_SET_SEPARATE_MODE_CODE,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,code)
#define SIO_API_SET_SEPARATE_MODE_SIZE 258
#define SIO_SetSeparateModeSize(device_id,size) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_SET_SEPARATE_MODE_SIZE,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U16,size)
// データ受信通知
#define SIO_NOTIFY_RS485 259
#define SIO_NotifyRxRS485() \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_NOTIFY_RS485,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
#define SIO_NOTIFY_RS232 260
#define SIO_NotifyRxRS232() \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_NOTIFY_RS232,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
#define SIO_NOTIFY_CAN 261
#define SIO_NotifyRxCAN(identifier) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_NOTIFY_CAN,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U32,identifier)
// 通信設定(UART)
#define SIO_API_SET_UART_MODE 262
#define SIO_SetUartMode(device_id,baudrate,parity) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_SET_UART_MODE,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U32,baudrate,EAPI_VTYPE_U8,parity)
// 通信設定(CAN)
#define SIO_API_SET_CAN_MODE 263
#define SIO_SetCanMode(device_id) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_SET_CAN_MODE,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,device_id)
// Modbus API
#define SIO_API_MODBUS_INTERFACE_SETTINGS 264
#define SIO_ModbusInterfaceSettings(echo,fifoid) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_INTERFACE_SETTINGS,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,echo,EAPI_VTYPE_U8,fifoid)
#define SIO_API_MODBUS_READ_COIL_STATUS 265
#define SIO_ModbusReadCoilStatus(device_id,server,addr,bitqty) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_READ_COIL_STATUS,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,server,EAPI_VTYPE_U16,addr,EAPI_VTYPE_U16,bitqty)
#define SIO_API_MODBUS_READ_INPUT_STATUS 266
#define SIO_ModbusReadInputStatus(device_id,server,addr,bitqty) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_READ_INPUT_STATUS,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,server,EAPI_VTYPE_U16,addr,EAPI_VTYPE_U16,bitqty)
#define SIO_API_MODBUS_READ_HOLDING_REGISTER 267
#define SIO_ModbusReadHoldingRegister(device_id,server,addr,regqty) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_READ_HOLDING_REGISTER,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,server,EAPI_VTYPE_U16,addr,EAPI_VTYPE_U16,regqty)
#define SIO_API_MODBUS_READ_INPUT_REGISTER 268
#define SIO_ModbusReadInputRegister(device_id,server,addr,regqty) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_READ_INPUT_REGISTER,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,server,EAPI_VTYPE_U16,addr,EAPI_VTYPE_U16,regqty)
#define SIO_API_MODBUS_FORCE_SINGLE_COIL 269
#define SIO_ModbusForceSingleCoil(device_id,server,addr,coil) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_FORCE_SINGLE_COIL,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,server,EAPI_VTYPE_U16,addr,EAPI_VTYPE_U8,coil)
#define SIO_API_MODBUS_WRITE_SINGLE_REGISTER 270
#define SIO_ModbusWriteSingleRegister(device_id,server,addr,regval) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_WRITE_SINGLE_REGISTER,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,server,EAPI_VTYPE_U16,addr,EAPI_VTYPE_U16,regval)
#define SIO_API_MODBUS_DIAGNOSTICS 271
#define SIO_ModbusDiagnostics(device_id,server,subfunc,data) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_DIAGNOSTICS,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,server,EAPI_VTYPE_U16,subfunc,EAPI_VTYPE_U16,data)
#define SIO_API_MODBUS_WRITE_MULTIPLE_REGISTERS 272
#define SIO_ModbusWriteMultipleRegisters(device_id,server,addr,regqty) \
  EAPI_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_WRITE_MULTIPLE_REGISTERS,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED,EAPI_VTYPE_U8,device_id,EAPI_VTYPE_U8,server,EAPI_VTYPE_U16,addr,EAPI_VTYPE_U16,regqty)
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 受信バッファ
#define SIO_RX_BUFFSIZE 512
// 1行最大サイズ
#define SIO_API_BUFFSIZE 1024
// シリアル送信Timeout
#define SIO_SEND_DATA_TIMEOUT 5000
// シリアルデバイス識別(device_id) ※KRDEFINE_EXTDEV_XXのdefineと番号を合わせること
#define SIO_DEVICE_RS485 0
#define SIO_DEVICE_RS232 1
#define SIO_DEVICE_CAN 2
#define SIO_DEVICE_RS485_2WIRE 5
// レジスト(sw)
#define SIO_BIND 1
#define SIO_RELEASE 0
// UART Parity
#define SIO_UART_PARITY_NONE 0
#define SIO_UART_PARITY_EVEN 1
#define SIO_UART_PARITY_ODD 2
// Modbus Echo cancel
#define SIO_MODBUS_RS485_HW_ECHO_CANCEL 0
#define SIO_MODBUS_RS485_SW_ECHO_CANCEL 1
// Modbus エラーコード
#define SIO_MODBUS_NO_ERROR 0                   // 0x00 : エラーなし
#define SIO_MODBUS_ERROR_RCV_ECHO 0x01          // 0x01 : エコーバック内容違い
#define SIO_MODBUS_ERROR_RCV_HEAD 0x02          // 0x02 : 応答メッセージヘッダ違い
#define SIO_MODBUS_ERROR_RCV_CRC 0x03           // 0x03 : 応答CRC違い
#define SIO_MODBUS_ERROR_SND_CMD 0x04           // 0x04 : コマンド送信エラー
#define SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 0x05   // 0x05 : バッファ未設定
#define SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 0x06  // 0x06 : バッファへデータ設定エラー
#define SIO_MODBUS_ERROR_RCV_RESP 0x07          // 0x07 : エラーレスポンス受信
#define SIO_MODBUS_ERROR_RCV_TIMEOUT 0xC8       // 0xC8 : 受信タイムアウト
// Modbus送信データ最大サイズ
#define SIO_MODBUS_TX_DATA_SIZE 256
// Modbus受信データ最大サイズ
#define SIO_MODBUS_RX_DATA_SIZE 256

#else

//////////////////////////////////////////////////////////////////
// *** define declaration for recipe users *** //
//////////////////////////////////////////////////////////////////
#include "taskid.h"
#include "eventLib.h"

#include "krdefine.h"
//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define SIO_API_INIT 0
func sys_api_SIO_Init() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define SIO_Init() sys_api_SIO_Init()
// データ受信イベント通知指定
#define SIO_API_REGIST 256
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_Regist(uint8 device_id, uint8 sw, uint8 event_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,sw);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,event_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_REGIST,EAPI_SYNC_RESULT,1000));
}
#define SIO_Regist(device_id,sw,event_id) sys_api_SIO_Regist(device_id,sw,event_id)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_SET_SEPARATE_MODE_CODE 257
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_SetSeparateModeCode(uint8 device_id, uint8 code) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,code);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_SET_SEPARATE_MODE_CODE,EAPI_SYNC_RESULT,1000));
}
#define SIO_SetSeparateModeCode(device_id,code) sys_api_SIO_SetSeparateModeCode(device_id,code)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_SET_SEPARATE_MODE_SIZE 258
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_SetSeparateModeSize(uint8 device_id, uint16 size) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,size);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_SET_SEPARATE_MODE_SIZE,EAPI_SYNC_RESULT,1000));
}
#define SIO_SetSeparateModeSize(device_id,size) sys_api_SIO_SetSeparateModeSize(device_id,size)
#endif // YIELD_TO_BASIC_INFOROMATION
// データ受信通知
#define SIO_NOTIFY_RS485 259
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_NotifyRxRS485() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_NOTIFY_RS485,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define SIO_NotifyRxRS485() sys_api_SIO_NotifyRxRS485()
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_NOTIFY_RS232 260
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_NotifyRxRS232() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_NOTIFY_RS232,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define SIO_NotifyRxRS232() sys_api_SIO_NotifyRxRS232()
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_NOTIFY_CAN 261
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_NotifyRxCAN(uint32 identifier) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,identifier);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_NOTIFY_CAN,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define SIO_NotifyRxCAN(identifier) sys_api_SIO_NotifyRxCAN(identifier)
#endif // YIELD_TO_BASIC_INFOROMATION
// 通信設定(UART)
#define SIO_API_SET_UART_MODE 262
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_SetUartMode(uint8 device_id, uint32 baudrate, uint8 parity) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,baudrate);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,parity);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_SET_UART_MODE,EAPI_SYNC_RESULT,1000));
}
#define SIO_SetUartMode(device_id,baudrate,parity) sys_api_SIO_SetUartMode(device_id,baudrate,parity)
#endif // YIELD_TO_BASIC_INFOROMATION
// 通信設定(CAN)
#define SIO_API_SET_CAN_MODE 263
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_SetCanMode(uint8 device_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_SET_CAN_MODE,EAPI_SYNC_RESULT,1000));
}
#define SIO_SetCanMode(device_id) sys_api_SIO_SetCanMode(device_id)
#endif // YIELD_TO_BASIC_INFOROMATION
// Modbus API
#define SIO_API_MODBUS_INTERFACE_SETTINGS 264
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_ModbusInterfaceSettings(uint8 echo, uint8 fifoid) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,echo);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,fifoid);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_INTERFACE_SETTINGS,EAPI_SYNC_RESULT,1000));
}
#define SIO_ModbusInterfaceSettings(echo,fifoid) sys_api_SIO_ModbusInterfaceSettings(echo,fifoid)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_MODBUS_READ_COIL_STATUS 265
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_ModbusReadCoilStatus(uint8 device_id, uint8 server, uint16 addr, uint16 bitqty) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,server);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,addr);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,bitqty);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_READ_COIL_STATUS,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED));
}
#define SIO_ModbusReadCoilStatus(device_id,server,addr,bitqty) sys_api_SIO_ModbusReadCoilStatus(device_id,server,addr,bitqty)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_MODBUS_READ_INPUT_STATUS 266
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_ModbusReadInputStatus(uint8 device_id, uint8 server, uint16 addr, uint16 bitqty) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,server);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,addr);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,bitqty);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_READ_INPUT_STATUS,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED));
}
#define SIO_ModbusReadInputStatus(device_id,server,addr,bitqty) sys_api_SIO_ModbusReadInputStatus(device_id,server,addr,bitqty)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_MODBUS_READ_HOLDING_REGISTER 267
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_ModbusReadHoldingRegister(uint8 device_id, uint8 server, uint16 addr, uint16 regqty) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,server);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,addr);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,regqty);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_READ_HOLDING_REGISTER,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED));
}
#define SIO_ModbusReadHoldingRegister(device_id,server,addr,regqty) sys_api_SIO_ModbusReadHoldingRegister(device_id,server,addr,regqty)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_MODBUS_READ_INPUT_REGISTER 268
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_ModbusReadInputRegister(uint8 device_id, uint8 server, uint16 addr, uint16 regqty) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,server);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,addr);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,regqty);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_READ_INPUT_REGISTER,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED));
}
#define SIO_ModbusReadInputRegister(device_id,server,addr,regqty) sys_api_SIO_ModbusReadInputRegister(device_id,server,addr,regqty)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_MODBUS_FORCE_SINGLE_COIL 269
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_ModbusForceSingleCoil(uint8 device_id, uint8 server, uint16 addr, uint8 coil) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,server);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,addr);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,coil);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_FORCE_SINGLE_COIL,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED));
}
#define SIO_ModbusForceSingleCoil(device_id,server,addr,coil) sys_api_SIO_ModbusForceSingleCoil(device_id,server,addr,coil)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_MODBUS_WRITE_SINGLE_REGISTER 270
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_ModbusWriteSingleRegister(uint8 device_id, uint8 server, uint16 addr, uint16 regval) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,server);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,addr);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,regval);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_WRITE_SINGLE_REGISTER,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED));
}
#define SIO_ModbusWriteSingleRegister(device_id,server,addr,regval) sys_api_SIO_ModbusWriteSingleRegister(device_id,server,addr,regval)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_MODBUS_DIAGNOSTICS 271
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_ModbusDiagnostics(uint8 device_id, uint8 server, uint16 subfunc, uint16 data) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,server);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,subfunc);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,data);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_DIAGNOSTICS,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED));
}
#define SIO_ModbusDiagnostics(device_id,server,subfunc,data) sys_api_SIO_ModbusDiagnostics(device_id,server,subfunc,data)
#endif // YIELD_TO_BASIC_INFOROMATION
#define SIO_API_MODBUS_WRITE_MULTIPLE_REGISTERS 272
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_SIO_ModbusWriteMultipleRegisters(uint8 device_id, uint8 server, uint16 addr, uint16 regqty) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,device_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,server);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,addr);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,regqty);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_SIO,SIO_API_MODBUS_WRITE_MULTIPLE_REGISTERS,EAPI_SYNC_RESULT,EAPI_TIMEOUT_UNLIMITED));
}
#define SIO_ModbusWriteMultipleRegisters(device_id,server,addr,regqty) sys_api_SIO_ModbusWriteMultipleRegisters(device_id,server,addr,regqty)
#endif // YIELD_TO_BASIC_INFOROMATION
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// 受信バッファ
#define SIO_RX_BUFFSIZE 512
// 1行最大サイズ
#define SIO_API_BUFFSIZE 1024
// シリアル送信Timeout
#define SIO_SEND_DATA_TIMEOUT 5000
// シリアルデバイス識別(device_id) ※KRDEFINE_EXTDEV_XXのdefineと番号を合わせること
#define SIO_DEVICE_RS485 0
#define SIO_DEVICE_RS232 1
#define SIO_DEVICE_CAN 2
#define SIO_DEVICE_RS485_2WIRE 5
// レジスト(sw)
#define SIO_BIND 1
#define SIO_RELEASE 0
// UART Parity
#define SIO_UART_PARITY_NONE 0
#define SIO_UART_PARITY_EVEN 1
#define SIO_UART_PARITY_ODD 2
// Modbus Echo cancel
#define SIO_MODBUS_RS485_HW_ECHO_CANCEL 0
#define SIO_MODBUS_RS485_SW_ECHO_CANCEL 1
// Modbus エラーコード
#define SIO_MODBUS_NO_ERROR 0                   // 0x00 : エラーなし
#define SIO_MODBUS_ERROR_RCV_ECHO 0x01          // 0x01 : エコーバック内容違い
#define SIO_MODBUS_ERROR_RCV_HEAD 0x02          // 0x02 : 応答メッセージヘッダ違い
#define SIO_MODBUS_ERROR_RCV_CRC 0x03           // 0x03 : 応答CRC違い
#define SIO_MODBUS_ERROR_SND_CMD 0x04           // 0x04 : コマンド送信エラー
#define SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 0x05   // 0x05 : バッファ未設定
#define SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 0x06  // 0x06 : バッファへデータ設定エラー
#define SIO_MODBUS_ERROR_RCV_RESP 0x07          // 0x07 : エラーレスポンス受信
#define SIO_MODBUS_ERROR_RCV_TIMEOUT 0xC8       // 0xC8 : 受信タイムアウト
// Modbus送信データ最大サイズ
#define SIO_MODBUS_TX_DATA_SIZE 256
// Modbus受信データ最大サイズ
#define SIO_MODBUS_RX_DATA_SIZE 256
// [rcplib]RS485もしくはRS232Cにデータを送信
#define SIO_SendDataSerial(device_id,data,data_size) rcplib_UART_Transmit(device_id,data,data_size,SIO_SEND_DATA_TIMEOUT)
// [rcplib]CANにデータを送信
#define SIO_SendDataCAN(data,data_size,can_id) rcplib_CAN_Transmit(KRDEFINE_EXTDEV_CAN1,data,data_size,can_id)

#endif

#endif
