﻿/**
 * @file eventLib.h
 * @brief queue event library
 * @details queue push/pop control
 * @author This software is contributed or developed by KYOCERA Corporation.
 * @copyright (C) 2022 KYOCERA Corporation
 * 
 * SPDX-License-Identifier: MIT
 * 
 */
/* Define to prevent recursive inclusion -----------------------*/
#ifndef __EVENTLIB_H__
#define __EVENTLIB_H__

/****************************************************************/
/* include header file */
/****************************************************************/
#include "svitem.h"

/****************************************************************/
/* common define */
/****************************************************************/
// タイムアウト
#define EAPI_TIMEOUT_UNLIMITED -1
#define EAPI_TIMEOUT_ZERO 0
// 同期実行
#define EAPI_SYNC_RESULT 0x00
#define EAPI_UNSYNC_NORESULT 0xff
// 強制停止
#define EAPI_EVENT_TASK_ENTER_FORCESTOP 60000
#define EAPI_EVENT_TASK_RESUME_FORCESTOP 60001
// 機能制限
#define EAPI_EVENT_TASK_ENTER_LIMIT 60002
#define EAPI_EVENT_TASK_RESUME_LIMIT 60003

/****************************************************************/
/* common typedef (other than enum/struct/union) */
/****************************************************************/

/****************************************************************/
/* common enum */
/****************************************************************/
// エラーリザルト値
#define EAPI_NO_ERROR 0
#define EAPI_ERR_TIMEOUT 200
#define EAPI_ERR_QUEUEFULL 201
#define EAPI_ERR_TASKNOMATCH 202
#define EAPI_ERR_BADSYNC 203
#define EAPI_ERR_BADEVENT 204
#define EAPI_ERR_FORCESTOP 205
#define EAPI_ERR_UNKNOWN 255

// 引数アイテム型定義
#define EAPI_VTYPE_I8 1
#define EAPI_VTYPE_I16 2
#define EAPI_VTYPE_I32 3
#define EAPI_VTYPE_I64 4
#define EAPI_VTYPE_U8 5
#define EAPI_VTYPE_U16 6
#define EAPI_VTYPE_U32 7
#define EAPI_VTYPE_U64 8
#define EAPI_VTYPE_F32 9
#define EAPI_VTYPE_F64 10
#define EAPI_VTYPE_STR 11

/****************************************************************/
/* common struct/union */
/****************************************************************/

/****************************************************************/
/* common variable */
/****************************************************************/

/****************************************************************/
/* common function */
/****************************************************************/

/****************************************************************/
/* common macro */
/****************************************************************/
#define rcplib_TASK_SendEventToThisTask(x) rcplib_TASK_SendEvent(rcplib_SV_Read(ENGINE_SVITEM_ID_MYID), x, EAPI_UNSYNC_NORESULT, EAPI_TIMEOUT_ZERO)

/* Define to prevent recursive inclusion -----------------------*/
#endif
