﻿/**
 * @file flashLib.h
 * @brief flash library header file
 * @details
 * @author This software is contributed or developed by KYOCERA Corporation.
 * @copyright (C) 2022 KYOCERA Corporation
 * 
 * SPDX-License-Identifier: MIT
 * 
*/
/* Define to prevent recursive inclusion -----------------------*/
#ifndef FLASHLIB_FLASHLIB_H_
#define FLASHLIB_FLASHLIB_H_

/****************************************************************/
/* include header file */
/****************************************************************/

/****************************************************************/
/* common define */
/****************************************************************/
// model型番 (製品型番をASCII文字で"KC4-C-100A")
#define NV_RO_MODEL_NO 9                           // [ReadOnly] index数:1 size:24
// Reserved
#define NV_RO_MODEL_SERIALNO 10
// BluetoothのMACアドレス
#define NV_RO_BLE_MAC 30                           // [ReadOnly] index数:1 size:6
// Reserved
#define NV_RW_CAL_ACC_OFS 39
// Reserved
#define NV_RW_CAL_GYRO_OFS 40
// Reserved
#define NV_RW_CAL_HIGACC_OFS 41
// レシピ実行ファイルのビルド日時JST
#define NV_RCP_FOTA_INFO_TIME 44                   // [ReadOnly] index数:1 size:13
// TLS通信で利用するCA証明書
#define NV_RW_USER_ROOT_CA (0x100 +11)             // [ReadWrite] index数:3 size:5120
// TLS通信で利用するクライアント証明書
#define NV_RW_USER_CRIENT_CERT (0x100 +12)         // [ReadWrite] index数:3 size:5120
// TLS通信で利用する秘密鍵
#define NV_RW_USER_PRIVATE_KEY (0x100 +13)         // [ReadWrite] index数:3 size:5120
// BLE受信時の窓幅設定
#define NV_RW_BLE_SCAN_WINDOW_WIDTH (0x100 +14)    // [ReadWrite] index数:1 size:5120
// BLE受信時の受信間隔設定
#define NV_RW_BLE_SCAN_INTERVAL (0x100 +15)        // [ReadWrite] index数:1 size:4
// BLE受信時のRSSI閾値
#define NV_RW_BLE_SCAN_DETECT_RSSI (0x100 +16)     // [ReadWrite] index数:1 size:4
// BLE送信時の送信間隔設定
#define NV_RW_BLE_SEND_INTERVAL (0x100 +17)        // [ReadWrite] index数:1 size:4
// BLE受信時のiBeacon受信機能の不感帯期間設定
#define NV_RW_STATIC_BCON_CLEAR_METHOD (0x100 +18) // [ReadWrite] index数:1 size:4
// Reserved
#define NV_RW_GPS_CLEAR_METHOD (0x100 +19)
// BLE受信時のセンサービーコン受信機能の不感帯期間設定
#define NV_RW_SENSOR_CLEAR_METHOD (0x100 +20)      // [ReadWrite] index数:1 size:4
// Reserved
#define NV_RW_BCON_PARAM (0x100 +21)
// BLE Long Range受信時のフィルターマスク設定
#define NV_RW_BLE_LONG_MASK (0x100 +22)            // [ReadWrite] index数:2 size:256
// BLE Long Range受信時のフィルター値設定
#define NV_RW_BLE_LONG_FILT (0x100 +23)            // [ReadWrite] index数:2 size:256
// ユーザー向けデータ
#define NV_RW_USER_DATA (0x100 +24)                // [ReadWrite] index数:1 size:4096
// クラウドサービス接続で利用する秘密鍵
#define NV_RW_USER_CLOUD_KEY (0x100 +27)           // [ReadWrite] index数:10 size:384
// クラウドサービス接続で利用する秘密鍵のサイズ
#define NV_RW_USER_CLOUD_KEY_SIZE (0x100 +28)      // [ReadWrite] index数:10 size:2
// クラウドサービス接続で利用するアクセス情報
#define NV_RW_USER_CLOUD_ACCESS_INFO (0x100 +29)   // [ReadWrite] index数:10 size:256
// クラウドサービス接続で利用するアクセス情報のサイズ
#define NV_RW_USER_CLOUD_ACCESS_INFO_SIZE (0x100 +30) // [ReadWrite] index数:10 size:2
// クラウドサービス接続で利用するその他の情報
#define NV_RW_USER_CLOUD_OTHER_INFO (0x100 +31)       // [ReadWrite] index数:10 size:128
// クラウドサービス接続で利用するその他の情報のサイズ
#define NV_RW_USER_CLOUD_OTHER_INFO_SIZE (0x100 +32)  // [ReadWrite] index数:10 size:2
// TLS通信で利用するPSK_Identity
#define NV_RW_USER_PSK_IDENTITY (0x100 +33)           // [ReadWrite] index数:3 size:64
// TLS通信で利用するPSK鍵
#define NV_RW_USER_PSK_KEY (0x100 +34)                // [ReadWrite] index数:3 size:64

/****************************************************************/
/* common typedef (other than enum/struct/union) */
/****************************************************************/

/****************************************************************/
/* common enum */
/****************************************************************/

/****************************************************************/
/* common struct/union */
/****************************************************************/

/****************************************************************/
/* common variable */
/****************************************************************/

/****************************************************************/
/* common function */
/****************************************************************/

/****************************************************************/
/* common macro */
/****************************************************************/

/* Define to prevent recursive inclusion -----------------------*/
#endif
