/**
 * @file main.h
 * @brief main
 * @details 
 * @author This software is contributed or developed by KYOCERA Corporation.
 * @copyright (C) 2022 KYOCERA Corporation
 * 
 * SPDX-License-Identifier: MIT
 * 
 */
/* Define to prevent recursive inclusion -----------------------*/
#ifndef __MAIN_H__
#define __MAIN_H__

/****************************************************************/
/* include header file */
/****************************************************************/
#include "stm32h753xx.h"
#include "stm32h7xx.h"
#include "stm32h7xx_hal_i2c.h"
#include "stm32h7xx_hal_gpio.h"
#include "stm32h7xx_hal_uart.h"
#include "stm32h7xx_hal_uart_ex.h"
#include "stm32h7xx_hal_fdcan.h"

/****************************************************************/
/* common define */
/****************************************************************/
//---- main.h ----

// センサ割込み検出ポート1[Config:可, Read:可, Write:可]
#define ACC_INT1_GPIO_Port GPIOI
#define ACC_INT1_Pin GPIO_PIN_14
#define ACC_INT1_EXTI_IRQn EXTI15_10_IRQn

// センサ割込み検出ポート2[Config:可, Read:可, Write:可]
#define ACC_INT2_GPIO_Port GPIOK
#define ACC_INT2_Pin GPIO_PIN_5
#define ACC_INT2_EXTI_IRQn EXTI9_5_IRQn

// センサ電源制御ポート[Config:不可, Read:可, Write:可]
#define ACC_PWR_ON_GPIO_Port GPIOJ
#define ACC_PWR_ON_Pin GPIO_PIN_12


// 接点入力ポート1(ピンコネクタGPI01)[Config:不可, Read:可, Write:不可]
#define EXT_USER_GPI1_GPIO_Port GPIOC
#define EXT_USER_GPI1_Pin GPIO_PIN_1

// 接点出力ポート1(ピンコネクタGPI01)[Config:不可, Read:不可, Write:可]
#define EXT_USER_GPO1_GPIO_Port GPIOK
#define EXT_USER_GPO1_Pin GPIO_PIN_1

// 接点入力ポート1(ピンコネクタGPI02)[Config:不可, Read:可, Write:不可]
#define EXT_USER_GPI2_GPIO_Port GPIOC
#define EXT_USER_GPI2_Pin GPIO_PIN_9

// 接点出力ポート1(ピンコネクタGPI02)[Config:不可, Read:不可, Write:可]
#define EXT_USER_GPO2_GPIO_Port GPIOG
#define EXT_USER_GPO2_Pin GPIO_PIN_7

// 接点入力ポート3(ピンコネクタGPI)[Config:不可, Read:可, Write:不可]
#define EXT_USER_GPI3_GPIO_Port GPIOH
#define EXT_USER_GPI3_Pin GPIO_PIN_7


// RS-485 Driver Enableポート[Config:不可, Read:不可, Write:可]
#define EXT_UART5_DE_GPIO_Port GPIOC
#define EXT_UART5_DE_Pin GPIO_PIN_8

// RS-485 Receive Enableポート[Config:不可, Read:不可, Write:可]
#define EXT_UART5_RE_GPIO_Port GPIOE
#define EXT_UART5_RE_Pin GPIO_PIN_4

// RS-232C CTSポート[Config:不可, Read:可, Write:不可]
#define EXT_USER_USART6_CTS_GPIO_Port GPIOG
#define EXT_USER_USART6_CTS_Pin GPIO_PIN_13

// RS-232C RTSポート[Config:不可, Read:不可, Write:可]
#define EXT_USER_USART6_RTS_GPIO_Port GPIOG
#define EXT_USER_USART6_RTS_Pin GPIO_PIN_12

// RS-232C Shutdownポート[Config:不可, Read:不可, Write:可]
#define EXT_SERIAL_PWRDOWN_GPIO_Port GPIOJ
#define EXT_SERIAL_PWRDOWN_Pin GPIO_PIN_0

// RS-232C Enableポート[Config:不可, Read:不可, Write:可]
#define EXT_SERIAL_EN_GPIO_Port GPIOE
#define EXT_SERIAL_EN_Pin GPIO_PIN_3


// CAN Standby制御ポート[Config:不可, Read:不可, Write:可]
#define EXT_CAN_STB_GPIO_Port GPIOA
#define EXT_CAN_STB_Pin GPIO_PIN_15

// CAN Shutdown制御ポート[Config:不可, Read:不可, Write:可]
#define EXT_CAN_SHDN_GPIO_Port GPIOK
#define EXT_CAN_SHDN_Pin GPIO_PIN_6


// 外部ポート用電源制御[Config:不可, Read:不可, Write:可]
#define EXT_BUF_POW_ON_GPIO_Port GPIOJ
#define EXT_BUF_POW_ON_Pin GPIO_PIN_15


// USB type-A VBUS出力制御[Config:不可, Read:不可, Write:可]
#define EXT_VBUS_OUT_EN_GPIO_Port GPIOB
#define EXT_VBUS_OUT_EN_Pin GPIO_PIN_14


// 接点入出力ポートの(port,pin)組み合わせ定義
#define EXT_USER_GPO1  GPIOK,GPIO_PIN_1
#define EXT_USER_GPO2  GPIOG,GPIO_PIN_7
#define EXT_USER_GPI1  GPIOC,GPIO_PIN_1
#define EXT_USER_GPI2  GPIOC,GPIO_PIN_9
#define EXT_USER_GPI3  GPIOH,GPIO_PIN_7

// GPIO設定の定義
#define EXT_USER_GPO_SET_OD  GPIO_PIN_RESET
#define EXT_USER_GPO_SET_LOW GPIO_PIN_SET
#define EXT_USER_GPI_HIGH    GPIO_PIN_RESET
#define EXT_USER_GPI_LOW     GPIO_PIN_SET

// 割込み有効/無効の定義
#define NVIC_IRQ_DISABLE 0
#define NVIC_IRQ_ENABLE 1

#endif
