﻿/**
 * @file modemMgrTask.h
 * @brief modem manager task header file
 * @details Modem manager
 * @author This software is contributed or developed by KYOCERA Corporation.
 * @copyright (C) 2022 KYOCERA Corporation
 * 
 * SPDX-License-Identifier: MIT
 * 
*/
/* Define to prevent recursive inclusion -----------------------*/
#ifndef MODEMMGRTASK_H_
#define MODEMMGRTASK_H_

/****************************************************************/
/* include header file */
/****************************************************************/

/****************************************************************/
/* common define */
/****************************************************************/
#define MDM_STATUS_NUM_MAX 16
#define MMG_SEND_ID_MAX 8
#define MMG_AUTH_ID_MAX 6
#define MMG_CLIENT_ID_MAX 4
#define MMG_MQTTCONN_ID_MAX 4
#define MMG_MQTTSUB_ID_MAX 4
#define MMG_HOST_NAME_MAX 128
#define MMG_URL_MAX 256
#define MMG_HEADER_MAX 768
#define MMG_MQTT_CLIENT_ID_MAX 192
#define MMG_MQTT_USER_NAME_MAX 128
#define MMG_MQTT_USER_PASS_MAX 256
#define MMG_MQTT_WILL_TOPIC_MAX 192
#define MMG_MQTT_WILL_PAYLOAD_MAX 128
#define MMG_MQTT_PUB_TOPIC_MAX 192
#define MMG_MQTT_SUB_TOPIC_MAX 192

#define MMG_MOVIE_BUF_ID 100

#define MMG_MAX_REVISION_SIZE 40  // Maximum string value of revision string
#define MMG_MAX_IMEI_SIZE     16  // byte
#define MMG_MAX_IMSI_SIZE     16  // byte
#define MMG_MAX_NUM_SIZE      16  // byte

// HTTP(S)送信時のURL文字列に利用できるリプレイス文字
#define MMG_URL_REPLACE_TIMESTAMP      "*rp_timestamp****" // LTE送信処理実行時のタイムスタンプを"YYYYMMDDhhmmssddd"という形式でリプレイス ※dddは[msec]
#define MMG_URL_REPLACE_MOVIETIME      "*rp_movietime****" // USBカメラ画像撮影時のタイムスタンプを"YYYYMMDDhhmmssddd"という形式でリプレイス(カメラバッファからのHTTP送信処理の時のみ利用可) ※dddは[msec]
#define MMG_URL_REPLACE_IMEI           "*rp_imei*******"   // 端末のIMEI(15桁の数値の文字列)でリプレイス
#define MMG_URL_REPLACE_ACCESS_INFO    "*rp_access_info**" // reserved
#define MMG_URL_REPLACE_OTHER_INFO     "*rp_other_info***" // reserved

// API実行時のリザルトコード
#define MMG_NO_ERROR                        0   // 正常
#define MMG_WARN_ALREADY_CONNECT            1   // ソケットまたはMQTT接続要求時、既に接続状態
#define MMG_WARN_DATA_RECV_NO_BUF_ASSIGN    2   // データ受信時、受信用FIFOバッファが割り当てられていない
#define MMG_WARN_END                        99  // ワーニングコードのエンドコード
#define MMG_ERR_INVALIDPARAM                100 // API実行時、引数設定値が異常
#define MMG_ERR_ATERROR                     101 // モデムへの命令時、ATコマンドなどのエラー
#define MMG_ERR_ATRETRY                     102 // (システム用定義)
#define MMG_ERR_AUTOFOTA                    103 // API実行時、自動FOTA実行中のため要求を棄却
#define MMG_ERR_NOT_REQUESTED               104 // ソケット送信API実行時、ソケット接続要求をしていないため要求を棄却
#define MMG_ERR_BUSY                        105 // (システム用定義)
#define MMG_ERR_DEVICE_FORCE_OFF            106 // API実行時、機能制限中のため要求を棄却
#define MMG_ERR_CONNECTING_OTHER            107 // ソケット接続またはデータ送信API実行時、異なる送信IDで接続中のため要求を棄却
#define MMG_ERR_NEED_TO_CLOSE               108 // API実行時、一度ソケット切断実行の必要があるため要求を棄却
#define MMG_ERR_NO_CONNECTION               109 // データ送信API実行時、ソケットが切断されているため要求を棄却
#define MMG_ERR_EC25_HAVE_DATA_YET          110 // データ送信API実行時、TCP送信が完了しなかった
#define MMG_ERR_SEND_COMP_BUT_NO_RECEPTION  111 // データ送信API実行時、送信は成功したが基地局との接続が切れた
#define MMG_ERR_SEND_TLS_FAIL               112 // (システム用定義)
#define MMG_ERR_UNSYNC_SOCKET_CLOSE         113 // 要求していないにもかかわらずソケットが切断された際のイベント通知
#define MMG_ERR_UNSYNC_PDP_DEACT            114 // SIMの抜去などPDP認証が無効化された際のイベント通知
#define MMG_ERR_UNSYNC_NO_RECEPTION         115 // 圏外など電界強度が十分ではなくなった際のイベント通知
#define MMG_ERR_NWP_API_ERR                 116 // API実行時、モデム制御関連のエラー
#define MMG_ERR_MQTTSUB_TIMEOUT             118 // MQTT接続API実行時、Subscribe処理でのタイムアウトが発生
#define MMG_ERR_TIMEOUT                     117 // API実行時、タイムアウトが発生
#define MMG_ERR_END                         199 // エラーコードのエンドコード

#define MMG_GET_GNSS_RESULT 99999 // GNSSの有効なデータ以外の通知コード

/****************************************************************/
/* common typedef (other than enum/struct/union) */
/****************************************************************/

/****************************************************************/
/* common enum */
/****************************************************************/
#define MMG_PROTOCOL_UDP 0
#define MMG_PROTOCOL_TCP 1
#define MMG_PROTOCOL_TLS 2
#define MMG_PROTOCOL_HTTP 3
#define MMG_PROTOCOL_HTTPS 4
#define MMG_PROTOCOL_MQTT 5
#define MMG_PROTOCOL_MQTTS 6
#define MMG_PROTOCOL_S3_STORAGE_HTTPS 0x10
#define MMG_PROTOCOL_AZURE_STORAGE_REST_HTTPS 0x11
#define MMG_PROTOCOL_AZURE_IOT_SASTOKEN_HTTPS 0x20
#define MMG_PROTOCOL_GCP_IOT_ES256_HTTPS 0x21
#define MMG_PROTOCOL_AZURE_IOT_SASTOKEN_MQTTS 0x30
#define MMG_PROTOCOL_GCP_IOT_ES256_MQTTS 0x31

#define MMG_NOTCONNECT_USB 0
#define MMG_CONNECT_USB 1

#define MMG_NOTUSE_USB 0
#define MMG_USE_USB 1

#define MMG_SNI_DISABLE 0
#define MMG_SNI_ENABLE 1

#define MMG_SOCKET_CLOSE 0
#define MMG_SOCKET_OPEN 1

#define MMG_SESSION_DISCONNECT 0
#define MMG_SESSION_CONNECT 1

#define MMG_DATA_NOTRETAIN 0
#define MMG_DATA_RETAIN 1

#define MMG_METHOD_HTTPGET 0
#define MMG_METHOD_HTTPPOST 1
#define MMG_METHOD_HTTPHEAD 2
#define MMG_METHOD_HTTPPUT 3
#define MMG_METHOD_HTTPDELETE 4
#define MMG_METHOD_HTTPCONNECT 5
#define MMG_METHOD_HTTPOPTIONS 6
#define MMG_METHOD_HTTPTRACE 7
#define MMG_METHOD_HTTPPATCH 8

#define MMG_MQTT_CLOSE 0
#define MMG_MQTT_OPEN 1

#define MMG_MQTT_CLEAN_DISABLE 0
#define MMG_MQTT_CLEAN_ENABLE 1

#define MMG_MQTT_NOTRETAIN 0
#define MMG_MQTT_RETAIN 1

#define MMG_MQTT_QOS0_AT_MOST_ONCE 0
#define MMG_MQTT_QOS1_AT_LEAST_ONCE 1
#define MMG_MQTT_QOS2_EXACTRY_ONCE 2

#define MMG_FOTAPARAM_QUERY 1
#define MMG_FOTAPARAM_NOTIFY 2
#define MMG_FOTAPARAM_APIKEY 3

#define MMG_AUTH_NONE 0
#define MMG_AUTH_SRV 1
#define MMG_AUTH_SRVCLI 2

#define MMG_AUTH_KIND_CACERT 0
#define MMG_AUTH_KIND_CLIENTCERT 1
#define MMG_AUTH_KIND_CLIENTKEY 2
#define MMG_AUTH_KIND_PSK_ID 3
#define MMG_AUTH_KIND_PSK_KEY 4

#define MMG_CONTEXTID_FOTA 1
#define MMG_CONTEXTID_DATA 2

#define MMG_APN_INDEX_FOTA 0
#define MMG_APN_INDEX_DATA 1
#define MMG_APN_INDEX_RSV1 2
#define MMG_APN_INDEX_RSV2 3

#define MMG_GNSS_END 0
#define MMG_GNSS_START_ONESHOT 1
#define MMG_GNSS_START_POLLING 2

/****************************************************************/
/* common struct/union */
/****************************************************************/

/****************************************************************/
/* common variable */
/****************************************************************/

/****************************************************************/
/* common function */
/****************************************************************/

/****************************************************************/
/* common macro */
/****************************************************************/
//モデムAPIのラッパーマクロ
#define MMG_SetSubscribeParamMQTT(timeout,sync,ex_result,mq_conn_id,mq_sub_id,mq_sub_qos,mq_sub_topic_name,rcv_databuf_id,rcv_event_id) MMG_SetSubscriveParamMQTT(timeout,sync,ex_result,mq_conn_id,mq_sub_id,mq_sub_qos,mq_sub_topic_name,rcv_databuf_id,rcv_event_id)

/* Define to prevent recursive inclusion -----------------------*/
#endif /* MODEMMGRTASK_H_ */
