/**
  ******************************************************************************
  * @file    stm32h753xx.h
  * @author  MCD Application Team
  * @brief   CMSIS STM32H753xx Device Peripheral Access Layer Header File.
  *
  *          This file contains:
  *           - Data structures and the address mapping for all peripherals
  *           - Peripheral's registers declarations and bits definition
  *           - Macros to access peripheral's registers hardware
  *
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; Copyright (c) 2017 STMicroelectronics.
  * All rights reserved.</center></h2>
  *
  * This software component is licensed by ST under BSD 3-Clause license,
  * the "License"; You may not use this file except in compliance with the
  * License. You may obtain a copy of the License at:
  *                        opensource.org/licenses/BSD-3-Clause
  *
  ******************************************************************************
  */
//---- stm32h753xx.h ----

/******  STM32 specific Interrupt Numbers **********************************************************************/
#define EXTI0_IRQn                6      //!< EXTI Line0 interrupt                                              */
#define EXTI1_IRQn                7      //!< EXTI Line1 interrupt                                              */
#define EXTI2_IRQn                8      //!< EXTI Line2 interrupt                                              */
#define EXTI3_IRQn                9      //!< EXTI Line3 interrupt                                              */
#define EXTI4_IRQn                10     //!< EXTI Line4 interrupt                                              */
#define EXTI9_5_IRQn              23     /*!< External Line[9:5] Interrupts                                     */
#define EXTI15_10_IRQn            40     /*!< External Line[15:10] Interrupts                                   */

/** @addtogroup Peripheral_memory_map
  * @{
  */
#define PERIPH_BASE               (0x40000000) /*!< Base address of : AHB/APB Peripherals                                                   */
/*!< Peripheral memory map */
#define D2_APB1PERIPH_BASE        PERIPH_BASE
#define D2_APB2PERIPH_BASE       (PERIPH_BASE + 0x00010000)
#define D2_AHB1PERIPH_BASE       (PERIPH_BASE + 0x00020000)
#define D2_AHB2PERIPH_BASE       (PERIPH_BASE + 0x08020000)

#define D1_APB1PERIPH_BASE       (PERIPH_BASE + 0x10000000)
#define D1_AHB1PERIPH_BASE       (PERIPH_BASE + 0x12000000)

#define D3_APB1PERIPH_BASE       (PERIPH_BASE + 0x18000000)
#define D3_AHB1PERIPH_BASE       (PERIPH_BASE + 0x18020000)

//FSI #define FDCAN1_BASE_NS        (APB1PERIPH_BASE_NS + 0xa400)
//FSI #define UART5_BASE_NS         (APB1PERIPH_BASE_NS + 0x5000)

//FSI #define FDCAN1_NS           FDCAN1_BASE_NS
//FSI #define UART5_NS            UART5_BASE_NS

/*!< D3_AHB1PERIPH peripherals */
#define GPIOA_BASE            (D3_AHB1PERIPH_BASE + 0x0000)
#define GPIOB_BASE            (D3_AHB1PERIPH_BASE + 0x0400)
#define GPIOC_BASE            (D3_AHB1PERIPH_BASE + 0x0800)
#define GPIOD_BASE            (D3_AHB1PERIPH_BASE + 0x0c00)
#define GPIOE_BASE            (D3_AHB1PERIPH_BASE + 0x1000)
#define GPIOF_BASE            (D3_AHB1PERIPH_BASE + 0x1400)
#define GPIOG_BASE            (D3_AHB1PERIPH_BASE + 0x1800)
#define GPIOH_BASE            (D3_AHB1PERIPH_BASE + 0x1c00)
#define GPIOI_BASE            (D3_AHB1PERIPH_BASE + 0x2000)
#define GPIOJ_BASE            (D3_AHB1PERIPH_BASE + 0x2400)
#define GPIOK_BASE            (D3_AHB1PERIPH_BASE + 0x2800)

#define GPIOA               GPIOA_BASE
#define GPIOB               GPIOB_BASE
#define GPIOC               GPIOC_BASE
#define GPIOD               GPIOD_BASE
#define GPIOE               GPIOE_BASE
#define GPIOF               GPIOF_BASE
#define GPIOG               GPIOG_BASE
#define GPIOH               GPIOH_BASE
#define GPIOI               GPIOI_BASE
#define GPIOJ               GPIOJ_BASE
#define GPIOK               GPIOK_BASE

/*!< D2_APB1PERIPH peripherals */
#define UART5_BASE            (D2_APB1PERIPH_BASE + 0x5000)
#define I2C1_BASE             (D2_APB1PERIPH_BASE + 0x5400)
#define I2C2_BASE             (D2_APB1PERIPH_BASE + 0x5800)
#define I2C3_BASE             (D2_APB1PERIPH_BASE + 0x5c00)
#define FDCAN1_BASE           (D2_APB1PERIPH_BASE + 0xa000)

/*!< D2_APB2PERIPH peripherals */
#define USART6_BASE           (D2_APB2PERIPH_BASE + 0x1400)

/*!< D3_APB1PERIPH peripherals */
#define I2C4_BASE             (D3_APB1PERIPH_BASE + 0x1c00)

#define I2C1                           I2C1_BASE
#define I2C2                           I2C2_BASE
#define I2C3                           I2C3_BASE
#define I2C4                           I2C4_BASE

/** @addtogroup Peripheral_declaration
  * @{
  */
#define USART6              USART6_BASE
#define UART5               UART5_BASE
#define FDCAN1              FDCAN1_BASE

/******************************************************************************/
/*                                                                            */
/*                      Inter-integrated Circuit Interface (I2C)              */
/*                                                                            */
/******************************************************************************/
/*******************  Bit definition for I2C_CR1 register  *******************/
//#define I2C_CR1_NOSTRETCH_Pos        (17U)
//#define I2C_CR1_NOSTRETCH_Msk        (0x1UL << I2C_CR1_NOSTRETCH_Pos)          /*!< 0x00020000 */
//#define I2C_CR1_NOSTRETCH            I2C_CR1_NOSTRETCH_Msk                     /*!< Clock stretching disable */
#define I2C_CR1_NOSTRETCH            0x00020000
//#define I2C_CR1_GCEN_Pos             (19U)
//#define I2C_CR1_GCEN_Msk             (0x1UL << I2C_CR1_GCEN_Pos)               /*!< 0x00080000 */
//#define I2C_CR1_GCEN                 I2C_CR1_GCEN_Msk                          /*!< General call enable */
#define I2C_CR1_GCEN                 0x00080000

/*******************  Bit definition for I2C_OAR2 register  ******************/
//#define I2C_OAR2_OA2EN_Pos           (15U)
//#define I2C_OAR2_OA2EN_Msk           (0x1UL << I2C_OAR2_OA2EN_Pos)             /*!< 0x00008000 */
//#define I2C_OAR2_OA2EN               I2C_OAR2_OA2EN_Msk                        /*!< Own address 2 enable */
#define I2C_OAR2_OA2EN               0x00008000

/******************************************************************************/
/*                                                                            */
/*      Universal Synchronous Asynchronous Receiver Transmitter (USART)       */
/*                                                                            */
/******************************************************************************/
/******************  Bit definition for USART_CR1 register  *******************/
//#define USART_CR1_RE_Pos                (2U)
//#define USART_CR1_RE_Msk                (0x1UL << USART_CR1_RE_Pos)            /*!< 0x00000004 */
//#define USART_CR1_RE                    USART_CR1_RE_Msk                       /*!< Receiver Enable */
#define USART_CR1_RE                    0x00000004
//#define USART_CR1_TE_Pos                (3U)
//#define USART_CR1_TE_Msk                (0x1UL << USART_CR1_TE_Pos)            /*!< 0x00000008 */
//#define USART_CR1_TE                    USART_CR1_TE_Msk                       /*!< Transmitter Enable */
#define USART_CR1_TE                    0x00000008
//#define USART_CR1_PS_Pos                (9U)
//#define USART_CR1_PS_Msk                (0x1UL << USART_CR1_PS_Pos)            /*!< 0x00000200 */
//#define USART_CR1_PS                    USART_CR1_PS_Msk                       /*!< Parity Selection */
#define USART_CR1_PS                    0x00000200
//#define USART_CR1_PCE_Pos               (10U)
//#define USART_CR1_PCE_Msk               (0x1UL << USART_CR1_PCE_Pos)           /*!< 0x00000400 */
//#define USART_CR1_PCE                   USART_CR1_PCE_Msk                      /*!< Parity Control Enable */
#define USART_CR1_PCE                   0x00000400
//#define USART_CR1_M0_Pos                (12U)
//#define USART_CR1_M0_Msk                (0x1UL << USART_CR1_M0_Pos)            /*!< 0x00001000 */
//#define USART_CR1_M0                    USART_CR1_M0_Msk                       /*!< Word length - Bit 0 */
#define USART_CR1_M0                    0x00001000
//#define USART_CR1_OVER8_Pos             (15U)
//#define USART_CR1_OVER8_Msk             (0x1UL << USART_CR1_OVER8_Pos)         /*!< 0x00008000 */
//#define USART_CR1_OVER8                 USART_CR1_OVER8_Msk                    /*!< Oversampling by 8-bit or 16-bit mode */
#define USART_CR1_OVER8                 0x00008000
//#define USART_CR1_M1_Pos                (28U)
//#define USART_CR1_M1_Msk                (0x1UL << USART_CR1_M1_Pos)            /*!< 0x10000000 */
//#define USART_CR1_M1                    USART_CR1_M1_Msk                       /*!< Word length - Bit 1 */
#define USART_CR1_M1                    0x10000000

/******************  Bit definition for USART_CR2 register  *******************/
//#define USART_CR2_STOP_Pos              (12U)
//#define USART_CR2_STOP_Msk              (0x3UL << USART_CR2_STOP_Pos)          /*!< 0x00003000 */
//#define USART_CR2_STOP                  USART_CR2_STOP_Msk                     /*!< STOP[1:0] bits (STOP bits) */
//#define USART_CR2_STOP_0                (0x1UL << USART_CR2_STOP_Pos)           /*!< 0x00001000 */
//#define USART_CR2_STOP_1                (0x2UL << USART_CR2_STOP_Pos)           /*!< 0x00002000 */
#define USART_CR2_STOP_0                0x00001000
#define USART_CR2_STOP_1                0x00002000

/******************  Bit definition for USART_CR3 register  *******************/
//#define USART_CR3_RTSE_Pos              (8U)
//#define USART_CR3_RTSE_Msk              (0x1UL << USART_CR3_RTSE_Pos)          /*!< 0x00000100 */
//#define USART_CR3_RTSE                  USART_CR3_RTSE_Msk                     /*!< RTS Enable */
#define USART_CR3_RTSE                  0x00000100
//#define USART_CR3_CTSE_Pos              (9U)
//#define USART_CR3_CTSE_Msk              (0x1UL << USART_CR3_CTSE_Pos)          /*!< 0x00000200 */
//#define USART_CR3_CTSE                  USART_CR3_CTSE_Msk                     /*!< CTS Enable */
#define USART_CR3_CTSE                  0x00000200
//#define USART_CR3_ONEBIT_Pos            (11U)
//#define USART_CR3_ONEBIT_Msk            (0x1UL << USART_CR3_ONEBIT_Pos)        /*!< 0x00000800 */
//#define USART_CR3_ONEBIT                USART_CR3_ONEBIT_Msk                   /*!< One sample bit method enable */
#define USART_CR3_ONEBIT                0x00000800
//#define USART_CR3_RXFTCFG_Pos           (25U)
//#define USART_CR3_RXFTCFG_Msk           (0x7UL << USART_CR3_RXFTCFG_Pos)       /*!< 0x0E000000 */
//#define USART_CR3_RXFTCFG               USART_CR3_RXFTCFG_Msk                  /*!< RXFTCFG [2:0]Receive FIFO threshold configuration */
//#define USART_CR3_RXFTCFG_0             (0x1UL << USART_CR3_RXFTCFG_Pos)        /*!< 0x02000000 */
//#define USART_CR3_RXFTCFG_1             (0x2UL << USART_CR3_RXFTCFG_Pos)        /*!< 0x04000000 */
//#define USART_CR3_RXFTCFG_2             (0x4UL << USART_CR3_RXFTCFG_Pos)        /*!< 0x08000000 */
#define USART_CR3_RXFTCFG_0             0x02000000
#define USART_CR3_RXFTCFG_1             0x04000000
#define USART_CR3_RXFTCFG_2             0x08000000
//#define USART_CR3_TXFTCFG_Pos           (29U)
//#define USART_CR3_TXFTCFG_Msk           (0x7UL << USART_CR3_TXFTCFG_Pos)       /*!< 0xE0000000 */
//#define USART_CR3_TXFTCFG               USART_CR3_TXFTCFG_Msk                  /*!< TXFIFO [2:0] threshold configuration */
//#define USART_CR3_TXFTCFG_0             (0x1UL << USART_CR3_TXFTCFG_Pos)        /*!< 0x20000000 */
//#define USART_CR3_TXFTCFG_1             (0x2UL << USART_CR3_TXFTCFG_Pos)        /*!< 0x40000000 */
//#define USART_CR3_TXFTCFG_2             (0x4UL << USART_CR3_TXFTCFG_Pos)        /*!< 0x80000000 */
#define USART_CR3_TXFTCFG_0             0x20000000
#define USART_CR3_TXFTCFG_1             0x40000000
#define USART_CR3_TXFTCFG_2             0x80000000

/******************************************************************************/
/*                                                                            */
/*                 Flexible Datarate Controller Area Network                  */
/*                                                                            */
/******************************************************************************/
/*!<FDCAN control and status registers */
/*****************  Bit definition for FDCAN_IE register  **********************/
//#define FDCAN_IE_RF0NE_Pos        (0U)
//#define FDCAN_IE_RF0NE_Msk        (0x1UL << FDCAN_IE_RF0NE_Pos)                /*!< 0x00000001 */
//#define FDCAN_IE_RF0NE            FDCAN_IE_RF0NE_Msk                           /*!<Rx FIFO 0 New Message Enable                 */
#define FDCAN_IE_RF0NE            0x00000001
//#define FDCAN_IE_RF0WE_Pos        (1U)
//#define FDCAN_IE_RF0WE_Msk        (0x1UL << FDCAN_IE_RF0WE_Pos)                /*!< 0x00000002 */
//#define FDCAN_IE_RF0WE            FDCAN_IE_RF0WE_Msk                           /*!<Rx FIFO 0 Watermark Reached Enable           */
#define FDCAN_IE_RF0WE            0x00000002
//#define FDCAN_IE_RF0FE_Pos        (2U)
//#define FDCAN_IE_RF0FE_Msk        (0x1UL << FDCAN_IE_RF0FE_Pos)                /*!< 0x00000004 */
//#define FDCAN_IE_RF0FE            FDCAN_IE_RF0FE_Msk                           /*!<Rx FIFO 0 Full Enable                        */
#define FDCAN_IE_RF0FE            0x00000004
//#define FDCAN_IE_RF0LE_Pos        (3U)
//#define FDCAN_IE_RF0LE_Msk        (0x1UL << FDCAN_IE_RF0LE_Pos)                /*!< 0x00000008 */
//#define FDCAN_IE_RF0LE            FDCAN_IE_RF0LE_Msk                           /*!<Rx FIFO 0 Message Lost Enable                */
#define FDCAN_IE_RF0LE            0x00000008
//#define FDCAN_IE_RF1NE_Pos        (4U)
//#define FDCAN_IE_RF1NE_Msk        (0x1UL << FDCAN_IE_RF1NE_Pos)                /*!< 0x00000010 */
//#define FDCAN_IE_RF1NE            FDCAN_IE_RF1NE_Msk                           /*!<Rx FIFO 1 New Message Enable                 */
#define FDCAN_IE_RF1NE            0x00000010
//#define FDCAN_IE_RF1WE_Pos        (5U)
//#define FDCAN_IE_RF1WE_Msk        (0x1UL << FDCAN_IE_RF1WE_Pos)                /*!< 0x00000020 */
//#define FDCAN_IE_RF1WE            FDCAN_IE_RF1WE_Msk                           /*!<Rx FIFO 1 Watermark Reached Enable           */
#define FDCAN_IE_RF1WE            0x00000020
//#define FDCAN_IE_RF1FE_Pos        (6U)
//#define FDCAN_IE_RF1FE_Msk        (0x1UL << FDCAN_IE_RF1FE_Pos)                /*!< 0x00000040 */
//#define FDCAN_IE_RF1FE            FDCAN_IE_RF1FE_Msk                           /*!<Rx FIFO 1 Full Enable                        */
#define FDCAN_IE_RF1FE            0x00000040
//#define FDCAN_IE_RF1LE_Pos        (7U)
//#define FDCAN_IE_RF1LE_Msk        (0x1UL << FDCAN_IE_RF1LE_Pos)                /*!< 0x00000080 */
//#define FDCAN_IE_RF1LE            FDCAN_IE_RF1LE_Msk                           /*!<Rx FIFO 1 Message Lost Enable                */
#define FDCAN_IE_RF1LE            0x00000080
//#define FDCAN_IE_HPME_Pos         (8U)
//#define FDCAN_IE_HPME_Msk         (0x1UL << FDCAN_IE_HPME_Pos)                 /*!< 0x00000100 */
//#define FDCAN_IE_HPME             FDCAN_IE_HPME_Msk                            /*!<High Priority Message Enable                 */
#define FDCAN_IE_HPME             0x00000100
//#define FDCAN_IE_TCE_Pos          (9U)
//#define FDCAN_IE_TCE_Msk          (0x1UL << FDCAN_IE_TCE_Pos)                  /*!< 0x00000200 */
//#define FDCAN_IE_TCE              FDCAN_IE_TCE_Msk                             /*!<Transmission Completed Enable                */
#define FDCAN_IE_TCE              0x00000200
//#define FDCAN_IE_TCFE_Pos         (10U)
//#define FDCAN_IE_TCFE_Msk         (0x1UL << FDCAN_IE_TCFE_Pos)                 /*!< 0x00000400 */
//#define FDCAN_IE_TCFE             FDCAN_IE_TCFE_Msk                            /*!<Transmission Cancellation Finished Enable    */
#define FDCAN_IE_TCFE             0x00000400
//#define FDCAN_IE_TFEE_Pos         (11U)
//#define FDCAN_IE_TFEE_Msk         (0x1UL << FDCAN_IE_TFEE_Pos)                 /*!< 0x00000800 */
//#define FDCAN_IE_TFEE             FDCAN_IE_TFEE_Msk                            /*!<Tx FIFO Empty Enable                         */
#define FDCAN_IE_TFEE             0x00000800
//#define FDCAN_IE_TEFNE_Pos        (12U)
//#define FDCAN_IE_TEFNE_Msk        (0x1UL << FDCAN_IE_TEFNE_Pos)                /*!< 0x00001000 */
//#define FDCAN_IE_TEFNE            FDCAN_IE_TEFNE_Msk                           /*!<Tx Event FIFO New Entry Enable               */
#define FDCAN_IE_TEFNE            0x00001000
//#define FDCAN_IE_TEFWE_Pos        (13U)
//#define FDCAN_IE_TEFWE_Msk        (0x1UL << FDCAN_IE_TEFWE_Pos)                /*!< 0x00002000 */
//#define FDCAN_IE_TEFWE            FDCAN_IE_TEFWE_Msk                           /*!<Tx Event FIFO Watermark Reached Enable       */
#define FDCAN_IE_TEFWE            0x00002000
//#define FDCAN_IE_TEFFE_Pos        (14U)
//#define FDCAN_IE_TEFFE_Msk        (0x1UL << FDCAN_IE_TEFFE_Pos)                /*!< 0x00004000 */
//#define FDCAN_IE_TEFFE            FDCAN_IE_TEFFE_Msk                           /*!<Tx Event FIFO Full Enable                    */
#define FDCAN_IE_TEFFE            0x00004000
//#define FDCAN_IE_TEFLE_Pos        (15U)
//#define FDCAN_IE_TEFLE_Msk        (0x1UL << FDCAN_IE_TEFLE_Pos)                /*!< 0x00008000 */
//#define FDCAN_IE_TEFLE            FDCAN_IE_TEFLE_Msk                           /*!<Tx Event FIFO Element Lost Enable            */
#define FDCAN_IE_TEFLE            0x00008000
//#define FDCAN_IE_TSWE_Pos         (16U)
//#define FDCAN_IE_TSWE_Msk         (0x1UL << FDCAN_IE_TSWE_Pos)                 /*!< 0x00010000 */
//#define FDCAN_IE_TSWE             FDCAN_IE_TSWE_Msk                            /*!<Timestamp Wraparound Enable                  */
#define FDCAN_IE_TSWE             0x00010000
//#define FDCAN_IE_MRAFE_Pos        (17U)
//#define FDCAN_IE_MRAFE_Msk        (0x1UL << FDCAN_IE_MRAFE_Pos)                /*!< 0x00020000 */
//#define FDCAN_IE_MRAFE            FDCAN_IE_MRAFE_Msk                           /*!<Message RAM Access Failure Enable            */
#define FDCAN_IE_MRAFE            0x00020000
//#define FDCAN_IE_TOOE_Pos         (18U)
//#define FDCAN_IE_TOOE_Msk         (0x1UL << FDCAN_IE_TOOE_Pos)                 /*!< 0x00040000 */
//#define FDCAN_IE_TOOE             FDCAN_IE_TOOE_Msk                            /*!<Timeout Occurred Enable                      */
#define FDCAN_IE_TOOE             0x00040000
//#define FDCAN_IE_DRXE_Pos         (19U)
//#define FDCAN_IE_DRXE_Msk         (0x1UL << FDCAN_IE_DRXE_Pos)                 /*!< 0x00080000 */
//#define FDCAN_IE_DRXE             FDCAN_IE_DRXE_Msk                            /*!<Message stored to Dedicated Rx Buffer Enable */
#define FDCAN_IE_DRXE             0x00080000
//#define FDCAN_IE_BECE_Pos         (20U)
//#define FDCAN_IE_BECE_Msk         (0x1UL << FDCAN_IE_BECE_Pos)                 /*!< 0x00100000 */
//#define FDCAN_IE_BECE             FDCAN_IE_BECE_Msk                            /*!<Bit Error Corrected Interrupt Enable         */
#define FDCAN_IE_BECE             0x00100000
//#define FDCAN_IE_BEUE_Pos         (21U)
//#define FDCAN_IE_BEUE_Msk         (0x1UL << FDCAN_IE_BEUE_Pos)                 /*!< 0x00200000 */
//#define FDCAN_IE_BEUE             FDCAN_IE_BEUE_Msk                            /*!<Bit Error Uncorrected Interrupt Enable       */
#define FDCAN_IE_BEUE             0x00200000
//#define FDCAN_IE_ELOE_Pos         (22U)
//#define FDCAN_IE_ELOE_Msk         (0x1UL << FDCAN_IE_ELOE_Pos)                 /*!< 0x00400000 */
//#define FDCAN_IE_ELOE             FDCAN_IE_ELOE_Msk                            /*!<Error Logging Overflow Enable                */
#define FDCAN_IE_ELOE             0x00400000
//#define FDCAN_IE_EPE_Pos          (23U)
//#define FDCAN_IE_EPE_Msk          (0x1UL << FDCAN_IE_EPE_Pos)                  /*!< 0x00800000 */
//#define FDCAN_IE_EPE              FDCAN_IE_EPE_Msk                             /*!<Error Passive Enable                         */
#define FDCAN_IE_EPE              0x00800000
//#define FDCAN_IE_EWE_Pos          (24U)
//#define FDCAN_IE_EWE_Msk          (0x1UL << FDCAN_IE_EWE_Pos)                  /*!< 0x01000000 */
//#define FDCAN_IE_EWE              FDCAN_IE_EWE_Msk                             /*!<Warning Status Enable                        */
#define FDCAN_IE_EWE              0x01000000
//#define FDCAN_IE_BOE_Pos          (25U)
//#define FDCAN_IE_BOE_Msk          (0x1UL << FDCAN_IE_BOE_Pos)                  /*!< 0x02000000 */
//#define FDCAN_IE_BOE              FDCAN_IE_BOE_Msk                             /*!<Bus_Off Status Enable                        */
#define FDCAN_IE_BOE              0x02000000
//#define FDCAN_IE_WDIE_Pos         (26U)
//#define FDCAN_IE_WDIE_Msk         (0x1UL << FDCAN_IE_WDIE_Pos)                 /*!< 0x04000000 */
//#define FDCAN_IE_WDIE             FDCAN_IE_WDIE_Msk                            /*!<Watchdog Interrupt Enable                    */
#define FDCAN_IE_WDIE             0x04000000
//#define FDCAN_IE_PEAE_Pos         (27U)
//#define FDCAN_IE_PEAE_Msk         (0x1UL << FDCAN_IE_PEAE_Pos)                 /*!< 0x08000000 */
//#define FDCAN_IE_PEAE             FDCAN_IE_PEAE_Msk                            /*!<Protocol Error in Arbitration Phase Enable   */
#define FDCAN_IE_PEAE             0x08000000
//#define FDCAN_IE_PEDE_Pos         (28U)
//#define FDCAN_IE_PEDE_Msk         (0x1UL << FDCAN_IE_PEDE_Pos)                 /*!< 0x10000000 */
//#define FDCAN_IE_PEDE             FDCAN_IE_PEDE_Msk                            /*!<Protocol Error in Data Phase Enable          */
#define FDCAN_IE_PEDE             0x10000000
//#define FDCAN_IE_ARAE_Pos         (29U)
//#define FDCAN_IE_ARAE_Msk         (0x1UL << FDCAN_IE_ARAE_Pos)                 /*!< 0x20000000 */
//#define FDCAN_IE_ARAE             FDCAN_IE_ARAE_Msk                            /*!<Access to Reserved Address Enable            */
#define FDCAN_IE_ARAE             0x20000000

/*****************  Bit definition for FDCAN_CCCR register  ********************/
//#define FDCAN_CCCR_FDOE_Pos       (8U)
//#define FDCAN_CCCR_FDOE_Msk       (0x1UL << FDCAN_CCCR_FDOE_Pos)               /*!< 0x00000100 */
//#define FDCAN_CCCR_FDOE           FDCAN_CCCR_FDOE_Msk                          /*!<FD Operation Enable                      */
#define FDCAN_CCCR_FDOE           0x00000100
//#define FDCAN_CCCR_BRSE_Pos       (9U)
//#define FDCAN_CCCR_BRSE_Msk       (0x1UL << FDCAN_CCCR_BRSE_Pos)               /*!< 0x00000200 */
//#define FDCAN_CCCR_BRSE           FDCAN_CCCR_BRSE_Msk                          /*!<FDCAN Bit Rate Switching                 */
#define FDCAN_CCCR_BRSE           0x00000200

/*****************  Bit definition for FDCAN_TXBC register  *********************/
//#define FDCAN_TXBC_TBSA_Pos       (2U)
//#define FDCAN_TXBC_TBSA_Msk       (0x3FFFUL << FDCAN_TXBC_TBSA_Pos)            /*!< 0x0000FFFC */
//#define FDCAN_TXBC_TBSA           FDCAN_TXBC_TBSA_Msk                          /*!<Tx Buffers Start Address                  */
#define FDCAN_TXBC_TBSA           0x0000FFFC
//#define FDCAN_TXBC_NDTB_Pos       (16U)
//#define FDCAN_TXBC_NDTB_Msk       (0x3FUL << FDCAN_TXBC_NDTB_Pos)              /*!< 0x003F0000 */
//#define FDCAN_TXBC_NDTB           FDCAN_TXBC_NDTB_Msk                          /*!<Number of Dedicated Transmit Buffers      */
#define FDCAN_TXBC_NDTB           0x003F0000
//#define FDCAN_TXBC_TFQS_Pos       (24U)
//#define FDCAN_TXBC_TFQS_Msk       (0x3FUL << FDCAN_TXBC_TFQS_Pos)              /*!< 0x3F000000 */
//#define FDCAN_TXBC_TFQS           FDCAN_TXBC_TFQS_Msk                          /*!<Transmit FIFO/Queue Size                  */
#define FDCAN_TXBC_TFQS           0x3F000000
//#define FDCAN_TXBC_TFQM_Pos       (30U)
//#define FDCAN_TXBC_TFQM_Msk       (0x1UL << FDCAN_TXBC_TFQM_Pos)               /*!< 0x40000000 */
//#define FDCAN_TXBC_TFQM           FDCAN_TXBC_TFQM_Msk                          /*!<Tx FIFO/Queue Mode                        */
#define FDCAN_TXBC_TFQM           0x40000000
