/**
  ******************************************************************************
  * @file    stm32h7xx_hal_fdcan.h
  * @author  MCD Application Team
  * @brief   Header file of FDCAN HAL module.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; Copyright (c) 2017 STMicroelectronics.
  * All rights reserved.</center></h2>
  *
  * This software component is licensed by ST under BSD 3-Clause license,
  * the "License"; You may not use this file except in compliance with the
  * License. You may obtain a copy of the License at:
  *                        opensource.org/licenses/BSD-3-Clause
  *
  ******************************************************************************
  */
//---- stm32h7xx_hal_fdcan.h ----

/** @defgroup FDCAN_frame_format FDCAN Frame Format
  * @{
  */
#define FDCAN_FRAME_CLASSIC   0x00000000                          /*!< Classic mode                      */
#define FDCAN_FRAME_FD_NO_BRS FDCAN_CCCR_FDOE                     /*!< FD mode without BitRate Switching */
#define FDCAN_FRAME_FD_BRS    (FDCAN_CCCR_FDOE | FDCAN_CCCR_BRSE) /*!< FD mode with BitRate Switching    */

/** @defgroup FDCAN_operating_mode FDCAN Operating Mode
  * @{
  */
#define FDCAN_MODE_NORMAL               0x00000000 /*!< Normal mode               */
#define FDCAN_MODE_RESTRICTED_OPERATION 0x00000001 /*!< Restricted Operation mode */
#define FDCAN_MODE_BUS_MONITORING       0x00000002 /*!< Bus Monitoring mode       */
#define FDCAN_MODE_INTERNAL_LOOPBACK    0x00000003 /*!< Internal LoopBack mode    */
#define FDCAN_MODE_EXTERNAL_LOOPBACK    0x00000004 /*!< External LoopBack mode    */

/** @defgroup FDCAN_data_field_size FDCAN Data Field Size
  * @{
  */
#define FDCAN_DATA_BYTES_8  0x00000004 /*!< 8 bytes data field  */
#define FDCAN_DATA_BYTES_12 0x00000005 /*!< 12 bytes data field */
#define FDCAN_DATA_BYTES_16 0x00000006 /*!< 16 bytes data field */
#define FDCAN_DATA_BYTES_20 0x00000007 /*!< 20 bytes data field */
#define FDCAN_DATA_BYTES_24 0x00000008 /*!< 24 bytes data field */
#define FDCAN_DATA_BYTES_32 0x0000000a /*!< 32 bytes data field */
#define FDCAN_DATA_BYTES_48 0x0000000e /*!< 48 bytes data field */
#define FDCAN_DATA_BYTES_64 0x00000012 /*!< 64 bytes data field */

/** @defgroup FDCAN_txFifoQueue_Mode FDCAN Tx FIFO/Queue Mode
  * @{
  */
#define FDCAN_TX_FIFO_OPERATION  0x00000000      /*!< FIFO mode  */
#define FDCAN_TX_QUEUE_OPERATION FDCAN_TXBC_TFQM /*!< Queue mode */

/** @defgroup FDCAN_id_type FDCAN ID Type
  * @{
  */
#define FDCAN_STANDARD_ID 0x00000000 /*!< Standard ID element */
#define FDCAN_EXTENDED_ID 0x40000000 /*!< Extended ID element */

/** @defgroup FDCAN_filter_type FDCAN Filter Type
  * @{
  */
#define FDCAN_FILTER_RANGE         0x00000000 /*!< Range filter from FilterID1 to FilterID2                        */
#define FDCAN_FILTER_DUAL          0x00000001 /*!< Dual ID filter for FilterID1 or FilterID2                       */
#define FDCAN_FILTER_MASK          0x00000002 /*!< Classic filter: FilterID1 = filter, FilterID2 = mask            */
#define FDCAN_FILTER_RANGE_NO_EIDM 0x00000003 /*!< Range filter from FilterID1 to FilterID2, EIDM mask not applied */

/** @defgroup FDCAN_filter_config FDCAN Filter Configuration
  * @{
  */
#define FDCAN_FILTER_DISABLE       0x00000000 /*!< Disable filter element                                    */
#define FDCAN_FILTER_TO_RXFIFO0    0x00000001 /*!< Store in Rx FIFO 0 if filter matches                      */
#define FDCAN_FILTER_TO_RXFIFO1    0x00000002 /*!< Store in Rx FIFO 1 if filter matches                      */
#define FDCAN_FILTER_REJECT        0x00000003 /*!< Reject ID if filter matches                               */
#define FDCAN_FILTER_HP            0x00000004 /*!< Set high priority if filter matches                       */
#define FDCAN_FILTER_TO_RXFIFO0_HP 0x00000005 /*!< Set high priority and store in FIFO 0 if filter matches   */
#define FDCAN_FILTER_TO_RXFIFO1_HP 0x00000006 /*!< Set high priority and store in FIFO 1 if filter matches   */
#define FDCAN_FILTER_TO_RXBUFFER   0x00000007 /*!< Store into Rx Buffer, configuration of FilterType ignored */

/** @defgroup FDCAN_Non_Matching_Frames FDCAN non-matching frames
  * @{
  */
#define FDCAN_ACCEPT_IN_RX_FIFO0 0x00000000 /*!< Accept in Rx FIFO 0 */
#define FDCAN_ACCEPT_IN_RX_FIFO1 0x00000001 /*!< Accept in Rx FIFO 1 */
#define FDCAN_REJECT             0x00000002 /*!< Reject              */

/** @defgroup FDCAN_Reject_Remote_Frames FDCAN reject remote frames
  * @{
  */
#define FDCAN_FILTER_REMOTE 0x00000000 /*!< Filter remote frames */
#define FDCAN_REJECT_REMOTE 0x00000001 /*!< Reject all remote frames */

/** @defgroup FDCAN_Rx_Fifo0_Interrupts FDCAN Rx FIFO 0 Interrupts
  * @{
  */
#define FDCAN_IT_RX_FIFO0_MESSAGE_LOST FDCAN_IE_RF0LE /*!< Rx FIFO 0 message lost                 */
#define FDCAN_IT_RX_FIFO0_FULL         FDCAN_IE_RF0FE /*!< Rx FIFO 0 full                         */
#define FDCAN_IT_RX_FIFO0_WATERMARK    FDCAN_IE_RF0WE /*!< Rx FIFO 0 fill level reached watermark */
#define FDCAN_IT_RX_FIFO0_NEW_MESSAGE  FDCAN_IE_RF0NE /*!< New message written to Rx FIFO 0       */

/** @defgroup FDCAN_Rx_Fifo1_Interrupts FDCAN Rx FIFO 1 Interrupts
  * @{
  */
#define FDCAN_IT_RX_FIFO1_MESSAGE_LOST FDCAN_IE_RF1LE /*!< Rx FIFO 1 message lost                 */
#define FDCAN_IT_RX_FIFO1_FULL         FDCAN_IE_RF1FE /*!< Rx FIFO 1 full                         */
#define FDCAN_IT_RX_FIFO1_WATERMARK    FDCAN_IE_RF1WE /*!< Rx FIFO 1 fill level reached watermark */
#define FDCAN_IT_RX_FIFO1_NEW_MESSAGE  FDCAN_IE_RF1NE /*!< New message written to Rx FIFO 1       */
