/**
  ******************************************************************************
  * @file    stm32h7xx_hal_uart.h
  * @author  MCD Application Team
  * @brief   Header file of UART HAL module.
  ******************************************************************************
  * @attention
  *
  * <h2><center>&copy; Copyright (c) 2017 STMicroelectronics.
  * All rights reserved.</center></h2>
  *
  * This software component is licensed by ST under BSD 3-Clause license,
  * the "License"; You may not use this file except in compliance with the
  * License. You may obtain a copy of the License at:
  *                        opensource.org/licenses/BSD-3-Clause
  *
  ******************************************************************************
  */
//---- stm32h7xx_hal_uart.h ----

/** @defgroup UART_Stop_Bits   UART Number of Stop Bits
  * @{
  */
#define UART_STOPBITS_0_5                   USART_CR2_STOP_0                      /*!< UART frame with 0.5 stop bit  */
#define UART_STOPBITS_1                     0x00000000                            /*!< UART frame with 1 stop bit    */
#define UART_STOPBITS_1_5                   (USART_CR2_STOP_0 | USART_CR2_STOP_1) /*!< UART frame with 1.5 stop bits */
#define UART_STOPBITS_2                     USART_CR2_STOP_1                      /*!< UART frame with 2 stop bits   */

/** @defgroup UART_Parity  UART Parity
  * @{
  */
#define UART_PARITY_NONE                    0x00000000                         /*!< No parity   */
#define UART_PARITY_EVEN                    USART_CR1_PCE                      /*!< Even parity */
#define UART_PARITY_ODD                     (USART_CR1_PCE | USART_CR1_PS)     /*!< Odd parity  */

/** @defgroup UART_Mode UART Transfer Mode
  * @{
  */
#define UART_MODE_RX                        USART_CR1_RE                    /*!< RX mode        */
#define UART_MODE_TX                        USART_CR1_TE                    /*!< TX mode        */
#define UART_MODE_TX_RX                     (USART_CR1_TE | USART_CR1_RE)   /*!< RX and TX mode */

/** @defgroup UART_Hardware_Flow_Control UART Hardware Flow Control
  * @{
  */
#define UART_HWCONTROL_NONE                 0x00000000                           /*!< No hardware control       */
#define UART_HWCONTROL_RTS                  USART_CR3_RTSE                       /*!< Request To Send           */
#define UART_HWCONTROL_CTS                  USART_CR3_CTSE                       /*!< Clear To Send             */
#define UART_HWCONTROL_RTS_CTS              (USART_CR3_RTSE | USART_CR3_CTSE)    /*!< Request and Clear To Send */

/** @defgroup UART_Over_Sampling UART Over Sampling
  * @{
  */
#define UART_OVERSAMPLING_16                0x00000000          /*!< Oversampling by 16 */
#define UART_OVERSAMPLING_8                 USART_CR1_OVER8     /*!< Oversampling by 8  */

/** @defgroup UART_OneBit_Sampling UART One Bit Sampling Method
  * @{
  */
#define UART_ONE_BIT_SAMPLE_DISABLE         0x00000000          /*!< One-bit sampling disable */
#define UART_ONE_BIT_SAMPLE_ENABLE          USART_CR3_ONEBIT    /*!< One-bit sampling enable  */

/** @defgroup UART_ClockPrescaler  UART Clock Prescaler
  * @{
  */
#define UART_PRESCALER_DIV1    0x00000000  /*!< fclk_pres = fclk     */
#define UART_PRESCALER_DIV2    0x00000001  /*!< fclk_pres = fclk/2   */
#define UART_PRESCALER_DIV4    0x00000002  /*!< fclk_pres = fclk/4   */
#define UART_PRESCALER_DIV6    0x00000003  /*!< fclk_pres = fclk/6   */
#define UART_PRESCALER_DIV8    0x00000004  /*!< fclk_pres = fclk/8   */
#define UART_PRESCALER_DIV10   0x00000005  /*!< fclk_pres = fclk/10  */
#define UART_PRESCALER_DIV12   0x00000006  /*!< fclk_pres = fclk/12  */
#define UART_PRESCALER_DIV16   0x00000007  /*!< fclk_pres = fclk/16  */
#define UART_PRESCALER_DIV32   0x00000008  /*!< fclk_pres = fclk/32  */
#define UART_PRESCALER_DIV64   0x00000009  /*!< fclk_pres = fclk/64  */
#define UART_PRESCALER_DIV128  0x0000000A  /*!< fclk_pres = fclk/128 */
#define UART_PRESCALER_DIV256  0x0000000B  /*!< fclk_pres = fclk/256 */

/** @defgroup UART_Advanced_Features_Initialization_Type  UART Advanced Feature Initialization Type
  * @{
  */
#define UART_ADVFEATURE_NO_INIT                 0x00000000          /*!< No advanced feature initialization       */
#define UART_ADVFEATURE_TXINVERT_INIT           0x00000001          /*!< TX pin active level inversion            */
#define UART_ADVFEATURE_RXINVERT_INIT           0x00000002          /*!< RX pin active level inversion            */
#define UART_ADVFEATURE_DATAINVERT_INIT         0x00000004          /*!< Binary data inversion                    */
#define UART_ADVFEATURE_SWAP_INIT               0x00000008          /*!< TX/RX pins swap                          */
#define UART_ADVFEATURE_RXOVERRUNDISABLE_INIT   0x00000010          /*!< RX overrun disable                       */
#define UART_ADVFEATURE_DMADISABLEONERROR_INIT  0x00000020          /*!< DMA disable on Reception Error           */
#define UART_ADVFEATURE_AUTOBAUDRATE_INIT       0x00000040          /*!< Auto Baud rate detection initialization  */
#define UART_ADVFEATURE_MSBFIRST_INIT           0x00000080          /*!< Most significant bit sent/received first */
