///
// @file uicAPI.h
// @brief header file generate from sdev_uic.kra
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef _SDEV_UIC_KRA_
#define _SDEV_UIC_KRA_

#ifdef C_SYNTAX
#define KC_EXPAND_RECIPE
#endif // C_SYNTAX

#ifndef KC_EXPAND_RECIPE

//////////////////////////////////////////////////////////////////
// *** define declaration that is not for recipe users *** //
//////////////////////////////////////////////////////////////////

#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define UIC_API_INIT 0
#define UIC_Init() \
  EAPI_SendEvent(EAPI_TASKID_UIC,UIC_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// ボタンセンスCB登録
#define UIC_API_SENSE_BUTTON 256
#define UIC_SenseButton(sense_min,sense_max,notiry_event_id) \
  EAPI_SendEvent(EAPI_TASKID_UIC,UIC_API_SENSE_BUTTON,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U32,sense_min,EAPI_VTYPE_U32,sense_max,EAPI_VTYPE_U8,notiry_event_id)
// LED制御
#define UIC_API_SET_LED 257
#define UIC_SetLED(priority,led_color) \
  EAPI_SendEvent(EAPI_TASKID_UIC,UIC_API_SET_LED,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,priority,EAPI_VTYPE_U8,led_color)
#define UIC_API_SET_LED_WITH_ID 258
#define UIC_SetLEDwithID(priority,led_color,task_id) \
  EAPI_SendEvent(EAPI_TASKID_UIC,UIC_API_SET_LED_WITH_ID,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO,EAPI_VTYPE_U8,priority,EAPI_VTYPE_U8,led_color,EAPI_VTYPE_U8,task_id)
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// LEDプライオリティ
#define UIC_LED_PRI_BOOTDOWN 0x80
#define UIC_LED_PRI_ERROR 0x40
#define UIC_LED_PRI_FWUPDATE 0x20
#define UIC_LED_PRI_CHARGE 0x10
#define UIC_LED_PRI_USER_H 0x08
#define UIC_LED_PRI_USER_L 0x04
#define UIC_LED_PRI_RELEASE 0x00
// LEDカラー
#define UIC_LED_COLOR_OFF 0x00
#define UIC_LED_COLOR_RED 0x01
#define UIC_LED_COLOR_GREEN 0x02
#define UIC_LED_COLOR_ORANGE 0x03
// 100-1000msec(短押し)通知
#define UIC_SenseButtonS(a) UIC_SenseButton(100,1000,a)
// 1-4秒押し通知
#define UIC_SenseButtonM(a) UIC_SenseButton(1000,4000,a)
// 4-10秒押し通知
#define UIC_SenseButtonL(a) UIC_SenseButton(4000,10000,a)

#else

//////////////////////////////////////////////////////////////////
// *** define declaration for recipe users *** //
//////////////////////////////////////////////////////////////////
#include "taskid.h"
#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define UIC_API_INIT 0
func sys_api_UIC_Init() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_UIC,UIC_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define UIC_Init() sys_api_UIC_Init()
// ボタンセンスCB登録
#define UIC_API_SENSE_BUTTON 256
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_UIC_SenseButton(uint32 sense_min, uint32 sense_max, uint8 notiry_event_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,sense_min);
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,sense_max);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,notiry_event_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_UIC,UIC_API_SENSE_BUTTON,EAPI_SYNC_RESULT,1000));
}
#define UIC_SenseButton(sense_min,sense_max,notiry_event_id) sys_api_UIC_SenseButton(sense_min,sense_max,notiry_event_id)
#endif // YIELD_TO_BASIC_INFOROMATION
// LED制御
#define UIC_API_SET_LED 257
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_UIC_SetLED(uint8 priority, uint8 led_color) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,priority);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,led_color);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_UIC,UIC_API_SET_LED,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define UIC_SetLED(priority,led_color) sys_api_UIC_SetLED(priority,led_color)
#endif // YIELD_TO_BASIC_INFOROMATION
#define UIC_API_SET_LED_WITH_ID 258
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_UIC_SetLEDwithID(uint8 priority, uint8 led_color, uint8 task_id) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,priority);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,led_color);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,task_id);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_UIC,UIC_API_SET_LED_WITH_ID,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define UIC_SetLEDwithID(priority,led_color,task_id) sys_api_UIC_SetLEDwithID(priority,led_color,task_id)
#endif // YIELD_TO_BASIC_INFOROMATION
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// LEDプライオリティ
#define UIC_LED_PRI_BOOTDOWN 0x80
#define UIC_LED_PRI_ERROR 0x40
#define UIC_LED_PRI_FWUPDATE 0x20
#define UIC_LED_PRI_CHARGE 0x10
#define UIC_LED_PRI_USER_H 0x08
#define UIC_LED_PRI_USER_L 0x04
#define UIC_LED_PRI_RELEASE 0x00
// LEDカラー
#define UIC_LED_COLOR_OFF 0x00
#define UIC_LED_COLOR_RED 0x01
#define UIC_LED_COLOR_GREEN 0x02
#define UIC_LED_COLOR_ORANGE 0x03
// 100-1000msec(短押し)通知
#define UIC_SenseButtonS(a) UIC_SenseButton(100,1000,a)
// 1-4秒押し通知
#define UIC_SenseButtonM(a) UIC_SenseButton(1000,4000,a)
// 4-10秒押し通知
#define UIC_SenseButtonL(a) UIC_SenseButton(4000,10000,a)

#endif

#endif
