///
// @file uvcAPI.h
// @brief header file generate from sdev_uvc.kra
// @details
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
///

// Define to prevent recursive inclusion -----------------------
#ifndef _SDEV_UVC_KRA_
#define _SDEV_UVC_KRA_

#ifdef C_SYNTAX
#define KC_EXPAND_RECIPE
#endif // C_SYNTAX

#ifndef KC_EXPAND_RECIPE

//////////////////////////////////////////////////////////////////
// *** define declaration that is not for recipe users *** //
//////////////////////////////////////////////////////////////////

#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define UVC_API_INIT 0
#define UVC_Init() \
  EAPI_SendEvent(EAPI_TASKID_UVC,UVC_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO)
// ステータスリスナーCB登録
#define UVC_API_REGIST_USB_VIDEO_STATUS_LISTNER 256
#define UVC_RegistUsbVideoStatusListener(notify_event_id,mode_sw) \
  EAPI_SendEvent(EAPI_TASKID_UVC,UVC_API_REGIST_USB_VIDEO_STATUS_LISTNER,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,notify_event_id,EAPI_VTYPE_U8,mode_sw)
// 動画バッファへの転送周期変更
#define UVC_API_BUF_CTRL_SMPRATE 257
#define UVC_BufCtrlSmpRate(smp_rate) \
  EAPI_SendEvent(EAPI_TASKID_UVC,UVC_API_BUF_CTRL_SMPRATE,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U32,smp_rate)
// カメラ制御開始,停止
#define UVC_API_VIDEO_STREAM_CTRL 258
#define UVC_VideoStreamCtrl(start,format,h_size,v_size,fps) \
  EAPI_SendEvent(EAPI_TASKID_UVC,UVC_API_VIDEO_STREAM_CTRL,EAPI_SYNC_RESULT,1000,EAPI_VTYPE_U8,start,EAPI_VTYPE_U8,format,EAPI_VTYPE_U16,h_size,EAPI_VTYPE_U16,v_size,EAPI_VTYPE_U16,fps)
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// リスナー登録設定/解除設定
#define UVC_LISTENER_REGIST_REMOVE 0
#define UVC_LISTENER_REGIST_ADD 1
// ステータスリスナーCB返答値
#define UVC_RESULT_OK 0
#define UVC_RESULT_STOP 1
#define UVC_RESULT_START 2
#define UVC_RESULT_NO_STREAM_TIMEOUT 3
#define UVC_RESULT_STARTED_RETRY 4
#define UVC_RESULT_P0_VBUS_ON 100
#define UVC_RESULT_P1_VBUS_ON 101
#define UVC_RESULT_P2_VBUS_ON 102
#define UVC_RESULT_P0_ENUMERATION_COMPLETED 103
#define UVC_RESULT_P1_ENUMERATION_COMPLETED 104
#define UVC_RESULT_P2_ENUMERATION_COMPLETED 105
#define UVC_RESULT_P0_VBUS_OFF 106
#define UVC_RESULT_P1_VBUS_OFF 107
#define UVC_RESULT_P2_VBUS_OFF 108
#define UVC_RESULT_P1_DISCONNECT_HUB 109
#define UVC_RESULT_P2_DISCONNECT_HUB 110
#define UVC_RESULT_P0_DISCONNECT_H7 111
#define UVC_RESULT_CALLER_DIFFERENCE 200
#define UVC_RESULT_EXCLUSIVE 201
#define UVC_RESULT_BUFF_SETUP_ERROR 202
#define UVC_RESULT_NOT_APPLICABLE_SMP_RATE 203
#define UVC_RESULT_NOT_APPLICABLE_RESOLUTION 204
#define UVC_RESULT_NOT_APPLICABLE_FORMAT 205
#define UVC_RESULT_NOT_APPLICABLE_FPS 206
#define UVC_RESULT_ERROR 255
// uvc stream control parameter
#define UVC_STREAM_CTRL_STOP 0
#define UVC_STREAM_CTRL_START 1
// uvc format parameter
#define UVC_STREAM_CODEC_MJPEG 0
#define UVC_STREAM_CODEC_H264 1
#define UVC_STREAM_CODEC_YUV 2
#define UVC_STREAM_CODEC_UNDEFINED 3

#else

//////////////////////////////////////////////////////////////////
// *** define declaration for recipe users *** //
//////////////////////////////////////////////////////////////////
#include "taskid.h"
#include "eventLib.h"

//////////////////////////////////////////////////////////////////
// API function //
//////////////////////////////////////////////////////////////////
// 初期化
#define UVC_API_INIT 0
func sys_api_UVC_Init() {
  return(rcplib_TASK_SendEvent(EAPI_TASKID_UVC,UVC_API_INIT,EAPI_UNSYNC_NORESULT,EAPI_TIMEOUT_ZERO));
}
#define UVC_Init() sys_api_UVC_Init()
// ステータスリスナーCB登録
#define UVC_API_REGIST_USB_VIDEO_STATUS_LISTNER 256
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_UVC_RegistUsbVideoStatusListener(uint8 notify_event_id, uint8 mode_sw) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,notify_event_id);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,mode_sw);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_UVC,UVC_API_REGIST_USB_VIDEO_STATUS_LISTNER,EAPI_SYNC_RESULT,1000));
}
#define UVC_RegistUsbVideoStatusListener(notify_event_id,mode_sw) sys_api_UVC_RegistUsbVideoStatusListener(notify_event_id,mode_sw)
#endif // YIELD_TO_BASIC_INFOROMATION
// 動画バッファへの転送周期変更
#define UVC_API_BUF_CTRL_SMPRATE 257
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_UVC_BufCtrlSmpRate(uint32 smp_rate) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U32,smp_rate);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_UVC,UVC_API_BUF_CTRL_SMPRATE,EAPI_SYNC_RESULT,1000));
}
#define UVC_BufCtrlSmpRate(smp_rate) sys_api_UVC_BufCtrlSmpRate(smp_rate)
#endif // YIELD_TO_BASIC_INFOROMATION
// カメラ制御開始,停止
#define UVC_API_VIDEO_STREAM_CTRL 258
#ifndef YIELD_TO_BASIC_INFOROMATION // for VS code view
func sys_api_UVC_VideoStreamCtrl(uint8 start, uint8 format, uint16 h_size, uint16 v_size, uint16 fps) {
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,start);
  rcplib_TASK_SetArg(EAPI_VTYPE_U8,format);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,h_size);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,v_size);
  rcplib_TASK_SetArg(EAPI_VTYPE_U16,fps);
  return(rcplib_TASK_SendEvent(EAPI_TASKID_UVC,UVC_API_VIDEO_STREAM_CTRL,EAPI_SYNC_RESULT,1000));
}
#define UVC_VideoStreamCtrl(start,format,h_size,v_size,fps) sys_api_UVC_VideoStreamCtrl(start,format,h_size,v_size,fps)
#endif // YIELD_TO_BASIC_INFOROMATION
//////////////////////////////////////////////////////////////////
// common define //
//////////////////////////////////////////////////////////////////
// リスナー登録設定/解除設定
#define UVC_LISTENER_REGIST_REMOVE 0
#define UVC_LISTENER_REGIST_ADD 1
// ステータスリスナーCB返答値
#define UVC_RESULT_OK 0
#define UVC_RESULT_STOP 1
#define UVC_RESULT_START 2
#define UVC_RESULT_NO_STREAM_TIMEOUT 3
#define UVC_RESULT_STARTED_RETRY 4
#define UVC_RESULT_P0_VBUS_ON 100
#define UVC_RESULT_P1_VBUS_ON 101
#define UVC_RESULT_P2_VBUS_ON 102
#define UVC_RESULT_P0_ENUMERATION_COMPLETED 103
#define UVC_RESULT_P1_ENUMERATION_COMPLETED 104
#define UVC_RESULT_P2_ENUMERATION_COMPLETED 105
#define UVC_RESULT_P0_VBUS_OFF 106
#define UVC_RESULT_P1_VBUS_OFF 107
#define UVC_RESULT_P2_VBUS_OFF 108
#define UVC_RESULT_P1_DISCONNECT_HUB 109
#define UVC_RESULT_P2_DISCONNECT_HUB 110
#define UVC_RESULT_P0_DISCONNECT_H7 111
#define UVC_RESULT_CALLER_DIFFERENCE 200
#define UVC_RESULT_EXCLUSIVE 201
#define UVC_RESULT_BUFF_SETUP_ERROR 202
#define UVC_RESULT_NOT_APPLICABLE_SMP_RATE 203
#define UVC_RESULT_NOT_APPLICABLE_RESOLUTION 204
#define UVC_RESULT_NOT_APPLICABLE_FORMAT 205
#define UVC_RESULT_NOT_APPLICABLE_FPS 206
#define UVC_RESULT_ERROR 255
// uvc stream control parameter
#define UVC_STREAM_CTRL_STOP 0
#define UVC_STREAM_CTRL_START 1
// uvc format parameter
#define UVC_STREAM_CODEC_MJPEG 0
#define UVC_STREAM_CODEC_H264 1
#define UVC_STREAM_CODEC_YUV 2
#define UVC_STREAM_CODEC_UNDEFINED 3

#endif

#endif
