//////////////////////////////////////////////////////////////////////////
// @file basicInformation.h
// @brief basic information header
// @details ※このファイルは説明のためだけのファイルで、端末動作には影響しない
// @author This software is contributed or developed by KYOCERA Corporation.
// @copyright (C) 2022 KYOCERA Corporation
//
// SPDX-License-Identifier: MIT
//
//////////////////////////////////////////////////////////////////////////
#ifndef _BASIC_INFORMATION_H_
#define _BASIC_INFORMATION_H_

#include <stdint.h>

//////////////////////////////////////////////////////////////////
// レシピシステム全般の定義 //
//////////////////////////////////////////////////////////////////
// ■Task制御関連の定義
// Taskに対する要求イベントQueueが来るまで待つ処理
#define WAIT_REQUEST_EVENT_QUEUE

// ■Taskのoption設定関連の定義
// Taskのoption設定
#define options void sysReserve_dummyOptionsFunction()
// Taskに割り当てるStackメモリーサイズ設定[word] ※Applicationでは1-65535を選択可
#define StackSize             int StackSize            // 未指定の場合1500[word] = 6000[Byte]
// Task優先度設定(設定値が大きいTaskほど高優先度) ※Applicationでは2-3を選択可
#define TaskPriority          int TaskPriority         // 未指定の場合2
// Taskのイベントキュー最大数 ※Applicationでは1-255を選択可
#define EventQueueSize        int EventQueueSize       // 未指定の場合5
// Taskに割り当てるLocal変数のためのメモリーサイズ設定[Byte] ※Applicationでは1-65535を選択可
#define LocalSize             int LocalSize            // 未指定の場合、定義されたLocal変数のネスト3段分を自動割り当て
// Taskに割り当てるJSON変数のためのメモリーサイズ設定[Byte] ※Applicationでは1-65535を選択可
#define JSONtmpSize           int JSONtmpSize          // 未指定の場合0
// Taskに割り当てるList変数のためのメモリーサイズ設定[Byte] ※Applicationでは1-65535を選択可
#define LISTtmpSize           int LISTtmpSize          // 未指定の場合0
// TaskのDriver属性設定 ※Applicationでの利用は不可
#define DeviceDriver          int DeviceDriver         // 未指定の場合、非Driver属性を自動割り当て
// Taskに割り当てるFormatInformationのためのメモリーサイズ設定[Byte] ※Applicationでは1-65535を選択可
#define BufferFormatInfoSize  int BufferFormatInfoSize // 未指定の場合0
// Taskに割り当てるFIFOバッファのためのメモリーサイズ設定 ※Applicationでは1-65535を選択可
#define BufferFIFOSize        int BufferFIFOSize       // 未指定の場合0
// Reserved
#define ModemSendBufferSize   int ModemSendBufferSize  // 未指定の場合0

// ■特殊型の定義
// 数値型
#define int8   int8_t     //8bitの符号あり整数
#define int16  int16_t    //16bitの符号あり整数
#define int32  int32_t    //32bitの符号あり整数
#define int64  int64_t    //64bitの符号あり整数
#define uint8  uint8_t    //8bitの符号なし整数
#define uint16 uint16_t   //16bitの符号なし整数
#define uint32 uint32_t   //32bitの符号なし整数
#define uint64 uint64_t   //64bitの符号なし整数
// 文字列型
#define str    char       //文字列変数
#define json   char       //JSON文字列変数
#define list   char       //List文字列変数
// 関数型
#define func   int32_t    //関数全般
// 複合型
#define str_arr       uint8*  //文字列変数かByte配列
#define str_json_list char    //文字列変数系全て
#define any           int32_t //整数、小数、文字列変数系全て

//////////////////////////////////////////////////////////////////
// ＜システムライブラリAPIの定義＞ //
//////////////////////////////////////////////////////////////////

///// ■システム制御ライブラリ■
//// ■レシピエンジン情報操作
///
// @brief タスクやタスク間通信関連の情報を読み出すAPI
// @param [in](uint8)item_id Read対象のアイテムのID
// @return uint8 or uint16の各ID値をreturnする
// @detail 必要なヘッダinclude : "svitem.h"
// @note
//     // item_id(Read対象のアイテムのID)への入力値
//     ENGINE_SVITEM_ID_MYID                      // 自タスクID
//     ENGINE_SVITEM_ID_TASKEVENTITEM_EVENT_ID    // 受信イベントID
//     ENGINE_SVITEM_ID_TASKEVENTITEM_SENDER_ID   // 相手タスクID
//     ENGINE_SVITEM_ID_TASKEVENTITEM_SYNC_ID     // 相手タスクからの同期設定ID
//     ENGINE_SVITEM_ID_TASKEVENTITEM_RESULT_CODE // 相手タスクからのリザルトコード
//     ENGINE_SVITEM_ID_TASKEVENTITEM_SEQ_ID      // 同期SeqID
// 
//     <参考>
//     ・自タスクID
//     　自タスクIDは現在処理している自タスクのIDを示す。
//     　"taskid.h"に定義されてある0～31のいずれかのIDを示す。
//     　0～19は機能毎にID固定、20～31はuapp_x.krsやuapp_blockly.krsの利用に応じた自動割り当て。
// 
//     ・受信イベントID
//     　受信イベントIDは現在処理しているイベントのIDを示す。
//     　イベント処理0～65535のいずれかのIDを示す。
//     　0は初期化処理、255は同期処理での利用で用途固定。
//     　1~254は各タスク内のイベント定義に任意に利用可能。
//     　256～はAPIコールに利用。(xxx.kraファイルからのyyyAPI.h自動生成にて256～自動割り当てされる)
//     　60000～はシステム系のブロードキャスト配信イベントに利用。
// 
//     ・相手タスクID
//     　相手タスクIDは現在処理しているイベントを発行した相手タスクのIDを示す。
//     　ID詳細は「自タスクID」の説明を参照。
// 
//     ・相手タスクからの同期設定ID
//     　相手タスクからの同期設定IDは現在の処理が同期/非同期要求の種類を示す。
//     　"eventLib.h"に定義されてある0(0x00)または0(0xff)いずれかのIDを示す。
//     　0(EAPI_SYNC_RESULT)は同期要求、255(EAPI_UNSYNC_NORESULT)は非同期要求を示す。
// 
//     ・相手タスクからのリザルトコード
//     　相手タスクからのリザルトコードはイベントを発行した相手タスクが設定したリザルトコードを示す。
//     　0～255のいずれかのリザルトコードを示す。
//     　0は成功、200(EAPI_ERR_TIMEOUT)～255(EAPI_ERR_UNKNOWN)はシステム系やその他のエラーで用途固定。
//     　システム系やその他のエラーの内訳は"eventLib.h"を参照。
//     　1~199は各API毎に任意に利用可能。
// 
//     ・同期SeqID
//     　同期SeqIDは同期処理に用いる連番IDを示す。
//     　0～255のいずれかのIDを示す。
//     　APIの同期要求実行の度にインクリメントして利用するルール。
///
func rcplib_SV_Read(uint8 item_id) {
    
}

///
// @brief タスク関連の情報を書き込むAPI ※基本的には利用禁止
// @param [in](uint8)item_id Write対象のアイテムのID
// @param [in](str||uint8[])write_data データ
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "svitem.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_SV_Write(uint32 item_id, str_arr write_data) {
    
}

//// ■システム制御
///
// @brief 端末を再起動するAPI
// @return なし
// @detail 必要なヘッダinclude : 無し
// @attention 
//    本APIを実行時、このAPI内でrcplib_NV_Sync()相当の処理と、再起動処理を実行する。
//    API内で再起動処理が実行されるため、同タスク内の後続の処理は実行されない。
//    内包されるrcplib_NV_Sync()の処理は、物理的に書換え回数が有限のメモリーを書き換える処理であるため
//    rcplib_NV_Write()やrcplib_NV_Sync()の説明に従い、注意して利用すること。
// @code
//  // 端末を再起動する
//  rcplib_SYS_Reboot();
///
func rcplib_SYS_Reboot() {

}

///
// @brief レシピエンジンのバージョン情報を取得するAPI
// @return uint32のレシピエンジンのバージョン情報をreturnする
// @detail 必要なヘッダinclude : 無し
///
func rcplib_SYS_VersionENGINE() {

}

///
// @brief 端末ファームウェアのバージョン情報を取得するAPI
// @return uint32の端末FWのバージョン情報をreturnする
// @detail 必要なヘッダinclude : 無し
///
func rcplib_SYS_VersionSTM() {

}

///
// @brief システム稼働時間(端末起動時を0とした[msec]単位のインクリメント値)を取得するAPI
// @return uint64のシステム稼働時間情報をreturnする
// @detail 必要なヘッダinclude : 無し
// @code
//  // システム稼働時間の取得結果を格納するための変数を定義
//  uint64 current_tick;
// 
//  // システム稼働時間を取得
//  current_tick = rcplib_SYS_GetTick();
///
func rcplib_SYS_GetTick() {

}

///
// @brief ベンダーコードを取得するAPI
// @return strの"Kyocera"という文字列をreturnする
// @detail 必要なヘッダinclude : 無し
///
func rcplib_SYS_VendorCode() {

}

///
// @brief 指定時間のウェイトを実行するAPI
// @param [in](uint32)sleep ウェイト時間設定 <1~4294967295[msec]>
// @return なし
// @detail 必要なヘッダinclude : 無し
// @note
//     実際にウェイトする時間は「指定したsleepの時間 - 1[msec]」の範囲でばらつく。
//     本ウェイト処理は実行したタスク自体の処理を停止させるため、次に要求を受けているイベント処理は実行できない。
// @code
//  // 1秒間ウェイトする
//  rcplib_SYS_Sleep(1000);
///
func rcplib_SYS_Sleep(uint32 sleep) {

}

///
// @brief ログ出力を実行するAPI
// @param [in](uint8)level 出力するログレベルを指定
// @param [in](int||uint||float||str)data 出力するデータ ※64bitの数値変数は利用不可
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @note
//     ENGINE_LOG_DとENGINE_LOG_L、ENGINE_LOG_MとENGINE_LOG_Hはそれぞれ機能的には同一。
//     それぞれ以下の通りの文字列を自動付与しログ出力される。
//     ENGINE_LOG_Dのログの冒頭には"[D]"。ENGINE_LOG_Lのログの冒頭には"[L]"。
//     ENGINE_LOG_Mのログの冒頭には"[M]"。ENGINE_LOG_Hのログの冒頭には"[H]"。
//     
//     // level(出力するログレベル指定)への入力値
//     ENGINE_LOG_D // ログの出力設定の有効化時のみ、USB(type-C) VirtualCOMポートにログ[D]を出力
//     ENGINE_LOG_L // ログの出力設定の有効化時のみ、USB(type-C) VirtualCOMポートにログ[L]を出力
//     ENGINE_LOG_M // ログの出力設定に関わらず、フラッシュログ(不揮発メモリーへのログ)[M]を出力 ※ユーザー用
//     ENGINE_LOG_H // ログの出力設定に関わらず、フラッシュログ(不揮発メモリーへのログ)[H]を出力 ※システムで利用
//     
//     128文字制限あり。ログ冒頭に「[XXX][Y]」(XXXはタスク名、Yはログレベル)が自動付与されるため実質120文字制限。
//     制限文字数を超える分は自動的にカットされる。
///
func rcplib_SYS_LogPrint(uint8 level, any data) {

}

///
// @brief ログの出力設定の有効化時のみ、USB(type-C) VirtualCOMポートにログ[D]を出力するAPI(ラッパー関数)
// @param [in](int||uint||float||str)data 出力するデータ ※64bitの数値変数は利用不可
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_SYS_LogPrint(ENGINE_LOG_D, data)。
// @code
//  // ※予め、キッティングツールで「USBポートからログの出力」の機能を有効化すること
// 
//  // USB(type-C) VirtualCOMポートにログ[D]を出力する
//  rcplib_LOG_Print(100);
//  rcplib_LOG_Print(-10);
//  rcplib_LOG_Print(0.5);
//  rcplib_LOG_Print("This is [D] log test");
///
func rcplib_LOG_Print(any data) {
    
}
///
// @brief ログの出力設定の有効化時のみ、USB(type-C) VirtualCOMポートにログ[L]を出力するAPI(ラッパー関数)
// @param [in](int||uint||float||str)data 出力するデータ ※64bitの数値変数は利用不可
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_SYS_LogPrint(ENGINE_LOG_L, data)。
///
func rcplib_LOG_Low(any data) {
    
}
///
// @brief ログの出力設定に関わらず、フラッシュログ(不揮発メモリーへのログ)[M]を出力するAPI(ラッパー関数) ※ブロックプログラミングで利用
// @param [in](int||uint||float||str)data 出力するデータ ※64bitの数値変数は利用不可
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @attention [NOT_FOR_USERS]ブロックプログラミングで利用のため利用は非推奨。
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_SYS_LogPrint(ENGINE_LOG_M, data)。
///
func rcplib_LOG_Blockly(any data) {
    
}
///
// @brief ログの出力設定に関わらず、フラッシュログ(不揮発メモリーへのログ)[M]を出力するAPI(ラッパー関数)
// @param [in](int||uint||float||str)data 出力するデータ ※64bitの数値変数は利用不可
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_SYS_LogPrint(ENGINE_LOG_M, data)。
///
func rcplib_LOG_Flash(any data) {
    
}

///
// @brief フォーマット指定付きログ出力を実行するAPI
// @param [in](uint8)level 出力するログレベルを指定
// @param [in](str)format フォーマット指定用文字列変数
// @param [in](int||uint||float||str)data1 変数データ1
// @param [in](int||uint||float||str)datax 変数データ2以降 ※64bitの数値変数は利用不可、変数データは最大data8まで
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @note
//     ENGINE_LOG_DとENGINE_LOG_L、ENGINE_LOG_MとENGINE_LOG_Hはそれぞれ機能的には同一。
//     それぞれ以下の通りの文字列を自動付与しログ出力される。
//     ENGINE_LOG_Dのログの冒頭には"[D]"。ENGINE_LOG_Lのログの冒頭には"[L]"。
//     ENGINE_LOG_Mのログの冒頭には"[M]"。ENGINE_LOG_Hのログの冒頭には"[H]"。
//     
//     // level(出力するログレベル指定)への入力値
//     ENGINE_LOG_D // ログの出力設定の有効化時のみ、USB(type-C) VirtualCOMポートにログ[D]を出力
//     ENGINE_LOG_L // ログの出力設定の有効化時のみ、USB(type-C) VirtualCOMポートにログ[L]を出力
//     ENGINE_LOG_M // ログの出力設定に関わらず、フラッシュログ(不揮発メモリーへのログ)[M]を出力 ※ユーザー用
//     ENGINE_LOG_H // ログの出力設定に関わらず、フラッシュログ(不揮発メモリーへのログ)[H]を出力 ※システムで利用
//     
//     128文字制限あり。ログ冒頭に「[XXX][Y]」(XXXはタスク名、Yはログレベル)が自動付与されるため実質120文字制限。
//     制限文字数を超える分は自動的にカットされる。
//     
//     フォーマット指定用文字列変数として指定可能なフォーマット指定子は「%d(整数), %f(実数), %s(文字列)」のみ。
//     それ以外の「%c, %x, %a」等をフォーマット指定用文字列変数内に記述した場合は「c, x, a」と変換される。
//     また、桁数や文字数を限定する「%5d, %5.2f, %5s」等も利用不可。%を表示するには「%%」を指定すること。
///
func rcplib_SYS_LogPrintf(uint8 level, any format, any data1, ...) {

}

///
// @brief ログの出力設定の有効化時のみ、USB(type-C) VirtualCOMポートにフォーマット指定付きログ[D]を出力するAPI(ラッパー関数)
// @param [in](str)format フォーマット指定用文字列変数
// @param [in](int||uint||float||str)data1 変数データ1
// @param [in](int||uint||float||str)datax 変数データ2以降 ※64bitの数値変数は利用不可、最大data8まで
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_SYS_LogPrintf(ENGINE_LOG_D, format, data1, ...)。
// @code
//  // ※予め、キッティングツールで「USBポートからログの出力」の機能を有効化すること
// 
//  // USB(type-C) VirtualCOMポートにログ[D]を出力する
//  rcplib_LOG_Printf("data1:%d, data2:%d, data3:%f", 100, -10, 0.5); //data1:100, data2:-10, data3:0.500000
//  rcplib_LOG_Printf("This is %s log test", "[D]"); //This is [D] log test
///
func rcplib_LOG_Printf(any format, any data1, ...) {
    
}
///
// @brief ログの出力設定の有効化時のみ、USB(type-C) VirtualCOMポートにフォーマット指定付きログ[L]を出力するAPI(ラッパー関数)
// @param [in](str)format フォーマット指定用文字列変数
// @param [in](int||uint||float||str)data1 変数データ1
// @param [in](int||uint||float||str)datax 変数データ2以降 ※64bitの数値変数は利用不可、最大data8まで
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_SYS_LogPrintf(ENGINE_LOG_L, format, data1, ...)。
///
func rcplib_LOG_Lowf(any format, any data1, ...) {
    
}
///
// @brief ログの出力設定に関わらず、フォーマット指定付きフラッシュログ(不揮発メモリーへのログ)[M]を出力するAPI(ラッパー関数) ※ブロックプログラミングで利用
// @param [in](str)format フォーマット指定用文字列変数
// @param [in](int||uint||float||str)data1 変数データ1
// @param [in](int||uint||float||str)datax 変数データ2以降 ※64bitの数値変数は利用不可、最大data8まで
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @attention [NOT_FOR_USERS]ブロックプログラミングで利用のため利用は非推奨。
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_SYS_LogPrintf(ENGINE_LOG_M, format, data1, ...)。
///
func rcplib_LOG_Blocklyf(any format, any data1, ...) {
    
}
///
// @brief ログの出力設定に関わらず、フォーマット指定付きフラッシュログ(不揮発メモリーへのログ)[M]を出力するAPI(ラッパー関数)
// @param [in](str)format フォーマット指定用文字列変数
// @param [in](int||uint||float||str)data1 変数データ1
// @param [in](int||uint||float||str)datax 変数データ2以降 ※64bitの数値変数は利用不可、最大data8まで
// @return なし
// @detail 必要なヘッダinclude : "logAPI.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_SYS_LogPrintf(ENGINE_LOG_M, format, data1, ...)。
///
func rcplib_LOG_Flashf(any format, any data1, ...) {
    
}

///
// @brief 入力文字列変数を数値に変換するAPI
// @param [in](str)src 数値に変換対象の文字列変数
// @return ピリオドを含む小数の場合はdouble、負符号指定のある整数の場合はint64、符号指定のない整数の場合はuint64をreturnする
// @detail 必要なヘッダinclude : なし
///
func rcplib_SYS_StoV(str src) {
    
}

///
// @brief LowPowerModeへの移行を抑制するAPI ※基本的には利用禁止
// @param [in](uint8)mode LowPowerMode抑制制御 <0=LPMへの移行を抑制, 1=LPMへの移行抑制を解除>
// @return なし
// @detail 必要なヘッダinclude : なし
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_ALPM_SetEnterLPM(uint8 mode) {
    
}

///
// @brief LowPowerModeへの移行が可能な状態かを取得するAPI
// @return 0:LowPowerには移行しない状態, 1:CPU低負荷時LowPowerに自動移行が可能な状態
// @detail 必要なヘッダinclude : なし
///
func rcplib_ALPM_IsEnterLPM() {
    
}

///
// @brief CPUのモードを変更するAPI
// @param [in](uint8)mode CPUのmode設定 <0=CPU High performance mode(HPM)要求, 1=CPU HPM要求解除>
// @return なし
// @detail 必要なヘッダinclude : なし
// @attention CPU HPM要求1回の実行に対して、必ず要求解除を1回実行すること。※要求回数以上の要求解除の実行は禁止
// @note 本制御を実行することにより、高温時の機能制限がかかる場合がある。
//       機能制限についてはホワイトペーパーの「9-2.高温時の機能制限」の項を参照。
//       CPU HPMは473.6MHzで動作。通常時は96MHzで動作。
//       本コマンドによる要求時、またはカメラ利用時、またはLTEデータ通信の一部機能を利用時に
//       CPU HPMで動作する。
///
func rcplib_PWRM_SetPerformanceMode(uint8 mode) {
    
}

///
// @brief IRQ設定を実行するAPI ※基本的には利用禁止
// @param [in](int32)target 設定対象を指定、詳細は"main.h"参照
// @param [in](uint8)enable 有効化/無効化設定 <1=有効化, 0=無効化>
// @return 0:成功, -1:レシピからアクセスできないIRQn_Typeが指定された
// @detail 必要なヘッダinclude : "main.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_NVIC_SetIRQ(int32 target, uint8 enable) {
    
}

///
// @brief UART(RS-485,RS-232C)/CAN機能使用時にLowPowerModeへの移行を抑制するAPI ※基本的には利用禁止
// @param [in](uint8)target 設定対象を指定 <KRDEFINE_EXTDEV_RS485, KRDEFINE_EXTDEV_RS232, KRDEFINE_EXTDEV_CAN1のみ利用可>
// @param [in](int8)enable ON/OFF設定 <KRDEFINE_EXTDEV_POW_ON=LPMへの移行を抑制, KRDEFINE_EXTDEV_POW_OFF=LPMへの移行抑制を解除>
// @return 0:成功, -1:制御デバイス指定エラー
// @detail 必要なヘッダinclude : "krdefine.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
// @note 本APIを実行せずにUART(RS-485,RS-232C)/CAN機能使用した場合、受信待受け時などでCPUが意図せずLowPowerModeに遷移されてしまい、受信データを取り漏らす可能性がある。
///
func rcplib_BUFFPOW_Control(uint8 target, uint8 enable) {
    
}

///
// @brief レシピOTA（Over The Air）を実行するAPI(ベータ版)
// @param [in](int32)timeout API実行時のタイムアウト値 <EAPI_TIMEOUT_ZERO固定>
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0:KCS_RCPOTA_RESULT_NO_ERROR, 1:KCS_RCPOTA_RESULT_ERR_INVALID_URL, 2:KCS_RCPOTA_RESULT_ERR_CANNOT_START> ※詳細は"kcSystemAPI.h"のRecipeOTA 返答値(ex_result)を参照
// @param [in](str)hosturl 接続先サーバーのURL <127文字以下で任意の文字列>
// @param [in](uint8)rcv_event_id コールバックを受けるイベントID <1～254>
// @param [in](str)http_header HTTPヘッダ指定 ※ベータ版のためHTTPヘッダの指定は不可
// @param [in](uint8)protocol 利用する通信プロトコル、詳細は"modemMgrTask.h"の#define MMG_PROTOCOL_XXX参照 ※ベータ版のためHTTPS固定(この設定でHTTPアクセスも可能)
// @param [in](uint8)sni TLS通信利用時のSNI設定 <MMG_SNI_DISABLE:無効, MMG_SNI_ENABLE:有効> ※ベータ版のため有効固定
// @param [in](uint8)auth_mode TLS通信利用時のmode設定 <MMG_AUTH_NONE:認証なし, MMG_AUTH_SRV:サーバー認証のみ, MMG_AUTH_SRVCLI:クライアント認証も含む> ※ベータ版のためサーバー認証のみ固定
// @param [in](uint8)auth_index 認証ID(TLS接続や証明書設定の管理ID) <1～5> ※ベータ版のため指定不可
// @return 0:成功, -1:失敗(詳細はex_resultに通知)
// @detail 必要なヘッダinclude : "modemMgrTask.h" "kcSystemAPI.h"
// @note 本API実行により、レシピのOTA機能が実行できる。
//       接続先サーバー上に"rcp_compress.zip"を展開したレシピ実行ファイル("rcp_info.bin","rcp_prog.bin")を配置しておき本APIを実行、レシピ実行ファイルのダウンロードが完了すると自動的に端末がリセットし更新処理が走る。
//       ダウンロードしたレシピ実行ファイルのタイムスタンプを確認し、現在動作させているものと同じであれば更新処理は実行されない。
//       レシピOTA実行中に、端末のファームウェアのOTAが実行された場合は、端末のファームウェアのOTAが優先されて実行される。
//       ベータ版のためhttp_headerは指定不可、protocolはHTTPS、sniは有効、auth_modeはサーバー認証のみ、auth_indexは指定不可、の固定利用のみとなる。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(uint16)response_code 実行結果のレスポンスコード ※kcSystemAPI.hのRecipeOTA Event返答値(resp_code)を参照
///
func rcplib_KCS_RcpOTA(int32 timeout, uint8 sync, uint8 ex_result, str hosturl, uint8 rcv_event_id, str http_header, uint8 protocol, uint8 sni, uint8 auth_mode, uint8 auth_index) {
    
}

//// ■タスク間通信
///
// @brief タスク間通信の引数管理情報を初期化するAPI
// @return なし
// @detail 必要なヘッダinclude : 無し
///
func rcplib_TASK_InitArg() {
    
}

///
// @brief 相手タスクに通知するイベント引数を追加するAPI
// @param [in](int32)type 設定対象の型を指定
// @param [in](int||uint||float||str)data 引数情報に追加するデータ
// @return なし
// @detail 必要なヘッダinclude : 無し
// @attention 基本的には「xxx.kraファイルからのyyyAPI.h自動生成」の際に利用されるAPIのため、直接利用は禁止。
// @note
//     rcplib_TASK_SetArg(type, data)
//     mainループ処理のrcplib_TASK_InitArg()にて
// 
//     // target(設定対象の型)への入力値
//     EAPI_VTYPE_I8  // int8
//     EAPI_VTYPE_I16 // int16
//     EAPI_VTYPE_I32 // int32
//     EAPI_VTYPE_I64 // int64
//     EAPI_VTYPE_U8  // uint8
//     EAPI_VTYPE_U16 // uint16
//     EAPI_VTYPE_U32 // uint32
//     EAPI_VTYPE_U64 // uint64
//     EAPI_VTYPE_F32 // float
//     EAPI_VTYPE_F64 // double
//     EAPI_VTYPE_STR // str
///
func rcplib_TASK_SetArg(int32 type, any data) {
    
}

///
// @brief 相手タスクから渡された引数情報を取得するAPI
// @param [in](int32)index 設定対象を指定、1番目の引数であれば0、2番目は1、、、の様に指定する
// @return -1:指定したindexが範囲外, indexが正しい場合は、相手タスクが指定した形式int64||uint64||double||str等に応じた値をreturnする
// @detail 必要なヘッダinclude : 無し
///
func rcplib_TASK_GetArg(int32 index) {
    
}

///
// @brief 指定したタスクIDにイベントを送信するAPI
// @param [in](uint8)task_id メッセージ送信先のタスクID
// @param [in](uint8)event_id メッセージ送信先のイベントID
// @param [in](uint8)sync メッセージ送信に対する同期的な返答有無設定 <EAPI_SYNC_RESULT=同期実行, EAPI_UNSYNC_NORESULT=非同期実行>
// @param [in](int32)timeout メッセージ送信に対する返答までのタイムアウト設定(syncが非同期実行の際は不問) <EAPI_TIMEOUT_UNLIMITED=タイムアウト無し, それ以外=単位[msec]で指定>
// @return EAPI_NO_ERROR // 正常
//         EAPI_ERR_TIMEOUT // タイムアウト発生
//         EAPI_ERR_QUEUEFULL // queue full発生
//         EAPI_ERR_TASKNOMATCH // タスクID異常
//         EAPI_ERR_BADEVENT // ユーザー利用できないイベントID指定
//         EAPI_ERR_FORCESTOP // 停止中のタスクへの送信
//         EAPI_ERR_API // メッセージ送信先のタスクが独自に定義したエラー発生
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 自タスクに対して実行する場合、syncにはEAPI_UNSYNC_NORESULTのみを指定すること。
//       タスクIDは"taskid.h"に定義されている。
//       syncやtimeout設定の利用方法は個々のAPI設計に依存する。詳細は各API仕様を参照。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ※利用方法毎に自由に定義可能、事前にrcplib_TASK_SetArg()にてSetした回数に応じて
//    　コールバックイベントにてrcplib_TASK_GetArg(x)を実行しGetできる
//    　Setした回数がn回の場合、xには0～n-1のいずれかを利用可能
///
func rcplib_TASK_SendEvent(uint8 task_id, uint8 event_id, uint8 sync, int32 timeout) {
    
}

///
// @brief 同期メッセージを受信した後の返答を送信するAPI
// @param [in](uint8)task_id 返答先(メッセージ送信元)のタスクID
// @param [in](uint8)sync_id 同期処理か否かを示すID(同期ID) <EAPI_SYNC_RESULT=同期実行, EAPI_UNSYNC_NORESULT=非同期実行>
// @param [in](uint8)result 返答する結果
// @param [in](uint8)seq_id 同期処理におけるシーケンシャルに自動生成される監理ID(連番ID)
// @return なし
// @detail 必要なヘッダinclude : 無し
// @note メッセージ送信元からのイベント処理実行中であれば、その情報である
//       タスクIDはrcplib_SV_Read(ENGINE_SVITEM_ID_TASKEVENTITEM_SENDER_ID)、
//       同期IDはrcplib_SV_Read(ENGINE_SVITEM_ID_TASKEVENTITEM_SYNC_ID)、
//       連番IDはrcplib_SV_Read(ENGINE_SVITEM_ID_TASKEVENTITEM_SEQ_ID)で取得可能。
///
func rcplib_TASK_SendResult(uint8 task_id, uint8 sync_id, uint8 result, uint8 seq_id) {
    
}

///
// @brief 自タスクに指定したイベントIDのメッセージを送信するAPI(ラッパー関数)
// @param [in](uint8)event_id メッセージ送信先のイベントID
// @return EAPI_NO_ERROR // 正常
//         EAPI_ERR_QUEUEFULL // queue full発生
//         EAPI_ERR_BADEVENT // ユーザー利用できないイベントID指定
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_TASK_SendEvent(rcplib_SV_Read(ENGINE_SVITEM_ID_MYID), event_id, EAPI_UNSYNC_NORESULT, EAPI_TIMEOUT_ZERO)。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ※利用方法毎に自由に定義可能、事前にrcplib_TASK_SetArg()にてSetした回数に応じて
//    　コールバックイベントにてrcplib_TASK_GetArg(x)を実行しGetできる
//    　Setした回数がn回の場合、xには0～n-1のいずれかを利用可能
///
func rcplib_TASK_SendEventToThisTask(uint8 event_id) {
    
}

//// ■不揮発メモリー
///
// @brief 不揮発メモリーのデータを読み出すAPI
// @param [in](uint32)nv_id 読み出す不揮発メモリーのアイテムID
// @param [in](uint32)index 読み出す不揮発メモリーのアイテムのindex指定(indexが1つのみのアイテムは0を指定すること)
// @param [out](uint8[])data データの出力先変数
// @return 0:成功, -1:NV_ParamIDがサポート外
// @detail 必要なヘッダinclude : "flashLib.h"
// @note NVアイテムの一覧は"flashLib.h"に定義されている。
///
func rcplib_NV_Read(uint32 nv_id, uint32 index, uint8 data[]) {
    
}

///
// @brief ミラー領域の不揮発メモリーのアイテムに任意のデータを書き込むAPI
// @param [in](uint32)nv_id 書き込む不揮発メモリーのアイテムID
// @param [in](uint32)index 書き込む不揮発メモリーのアイテムのindex指定(indexが1つのみのアイテムは0を指定すること)
// @param [in](uint8[]||int||uint||float||str)data 書き込むデータ
// @param [in](uint32)size 書き込むデータの長さ
// @return 0:成功, -1:NV_ParamIDがサポート外、または指定したサイズが不一致
// @detail 必要なヘッダinclude : "flashLib.h"
// @attention 本APIは、物理的に書換え回数が有限のメモリーを書き換えうる処理。
//            本APIを実行後、実際にメモリーを書き換える契機はrcplib_NV_Sync()のAPIを実行した時や、
//            rcplib_SYS_Reboot()のAPIを実行した時や、キッティングツール接続や、
//            ボタン4秒長押しによる電源OFF時が該当する。
//            電源ケーブルの抜去による電源OFF時は該当しない。
//            本APIを利用する場合は、必ずトータルで5000回以下のメモリー書き換え実行となるよう注意すること。
// @note NVアイテムの一覧は"flashLib.h"に定義されている。
///
func rcplib_NV_Write(uint32 nv_id, uint32 index, any data, uint32 size) {
    
}

///
// @brief 書き込んだミラー領域のデータ全てを不揮発メモリーに反映させるAPI
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "flashLib.h"
// @attention 本APIは、物理的に書換え回数が有限のメモリーを書き換える処理。
//            本APIをご利用になる場合は、必ずトータルで5000回以下の実行となるよう注意すること。
///
func rcplib_NV_Sync() {
    
}

//// ■タイマー
///
// @brief タイマーを作成するAPI
// @param [in](uint8)timer_id タイマーID <タスクごとに0～15>
// @param [in](uint32)interval タイマーの周期<1～4294967295[msec]>
// @param [in](int8)auto_reload 自動の再開 <0=再開しない、1=再開する>
// @param [in](uint8)event_id タイマー満了時のイベントID <1～254>
// @return 0:成功, -1:timer_idが不正
// @detail 必要なヘッダinclude : 無し
// @attention タスクの初期化処理内でのみ実行すること。
// @note タスク内での同タイマーIDによる2度目以降の実行は再設定処理となる。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・取得値なし
///
func rcplib_TIMER_Create(uint8 timer_id, uint32 interval, int8 auto_reload, uint8 event_id) {
    
}

///
// @brief タイマーを開始するAPI
// @param [in](uint8)timer_id タイマーID <タスクごとに0～15>
// @return 0:成功, -1:timer_idが不正
// @detail 必要なヘッダinclude : 無し
// @note 本API実行後、設定周期経過後にタイマー満了イベントが発生する。
//       稼動中のタイマーに本APIを実行した場合、タイマーは再開される。
// @code
// // グローバル変数
// uint8 l_timer_id; 
// uint32 l_interval;
// int8 l_auto_reload; 
// int8 l_event_id; 
//
// // 初期化処理
// func event_init() {
//     // グローバル変数を初期化
//     l_timer_id = 0; 
//     l_interval = 1000;
//     l_auto_reload = 0; 
//     l_event_id = 0; 
//     // 初期化処理でタイマーを作成
//     rcplib_TIMER_Create(l_timer_id, l_interval, l_auto_reload, l_event_id);
//     // タイマーを開始(初期化処理以外で実行してもOK)
//     rcplib_TIMER_Start(l_timer_id);
// }
// 
// // mainループ処理
// void main_loop() {
// 
//     //...基本処理省略...//
// 
//     // タイマー満了イベント処理 (l_interval = 1000の設定なので、初期化処理の1秒後にイベントが飛んでくる)
//     else if(event_id == l_event_id) {
//         // ★Timer満了時の処理をここに記載すること★
//     }
// }
///
func rcplib_TIMER_Start(uint8 timer_id) {
    
}

///
// @brief タイマーを停止するAPI
// @param [in](uint8)timer_id タイマーID <タスクごとに0～15を利用可>
// @return 0:成功, -1:timer_idが不正
// @detail 必要なヘッダinclude : 無し
// @note 本APIは停止中のタイマーに何度実行しても問題ない。
// @code
// // タイマーを作成
// rcplib_TIMER_Create(l_timer_id, l_interval, l_auto_reload, l_event_id);
// // タイマーを開始
// rcplib_TIMER_Start(l_timer_id);
// // タイマーを停止(停止中に実行してもOK)
// rcplib_TIMER_Stop(l_timer_id);
// 
// ※タイマー自体の利用方法詳細はrcplib_TIMER_Start()の利用例を参照
///
func rcplib_TIMER_Stop(uint8 timer_id) {
    
}

///
// @brief タイマーの周期を変更するAPI
// @param [in](uint8)timer_id タイマーID <タスクごとに0～15を利用可>
// @param [in](uint32)interval タイマーの周期 <1～4294967295[msec]>
// @return 0:成功, -1:timer_idが不正
// @detail 必要なヘッダinclude : 無し
// @note 本APIはタイマー停止中に何度実行しても問題ない。
//       タイマー開始中の本APIの実行では、タイマーは停止される。
// @code
// // タイマーを作成
// rcplib_TIMER_Create(l_timer_id, l_interval, l_auto_reload, l_event_id);
// // タイマーの周期を変更する
// rcplib_TIMER_SetPeriod(l_timer_id, l_interval);
// 
///
func rcplib_TIMER_SetPeriod(uint8 timer_id, uint32 interval) {
    
}

///
// @brief タイマーの動作状態を取得するAPI
// @param [in](uint8)timer_id タイマーID <タスクごとに0～15を利用可>
// @return 0:タイマー停止中(またはtimer_idが不正), 1:Timer稼働中
// @detail 必要なヘッダinclude : 無し
///
func rcplib_TIMER_IsActive(uint8 timer_id) {
    
}

//// ■端末内の時刻を管理するReal Time Clock(RTC)
///
// @brief RTC時刻をUNIX時間(UTC)で取得するAPI
// @return uint64のUNIX時間(UTC)をreturnする
// @detail 必要なヘッダinclude : 無し
// @note UNIX時間とは、UTC時刻における1970年1月1日午前0時0分0秒からの経過秒数になる。
//       日本標準時(JST)は、UTC時刻から9時間進めた時刻になる。
//       端末の電源ON以降一度も(圏外などの影響により)基地局からの時刻情報を取得できない場合は
//       0(=1970年1月1日0時0分0秒)がreturnされる。
///
func rcplib_RTC_GetTime() {
    
}

///
// @brief RTC時刻をUNIX時間(UTC)で設定するAPI ※基本的には利用禁止
// @param [in](uint64)time 設定するUNIX時間(UTC)時刻
// @return なし
// @detail 必要なヘッダinclude : 無し
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_RTC_SetTime(uint64 time) {
    
}

///
// @brief RTCアラームの作成と設定を行うAPI
// @param [in](uint8)event_id 設定時刻到達時の発行イベントID <1～254>
// @param [in](uint32)time 設定するアラーム時刻、UTCで0時からの経過秒数を指定 <0～86399[秒]>
// @param [in](uint8)oneshot 繰り返しの設定 <0:繰り返しをする, 1:1回のみ>
// @return -1:アラーム時刻不正、アラーム登録数(上限16個)を超過
//         0～15:作成したRTCアラームのアラームID
// @detail 必要なヘッダinclude : 無し
// @note 日本標準時(JST)は、UTC時刻から9時間進めた時刻になる。
//       同時に最大16個のアラームを利用可能。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・取得値なし
///
func rcplib_RTC_CreateAlarm(uint8 event_id, uint32 time, uint8 oneshot) {
    
}

///
// @brief RTCアラームを削除するAPI
// @param [in](uint8)alarm_id 削除するアラームID <0～15、アラーム作成時のreturn値を利用>
// @return なし
// @detail 必要なヘッダinclude : 無し
///
func rcplib_RTC_DeleteAlarm(uint8 alarm_id) {
    
}

///
// @brief RTCアラーム時刻を再設定するAPI
// @param [in](uint8)alarm_id 再設定するアラームID <0～15、アラーム作成時のreturn値を利用>
// @param [in](uint32)time 再設定するアラーム時刻、UTCで0時からの経過秒数を指定 <0～86399[秒]>
// @return なし
// @detail 必要なヘッダinclude : 無し
///
func rcplib_RTC_ChangeAlarm(uint8 alarm_id, uint32 time) {
    
}

///
// @brief ミリ秒情報を含むRTC時刻をUNIX時間(UTC)で取得するAPI
// @return doubleのUNIX時間(UTC)をreturnする
// @detail 必要なヘッダinclude : 無し
// @note UNIX時間とは、UTC時刻における1970年1月1日午前0時0分0秒からの経過秒数になる。
//       日本標準時(JST)は、UTC時刻から9時間進めた時刻になる。
//       端末の電源ON以降一度も(圏外などの影響により)基地局からの時刻情報を取得できない場合は
//       0(=1970年1月1日0時0分0秒)がreturnされる。
//       類似の時刻取得APIであるrcplib_RTC_GetTime()との違いは、本APIのreturn値がdouble形式であることと
//       その小数部分にミリ秒単位の情報を含むことである。
///
func rcplib_RTC_GetTimeMsec() {
    
}

///// ■各種機能部ライブラリ■
//// ■GPIO制御
///
// @brief GPIO 機能設定変更 API  ※基本的には利用禁止
// @param [in](uint32)port ポート番号 ※"main.h"のdefineを利用可能
// @param [in](uint32)pin  ピン番号 ※"main.h"のdefineを利用可能
// @param [in](uint32)mode 設定モード
// @param [in](uint32)pull pull-up/pull-down抵抗の指定
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "main.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
// @note 本APIを実行することによりGPIOポートのconfig設定が可能。
//       制御可能ポートは"main.h"に記載のもののみ。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "main.h"
// 
//  // GPIOの機能設定
//  rcplib_GPIO_Config(ACC_INT1_GPIO_Port, ACC_INT1_Pin, GPIO_MODE_IT_RISING, GPIO_PULLDOWN);
///
func rcplib_GPIO_Config(uint32 port, uint32 pin, uint32 mode, uint32 pull) {
    
}

///
// @brief GPIOの入力情報を取得するAPI
// @param [in](uint32)port ポート番号 ※"main.h"のdefineを利用可能
// @param [in](uint16)pin  ピン番号 ※"main.h"のdefineを利用可能
// @return 0:GPIOの状態がCLOSE(LOW), 1:GPIOの状態がOPEN(HIGH), -1:失敗
// @detail 必要なヘッダinclude : "main.h"
// @note 本APIを実行することによりGPIOポートの状態を読み取ることが可能。
//       制御可能ポートは"main.h"に記載のもののみ。
//       EXT_USER_GPI1は端子10pin、EXT_USER_GPI2は端子11pin、
//       EXT_USER_GPI3は端子13pinを示す。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "main.h"
// 
//  uint8 val;
// 
//  // 接点GPIO2(11pin)の状態を読み取る
//  val = rcplib_GPIO_Read(EXT_USER_GPI2);
//  if (val == EXT_USER_GPI_HIGH) {
//      rcplib_LOG_Print("接点11pinの入力状態はOPEN");
//  } else {
//      rcplib_LOG_Print("接点11pinの入力状態はCLOSE");
//  }
///
func rcplib_GPIO_Read(uint32 port, uint16 pin) {
    
}

///
// @brief GPIOの出力状態を設定するAPI
// @param [in](uint32)port ポート番号 ※"main.h"のdefineを利用可能
// @param [in](uint16)pin  ピン番号 ※"main.h"のdefineを利用可能
// @param [in](uint8)data  設定値 <EXT_USER_GPO_SET_LOW:CLOSE制御, EXT_USER_GPO_SET_OD:OPEN制御>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "main.h"
// @attention
//    EXT_USER_GPO1, EXT_USER_GPO2, EXT_USER_USART6_RTS以外のGPIOは、
//    センサドライバやシリアル制御サブアプリなどのAPI利用の際に動作するため利用禁止。
// @note 本APIを実行することによりGPIOポートの出力状態を変えることが可能。
//       制御可能ポートは"main.h"に記載のもののみ。
//       EXT_USER_GPO1は端子10pin、EXT_USER_GPO2は端子11pinを示す。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "main.h"
// 
//  // 接点GPIO2(11pin)をOPENに設定
//  rcplib_GPIO_Write(EXT_USER_GPO2, EXT_USER_GPO_SET_OD);
// 
//  // 接点GPIO2(11pin)をCLOSEに設定
//  rcplib_GPIO_Write(EXT_USER_GPO2, EXT_USER_GPO_SET_LOW);
///
func rcplib_GPIO_Write(uint32 port, uint16 pin, uint8 data) {
    
}

///// ■I2C制御[NOT_FOR_USERS]
///
// @brief I2Cポート初期化API ※センサドライバ(sdev_sensor)経由で操作し基本的には利用禁止/引数の値も変えないこと
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_I2C2固定>
// @param [in](uint32)instance インスタンスID <I2C2固定>
// @param [in](uint32)timing 0x0000020dを指定
// @param [in](uint32)own_address1 0を指定
// @param [in](uint32)addressing_mode I2C_ADDRESSINGMODE_7BITを指定
// @param [in](uint32)dual_address_mode I2C_DUALADDRESS_DISABLEを指定
// @param [in](uint32)own_address2 0を指定
// @param [in](uint32)own_address2_masks I2C_OA2_NOMASKを指定
// @param [in](uint32)general_call_mode I2C_GENERALCALL_DISABLEを指定
// @param [in](uint32)no_stretch_mode I2C_NOSTRETCH_DISABLEを指定
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "krdefine.h", "stm32h7xx_hal_i2c.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
// @note 本API実行後I2Cポートが初期化され、rcplib_I2C_Read()/rcplib_I2C_Write()が使用可能となる。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "krdefine.h"
//  #include "stm32h753xx.h"
//  #include "stm32h7xx_hal_i2c.h"
// 
//  // I2Cの初期化(センサ)
//  rcplib_I2C_Init(
//      KRDEFINE_EXTDEV_I2C2,      // ここはKRDEFINE_EXTDEV_I2C2にする
//      I2C2,                      // ここはI2C2にする
//      0x0000020d,                // ここは0x0000020dにする
//      0,                         // ここは0にする
//      I2C_ADDRESSINGMODE_7BIT,   // ここはI2C_ADDRESSINGMODE_7BITにする
//      I2C_DUALADDRESS_DISABLE,   // ここはI2C_DUALADDRESS_DISABLEにする
//      0,                         // ここは0にする
//      I2C_OA2_NOMASK,            // ここはI2C_OA2_NOMASKにする
//      I2C_GENERALCALL_DISABLE,   // ここはI2C_GENERALCALL_DISABLEにする
//      I2C_NOSTRETCH_DISABLE      // ここはI2C_NOSTRETCH_DISABLEにする
//      );
///
func rcplib_I2C_Init(uint32 id, uint32 instance, uint32 timing, uint32 own_address1, uint32 addressing_mode, uint32 dual_address_mode, uint32 own_address2, uint32 own_address2_masks, uint32 general_call_mode, uint32 no_stretch_mode) {
    
}

///
// @brief I2Cポート解除API ※センサドライバ(sdev_sensor)経由で操作し基本的には利用禁止/引数の値も変えないこと
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_I2C2固定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "krdefine.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
// @note 本API実行後I2Cポートが無効化される。再度有効化するにはrcplib_I2C_Init()を実行すること。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "krdefine.h"
// 
//  // I2Cポート解除(センサ)
//  rcplib_I2C_DeInit(KRDEFINE_EXTDEV_I2C2);
///
func rcplib_I2C_DeInit(uint32 id) {
    
}

///
// @brief I2C Read API  ※センサドライバ(sdev_sensor)経由で操作し基本的には利用禁止
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_I2C2固定>
// @param [in](uint16)dev_addr スレーブアドレス(8bitアドレス表記で指定)
// @param [in](uint16)mem_addr 読み出し先のメモリーアドレス
// @param [in](uint16)mem_addr_size メモリーアドレスサイズ
// @param [out](uint8[])data 読み出したデータ
// @param [in](uint16)data_size 読み出すデータサイズ
// @param [in](uint32)timeout タイムアウト値 [msec]
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "krdefine.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
// @note 本APIを実行することによりI2C Readアクセスが可能。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "krdefine.h"
// 
//  // センサのスレーブアドレスを定義
//  #define ACC_GYR_I2C_SLAVE_ADDR_R 0xd5
// 
//  // 読み出した値を入れる配列を作成
//  uint8 data[1];
// 
//  // WHO_AM_I(0x0f)レジスタから1バイトデータを読み出す
//  rcplib_I2C_Read(KRDEFINE_EXTDEV_I2C2, ACC_GYR_I2C_SLAVE_ADDR_R, 0x0f, 1, data, 1, 100);
//  // 読み出した値をログ出力
//  rcplib_LOG_Print(data);
///
func rcplib_I2C_Read(uint32 id, uint16 dev_addr, uint16 mem_addr, uint16 mem_addr_size, uint8 data[], uint16 data_size, uint32 timeout) {
    
}

///
// @brief I2C Write API  ※センサドライバ(sdev_sensor)経由で操作し基本的には利用禁止
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_I2C2固定>
// @param [in](uint16)dev_addr スレーブアドレス(8bitアドレス表記で指定)
// @param [in](uint16)mem_addr 書き込み先のメモリーアドレス
// @param [in](uint16)mem_addr_size メモリーアドレスサイズ
// @param [in](uint8[])data 書き込むデータ
// @param [in](uint16)data_size 書き込むデータサイズ
// @param [in](uint32)timeout タイムアウト値 [msec]
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "krdefine.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
// @note 本APIを実行することによりI2C Writeアクセスが可能。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "krdefine.h"
// 
//  // センサのスレーブアドレスを定義
//  #define ACC_GYR_I2C_SLAVE_ADDR_W 0xd4
// 
//  // 書き込む値を入れる配列を作成
//  uint8 data[1];
// 
//  // CTRL6_C(0x15)レジスタに1バイトデータ0x10を書き込む
//  data[0] = 0x10;
//  rcplib_I2C_Write(KRDEFINE_EXTDEV_I2C2, ACC_GYR_I2C_SLAVE_ADDR_W, 0x15, 1, data, 1, 100);
///
func rcplib_I2C_Write(uint32 id, uint16 dev_addr, uint16 mem_addr, uint16 mem_addr_size, uint8 data[], uint16 data_size, uint32 timeout) {
    
}

//// ■CAN制御
///
// @brief CANポートを初期化するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @param [in](uint32)Instance インスタンスID <FDCAN1固定>
// @param [in](uint32)FrameFormat FDCANのフレームフォーマット指定 <Classic mode もしくは FD mode> ※"stm32h7xx_hal_fdcan.h"のFDCAN_frame_formatの定義を参照
// @param [in](uint32)Mode FDCANの動作モード <Normal mode もしくは Other mode> ※"stm32h7xx_hal_fdcan.h"のFDCAN_operating_modeの定義を参照
// @param [in](uint8)AutoRetransmission 自動再送信の有効/無効 <DISABLE:0, ENABLE:1>
// @param [in](uint8)TransmitPause 送信一時停止機能の有効/無効 <DISABLE:0, ENABLE:1>
// @param [in](uint8)ProtocolException プロトコル例外処理の有効/無効 <DISABLE:0, ENABLE:1>
// @param [in](uint32)NominalPrescaler NominalSectionのプリスケーラ(1～512)
// @param [in](uint32)NominalSyncJumpWidth NominalSectionの同期セグメントのJumpWidth(1～128) <単位:TQ>
// @param [in](uint32)NominalTimeSeg1 NominalSectionのタイムセグメント1(2～256) <単位:TQ>
// @param [in](uint32)NominalTimeSeg2 NominalSectionのタイムセグメント2(2～128) <単位:TQ>
// @param [in](uint32)DataPrescaler DataSectionのプリスケーラ(1～32)
// @param [in](uint32)DataSyncJumpWidth DataSectionの同期セグメントのJumpWidth(1～16) <単位:TQ>
// @param [in](uint32)DataTimeSeg1 DataSectionのタイムセグメント1(1～32) <単位:TQ>
// @param [in](uint32)DataTimeSeg2 DataSectionのタイムセグメント2(1～16) <単位:TQ>
// @param [in](uint32)MessageRAMOffset メッセージRAMの開始アドレス(0～2560)
// @param [in](uint32)StdFiltersNbr 標準メッセージIDのフィルター数(0～128)
// @param [in](uint32)ExtFiltersNbr 拡張メッセージIDのフィルター数(0～64)
// @param [in](uint32)RxFifo0ElmtsNbr RxFIFO0エレメント数(0～64)
// @param [in](uint32)RxFifo0ElmtSize RxFIFO0エレメントのデータフィールドサイズ
// @param [in](uint32)RxFifo1ElmtsNbr RxFIFO1エレメント数(0～64)
// @param [in](uint32)RxFifo1ElmtSize RxFIFO1エレメントのデータフィールドサイズ
// @param [in](uint32)RxBuffersNbr Rxバッファエレメント数(0～64)
// @param [in](uint32)RxBufferSize Rxバッファエレメントのデータフィールドサイズ
// @param [in](uint32)TxEventsNbr TxイベントFIFOエレメント数(0～32)
// @param [in](uint32)TxBuffersNbr Txバッファの数(0～32)
// @param [in](uint32)TxFifoQueueElmtsNbr TxFIFO/キューに使用されるTxバッファ数(0～32)
// @param [in](uint32)TxFifoQueueMode TxFIFO/キューモードの選択
// @param [in](uint32)TxElmtSize Txエレメントのデータフィールドサイズ
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx.h", "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本API実行後CANポートが初期化され、CAN関連のアクセスAPIが使用可能となる。
// <参考>
// 　ビットレート500kbps / サンプリングポイント 80% に設定するための計算方法
// 　CANのクロックは、システムでFDCAN_CLK=40MHz固定となっているので、下記のように各パラメーターを計算することができる。
// ・NominalSectionの設定計算:
// 　プリスケール後のクロック = FDCAN_CLK / NominalPrescaler = 40MHz / 4分周 = 10MHz, 1 TimeQuantum[TQ] = 1 / 10 = 0.1 usec
// 　1bit送信時間 = (SynchronizationSegment[1TQ] + NominalTimeSeg1 + NominalTimeSeg2) TQ = 1 + 15 + 4 = 20 TQ
// 　通信レート = 10MHz / (SynchronizationSegment[1TQ] + NominalTimeSeg1 + NominalTimeSeg2) = 10MHz / (1 + 15 + 4) = 500kbit/s
// 　サンプリングポイント = (SynchronizationSegment[1TQ] + NominalTimeSeg1) / (SynchronizationSegment[1TQ] + NominalTimeSeg1 + NominalTimeSeg2) = 16 / 20 = 0.8 = 80%
// ・DataSectionの設定計算:
// 　プリスケール後のクロック = FDCAN_CLK / DataPrescaler = 40MHz / 4分周 = 10MHz, 1 TimeQuantum[TQ] = 1 / 10 = 0.1 usec
// 　1bit送信時間 = (SynchronizationSegment[1TQ] + DataTimeSeg1 + DataTimeSeg2) TQ = 1 + 15 + 4 = 20 TQ
// 　通信レート = 10MHz / (SynchronizationSegment[1TQ] + DataTimeSeg1 + DataTimeSeg2) = 10MHz / (1 + 15 + 4) = 500kbit/s
// 　サンプリングポイント = (SynchronizationSegment[1TQ] + DataTimeSeg1) / (SynchronizationSegment[1TQ] + DataTimeSeg1 + DataTimeSeg2) = 16 / 20 = 0.8 = 80%
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "stm32h7xx.h"
//  #include "stm32h7xx_hal_fdcan.h"
//  #include "krdefine.h"
// 
//  // ビットレート 500kbps, サンプリングポイント 80% に設定する
//  rcplib_CAN_Init(
//      KRDEFINE_EXTDEV_CAN1,     // ここはKRDEFINE_EXTDEV_CAN1にする
//      FDCAN1,                   // ここはFDCAN1にする
//      FDCAN_FRAME_CLASSIC,      // Classic mode
//      FDCAN_MODE_NORMAL,        // Normal mode
//      ENABLE,                   // 自動再送信有効
//      DISABLE,                  // 送信一時停止機能無効
//      DISABLE,                  // プロトコル例外処理無効
//      4,                        // NominalSectionプリスケーラ: 4分周, FDCAN_CLK=40[MHz]になっているため40/4分周=10[MHz], 1[TQ]=1/10=0.1[usec]となる
//      4,                        // NominalSection同期セグメントのJumpWidth: 4[TQ] (ビットタイミング再同期のためにタイムセグメントを増加もしくは減少させて調整可能な上限)
//      15,                       // NominalSectionタイムセグメント1: 15[TQ]
//      4,                        // NominalSectionタイムセグメント2:  4[TQ]
//      4,                        // DataSectionプリスケーラ: 4分周, FDCAN_CLK=40[MHz]になっているため40/4分周=10[MHz], 1[TQ]=1/10=0.1[usec]となる
//      4,                        // DataSection同期セグメントのJumpWidth: 4[TQ] (ビットタイミング再同期のためにタイムセグメントを増加もしくは減少させて調整可能な上限)
//      15,                       // DataSectionタイムセグメント1: 15[TQ]
//      4,                        // DataSectionタイムセグメント2:  4[TQ]
//      0,                        // メッセージRAMの開始アドレス: 0
//      5,                        // 標準メッセージIDのフィルター数: 5
//      0,                        // 拡張メッセージIDのフィルター数: 0
//      3,                        // RxFIFO0エレメント数: 3
//      FDCAN_DATA_BYTES_8,       // RxFIFO0エレメントのデータフィールドサイズ
//      1,                        // RxFIFO1エレメント数: 1
//      FDCAN_DATA_BYTES_8,       // RxFIFO1エレメントのデータフィールドサイズ
//      0,                        // Rxバッファエレメント数: 0(RxFIFOを使用し、Rxバッファは使用しない)
//      FDCAN_DATA_BYTES_8,       // Rxバッファエレメントのデータフィールドサイズ
//      0,                        // TxイベントFIFOエレメント数: 0
//      0,                        // Txバッファの数を指定: 0
//      3,                        // TxFIFO/キューに使用されるTxバッファ数: 3
//      FDCAN_TX_FIFO_OPERATION,  // TxFIFOを使用
//      FDCAN_DATA_BYTES_8        // Txエレメントのデータフィールドサイズ
//      );
///
func rcplib_CAN_Init(uint32 id, uint32 Instance, uint32 FrameFormat, uint32 Mode, uint8 AutoRetransmission, uint8 TransmitPause, uint8 ProtocolException, uint32 NominalPrescaler, uint32 NominalSyncJumpWidth, uint32 NominalTimeSeg1, uint32 NominalTimeSeg2, uint32 DataPrescaler, uint32 DataSyncJumpWidth, uint32 DataTimeSeg1, uint32 DataTimeSeg2, uint32 MessageRAMOffset, uint32 StdFiltersNbr, uint32 ExtFiltersNbr, uint32 RxFifo0ElmtsNbr, uint32 RxFifo0ElmtSize, uint32 RxFifo1ElmtsNbr, uint32 RxFifo1ElmtSize, uint32 RxBuffersNbr, uint32 RxBufferSize, uint32 TxEventsNbr, uint32 TxBuffersNbr, uint32 TxFifoQueueElmtsNbr, uint32 TxFifoQueueMode, uint32 TxElmtSize) {
    
}

///
// @brief CANポートを解除するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本API実行後CANポートが無効化される。再度有効化するにはrcplib_CAN_Init()を実行すること。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "krdefine.h"
// 
//  // CAN DeInitialize
//  rcplib_CAN_DeInit(
//      KRDEFINE_EXTDEV_CAN1  // ここはKRDEFINE_EXTDEV_CAN1にする
//      );
///
func rcplib_CAN_DeInit(uint32 id) {
    
}

///
// @brief CANのグローバルフィルターを設定するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @param [in](uint32)NonMatchingStd フィルターリストのどのエレメントとも一致しない11ビットIDを持つ受信メッセージの処理方法を定義
// @param [in](uint32)NonMatchingExt フィルターリストのどのエレメントとも一致しない29ビットIDを持つ受信メッセージの処理方法を定義
// @param [in](uint32)RejectRemoteStd すべての11ビットIDリモートフレームをフィルタリングまたは拒否を指定
// @param [in](uint32)RejectRemoteExt すべての29ビットIDリモートフレームをフィルタリングまたは拒否を指定
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本APIを実行することにより、グローバルフィルターの設定ができる。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "stm32h7xx_hal_fdcan.h"
//  #include "krdefine.h"
// 
//  // CANのグローバルフィルターを設定
//  rcplib_CAN_ConfigGlobalFilter(
//      KRDEFINE_EXTDEV_CAN1,  // ここはKRDEFINE_EXTDEV_CAN1にする
//      FDCAN_REJECT,          // 標準メッセージの個別フィルターを使用するためグローバルフィルターはREJECTにする
//      FDCAN_REJECT,          // 拡張メッセージの個別フィルターを使用するためグローバルフィルターはREJECTにする
//      FDCAN_REJECT_REMOTE,   // 標準メッセージのリモートフレームをREJECT
//      FDCAN_REJECT_REMOTE    // 拡張メッセージのリモートフレームをREJECT
//      );
///
func rcplib_CAN_ConfigGlobalFilter(uint32 id, uint32 NonMatchingStd, uint32 NonMatchingExt, uint32 RejectRemoteStd, uint32 RejectRemoteExt) {
    
}

///
// @brief CANの個別フィルターを設定するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @param [in](uint32)IdType 識別子の種類を指定 <FDCAN_STANDARD_IDもしくはFDCAN_EXTENDED_ID>
// @param [in](uint32)FilterIndex 初期化するフィルター番号(IdTypeがFDCAN_STANDARD_IDの場合:0～127, IdTypeがFDCAN_EXTENDED_IDの場合:0～63)
// @param [in](uint32)FilterType フィルタータイプ。FDCAN_EXT_FILTER_RANGE_NO_EIDMは、IdTypeがFDCAN_EXTENDED_IDの場合にのみ許可される。FilterConfigがFDCAN_FILTER_TO_RXBUFFERに設定されている場合、このパラメーターは無視される。
// @param [in](uint32)FilterConfig フィルター構成
// @param [in](uint32)FilterID1 フィルター(IdTypeがFDCAN_STANDARD_IDの場合:0～0x7FF, IdTypeがFDCAN_EXTENDED_IDの場合:0～0x1FFFFFFF)
// @param [in](uint32)FilterID2 フィルターマスク(IdTypeがFDCAN_STANDARD_IDの場合:0～0x7FF, IdTypeがFDCAN_EXTENDED_IDの場合:0～0x1FFFFFFF)
// @param [in](uint32)RxBufferIndex 一致するメッセージが保存されるRxバッファ番号 FilterConfigがFDCAN_FILTER_TO_RXBUFFERと異なる場合、このパラメーターは無視される。(0～63)
// @param [in](uint32)IsCalibrationMsg フィルターがキャリブレーションメッセージ用に設定されているかどうかを指定。FilterConfigがFDCAN_FILTER_TO_RXBUFFERと異なる場合、このパラメーターは無視される。(一般メッセージ:0, キャリブレーションメッセージ:1)
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本APIを実行することにより、個別フィルターの設定ができる。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "stm32h7xx_hal_fdcan.h"
//  #include "krdefine.h"
// 
//  // CANの個別フィルターを設定
//  rcplib_CAN_ConfigFilter(
//      KRDEFINE_EXTDEV_CAN1,    // ここはKRDEFINE_EXTDEV_CAN1にする
//      FDCAN_STANDARD_ID,       // 標準メッセージIDを使う
//      0,                       // FilterIndex(IdTypeがFDCAN_STANDARD_IDの場合:0～127, IdTypeがFDCAN_EXTENDED_IDの場合:0～63の範囲で使用可)
//      FDCAN_FILTER_MASK,       // FilterType      Classic filterの設定(FilterID1 = filter, FilterID2 = mask)
//      FDCAN_FILTER_TO_RXFIFO0, // FilterConfig    Rx FIFO 0 のフィルター設定
//      0x0005,                  // FilterID1       フィルタリングするMessageIDを指定
//      0x07ff,                  // FilterID2       フィルタマスクを指定(検証対象のbitを1に, 検証対象外のbitを0にしてマスクすることが可能)
//      0,                       // RxBufferIndex
//      0                        // IsCalibrationMsg
//      );
///
func rcplib_CAN_ConfigFilter(uint32 id, uint32 IdType, uint32 FilterIndex, uint32 FilterType, uint32 FilterConfig, uint32 FilterID1, uint32 FilterID2, uint32 RxBufferIndex, uint32 IsCalibrationMsg) {
    
}

///
// @brief CANを開始するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本APIを実行することにより、CANを開始する。
///
func rcplib_CAN_Start(uint32 id) {
    
}

///
// @brief CANを停止するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本APIを実行することにより、CANを停止する。
///
func rcplib_CAN_Stop(uint32 id) {
    
}

///
// @brief CANの受信通知を有効化するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @param [in](uint32)ActiveITs どの割込み通知を有効にするかの指定
// @param [in](uint32)BufferIndexes 送信バッファ番号 ActiveITにFDCAN_IT_TX_COMPLETEもしくはFDCAN_IT_TX_ABORT_COMPLETEが含まれている場合のみ、このパラメーターが有効になる
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本APIを実行することにより、CANの受信通知の条件を設定し有効化できる。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "stm32h7xx_hal_fdcan.h"
//  #include "krdefine.h"
// 
//  // CANの受信通知の有効化
//  rcplib_CAN_ActivateNotification(
//      KRDEFINE_EXTDEV_CAN1,                                             // ここはKRDEFINE_EXTDEV_CAN1にする
//      (FDCAN_IT_RX_FIFO0_NEW_MESSAGE | FDCAN_IT_RX_FIFO1_NEW_MESSAGE),  // RX_FIFO0とRX_FIFO1のNEW_MESSAGE受信割込みイベントを有効化
//      0                                                                 // 送信バッファ番号は0(ActiveITにFDCAN_IT_TX_COMPLETEもしくはFDCAN_IT_TX_ABORT_COMPLETEを指定していないので、ここのパラメーターは無効)
//  );
///
func rcplib_CAN_ActivateNotification(uint32 id, uint32 ActiveITs, uint32 BufferIndexes) {
    
}

///
// @brief CANの受信通知を無効化するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @param [in](uint32)ActiveITs どの割込み通知を無効にするかの指定
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本APIを実行することにより、CANの受信通知を無効化できる。再度有効化するにはrcplib_CAN_ActivateNotification()を実行すること。
///
func rcplib_CAN_DeactivateNotification(uint32 id, uint32 ActiveITs) {
    
}

///
// @brief CANのデータ送信するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @param [in](uint8[])data 送信データ
// @param [in](uint16)data_size データサイズ
// @param [in](uint32)Identifier CANの識別ID
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention
//    sapp_serial.krs内でのみ利用可能。
//    UART送信の際は、SIO_SendDataCAN()を利用すること。
// @note 本APIを実行することにより、CANに対してデータ送信を行うことができる。
///
func rcplib_CAN_Transmit(uint32 id, uint8 data[], uint16 data_size, uint32 Identifier) {
    
}

///
// @brief CANのデータ送信を中断するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_CAN1固定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_fdcan.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note rcplib_CAN_Transmit()実行後、TxFIFOに追加した送信要求を取り消すためのAPI。
///
func rcplib_CAN_AbortTxRequest(uint32 id) {
    
}

//// ■UART(RS-485,RS-232C)制御
///
// @brief UARTポート初期化API
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_RS485 もしくは KRDEFINE_EXTDEV_RS232>
// @param [in](uint32)Instance インスタンスID <コントロールIDをKRDEFINE_EXTDEV_RS485に指定した場合はUART5を、KRDEFINE_EXTDEV_RS232に指定した場合はUSART6>
// @param [in](uint32)BaudRate ボーレート設定[baud]
// @param [in](uint32)WordLength データ長設定
// @param [in](uint32)StopBits ストップビット設定
// @param [in](uint32)Parity パリティビット設定
// @param [in](uint32)Mode モード設定(RXモード、TXモード、TX_RXモードがある)
// @param [in](uint32)HwFlowCtl ハードウェアコントロール設定(ハードウェアコントロール(RTS/CTS)を使用するかを選択)
// @param [in](uint32)OverSampling オーバーサンプリング(8倍と16倍が指定可能)
// @param [in](uint32)OneBitSampling USARTの1ビットサンプリング方式を有効または無効に設定
// @param [in](uint32)ClockPrescaler UARTクロックプリスケーラ
// @param [in](uint32)AdvFeatureInit 拡張機能の初期化
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_uart.h","stm32h7xx_hal_uart_ex.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本API実行後UARTポートが初期化され、UART関連のアクセスAPIが使用可能となる。
//       ボーレート設定を600[baud]より遅く設定する場合は、ClockPrescalerの変更が必要です。110,300,600[baud]に設定する場合は、ClockPrescalerをUART_PRESCALER_DIV8に設定すること。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "stm32h7xx_hal_uart.h"
//  #include "stm32h7xx_hal_uart_ex.h"
//  #include "krdefine.h"
// 
//  // RS232ポートを ボーレート115200[baud]/データ長8/ストップビット1/パリティなし に設定する
//  rcplib_UART_Init(
//      KRDEFINE_EXTDEV_RS232,       // ここはKRDEFINE_EXTDEV_RS232もしくはKRDEFINE_EXTDEV_RS485にする
//      USART6,                      // ここはUSART6もしくはUART5にする
//      115200,                      // ボーレート115200[baud]
//      UART_WORDLENGTH_8B,          // データ長8
//      UART_STOPBITS_1,             // ストップビット1
//      UART_PARITY_NONE,            // パリティなし
//      UART_MODE_TX_RX,             // 送受信モード
//      UART_HWCONTROL_NONE,         // ハードウェアフローコントロールなし
//      UART_OVERSAMPLING_16,        // オーバーサンプリングはUART_OVERSAMPLING_16にする
//      UART_ONE_BIT_SAMPLE_DISABLE, // USARTの1ビットサンプリング方式はUART_ONE_BIT_SAMPLE_DISABLEにする
//      UART_PRESCALER_DIV1,         // UARTクロックプリスケーラはUART_PRESCALER_DIV1にする
//      UART_ADVFEATURE_NO_INIT      // UART_ADVFEATURE_NO_INITにする
//      );
///
func rcplib_UART_Init(uint32 id, uint32 Instance, uint32 BaudRate, uint32 WordLength, uint32 StopBits, uint32 Parity, uint32 Mode, uint32 HwFlowCtl, uint32 OverSampling, uint32 OneBitSampling, uint32 ClockPrescaler, uint32 AdvFeatureInit) {
    
}

///
// @brief UARTポート解除API
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_RS485 もしくは KRDEFINE_EXTDEV_RS232>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_uart.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本API実行後UARTポートが無効化される。再度有効化するにはrcplib_UART_Init()を実行すること。
///
func rcplib_UART_DeInit(uint32 id) {
    
}

///
// @brief UART送信FIFO閾値設定API
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_RS485 もしくは KRDEFINE_EXTDEV_RS232>
// @param [in](uint32)threshold 設定する閾値レベル <UART_TXFIFO_THRESHOLD_1_8固定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_uart.h", "stm32h7xx_hal_uart_ex.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本APIを実行することにより、送信FIFOの閾値を変更することができる。
///
func rcplib_UART_SetTxFifoThreshold(uint32 id, uint32 threshold) {
    
}

///
// @brief UART受信FIFO閾値設定API
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_RS485 もしくは KRDEFINE_EXTDEV_RS232>
// @param [in](uint32)threshold 設定する閾値レベル <UART_TXFIFO_THRESHOLD_1_8固定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_uart.h", "stm32h7xx_hal_uart_ex.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本APIを使用することにより、受信FIFOの閾値を変更することができる。
///
func rcplib_UART_SetRxFifoThreshold(uint32 id, uint32 threshold) {
    
}

///
// @brief UARTのFIFOモードの有効/無効を設定するAPI
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_RS485 もしくは KRDEFINE_EXTDEV_RS232>
// @param [in](uint32)Mode FIFOモード有効/無効 <0(無効)固定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_uart.h", "krdefine.h"
// @attention sapp_serial.krs内でのみ利用可能。
// @note 本APIを実行することにより、FIFOのモード選択をすることができる。
///
func rcplib_UART_SetFifoMode(uint32 id, uint32 Mode) {
    
}

///
// @brief UART送信API
// @param [in](uint32)id コントロールID <KRDEFINE_EXTDEV_RS485, KRDEFINE_EXTDEV_RS485_2WIRE, KRDEFINE_EXTDEV_RS232>
// @param [in](uint8[])data 送信データ
// @param [in](uint16)data_size 送信データサイズ
// @param [in](uint32)timeout タイムアウト[msec]
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "stm32h7xx_hal_uart.h", "krdefine.h"
// @attention
//    sapp_serial.krs内でのみ利用可能。
//    UART送信の際は、SIO_SendDataSerial()を利用すること。
//    コントロールIDをKRDEFINE_EXTDEV_RS485_2WIREにした時の注意事項についてはSIO_SendDataSerial()の項目を参照のこと。
// @note 本APIを実行することにより、RS-485もしくはRS-232Cに対してデータ送信を行うことができる。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "stm32h7xx_hal_uart.h"
//  #include "krdefine.h"
//  #include "cmd_str.h" // rcplib_STR_SetStringを利用するため
// 
//  // 送信文字列変数を定義
//  str tx_data_str[10];
// 
//  // 送信文字列変数に文字列"TEST_DATA"を代入
//  rcplib_STR_SetString(tx_data_str, "TEST_DATA");
// 
//  // 送信文字列を格納するデータ配列を作成
//  uint8 tx_data_uint[15];
// 
//  // 送信文字列をデータ配列に入れる(改行文字コードを追加するために必要)
//  rcplib_FORMAT_Binary(tx_data_uint[], 0, EAPI_VTYPE_STR, rcplib_STR_Len(tx_data_str), tx_data_str);
// 
//  // 改行文字コード"\r"=13を送信文字列の最後に追加
//  tx_data_uint[rcplib_STR_Len(tx_data_str)] = 13;
// 
//  // 文字列の終了を示すNULL文字"\0"=0を最後に追加
//  tx_data_uint[rcplib_STR_Len(tx_data_str)+1] = 0;
// 
//  // 送信処理
//  rcplib_UART_Transmit(
//      KRDEFINE_EXTDEV_RS232_2WIRE,      // ここはKRDEFINE_EXTDEV_RS485, KRDEFINE_EXTDEV_RS485_2WIRE, KRDEFINE_EXTDEV_RS232にする
//      tx_data_uint,                     // 送信文字列を格納したデータ配列を渡す
//      rcplib_STR_Len(tx_data_str)+1,    // 文字列の終了を示すNULL文字までの長さ
//      100                               // タイムアウト 100[msec]
//      );
///
func rcplib_UART_Transmit(uint32 id, uint8 data[], uint16 data_size, uint32 timeout) {
    
}

//// ■数学関数
///
// @brief 正弦(sin)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note 引数xのラジアン値の正弦を計算する。
///
func rcplib_MATH_Sin(double x) {
    
}

///
// @brief 余弦(cos)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note 引数xのラジアン値の余弦を計算する。
///
func rcplib_MATH_Cos(double x) {
    
}

///
// @brief 正接(tan)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note 引数xのラジアン値の正接を計算する。
///
func rcplib_MATH_Tan(double x) {
    
}

///
// @brief 逆正弦(arcsin)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note -π/2～+π/2のラジアンの逆正接が返される。
//       引数xの範囲は-1～+1で指定。
///
func rcplib_MATH_Asin(double x) {
    
}

///
// @brief 逆余弦(arccos)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note -π/2～+π/2のラジアンの逆余弦が返される。
//       引数xの範囲は-1～+1で指定。
///
func rcplib_MATH_Acos(double x) {
    
}

///
// @brief 逆正接(arctan)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note -π/2～+π/2のラジアンの逆正接が返される。
//       引数xの範囲は-1～+1で指定。
///
func rcplib_MATH_Atan(double x) {
    
}

///
// @brief 自然対数(log)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note 引数xのeを底とする自然対数を計算する。
//       引数xが0以下となる場合は定義域エラーになるため、設定不可。
///
func rcplib_MATH_Log(double x) {
    
}

///
// @brief 指数(exp)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note 自然対数の底eのx乗を計算する。
///
func rcplib_MATH_Exp(double x) {
    
}

///
// @brief 常用対数(log10)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note 引数xの10を底とする常用対数を計算する。
//       引数xが0以下となる場合は定義域エラーになるため、設定不可。
///
func rcplib_MATH_Log10(double x) {
    
}

///
// @brief 平方根(sqrt)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note 引数xの平方根を計算する。
//       引数xが0より小さくなる場合は定義域エラーになるため、設定不可。
///
func rcplib_MATH_Sqrt(double x) {
    
}

///
// @brief べき乗(pow)関数API
// @param [in](int||uint||double)x 入力データ
// @param [in](int||uint||double)y 入力データ
// @return 計算結果(double)
// @detail 必要なヘッダinclude : なし
// @note xのy乗を計算する。
///
func rcplib_MATH_Pow(double x, double y) {
    
}

///
// @brief 絶対値(abs)関数API
// @param [in](int||uint||double)x 入力データ
// @return 計算結果(入力データの型に応じた型で結果が戻る)
// @detail 必要なヘッダinclude : なし
// @note 引数xの絶対値を計算する。
///
func rcplib_MATH_Abs(double x) {
    
}

//// ■文字列変数操作
///
// @brief 2つの文字列変数を連結するAPI
// @param [in,out](str)dst 連結先の文字列変数
// @param [in](str||json||list)src 連結する文字列変数
// @return 0:成功, -1:連結先のサイズ不足、または連結元(src)の型が不正
// @detail 必要なヘッダinclude : 無し
// @code
//  // ソース冒頭でヘッダをinclude ※rcplib_STR_SetStringを利用するため
//  #include "cmd_str.h"
// 
//  // 文字列変数を定義
//  str str_cat_dst[13];
//  str str_cat_src[5];
// 
//  // 文字列変数の初期値を代入
//  rcplib_STR_SetString(str_cat_dst, "ABCD");
//  rcplib_STR_SetString(str_cat_src, "01234");
// 
//  // 連結APIを実行する
//  rcplib_STR_Cat(str_cat_dst, str_cat_src); // 戻り値は0, str_cat_dstは"ABCD01234"
//  rcplib_STR_Cat(str_cat_dst, "XYZ"); // 戻り値は0, str_cat_dstは"ABCD01234XYZ"
///
func rcplib_STR_Cat(str dst, str_json_list src) {
    
}

///
// @brief 文字列変数の文字数を取得するAPI
// @param [in](str||json||list)src 文字数を取得する文字列変数
// @return 文字列の文字数, -1:入力(src)の型が不正
// @detail 必要なヘッダinclude : 無し
// @code
//  // ソース冒頭でヘッダをinclude ※rcplib_STR_SetStringを利用するため
//  #include "cmd_str.h"
// 
//  // 文字列変数を定義
//  str str_len_src[10];
//  uint16 ret;
// 
//  // 文字列変数の初期値を代入
//  rcplib_STR_SetString(str_len_src, "ABCD");
// 
//  // 文字数取得APIを実行する
//  ret = rcplib_STR_Len(str_len_src); // 戻り値は4
//  ret = rcplib_STR_Len("01234"); // 戻り値は5
///
func rcplib_STR_Len(str_json_list src) {
    
}

///
// @brief 文字列変数内のキーワード有無を検索するAPI
// @param [in](str||json||list)src 参照する文字列変数
// @param [in](str||json||list)keyword 検索キーワードの文字列変数
// @return 0:存在しない, 1以上:存在する(検索結果の文字位置), -1:入力の型が不正
// @detail 必要なヘッダinclude : 無し
// @note キーワードが複数存在する場合は最初に現れる文字位置をreturnする
// @code
//  // ソース冒頭でヘッダをinclude ※rcplib_STR_SetStringを利用するため
//  #include "cmd_str.h"
// 
//  // 文字列変数を定義
//  str str_find_src[8];
// 
//  // 文字列変数の初期値を代入
//  rcplib_STR_SetString(str_find_src, "ABCDEFG");
// 
//  // 検索APIを実行する
//  rcplib_STR_Find(str_find_src, "CD"); // 戻り値は3
//  rcplib_STR_Find("ABCDEFG", "DC"); // 戻り値は0
///
func rcplib_STR_Find(str_json_list src, str_json_list keyword) {
    
}

///
// @brief 文字列変数内のキーワード有無を検索するAPI(検索開始位置指定オフセットあり)
// @param [in](str||json||list)src 参照する文字列変数
// @param [in](str||json||list)keyword 検索キーワードの文字列変数
// @param [in](uint16)offset 検索開始位置のオフセット(開始位置の先頭は1)
// @return 0:存在しない, 1以上:存在する(検索結果の文字位置), -1:入力値が不正
// @detail 必要なヘッダinclude : 無し
// @note 検索開始位置のオフセットから検索を開始し、最初に現れる文字位置をreturnする
// @code
//  // ソース冒頭でヘッダをinclude ※rcplib_STR_SetStringを利用するため
//  #include "cmd_str.h"
// 
//  // 文字列変数を定義
//  str str_find_src[10];
// 
//  // 文字列変数の初期値を代入
//  rcplib_STR_SetString(str_find_src, "strstrstr");
// 
//  // 検索APIを実行する
//  rcplib_STR_FindWithOfs(str_find_src, "str", 1); // 戻り値は1
//  rcplib_STR_FindWithOfs(str_find_src, "str", 3); // 戻り値は4
//  rcplib_STR_FindWithOfs(str_find_src, "str", 5); // 戻り値は7
//  rcplib_STR_FindWithOfs(str_find_src, "str", 0); // 戻り値は-1(検索開始位置のオフセット値不正)
//  rcplib_STR_FindWithOfs(str_find_src, "str", -1); // 戻り値は-1(検索開始位置のオフセット値不正)
//  rcplib_STR_FindWithOfs("ABCDEFG", "DC", 1); // 戻り値は0
//  rcplib_STR_FindWithOfs(0, 0, 1); // 戻り値は-1(入力値の型不正)
///
func rcplib_STR_FindWithOfs(str_json_list src, str_json_list keyword, uint16 offset) {
    
}

///
// @brief 文字列変数の指定オフセット位置から指定長の文字列を抜き出すAPI
// @param [in,out](str)dst 抜き出した文字列の格納先文字列変数
// @param [in](str||json||list)src 抜き出す対象の文字列変数
// @param [in](uint16)offset 抜き出し開始位置(先頭:0)
// @param [in](uint16)len 抜き出す文字数
// @return 0:成功, -1:参照する文字列(src)の型が不正
// @detail 必要なヘッダinclude : 無し
// @code
//  // 文字列変数を定義
//  str str_cut_dst[8];
// 
//  // 抜き出しAPIを実行する　("0123456"の'2'の位置から3文字分"234"を抜き出す)
//  rcplib_STR_Cut(str_cut_dst, "0123456", 2, 3); // 戻り値は0, str_cut_dstは"234"
// 
//  // 抜き出しAPIを実⾏する (0⽂字の情報を抜き出す ※実質⽂字列変数の初期化処理)
//  rcplib_STR_Cut(str_cut_dst, "", 0, 0); // 戻り値は0, str_cut_dstは""
///
func rcplib_STR_Cut(str dst, str_json_list src, uint16 offset, uint16 len) {
    
}

///
// @brief 文字列内の文字を別の文字に置き換えるAPI
// @param [out](str)dst 結果を書き込む先の文字列変数
// @param [in](str||json||list)src 参照する文字列変数
// @param [in](str||json||list)before 置き換え元の文字列変数
// @param [in](str||json||list)after 置き換え先の文字列変数
// @return 0:成功, -1:入力の型が不正
// @detail 必要なヘッダinclude : 無し
// @code
//  // ソース冒頭でヘッダをinclude ※rcplib_STR_SetStringを利用するため
//  #include "cmd_str.h"
// 
//  // 文字列変数を定義
//  str str_replace_dst[16];
//  str str_replace_src[8];
// 
//  // 文字列変数の初期値を代入
//  rcplib_STR_SetString(str_replace_src, "ABCDCDE");
// 
//  // 置き換えAPIを実行する  (str_replace_srcの"CD"を"XXYYZZ"に置き換える)
//  rcplib_STR_Replace(str_replace_dst, str_replace_src, "CD", "XXYYZZ"); // 戻り値は0, str_replace_dstは"ABXXYYZZXXYYZZE"
///
func rcplib_STR_Replace(str dst, str_json_list src, str_json_list before, str_json_list after) {
    
}

///
// @brief 文字列変数に任意の文字列を書き込むAPI(ラッパー関数)
// @param [in,out](str)dst 書き込み先の文字列変数
// @param [in](str||json||list)src 参照する文字列変数
// @return 0:成功, -1:参照する文字列(src)の型が不正
// @detail 必要なヘッダinclude : "cmd_str.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_STR_Cut(dst, src, 0, 0xFFFF)。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "cmd_str.h"
// 
//  // 文字列変数を定義
//  str str_init[10];
// 
//  // 書き込みAPIを実行する
//  rcplib_STR_SetString(str_init, "0123456"); // 戻り値は0, str_initは"0123456"
// 
//  // 書き込みAPIを実行する  (文字列変数を初期化する)
//  rcplib_STR_SetString(str_init, ""); // 戻り値は0, str_initは""
///
func rcplib_STR_SetString(str dst, str_json_list src) {
    
}

//// ■フォーマット変換
///
// @brief UTC時刻を任意の時刻関連の文字列変数に変換するAPI
// @param [out](str)dst エンコード結果の出力先文字列変数
// @param [in](str)src 入力するフォーマット指定用文字列変数
// @param [in](uint64)utc 入力するUTC時刻設定
// @param [in](uint32)time_zone 入力するタイムゾーン設定 <-12～+14[時間]で指定、日本の場合は9を設定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : なし
// @note UNIX時間(UTC)の取得APIであるrcplib_RTC_GetTime()の実行により現在時刻を取得可能。
//       実際の変換処理はC言語のstrftime()関数の動作になる。
// @code
//  // 出力先の文字列変数を定義
//  str str_time[32];
// 
//  // 時刻⇒文字列変換APIを実行する  ("%Y/%m/%d(%A) %H:%M:%S"のフォーマット指定で日本の現在時刻を変換)
//  rcplib_FORMAT_Time(str_time, "%Y/%m/%d(%A) %H:%M:%S", rcplib_RTC_GetTime(), 9); // 戻り値は0
//  // str_timeのデータは"2022/07/12(Tuesday) 13:20:28"になる。
///
func rcplib_FORMAT_Time(str dst, str src, uint64 utc, uint32 time_zone) {
    
}

///
// @brief 任意のデータをuint8配列に変換するAPI
// @param [out](uint8[])dst 出力先変数のuint8配列変数
// @param [in](uint16)offset 出力先変数の出力開始index番号
// @param [in](uint8)format 入力するデータの型を指定
// @param [in](uint32)num 入力対象とする配列index数、入力データが文字列または配列変数ではない場合は1
// @param [in](int||uint||double||int[]||uint[]||double[]||str)src 入力するデータ
// @return 0:成功, -1:失敗(オフセット指定が変数サイズを超過、num指定が2以上で入力データが文字列または配列変数ではない、サポート外の型指定)
// @detail 必要なヘッダinclude : なし
// @note format(入力するデータの型)への入力値
//       EAPI_VTYPE_I8  // int8
//       EAPI_VTYPE_I16 // int16
//       EAPI_VTYPE_I32 // int32
//       EAPI_VTYPE_I64 // int64
//       EAPI_VTYPE_U8  // uint8
//       EAPI_VTYPE_U16 // uint16
//       EAPI_VTYPE_U32 // uint32
//       EAPI_VTYPE_U64 // uint64
//       EAPI_VTYPE_F32 // float
//       EAPI_VTYPE_F64 // double
//       EAPI_VTYPE_STR // str
///
func rcplib_FORMAT_Binary(uint8 dst[], uint16 offset, uint8 format, uint32 num, any src) {
    
}

///
// @brief uint8配列のデータを任意のデータに変換するAPI
// @param [out](int||uint||double||int[]||uint[]||double[]||str||json||list)dst 出力先変数
// @param [in](uint8[])src 入力するuint8配列データ
// @param [in](uint16)offset 入力するuint8配列データの入力開始index番号
// @param [in](uint8)format 出力するデータの型を指定
// @param [in](uint32)num  出力対象とする配列index数、出力データが文字列または配列変数ではない場合は1
// @return 0:成功, -1:失敗(サポート外の型指定)
// @detail 必要なヘッダinclude : なし
// @note
//     // format(入力するデータの型)への入力値
//     EAPI_VTYPE_I8  // int8
//     EAPI_VTYPE_I16 // int16
//     EAPI_VTYPE_I32 // int32
//     EAPI_VTYPE_I64 // int64
//     EAPI_VTYPE_U8  // uint8
//     EAPI_VTYPE_U16 // uint16
//     EAPI_VTYPE_U32 // uint32
//     EAPI_VTYPE_U64 // uint64
//     EAPI_VTYPE_F32 // float
//     EAPI_VTYPE_F64 // double
//     EAPI_VTYPE_STR // str
///
func rcplib_FORMAT_Value(any dst, uint8 src[], uint16 offset, uint8 format, uint32 num) {
    
}

///
// @brief 任意のデータをstr配列に変換するAPI
// @param [out](str)dst エンコード結果の出力先文字列変数
// @param [in](str)src_fmt 入力するフォーマット指定用文字列変数
// @param [in](int||uint||float||double||str||json||list)src_data 入力するデータ
// @return 0:成功, -1:失敗(src_fmtの型が不正)
// @detail 必要なヘッダinclude : なし
// @note 実際の変換処理はC言語のsnprintf()関数の動作になる。
// @code
//  // ※利用例 //
//  // ソース冒頭でヘッダをinclude ※rcplib_STR_SetStringを利用するため
//  #include "cmd_str.h"
// 
//   // 入出力に使う各変数を定義
//   str dst[16];
//   str src_fmt[16];
//   uint32 src_data;
// 
//   // 入力変数の初期値を代入
//   rcplib_STR_SetString(src_fmt, "src_data = %d"); //入力するフォーマット指定用文字列変数は"src_data = %d"
//   src_data = 1234; //入力するデータは整数1234
// 
//   rcplib_FORMAT_String(dst, src_fmt, src_data); // 戻り値は0, dstは"src_data = 1234"
///
func rcplib_FORMAT_String(str dst, str src_fmt, any src_data) {
    
}

///
// @brief 任意のデータをフォーマット指定付きでstr配列に変換するAPI
// @param [out](str)dst エンコード結果の出力先文字列変数
// @param [in](str)src_fmt 入力するフォーマット指定用文字列変数
// @param [in](int||uint||float||double||str||json||list)src_data1 変数データ1
// @param [in](int||uint||float||double||str||json||list)src_datax 変数データ2以降 ※64bitの数値変数は利用不可、変数データは最大data8まで
// @return 0:成功, -1:失敗(src_fmt もしくは src_datax の型が不正)
// @detail 必要なヘッダinclude : なし
// @note 
//     フォーマット指定用文字列変数として指定可能なフォーマット指定子は「%d(整数), %f(実数), %s(文字列)」のみ。
//     それ以外の「%c, %x, %a」等をフォーマット指定用文字列変数内に記述した場合は「c, x, a」と変換される。
//     また、桁数や文字数を限定する「%5d, %5.2f, %5s」等も利用不可。%を表示するには「%%」を指定すること。
//
//     変数データを変換した文字列が出力先文字列変数dstとして定義した文字数を超えた場合、以降の文字列はdstに格納されず自動的にカットされる。
// @code
//  // ※利用例 //
//   // 入出力に使う各変数を定義
//   str dst1[100];
//   str dst2[25]; //出力先文字列変数の定義サイズが小さい場合
//   uint32 src_data1;
//   int32  src_data2;
//   float  src_data3;
//
//   // 入力変数の初期値を代入
//   src_data1 = 1234;  //入力するデータは整数1234
//   src_data2 = -1234; //入力するデータは整数-1234
//   src_data3 = 11.6;  //入力するデータは実数11.6
//
//   rcplib_FORMAT_StrPrint(dst1, "src_data:%d,%d,%f", src_data1, src_data2, src_data3); // 戻り値は0, dst1は"src_data:1234,-1234,11.600000"
//   rcplib_FORMAT_StrPrint(dst2, "src_data:%d,%d,%f", src_data1, src_data2, src_data3); // 戻り値は0, dst2はsrc_data3を変換した文字列が格納されず"src_data:1234,-1234,"となる
///
func rcplib_FORMAT_StrPrint(str dst, str src_fmt, any src_data) {
    
}

///
// @brief 入力文字列変数をパーセント表記の文字列変数に変換するAPI
// @param [out](str)dst エンコード結果の出力先文字列変数
// @param [in](str)src 入力する文字列変数
// @return 0:成功, -1:失敗(src_fmtの型が不正、出力先のサイズ不足)
// @detail 必要なヘッダinclude : なし
// @note 本APIは"-._"以外の記号の文字変数を"%XX"(XXはASCIIコード)に変換する。
///
func rcplib_FORMAT_EncPercent(str dst, str src) {
    
}

///
// @brief 入力文字列変数をx-www-form-urlencodedの文字列変数に変換するAPI
// @param [out](str)dst エンコード結果の出力先文字列変数
// @param [in](str)src 入力する文字列変数
// @return 0:成功, -1:失敗(src_fmtの型が不正、出力先のサイズ不足)
// @detail 必要なヘッダinclude : なし
// @note 本APIは"*-._"以外の記号の文字変数を"%XX"(XXはASCIIコード)に変換する。
//       " "の文字変数は"+"に変換する。
///
func rcplib_FORMAT_EncWWWForm(str dst, str src) {
    
}

///
// @brief Base64エンコーダAPI
// @param [out](str)dst エンコード結果の出力先文字列変数
// @param [in](str||uint8[])src 入力する文字列変数またはuint8配列
// @param [in](uint16)src_len 入力サイズ <0-32768[Byte]>
// @param [in](uint8)type エンコード方式 <FORMAT_BASE64_NORMAL:通常, FORMAT_BASE64_URL_SAFE:URLセーフ, FORMAT_BASE64_PERCENT:%文字エンコード>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "cmd_format.h"
// @code
//    // ソース冒頭でヘッダをinclude
//    #include "cmd_str.h"
//    #include "cmd_format.h"
//    --------
//    // 任意の関数内でBase64エンコード実行
//    func any_func() {
//        str str_src[9]; // 変換したい文字列変数
//        str str_res1[32]; // 変換結果の出力先文字列変数
//        rcplib_STR_SetString(str_src, "ABCDE"); // 変換したい文字を代入
//        // Bse64エンコード実行
//        rcplib_FORMAT_EncBase64(str_res1, str_src, rcplib_STR_Len(str_src), FORMAT_BASE64_NORMAL);
//        // str_res1には"QUJDREU="が出力される
//    --------
//        uint8 bin_src[9]; // 変換したい配列変数
//        str str_res2[32]; // 変換結果の出力先文字列変数
//        rcplib_FORMAT_Binary(bin_src, 0, EAPI_VTYPE_STR, 5, "ABCDE"); // 変換したい文字をuint8配列変数に代入
//        // Base64エンコード実行
//        rcplib_FORMAT_EncBase64(str_res2, str_src, 5, FORMAT_BASE64_NORMAL);
//        // str_res1には"QUJDREU="が出力される
//    --------
//    }
///
func rcplib_FORMAT_EncBase64(str dst, str_arr src, uint16 src_len, uint8 type) {
    
}

///
// @brief Base64デコーダAPI
// @param [out](uint8[])dst デコード結果の出力先uint8配列
// @param [in](str)src 入力する文字列変数
// @param [in](uint8)type デコード方式 <FORMAT_BASE64_NORMAL:通常, FORMAT_BASE64_URL_SAFE:URLセーフ>
// @return -1:失敗, 正常の場合、int32の出力サイズをreturnする
// @detail 必要なヘッダinclude : "cmd_format.h"
// @code
//    // ソース冒頭でヘッダをinclude
//    #include "cmd_str.h"
//    #include "cmd_format.h"
//    --------
//    // 任意の関数内でBase64デコード実行
//    func any_func() {
//        str str_src[9]; // 変換したい文字列変数
//        uint8 bin_res[32]; // 変換結果の出力先文字列変数
//        int32 res_size; // 変換結果の出力先文字列変数
//        rcplib_STR_SetString(str_src, "QUJDREU="); // 変換したい文字を代入
//        // Base64デコード実行
//        res_size = rcplib_FORMAT_DecBase64(bin_res, str_src, FORMAT_BASE64_NORMAL);
//        // res_sizeには5が出力され、bin_resには"ABCDE"相当の0x41, 0x42, 0x43, 0x44, 0x45が出力される
//    --------
//    }
///
func rcplib_FORMAT_DecBase64(uint8 dst[], str src, uint8 type) {
    
}

//// ■JSON変数操作
///
// @brief json変数をクリアするAPI
// @param [in](json)src クリア対象のjson変数
// @return なし
// @detail 必要なヘッダinclude : なし
// @note 本APIを事項することにより対象のjson変数のデータは"{}"にクリアされる。
///
func rcplib_JSON_Clear(json src) {
    
}

///
// @brief json変数内の指定したkeyを消去するAPI
// @param [in](json)src 制御対象のjson変数
// @param [in](str)key 指定するkey名
// @return 0:成功, -1:JSONデータが異常、またはkeyの型が不一致
// @detail 必要なヘッダinclude : なし
///
func rcplib_JSON_Delete(json src, str key) {
    
}

///
// @brief json変数内の指定したkeyのvalueのデータを書き換えるAPI
// @param [in](json)src 書換え対象のjson変数
// @param [in](str)key 指定するkey名
// @param [in](int||uint||float||str||json||list)value 書換えに利用する入力データ
// @return 0:成功, -1:JSONデータが異常、またはkeyの型が不一致、または出力先サイズ不足
// @detail 必要なヘッダinclude : なし
///
func rcplib_JSON_UpdateV(json src, str key, any value) {
    
}

///
// @brief json変数内の指定したkeyのvalueのデータを文字列で書き換えるAPI ※rcplib_JSON_UpdateV()で代替利用可能
// @param [in](json)src 書換え対象のjson変数
// @param [in](str)key 指定するkey名
// @param [in](str)value 書換えに利用する入力データ
// @return 0:成功, -1:JSONデータが異常、またはkeyやdataの型が不一致、または出力先サイズ不足
// @detail 必要なヘッダinclude : なし
// @note rcplib_JSON_UpdateV()で代替利用可能。
///
func rcplib_JSON_UpdateK(json src, str key, str value) {
    
}

///
// @brief json変数から指定したkeyの存在を確認するAPI
// @param [in](json)src 確認対象のjson変数
// @param [in](str)key 指定するkey名
// @return 1:存在する, 0:存在しない, -1:JSONデータが異常
// @detail 必要なヘッダinclude : なし
///
func rcplib_JSON_SearchK(json src, str key) {
    
}

///
// @brief json変数内の指定したkeyのvalueを数値形式で取得するAPI
// @param [in](json)src 確認対象のjson変数
// @param [in](str)key 指定するkey名
// @return -1:JSONデータが異常, 正常の場合、int64||uint64||double等の内容に応じた値をreturnする
// @detail 必要なヘッダinclude : なし
///
func rcplib_JSON_SearchN(json src, str key) {
    
}

///
// @brief json変数内の指定したkeyのvalueを文字列形式で取得するAPI
// @param [in](json)src 確認対象のjson変数
// @param [out](str)dst 出力先の文字列変数
// @param [in](str)key 指定するkey名
// @return 0:成功, -1:JSONデータが異常、またはkeyの型が不一致、または出力先サイズ不足
// @detail 必要なヘッダinclude : なし
///
func rcplib_JSON_SearchS(json src, str dst, str key) {
    
}

///
// @brief json変数のデータの有無を確認するAPI
// @param [in](json)src 確認対象のjson変数
// @return 0:データあり, 1:データ無し
// @detail 必要なヘッダinclude : なし
///
func rcplib_JSON_IsEmpty(json src) {
    
}

///
// @brief json変数のデータ数を取得するAPI
// @param [in](json)src 確認対象のjson変数
// @return int64のデータ数をreturnする
// @detail 必要なヘッダinclude : なし
///
func rcplib_JSON_GetEntry(json src) {
    
}

//// ■LIST変数操作
///
// @brief list変数をクリアするAPI
// @param [in](list)src クリア対象のlist変数
// @return なし
// @detail 必要なヘッダinclude : なし
///
func rcplib_LIST_Clear(list src) {
    
}

///
// @brief list変数内の指定したindexデータを消去するAPI
// @param [in](list)src 制御対象のlist変数
// @param [in](uint16)index 指定するindex
// @return 0:成功, -1:LISTデータが異常
// @detail 必要なヘッダinclude : なし
///
func rcplib_LIST_Delete(list src, uint16 index) {
    
}

///
// @brief list変数内の指定したindexのvalueのデータを書き換えるAPI
// @param [in](list)src 書換え対象のlist変数
// @param [in](uint16)index 指定するindex
// @param [in](int||uint||float||str||json||list)value 書換えに利用する入力データ
// @return 0:成功, -1:LISTデータが異常、または出力先サイズ不足
// @detail 必要なヘッダinclude : なし
///
func rcplib_LIST_Update(list src, uint16 index, any value) {
    
}

///
// @brief list変数内の指定したindexのvalueを数値形式で取得するAPI
// @param [in](list)src 確認対象のlist変数
// @param [in](uint16)index 指定するindex
// @return -1:LISTデータが異常, 正常の場合、int64||uint64||double等の内容に応じた値をreturnする
// @detail 必要なヘッダinclude : なし
///
func rcplib_LIST_SearchN(list src, uint16 index) {
    
}

///
// @brief list変数内の指定したindexのvalueを文字列形式で取得するAPI
// @param [in](list)src 確認対象のlist変数
// @param [out](str)dst 出力先の文字列変数
// @param [in](uint16)index 指定するindex
// @return 0:成功, -1:LISTデータが異常、または出力先サイズ不足
// @detail 必要なヘッダinclude : なし
///
func rcplib_LIST_SearchS(list src, str dst, uint16 index) {
    
}

///
// @brief list変数のデータの有無を確認するAPI
// @param [in](list)src 確認対象のlist変数
// @return 0:データあり, 1:データ無し
// @detail 必要なヘッダinclude : なし
///
func rcplib_LIST_IsEmpty(list src) {
    
}

///
// @brief list変数のデータ数を取得するAPI
// @param [in](list)src 確認対象のlist変数
// @return int64のデータ数をreturnする
// @detail 必要なヘッダinclude : なし
///
func rcplib_LIST_GetEntry(list src) {
    
}

///
// @brief list変数の残りのバッファサイズを取得するAPI
// @param [in](list)src 確認対象のlist変数
// @return int64の残りのバッファサイズをreturnする
// @detail 必要なヘッダinclude : なし
///
func rcplib_LIST_GetRemainSize(list src) {
    
}

//// ■セキュリティ関数
///
// @brief ランダム値を生成するAPI
// @return 0～4294967295:生成したランダム値, -1:異常(基本的に異常は発生しないが、int64で取得することで判断可能)
// @detail 必要なヘッダinclude : なし
// @note AIS-31規格に従って検証された真性乱数生成器によるランダム値を出力する。
// @code
//  // ランダム値の出力先変数を定義し代入
//  uint32 random = rcplib_CRPT_Random();
///
func rcplib_CRPT_Random() {
    
}

///
// @brief AES-GCM-256の暗号化処理を実行するAPI
// @param [out](uint8[])dst 暗号化結果の出力先uint8配列
// @param [out](uint8[])auth_tag 暗号化後に生成した認証タグの出力先uint8配列 ※暗号化処理では16Byte分のデータを出力する
// @param [in](uint8[])src 入力する平文のuint8配列
// @param [in](uint16)word_size 入出力するデータのサイズ[単位:word](1[word]=4[Byte])
// @param [in](uint8[])common_key 入力する共通鍵のuint8配列 ※暗号化処理では32Byte分のデータを使用する
// @param [in](uint8[])init_vector 入力する初期化ベクトルのuint8配列 ※暗号化処理では12Byte分のデータを使用する
// @param [in](uint8[])add_auth_data 入力する追加認証データのuint8配列 ※暗号化処理では16Byte分のデータを使用する
// @return 0:成功, -1:サポート外の型指定, -2:入出力引数のサイズ不足, -3:暗号化失敗, -4:暗号化後の認証タグ生成失敗
// @detail 必要なヘッダinclude : なし
// @note 暗号化処理を行うデータは1[word]=4[Byte]単位のみ実行可能。
//       dstとsrcにはword_sizeで指定するサイズ以上のindex数を定義したuint8配列変数を使用すること。
//       auth_tagには16、common_keyには32、init_vectorには12、add_auth_dataには16以上のindex数を定義したuint8配列変数を使用すること。
///
func rcplib_CRPT_AesGcm256Enc(uint8 dst[], uint8 auth_tag[], uint8 src[], uint16 word_size, uint8 common_key[], uint8 init_vector[], uint8 add_auth_data[]) {
    
}

///
// @brief AES-GCM-256の復号処理を実行するAPI
// @param [out](uint8[])dst 復号結果の出力先uint8配列
// @param [in](uint8[])auth_tag 入力する照合のための認証タグのuint8配列 ※復号処理では16Byte分のデータを使用する
// @param [in](uint8[])src 入力する暗号文のuint8配列
// @param [in](uint16)word_size 入出力するデータのサイズ[単位:word](1[word]=4[Byte])
// @param [in](uint8[])common_key 入力する共通鍵のuint8配列 ※復号処理では32Byte分のデータを使用する
// @param [in](uint8[])init_vector 入力する初期化ベクトルのuint8配列 ※復号処理では12Byte分のデータを使用する
// @param [in](uint8[])add_auth_data 入力する追加認証データのuint8配列 ※復号処理では16Byte分のデータを使用する
// @return 0:成功, -1:サポート外の型指定, -2:入出力引数のサイズ不足, -3:復号失敗, -4:認証タグの照合失敗
// @detail 必要なヘッダinclude : なし
// @note 復号処理を行うデータは1[word]=4[Byte]単位のみ実行可能。
//       dstとsrcにはword_sizeで指定するサイズ以上のindex数を定義したuint8配列変数を使用すること。
//       auth_tagには16、common_keyには32、init_vectorには12、add_auth_dataには16以上のindex数を定義したuint8配列変数を使用すること。
// @code
//  // 入出力サイズのdefine定義
//  #define CRPT_DATA_SIZE  40000
//  #define CRPT_DATA_WORDS (CRPT_DATA_SIZE / 4)
//  // 大きなサイズの入出力データはグローバル変数で定義しておく
//  uint8 l_plane_data[CRPT_DATA_SIZE]; // 平文データ変数
//  uint8 l_crpt_data[CRPT_DATA_SIZE]; // 暗号文データ変数
// 
//  //...基本処理省略...//
// 
//  func any_func() {
//      // 共通鍵
//      uint8 common_key[32] = {
//          0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
//          0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F,
//          0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
//          0x18, 0x19, 0x1A, 0x1B, 0x1C, 0x1D, 0x1E, 0x1F
//          };
//      // 初期化ベクトル
//      uint8 init_vector[12] = {
//          0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
//          0x08, 0x09, 0x0A, 0x0B
//          };
//      // 追加認証データ
//      uint8 add_auth_data[16] = {
//          0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
//          0x08, 0x09, 0x0A, 0x0B, 0x0C, 0x0D, 0x0E, 0x0F
//          };
//      // 認証タグ
//      uint8 auth_tag[16];
//      int32 ret;
//      int32 i;
//      for (i=0; i<CRPT_DATA_SIZE; i=i+1) {
//          // 平文の入力データを作成
//          l_plane_data[i] = i;
//      }
//
//      // 暗号化処理実行＆認証タグの取得
//      rcplib_CRPT_AesGcm256Enc(l_crpt_data, auth_tag, l_plane_data, CRPT_DATA_WORDS, common_key, init_vector, add_auth_data);
//
//      for (i=0; i<CRPT_DATA_SIZE; i=i+1) {
//          // 復号データ出力先変数を0クリア
//          l_plane_data[i] = 0x00;
//      }
//
//      // 復号処理実行＆認証タグの照合
//      ret = rcplib_CRPT_AesGcm256Dec(l_plane_data, auth_tag, l_crpt_data, CRPT_DATA_WORDS, common_key, init_vector, add_auth_data);
//
//      rcplib_LOG_Print(ret); // ログ出力で0が出力され、成功が確認できる
//  }
///
func rcplib_CRPT_AesGcm256Dec(uint8 dst[], uint8 auth_tag[], uint8 src[], uint16 word_size, uint8 common_key[], uint8 init_vector[], uint8 add_auth_data[]) {
    
}


///// ■バッファ制御ライブラリ■
//// ■FIFOバッファ
///
// @brief FIFOバッファを定義するAPI
// @param [in](uint8)fifo_buff_id FIFOバッファID <0～31>
// @param [in](uint32)buf_size バッファのトータルサイズ [byte]
// @param [in](uint16)buf_depth バッファに保存可能なデータブロック数 <1～65535[個]>
// @param [in](uint8)overwrite バッファ満了時の書き込み処理の挙動 <FIFOBUF_OVERWRITE_DISABLE:書き込みは失敗させる, FIFOBUF_OVERWRITE_ENABLE:古いデータを消して書き込む>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention タスクの初期化処理内でのみ実行すること。
// @note FIFOバッファID(0～31)はシステム全体で重複しない様に定義すること。
//       タスク内で利用するFIFOバッファの合計サイズ以上のBufferFIFOSize指定をoptionsにて行うこと。
//       サイズ上限はレシピビルド実行時に決定され、メモリー不足の場合はビルドエラーとなる。(OSでも利用する合計約370[KB]のメモリー内で割り当て)
// 
//       ＜BufferFIFOSizeの設定例＞
//       //////////////////////////////////////////////////////////////////
//       // event driven task process //
//       //////////////////////////////////////////////////////////////////
//       options {
//           BufferFIFOSize = 2048;
//       }
///
func rcplib_FIFOBUF_Create(uint8 fifo_buff_id, uint32 buf_size, uint16 buf_depth, uint8 overwrite) {
    
}

///
// @brief FIFOバッファにデータブロックを書き込むAPI
// @param [in](uint8)fifo_buff_id FIFOバッファID <0～31>
// @param [in](uint16)size 入力サイズ <0-65535[Byte]>
// @param [in](uint8[])data FIFOバッファに書き込むuint8配列データブロック
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @note sizeを0で指定するとデータ無しの書き込みができ、一つのデータブロックとして扱われ、
//       例えばHTTP GET処理における「Bodyデータ無し」の通信などにも利用可能。
///
func rcplib_FIFOBUF_SetData(uint8 fifo_buff_id, uint16 size, uint8 data[]) {
    
}

///
// @brief FIFOバッファにFormat定義したデータブロックを書き込むAPI
// @param [in](uint8)fifo_buff_id FIFOバッファID <0～31>
// @param [in](uint8)type データブロックを読み出す際の形式指定<FIFOBUF_KIND_BIN:バイナリ, FIFOBUF_KIND_JSON:JSON, FIFOBUF_KIND_CSV:CSV>
// @param [in](int||uint||float||str)data1 FIFOバッファに書き込むデータ1
// @param [in](int||uint||float||str)datax FIFOバッファに書き込むデータ2以降 ※Format定義数に応じて利用可(最大data32まで)
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @note typeにはrcplib_FIFOBUF_DefineFormatData()で定義したものと同じ設定をすること。
///
func rcplib_FIFOBUF_SetFormatData(uint8 fifo_buff_id, uint8 type, any data1, ...) {
    
}

///
// @brief FIFOバッファのデータブロックを読み出すAPI(読み出し後、データブロックを消去する)
// @param [in](uint8)fifo_buff_id FIFOバッファID <0～31>
// @param [in](uint16)size 出力先変数data[]の配列サイズ <1-65535[Byte]、0で指定した場合はdataの配列サイズに合わせる>
// @param [out](uint8[])data 読み出すデータブロックの出力先変数
// @return 0以上:成功(データサイズをreturnする), -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @note クラウド送信用に指定したFIFOバッファに対してこのAPIを実行するとデータが消えるので注意すること。
///
func rcplib_FIFOBUF_GetData(uint8 fifo_buff_id, uint16 size, uint8 data[]) {
    
}

///
// @brief FIFOバッファのデータブロックを読み出すAPI(読み出し後もデータブロックが残る)
// @param [in](uint8)fifo_buff_id FIFOバッファID <0～31>
// @param [in](uint16)size 出力先変数data[]の配列サイズ <1-65535[Byte]、0で指定した場合はdataの配列サイズに合わせる>
// @param [out](uint8[])data 読み出すデータブロックの出力先変数
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
///
func rcplib_FIFOBUF_PeekData(uint8 fifo_buff_id, uint16 size, uint8 data[]) {
    
}

///
// @brief rcplib_FIFOBUF_SetFormatData()で利用するフォーマットを定義するAPI
// @param [in](uint8)format_id フォーマット定義ID <0～254>
// @param [in](uint8)type データを読み出す際の形式指定<FIFOBUF_KIND_BIN:バイナリ, FIFOBUF_KIND_JSON:JSON, FIFOBUF_KIND_CSV:CSV>
// @param [in](uint8)data_type1 データ1の型指定
// @param [in](str)data_key_name1 データ1のkey名の文字列変数(typeがJSON指定以外の際は不問)
// @param [in](uint8)data_typex データ2以降の型指定 ※最大data_type32まで
// @param [in](str)data_key_namex データ2以降のkey名の文字列変数 ※最大data_key_name32まで)
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h" "eventLib.h"
// @note
//     ID定義1つあたり、基本利用分32[Byte] + (data_key_namexの文字数 + 1)の合計分のメモリーを利用する。
//     例えば、data_key_name1に"key_fisrt"、data_key_name2に"key_second"を定義した場合、
//     53[Byte](内訳は32 + (9 + 1) + (10 + 1))分のメモリーを利用する計算となる。
//     タスク内で利用するフォーマットの合計サイズ以上のBufferFormatInfoSize指定をoptionsにて行うこと。
// 
//     // data_typex(データ1の型指定)への入力値
//     EAPI_VTYPE_I8  // int8
//     EAPI_VTYPE_I16 // int16
//     EAPI_VTYPE_I32 // int32
//     EAPI_VTYPE_I64 // int64
//     EAPI_VTYPE_U8  // uint8
//     EAPI_VTYPE_U16 // uint16
//     EAPI_VTYPE_U32 // uint32
//     EAPI_VTYPE_U64 // uint64
//     EAPI_VTYPE_F32 // float
//     EAPI_VTYPE_F64 // double
//     EAPI_VTYPE_STR // str
///
func rcplib_FIFOBUF_DefineFormatData(int8 format_id, uint16 type, uint8 data_type1, str data1, ...) {
    
}

///
// @brief FIFOバッファ内のデータブロック数を取得するAPI
// @param [in](uint8)fifo_buff_id FIFOバッファID <0～31>
// @return uint32のデータブロック数をreturnする
// @detail 必要なヘッダinclude : "bufferLib.h"
///
func rcplib_FIFOBUF_GetEntryNumber(uint8 fifo_buff_id) {
    
}

//// ■Fixedバッファ(Bluetooth Low Energy受信データ専用)
///
// @brief Fixedバッファのデータを読み出すAPI
// @param [in](uint8)fixed_buff_id FixedバッファID <FIXBUF_ID_BLE_SENCE～FIXBUF_ID_BLE_LONGRANGEを利用可>
// @param [in](int32)index 読み出す対象のindex指定 <FIXBUF_ID_BLE_LONGRANGE利用時は0～1、それ以外利用時は0～119>
// @param [out](uint8[])data 読み出すデータの出力先
// @return なし
// @detail 必要なヘッダinclude : "bufferLib.h"
///
func rcplib_FIXBUF_Pop(uint8 fixed_buff_id, int32 index, uint8 data[]) {
    
}

//// ■Indexバッファ(本Indexバッファは利用非推奨、FIFOバッファを利用すること)[NOT_FOR_USERS]
///
// @brief Indexバッファを定義するAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @param [in](uint8[])buffer Indexバッファとして利用するメモリー空間
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_Allocate(uint8 index_buff_id, uint8 buffer[]) {
    
}

///
// @brief Indexバッファを解放するAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_Free(uint8 index_buff_id) {
    
}

///
// @brief Indexバッファの全データをクリアするAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @param [in](str||json||list)src 書き込む文字列変数
// @param [in](uint8)overwrite バッファ満了時の書き込み処理の挙動 <0:書き込みは失敗させる, 1:古いデータを消して書き込む>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_Push(uint8 index_buff_id, str_json_list src, uint8 overwrite) {
    
}

///
// @brief Indexバッファのデータを読み出すAPI(読み出し後、データを消去する)
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @param [out](str)dst 読み出すデータの出力先文字列変数
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_Pop(uint8 index_buff_id, str dst) {
    
}

///
// @brief Indexバッファの指定したデータを読み出すAPI(読み出し後のデータを消去有無指定可能)
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @param [out](str)dst 読み出すデータの出力先文字列変数
// @param [in](int32)index 読み出すデータのindex指定
// @param [in](uint8)delete 読み出したデータの削除有無指定 <0:削除しない, 1:削除する>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_Peek(uint8 index_buff_id, str dst, int32 index, uint8 delete) {
    
}

///
// @brief Indexバッファの指定したデータを更新するAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @param [in](int32)index 更新するデータのindex指定
// @param [in](str||json||list)src 書き込む文字列変数
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_Update(uint8 index_buff_id, int32 index, str_json_list src) {
    
}

///
// @brief Indexバッファの指定したデータを削除するAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @param [in](int32)index 削除するデータのindex指定
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_Delete(uint8 index_buff_id, int32 index) {
    
}

///
// @brief Indexバッファ内のデータ数を取得するAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @return 0以上:データ数, 0未満:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_GetEntryNumber(uint8 index_buff_id) {
    
}

///
// @brief Indexバッファ内の全データを文字列変数に出力するAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @param [out](str)dst データの出力先文字列変数
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_GetEntryData(uint8 index_buff_id, str dst) {
    
}

///
// @brief Indexバッファの未利用のワークサイズを取得するAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @return 0以上:未利用のワークサイズ, 0未満:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_GetRemainSize(uint8 index_buff_id) {
    
}

///
// @brief Indexバッファ内のデータ有無を取得するAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @return 0:データあり, 1:データ無し
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_IsEmpty(uint8 index_buff_id) {
    
}

///
// @brief Indexバッファの格納データを消去するAPI
// @param [in](uint8)index_buff_id IndexバッファID <0～31>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "bufferLib.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func rcplib_IDXBUF_Clear(uint8 index_buff_id) {
    
}

//////////////////////////////////////////////////////////////////
// ＜デバイスライブラリAPIの定義＞ //
//////////////////////////////////////////////////////////////////

///// ■モジュールやシステム制御タスク■
//// ■モデム
///
// @brief 利用が無い場合のモデムを電源OFFするまでの時間を設定するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0:成功>
// @param [in](uint32)delay_time 電源OFFするまでの時間[msec]、0xFFFFFFFFを設定した場合は常時ON設定
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、設定値のみの変更なので、モデムの電源制御には影響しない。
///
func MMG_SetDelayOfftime(int32 timeout, uint8 sync, uint8 ex_result, uint32 delay_time) {
    
}

///
// @brief 基地局からのUNIX時間を取得するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0:成功>
// @return -1(0xFFFFFFFFFFFFFFFF):失敗, uint64のUNIX時刻をreturnする
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
///
func MMG_GetTime(int32 timeout, uint8 sync, uint8 ex_result) {
    
}

///
// @brief 電波強度情報を取得するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果出力先 <0:成功>
// @return -1:失敗, uint8の電波強度情報(0～4)をreturnする
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
///
func MMG_GetAntLevel(int32 timeout, uint8 sync, uint8 ex_result) {
    
}

///
// @brief IMEIを取得するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果出力先 <0:成功>
// @return strのIMEI情報(15文字)をreturnする, 失敗の場合は0文字の""をreturnする
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
///
func MMG_GetIMEI(int32 timeout, uint8 sync, uint8 ex_result) {
    
}

///
// @brief IMSIを取得するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果出力先 <0:成功>
// @return strのIMSI情報(15文字)をreturnする, 失敗の場合は0文字の""をreturnする
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
///
func MMG_GetIMSI(int32 timeout, uint8 sync, uint8 ex_result) {
    
}

///
// @brief 電話番号を取得するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果出力先 <0:成功>
// @return strの電番情報(一般的には11文字)をreturnする, 失敗の場合は0文字の""をreturnする
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
///
func MMG_GetNUM(int32 timeout, uint8 sync, uint8 ex_result) {
    
}

///
// @brief モデムのファームウェアバージョンを取得するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [out](uint8)ex_result API実行結果 <0:成功>
// @return strのファームウェアバージョン情報(30文字)をreturnする, 失敗の場合は0文字の""をreturnする
// @detail 必要なヘッダinclude : "modemMgrTask.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
///
func MMG_GetRevision(int32 timeout, uint8 ex_result) {
    
}

///
// @brief モデム起動中の常時USB接続設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)usb_conn モデム起動中の常時USB接続設定 <MMG_NOTCONNECT_USB:無効, MMG_CONNECT_USB:有効>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
//       USBの通信パスを用いてLTEデータ送信をする際、予め常時USB接続設定を行っておくことでUSB接続の処理負荷を軽減できる。
///
func MMG_SetAlwayseConnectUsb(int32 timeout, uint8 usb_conn) {
    
}

//// ■通信プロトコル
///
// @brief ソケット接続の基本設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8>
// @param [in](str)hostname 接続先のホスト名 <127文字以下で任意の文字列>
// @param [in](uint16)port 接続先のポート番号 <0～65535>
// @param [in](uint8)protocol 利用する通信プロトコル
// @param [in](uint8)sni TLS通信利用時のSNI設定 <MMG_SNI_DISABLE:無効, MMG_SNI_ENABLE:有効>
// @param [in](uint8)auth_mode TLSのモード設定 <MMG_AUTH_NONE:認証なし, MMG_AUTH_SRV:サーバー認証, MMG_AUTH_SRVCLI:クライアント認証も含む>
// @param [in](uint8)auth_index 認証ID(TLS接続や証明書の管理ID) <1～5>
// @param [in](uint8)use_usb ハードウェア内部の通信パスの設定 <MMG_NOTUSE_USB:無効, MMG_USE_USB:有効> ※MMG_NOTUSE_USBのみ利用可
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、設定値のみの変更なので、モデムの電源制御には影響しない。
// 
//       // protocol(利用する通信プロトコル)への入力値
//       MMG_PROTOCOL_UDP
//       MMG_PROTOCOL_TCP
//       MMG_PROTOCOL_TLS
//       MMG_PROTOCOL_HTTP
//       MMG_PROTOCOL_HTTPS
//       MMG_PROTOCOL_MQTT
//       MMG_PROTOCOL_MQTTS
//       MMG_PROTOCOL_S3_STORAGE_HTTPS
//       MMG_PROTOCOL_AZURE_STORAGE_REST_HTTPS
//       MMG_PROTOCOL_AZURE_IOT_SASTOKEN_HTTPS
//       MMG_PROTOCOL_GCP_IOT_ES256_HTTPS
//       MMG_PROTOCOL_AZURE_IOT_SASTOKEN_MQTTS
//       MMG_PROTOCOL_GCP_IOT_ES256_MQTTS
///
func MMG_SetConnectParam(int32 timeout, uint8 sync, uint8 ex_result, uint8 send_id, str hostname, uint16 port, uint8 protocol, uint8 sni, uint8 auth_mode, uint8 auth_index, uint8 use_usb) {
    
}

///
// @brief データ受信やソケット切断時のイベントの基本設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8>
// @param [in](uint8)rcv_databuf_id 受信に利用するFIFOバッファID <0～31>
// @param [in](uint8)rcv_event_id データ受信やソケット切断時に発行されるイベントID <1～254>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、設定値のみの変更なので、モデムの電源制御には影響しない。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(uint16)response_code 受信結果のレスポンスコード
//    ・rcplib_TASK_GetArg(1)
//    　(uint8)rcv_datbuf_id 受信データを格納したFIFOバッファID
///
func MMG_SetReceiveParam(int32 timeout, uint8 sync, uint8 ex_result, uint8 send_id, uint8 rcv_databuf_id, uint8 rcv_event_id) {
    
}

///
// @brief ソケット接続/切断を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8>
// @param [in](uint8)connect ソケット接続/切断設定 <MMG_SOCKET_CLOSE:ソケット切断要求, MMG_SOCKET_OPEN:ソケット接続要求>
// @return 0:成功, -1:失敗またはワーニング
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
//       圏外やサーバー等の要因で切断された後のソケット接続処理は失敗となる。必ずその前にソケット切断を実行すること。
///
func MMG_ConnectSOCKET(int32 timeout, uint8 sync, uint8 ex_result, uint8 send_id, uint8 connect) {
    
}

///
// @brief 「UDP/TCP/TLS」でデータ送信を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8>
// @param [in](uint8)databuf_id 送信データのFIFOバッファID <0～31>
// @param [in](uint16)mov_target カメラの撮影画像送信時の対象指定 <0:最新の画像, 1～:最新から指定毎数分さかのぼった画像, 0xFFFF:一番古い画像>
// @param [in](uint8)burst FIFOバッファから連続で送信するデータ数 <1～:指定数分を連続送信(0代入時は1として扱われる), 0xFFFF:FIFOバッファ内の全てのデータを送信>
// @param [in](uint8)session 送信後の通信接続状態設定 <MMG_SESSION_DISCONNECT:切断, MMG_SESSION_CONNECT:接続のまま> ※MMG_SESSION_CONNECTのみ利用可
// @param [in](uint8)retain 送信に失敗したデータをFIFOバッファに残す設定 <MMG_DATA_NOTRETAIN:残す, MMG_DATA_RETAIN:残さない(消去する)>
// @param [out](uint16)send_success_num 送信に成功した数の出力先
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
//       「UDP/TCP/TLS」のprotocolを選択した際に本APIを利用すること。「HTTP(S)/MQTT(S)」選択時は利用不可。
//       ex_resultが失敗の返答だった場合、次のデータ通信を成功させるためには必ずソケット切断を実行すること。
///
func MMG_SendSOCKET(int32 timeout, uint8 sync, uint8 ex_result, uint8 send_id, uint8 databuf_id, uint16 mov_target, uint8 burst, uint8 session, uint8 retain, uint16 send_success_num) {
    
}

///
// @brief HTTP(S)の基本設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8>
// @param [in](str)http_url 接続先のURL名 <255文字以下で任意の文字列("http:abc.com/a/b/c"に送信する場合"/a/b/c"を指定する)>
// @param [in](str)http_header 付与するHTTPヘッダ情報 <767文字以下で任意の文字列>
// @param [in](uint8)http_method 送信時に利用するHTTPメソッド
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、設定値のみの変更なので、モデムの電源制御には影響しない。
//       HTTP送信時のヘッダに関して、URLやHostやContent-LengthやConnection: Keep-Aliveは自動付与される。
//       上記以外のHTTPヘッダを付与する場合は、項目ごとにFiledとValueの間は必ず": "の2Byteで区切り、CRLFの2Byteで終端すること。
// 
//       http_method(送信時に利用するHTTPメソッド)への入力値
//       MMG_METHOD_HTTPGET
//       MMG_METHOD_HTTPPOST
//       MMG_METHOD_HTTPHEAD
//       MMG_METHOD_HTTPPUT
//       MMG_METHOD_HTTPDELETE
//       MMG_METHOD_HTTPCONNECT
//       MMG_METHOD_HTTPOPTIONS
//       MMG_METHOD_HTTPTRACE
//       MMG_METHOD_HTTPPATCH
// 
//       URL名には特殊なリプレイス文字を含めることで「HTTP送信時の時刻情報や端末のIMEIなどに置き換える機能」を利用することができる
//       例えば"http://harvest-files.soracom.io"に送信する場合のURLを"/KC4C_test/*rp_imei*******/"と設定することで、
//       "http://harvest-files.soracom.io/KC4C_test/012345678901234/"の様に端末のIMEI情報に置き換えて送信処理が行われる。
//       対応しているリプレイス文字は以下3種類。
//       "*rp_timestamp****" : LTE送信処理実行時のタイムスタンプを"YYYYMMDDhhmmssddd"という形式でリプレイス ※dddは[msec]
//       "*rp_movietime****" : USBカメラ画像撮影時のタイムスタンプを"YYYYMMDDhhmmssddd"という形式でリプレイス(カメラバッファからのHTTP送信処理の時のみ利用可) ※dddは[msec]
//       "*rp_imei*******"   : 端末のIMEI(15桁の数値の文字列)でリプレイス
///
func MMG_SetConnectParamHTTP(int32 timeout, uint8 sync, uint8 ex_result, uint8 send_id, str http_url, str http_header, uint8 http_method) {
    
}

///
// @brief HTTP(S)でデータ送信を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト最小値設定 <[msec]で指定>
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8>
// @param [in](uint8)databuf_id 送信に利用するFIFOバッファID <0～31または100（MMG_MOVIE_BUF_ID：カメラバッファ)>
// @param [in](uint16)mov_target カメラの撮影画像送信時の対象指定 <0:最新の画像, 1～:最新から指定毎数分さかのぼった画像, 0xFFFF:一番古い画像>
// @param [in](uint8)burst FIFOバッファから連続で送信するデータ数 <1～:指定数分を連続送信(0代入時は1として扱われる), 0xFFFF:FIFOバッファ内の全てのデータを送信>
// @param [in](uint8)session 送信後の通信接続状態 <MMG_SESSION_DISCONNECT:切断, MMG_SESSION_CONNECT:接続のまま> ※MMG_SESSION_CONNECTのみ利用可
// @param [in](uint8)retain 送信に失敗したデータをFIFOバッファに残す設定 <MMG_DATA_NOTRETAIN:残す, MMG_DATA_RETAIN:残さない(消去する)>
// @param [out](uint16)http_rsp_code HTTP通信結果のリザルトコード(成功時は2XX、失敗時は4XX等が得られる)
// @param [out](uint8)rcv_buff_id HTTPレスポンスのBodyデータの出力先 ※MMG_SetReceiveParam()で事前にバッファを指定した場合にのみ有効
// @param [out](uint16)send_success_num 送信に成功した数の出力先
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
//       ex_resultが失敗の返答だった場合、次のデータ通信を成功させるためには必ずソケット切断を実行すること。
///
func MMG_SendHTTP(int32 timeout, uint8 sync, uint8 ex_result, uint8 send_id, uint8 databuf_id, uint16 mov_target, uint8 burst, uint8 session, uint8 retain, uint16 http_rsp_code, uint8 rcv_buff_id, uint16 send_success_num) {
    
}

///
// @brief MQTT(S)の接続基本設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)mq_conn_id MQTT接続ID(MQTT接続や送受信の管理ID) <1～4>
// @param [in](uint8)mq_clean clean sessionの設定 <MMG_MQTT_CLEAN_DISABLE:設定無し, MMG_MQTT_CLEAN_ENABLE:Clean設定する>
// @param [in](uint8)mq_keep_alive keep-alive時間の設定 <[秒]で指定>
// @param [in](str)mq_client_id クライアントID <191文字以下で任意の文字列>
// @param [in](str)mq_user_name ユーザー名 <127文字以下で任意の文字列>
// @param [in](str)mq_user_pass パスワードの設定 <255文字以下で任意の文字列>
// @param [in](uint8)mq_will_qos Will設定のQoS <MMG_MQTT_QOS0_AT_MOST_ONCE:QoS0, MMG_MQTT_QOS1_AT_LEAST_ONCE:QoS1, MMG_MQTT_QOS2_EXACTRY_ONCE:QoS2>
// @param [in](uint8)mq_will_retain Will設定のretain <MMG_MQTT_NOTRETAIN:retain設定無し, MMG_MQTT_TRETAIN:retain設定あり>
// @param [in](str)mq_will_topic_name Will設定のトピック名 <191文字以下で任意の文字列>
// @param [in](str)mq_will_payload Will設定のメッセージ <127文字以下で任意の文字列>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、設定値のみの変更なので、モデムの電源制御には影響しない。
///
func MMG_SetConnectParamMQTT(int32 timeout, uint8 sync, uint8 ex_result, uint8 mq_conn_id, uint8 mq_clean, uint8 mq_keep_alive, str mq_client_id, str mq_user_name, str mq_user_pass, uint8 mq_will_qos, uint8 mq_will_retain, str mq_will_topic_name, str mq_will_payload) {
    
}

///
// @brief MQTT(S)のSubscribe基本設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)mq_conn_id MQTT接続ID(MQTT接続や送受信の管理ID) <1～4>
// @param [in](uint8)mq_sub_id MQTT Subscribe ID(Subscribeの管理ID、本APIを複数回実行することで一つのmq_conn_idに対して複数登録可) <1～4>
// @param [in](uint8)mq_sub_qos MQTT SubscribeにおけるQoS <MMG_MQTT_QOS0_AT_MOST_ONCE:QoS0, MMG_MQTT_QOS1_AT_LEAST_ONCE:QoS1, MMG_MQTT_QOS2_EXACTRY_ONCE:QoS2>
// @param [in](str)mq_sub_topic_name MQTT Subscribeにおけるトピック名 <191文字以下で任意の文字列>
// @param [in](uint8)rcv_databuf_id 受信に利用するFIFOバッファID <0～31>
// @param [in](uint8)rcv_event_id データ受信で発行されるイベントID <1～254>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、設定値のみの変更なので、モデムの電源制御には影響しない。
//       本APIにて設定した情報を元に、MQTT接続処理の実行完了直後に自動でSubscribe登録処理が実行される。
//       rcv_databuf_idやrcv_event_idは、必ずMMG_SetReceiveParam()で設定したものと同じidを指定すること。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(uint16)response_code 受信結果のレスポンスコード
//    ・rcplib_TASK_GetArg(1)
//    　(uint8)rcv_datbuf_id 受信データを格納したFIFOバッファID
///
func MMG_SetSubscriveParamMQTT(int32 timeout, uint8 sync, uint8 ex_result, uint8 mq_conn_id, uint8 mq_sub_id, uint8 mq_sub_qos, str mq_sub_topic_name, uint8 rcv_databuf_id, uint8 rcv_event_id) {
    
}

///
// @brief MQTT(S)接続/切断を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8>
// @param [in](uint8)mq_conn_id MQTT接続ID(MQTT接続や送受信の管理ID) <1～4>
// @param [in](uint8)connect MQTT(S)接続/切断設定 <MMG_MQTT_CLOSE:MQTT(S)切断要求, MMG_MQTT_OPEN:MQTT(S)接続要求>
// @return 0:成功, -1:失敗またはワーニング
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
///
func MMG_ConnectMQTT(int32 timeout, uint8 sync, uint8 ex_result, uint8 send_id, uint8 mq_conn_id, uint8 connect) {
    
}

///
// @brief MQTT(S)でデータ送信(Publish送信)を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [out](uint8)ex_result API実行結果 <0(MMG_NO_ERROR):成功, 1～99:Warning, 100～199:失敗> ※詳細は"modemMgrTask.h"を参照
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8>
// @param [in](uint8)mq_conn_id MQTT接続ID(MQTT接続や送受信の管理ID) <1～4>
// @param [in](uint8)mq_pub_qos MQTT Publish送信におけるQoSの設定 <MMG_MQTT_QOS0_AT_MOST_ONCE:QoS0, MMG_MQTT_QOS1_AT_LEAST_ONCE:QoS1, MMG_MQTT_QOS2_EXACTRY_ONCE:QoS2>
// @param [in](uint8)mq_pub_retain Will設定のretain <MMG_MQTT_NOTRETAIN:retain設定無し, MMG_MQTT_TRETAIN:retain設定あり>
// @param [in](str)mq_pub_topic_name MQTT Publish送信におけるトピック名 <191文字以下で任意の文字列>
// @param [in](uint8)databuf_id 送信に利用するFIFOバッファID <0～31>
// @param [in](uint16)mov_target カメラの撮影画像送信時の対象指定 <0:最新の画像, 1～:最新から指定毎数分さかのぼった画像, 0xFFFF:一番古い画像>
// @param [in](uint8)burst FIFOバッファから連続で送信するデータ数 <1～:指定数分を連続送信(0代入時は1として扱われる), 0xFFFF:FIFOバッファ内の全てのデータを送信>
// @param [in](uint8)session 送信後の通信接続状態設定 <MMG_SESSION_DISCONNECT:切断, MMG_SESSION_CONNECT:接続のまま> ※MMG_SESSION_CONNECTのみ利用可
// @param [in](uint8)retain 送信に失敗したデータをFIFOバッファに残す設定 <MMG_DATA_NOTRETAIN:残す, MMG_DATA_RETAIN:残さない(消去する)>
// @param [out](uint16)send_success_num 送信に成功した数
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
//       ex_resultが失敗の返答だった場合、次のデータ通信を成功させるためには必ずソケット切断を実行すること。
///
func MMG_SendMQTT(int32 timeout, uint8 sync, uint8 ex_result, uint8 send_id, uint8 mq_conn_id, uint8 mq_pub_qos, uint8 mq_pub_retain, str mq_pub_topic_name, uint8 databuf_id, uint16 mov_target, uint8 burst, uint8 session, uint8 retain, uint16 send_success_num) {
    
}

///
// @brief TLS認証情報(CA証明書/クライアント証明書/秘密鍵/PSK)を設定するAPI
// @param [in](uint8)auth_index 認証ID(TLS接続や証明書設定の管理ID) <1～5>
// @param [in](uint8)type 設定対象
// @param [in](uint8[])data 入力するuint8配列データ
// @param [in](uint16)size 入力サイズ <1-5120[Byte]>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @attention タスクの初期化処理内でのみ実行すること。
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
//       CA証明書/クライアント証明書/秘密鍵は最大5120[Byte]のものまで設定可能。
//       PSKのIdentity/PSKのkeyは最大63[Byte]のものまで設定可能。
//       本APIは必ずアプリケーションタスクの初期化処理event_init()内でのみ実行すること。
//       実行時は同期処理かつtimeout設定=60[秒]にて実行される。
// 
//       type(設定対象)への入力値
//       MMG_AUTH_KIND_CACERT     // CA証明書
//       MMG_AUTH_KIND_CLIENTCERT // クライアント証明書
//       MMG_AUTH_KIND_CLIENTKEY  // 秘密鍵
//       MMG_AUTH_KIND_PSK_ID     // PSKのIdentity
//       MMG_AUTH_KIND_PSK_KEY    // PSKのkey
///
func MMG_SetCertificate(uint8 auth_index, uint8 type, uint8 data[], uint16 size) {
    
}

//// ■位置情報
///
// @brief GNSS位置情報を取得するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)event_id API実行方法 <非同期実行の場合は1～254の任意のevent_id、同期の場合は0(EAPI_SYNC_RESULT)> 
// @param [in](uint8)mode 位置情報要求設定 <MMG_GNSS_END:位置情報の測位を停止する要求, MMG_GNSS_START_ONESHOT:1回だけ位置情報の測位をする要求（非同期/同期）, MMG_GNSS_START_POLLING:1秒毎の繰り返しで位置情報の測位をする要求（非同期のみ）>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "modemMgrTask.h" "eventLib.h"
// @note 「MMG_」から始まるAPIはsapp_modem.krsからの実行を除いて必ず1つのタスクからのみ実行すること。
//       モデムの動作状況(電源OFF->ONの際など)に応じて、指定したtimeoutより数十秒程度長くかかることがある。
//       本API実行時、モデムがOFFだった場合は、自動的に電源ONから制御される。
//       MMG_GNSS_START_POLLINGでの要求後、位置情報が定まれば最速1秒間隔で位置情報のイベントが通知される。
// 
//    ＜コールバックイベント(または同期実行後の)での取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(double)latitude 位置測位結果の緯度情報[deg](-90.0～+90.0) ※latitudeが99999.0の場合は位置情報以外の通知
//    ・rcplib_TASK_GetArg(1)
//    　(double)longitude 位置測位結果の経度情報[deg](-180.0～+180.0) ※latitudeが99999.0の場合は、longitudeからその詳細("modemMgrTask.h"の「API実行時のリザルトコード」参照)が得られる。
///
func MMG_GetGNSS(int32 timeout, uint8 event_id, uint8 mode) {
    
}

//// ■Bluetooth Low Energy
///
// @brief ビーコンの送受信機能の基本設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](uint32)send_interval Advertise送信周期 <20～10000[msec]>
// @param [in](uint32)recv_width Advertise受信窓幅(受信周期以上の設定値で受信Duty100%動作) <3～40000[msec]>
// @param [in](uint32)recv_interval Advertise受信周期 <3～3600000[msec]>
// @param [in](int8)recv_rssi_th Advertise受信時の信号強度閾値 <-128～0[dBm]>
// @param [in](uint32)ibeacon_recv iBeacon毎の通知を抑制する期間。Long Range送信の場合、不問。<1秒以上、0指定で1回だけ通知を行う>
// @param [in](uint32)sensor_recv ビーコン毎の通知を抑制する期間。Long Range送信の場合、フィルター検出したBeacon毎の通知を抑制する期間。<1秒以上、0指定で1回だけ通知を行う>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h"
// @note Bluetooth Low Energy送信機能を利用される場合、受信関連の全ての設定値は不問となり、何を設定しても構わない。
//       Bluetooth Low Energy受信機能を利用される場合、send_intervalの設定値は不問となり、何を設定しても構わない。
//       Bluetooth Low Energy受信のiBeacon検出またはビーコン検出機能のいずれかのみを利用される場合、利用しないもの(ibeacon_recvまたはsensor_recv)の設定値は不問となり、何を設定しても構わない。
//       各周期や窓幅の設定において、範囲外の設定を行った場合は100[msec]の設定値が適用される。
//       
//       |引数 |送信設定<br>(LongRange含む)|受信設定<br>（センサ機器、<br>LongRange）|受信設定<br>（iBeacon）|
//       |:--:         |:--:              |:--:                                  |:--:                  |
//       |send_interval|〇                |☓                                     |☓                    |
//       |recv_width   |☓                |〇                                     |〇                    |
//       |recv_interval|☓                |〇                                     |〇                    |
//       |recv_rssi_th |☓                |〇                                     |〇                    |
//       |ibeacon_recv |☓                |☓                                     |〇                    |
//       |sensor_recv  |☓                |〇                                     |☓                    |
///
func BLE_SettingDataSet(int32 timeout, uint8 sync, uint32 send_interval, uint32 recv_width, uint32 recv_interval, int8 recv_rssi_th, uint32 ibeacon_recv, uint32 sensor_recv) {
    
}

///
// @brief ビーコンを検するためのフィルター設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](int64)filter_id フィルター番号 <0～49、iBeaconと共有なので重複利用は禁止>
// @param [in](uint8)beacon_type ビーコンの種別 <2～5>
// @param [in](uint8[])adv_address Advertiser's Address（AdvA） <6Byte配列>
// @param [in](uint8[])f1_ad_type フィルター設定１のAD Type <1Byte配列またはuint8変数>
// @param [in](uint8[])f1_ad_data_filter フィルター設定１のAD Data <32Byte配列>
// @param [in](uint8[])f1_ad_data_mask フィルター設定１のAD Dataの場所 <32Byte配列でビットマスク>
// @param [in](uint8[])f2_ad_type フィルター設定２のAD Type <1Byte配列またはuint8変数>
// @param [in](uint8)f2_ad_data_offset フィルター設定２のAD Dataのオフセット指定 <0～29>
// @param [in](uint8[])f2_ad_data_filter フィルター設定２のAD Data <6Byte配列>
// @param [in](uint8[])f2_ad_data_mask フィルター設定２のAD Dataの場所 <6Byte配列でビットマスク>
// @param [in](uint8[])f2_ad_data_free_mask フィルター設定２のAD Dataに対する部分一致を利用する場合の特定範囲用のビットマスク箇所 <6Byte配列でビットマスク>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h" "bleCtrlTask.h"
// @note 本製品はAdvertiser's Dataが31Byte以下のデータにのみ対応している。(それを超える拡張フォーマットは非対応)
//       beacon_typeにBLE_SENSOR_BEACON_TYPE2_IDを指定時、f2_xxxの設定値は全て不問となり、何を設定しても構わない。
//       beacon_typeにBLE_SENSOR_BEACON_TYPE3_IDを指定時、adv_addressとf2_xxxの設定値は全て不問となり、何を設定しても構わない。
//       beacon_typeにBLE_SENSOR_BEACON_TYPE4_IDを指定時、adv_addressの設定値は不問となり、何を設定しても構わない。
//       beacon_typeにBLE_SENSOR_BEACON_TYPE5_IDを指定時、f2_ad_data_free_maskの設定値は不問となり、何を設定しても構わない。
// 
//       beacon_type(ビーコンの種別)への入力値
//       BLE_SENSOR_BEACON_TYPE2_ID // Advertiser's Addressと一つのAD Structureで判別するパターン
//       BLE_SENSOR_BEACON_TYPE3_ID // 1つのAD Structureで判別するパターン
//       BLE_SENSOR_BEACON_TYPE4_ID // 1～2つのAD Structureで判別、更に、特定のデータ部を違うデバイスと判別するパターン
//       BLE_SENSOR_BEACON_TYPE5_ID // Advertiser's Addressと1～2つのAD Structureで判別するパターン
///
func BLE_FilterDataSetSensor(int32 timeout, uint8 sync, int64 filter_id, uint8 beacon_type, uint8 adv_address[], uint8 f1_ad_type[], uint8 f1_ad_data_filter[], uint8 f1_ad_data_mask[], uint8 f2_ad_type[], uint8 f2_ad_data_offset, uint8 f2_ad_data_filter[], uint8 f2_ad_data_mask[], uint8 f2_ad_data_free_mask[]) {
    
}

///
// @brief iBeacon（ビーコン）を検出するためのフィルター設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](int64)filter_id フィルター番号 <0～49、ビーコンで共有なので重複利用は禁止>
// @param [in](uint8[])uuid_filter UUIDに対するフィルター設定 <16Byte配列>
// @param [in](uint8[])uuid_mask UUIDに対するマスク設定 <16Byte配列で対象箇所をbit指定>
// @param [in](uint8[])major_filter Majorに対するフィルター設定 <2Byte配列>
// @param [in](uint8[])major_mask Majorに対する設定 <2Byte配列で対象箇所をbit指定>
// @param [in](uint8[])minor_filter Minorに対するフィルター設定 <2Byte配列>
// @param [in](uint8[])minor_mask Minorに対するマスク設定 <2Byte配列で対象箇所をbit指定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 本製品はAdvertiser's Dataが31Byte以下のデータにのみ対応している。(それを超える拡張フォーマットは非対応)
///
func BLE_FilterDataSetBeacon(int32 timeout, uint8 sync, int64 filter_id, uint8 uuid_filter[], uint8 uuid_mask[], uint8 major_filter[], uint8 major_mask[], uint8 minor_filter[], uint8 minor_mask[]) {
    
}

///
// @brief Long Rangeのビーコンの検出をするためのフィルター設定を行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](int64)filter_id Long Range向けのフィルター番号 <0～1>
// @param [in](uint8[])filter 受信データに対するフィルター設定 <256Byte配列でbit毎に指定、244Byteまで利用可能、利用しない範囲は0を代入する>
// @param [in](uint8[])mask 受信データに対するマスク設定 <256Byte配列でフィルター対象とする箇所をbit毎に指定、244Byteまで利用可能、利用しない範囲は0を代入する>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 本Long Range向けのフィルターは、ビーコンやiBeacon向けのようなAD Structure構造の解析処理はなく、
//       Advertiser's dataの1Byte目から最大244Byte目までをフィルタリングする機能となる。
///
func BLE_FilterDataSetLongRange(int32 timeout, uint8 sync, int64 filter_id, uint8 filter[], uint8 mask[]) {
    
}

///
// @brief ビーコンの受信を開始するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](int64)filter_id フィルター番号 <0～49>
// @param [in](uint8)event_id ビーコンの受信をした場合に発行されるイベントID <1～254>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 「ビーコンの受信」「ビーコンの送信」「Long Rangeの受信」「Long Rangeの送信」の機能は
//       同時に利用不可。必ず他の機能を停止した状態で利用開始すること。
//       「ビーコンの受信」または「Long Rangeの受信」のいずれかに限られるが、受信設定は同時に50種類まで実行できる。
//       複数タスクからの受信設定利用も可能。
//       Fixedバッファからは、実際の受信データに加え、受信時のRSSI(1Byte)が付与されたデータが取得できます。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(int32)fixed_buff_index  受信データを格納したFixedバッファのindex
//    ・rcplib_TASK_GetArg(1)
//    　(uint8)fixed_buff_id 受信データを格納したFixedバッファID
///
func BLE_StartPolling(int32 timeout, uint8 sync, int64 filter_id, uint8 event_id) {
    
}

///
// @brief Long Rangeのビーコンの受信を開始するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](int64)filter_id Long Range向けのフィルター番号 <0～1>
// @param [in](uint8)event_id Long Rangeのビーコンを受信したときに発行されるイベントID <1～254>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 「ビーコンの受信」「ビーコンの送信」「Long Rangeの受信」「Long Rangeの送信」の機能は
//       同時に利用不可。必ず他の機能を停止した状態で利用開始すること。
//       「ビーコンの受信」または「Long Rangeの受信」のいずれかに限られるが、受信設定は同時に50種類まで実行できる。
//       複数タスクからの受信設定利用も可能。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(int32)fixed_buff_index  受信データを格納したFixedバッファのindex
//    ・rcplib_TASK_GetArg(1)
//    　(uint8)fixed_buff_id 受信データを格納したFixedバッファID
///
func BLE_StartPollingLongRange(int32 timeout, uint8 sync, int64 filter_id, uint8 event_id) {
    
}

///
// @brief ビーコンの受信を1回行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](int64)filter_id フィルター番号 <0～49>
// @param [in](uint8)event_id ビーコンを受信した場合に発行されるイベントID <1～254>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 「ビーコンの受信」「ビーコンの送信」「Long Rangeの受信」「Long Rangeの送信」の機能は
//       同時に利用不可。必ず他の機能を停止した状態で利用開始すること。
//       「ビーコンの受信」または「Long Rangeの受信」のいずれかに限られるが、受信設定は同時に50種類まで実行できる。
//       複数タスクからの受信設定利用も可能。
//       本API実行後、有効な「データ受信時のイベント」をコール元に通知した後、自動的にその受信要求は解除される。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(int32)fixed_buff_index  受信データを格納したFixedバッファのindex
//    ・rcplib_TASK_GetArg(1)
//    　(uint8)fixed_buff_id 受信データを格納したFixedバッファID
///
func BLE_StartOneShot(int32 timeout, uint8 sync, int64 filter_id, uint8 event_id) {
    
}

///
// @brief Long Rangeのビーコンの受信を1回行うAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](int64)filter_id Long Range向けのフィルター番号 <0～1>
// @param [in](uint8)event_id Long Rangeのビーコンを受信した場合に発行されるイベントID <1～254>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 「ビーコンの受信」「ビーコンの送信」「Long Rangeの受信」「Long Rangeの送信」の機能は
//       同時に利用不可。必ず他の機能を停止した状態で利用開始すること。
//       「ビーコンの受信」または「Long Rangeの受信」のいずれかに限られるが、受信設定は同時に50種類まで実行できる。
//       複数タスクからの受信設定利用も可能。
//       本API実行後、有効な「データ受信時のイベント」をコール元に通知した後、自動的にその受信要求は解除される。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(int32)fixed_buff_index  受信データを格納したFixedバッファのindex
//    ・rcplib_TASK_GetArg(1)
//    　(uint8)fixed_buff_id 受信データを格納したFixedバッファID
///
func BLE_StartOneShotLongRange(int32 timeout, uint8 sync, int64 filter_id, uint8 event_id) {
    
}

///
// @brief ビーコンの送信を開始するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](uint8)send_data[] 送信対象とするuint8配列のデータ <最大31Byte、Long Range送信時は最大244Byte>
// @param [in](uint32)size 送信対象とする配列のデータサイズ <最大31、Long Range送信時は最大244Byte>
// @param [in](uint8)long_range ビーコン送信かLong Range送信の設定 <0:ビーコン送信, 1:Long Range送信>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 「ビーコンの受信」「ビーコンの送信」「Long Rangeの受信」「Long Rangeの送信」の機能は
//       同時に利用不可。必ず他の機能を停止した状態で利用開始すること。
///
func BLE_StartPDUSending(int32 timeout, uint8 sync, uint8 send_data[], uint32 size, uint8 long_range) {
    
}

///
// @brief ビーコンの送受信要求を解除するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @param [in](uint8)event_id 処理完了後に発行されるイベントID <1～254>　※ビーコンの送信を停止する場合はこの入力値は不要
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "eventLib.h"
// @note 受信機能利用時に本要求解除APIを実行する際は、受信開始時に設定したタスクと同じタスクから設定したevent_id毎に正しくAPI実行すること。
//       同じevent_idを複数のFilterIDで設定した場合は、設定した回数分本APIを実行すること。
//       送信機能利用時に本要求解除APIを実行する際は、event_id設定は不問。API実行に伴い送信停止、Bluetooth Low EnergyモジュールはOFFされる。
///
func BLE_ScanStop(int32 timeout, uint8 sync, uint8 event_id) {
    
}

///
// @brief Bluetooth Low Energyモジュールのファームウェアバージョン情報を取得するAPI
// @param [in](int32)timeout API実行時のタイムアウト値 [msec]
// @param [in](uint8)sync API実行方法 <EAPI_SYNC_RESULT固定>
// @return -1:失敗, 成功時はuint32のバージョン情報をreturnする
// @detail 必要なヘッダinclude : "eventLib.h"
///
func BLE_GetRevision(int32 timeout, uint8 sync) {
    
}

//// ■システム
///
// @brief 工程コマンド要求を行うAPI ※基本的には利用禁止
// @param [in](uint8)message_id ID情報
// @param [in](uint32)cmd コマンド情報
// @return なし
// @detail 必要なヘッダinclude : "kcSystemAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func KCS_RequestInspection(uint8 message_id, uint32 cmd) {
    
}

///
// @brief 最新の温度情報通知を要求するAPI ※基本的には利用禁止
// @return なし
// @detail 必要なヘッダinclude : "kcSystemAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func KCS_RequestTemp() {
    
}

///
// @brief システムタスクに重要情報を通知するAPI ※基本的には利用禁止
// @param [in](uint8)cmd 通知情報
// @return なし
// @detail 必要なヘッダinclude : "kcSystemAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func KCS_NotifyInspection(uint8 cmd) {
    
}

///
// @brief 端末の電源をOFFにする要求を行うAPI
// @return なし
// @detail 必要なヘッダinclude : "kcSystemAPI.h"
// @note 端末の電源OFFの要求を行い、要求受付時は端末のボタンを4秒以上長押しした時同様の処理が実行される。
//       端末のボタン操作による仕様と同様、USB type-Cを接続中の実行では電源OFFされない。
//       本APIは「端末の電源OFFの要求」を行った時点で実行完了となるため、同タスク内の後続の処理は実行される。
//       本API実行後、全てのタスクからの準備完了通知が得られ次第、端末の電源はOFFされる。
//       全てのタスクからの準備完了通知が得られない場合でも、60秒の経過をもってOFFされる。
//       電源OFFの後は、ボタン押下、またはUSB(type-C)接続、または電源入れ直し
//       のいずれかを行わないと電源ONに遷移しない。
///
func KCS_Shutdown() {
    
}

///
// @brief システムタスクに電源OFFに対する準備完了を通知するAPI
// @return なし
// @detail 必要なヘッダinclude : "kcSystemAPI.h"
// @note ボタン4秒以上押し、またはKCS_Shutdown()API実行による端末電源OFF処理の前に
//       実行すべき処理がある場合は、イベントIDが60000(EAPI_EVENT_TASK_ENTER_FORCESTOP)の処理にて
//       本API実行前に行うこと。
//       その場合でも、本APIを実行せずとも、60秒経過時には強制的に端末の電源がOFFされるため要注意。
//       また、電源ケーブル断による電源OFFの際は、即座に端末の電源がOFFされるため要注意。
///
func KCS_NotifyReadyShutdown() {
    
}

///
// @brief 端末のファームウェアのOver The Airのタイムアウトを通知するAPI ※基本的には利用禁止
// @param [in](uint8)message_id メッセージデータ
// @return なし
// @detail 必要なヘッダinclude : "kcSystemAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func KCS_NotifyFotaTimeout(uint8 message_id) {
    
}

///
// @brief 端末のファームウェアのOver The Airのアラームイベントを通知するAPI ※基本的には利用禁止
// @return なし
// @detail 必要なヘッダinclude : "kcSystemAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func KCS_NotifyFotaAlarm() {
    
}

///
// @brief レシピのOver The Air機能を開始するAPI ※基本的には利用禁止
// @return なし
// @detail 必要なヘッダinclude : "kcSystemAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func KCS_NotifyRcpOtaStart() {

}

///
// @brief レシピのOver The Airのタイムアウトを通知するAPI ※基本的には利用禁止
// @param [in](uint8)message_id メッセージデータ
// @return なし
// @detail 必要なヘッダinclude : "kcSystemAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func KCS_NotifyRcpOtaTimeout(uint8 message_id) {
    
}

///// ■ドライバタスク■
//// ■ディスプレイドライバ
///
// @brief ディスプレイの電源を制御するAPI ※直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
// @param [in](uint8)power 電源制御設定 <OLED_POWER_OFF:電源OFF, OLED_POWER_ON:電源ON>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "oledAPI.h"
// @attention [NOT_FOR_USERS]直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
///
func OLED_Power(uint8 power) {
    
}

///
// @brief ディスプレイに「動作の状況」を確認する画面を表示するAPI ※直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
// @param [in](uint8)sync API実行方法
// @param [in](int32)timeout API実行時のタイムアウト値
// @param [in](uint8)pict 電波レベル
// @param [in](uint8)battery 電池
// @param [in](uint8)gnss GNSS
// @param [in](uint8)ble Bluetooth Low Energy
// @param [in](uint8)uvc カメラ
// @param [in](uint8)sio シリアル
// @param [in](uint64)utc 時刻
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "oledAPI.h"
// @attention [NOT_FOR_USERS]直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
///
func OLED_DisplayState(uint8 sync, int32 timeout, uint8 pict, uint8 battery, uint8 gnss, uint8 ble, uint8 uvc, uint8 sio, uint64 utc) {
    
}

///
// @brief ディスプレイに「設定の状況」を確認する画面を表示するAPI ※直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
// @param [in](uint8)sync API実行方法
// @param [in](int32)timeout API実行時のタイムアウト値
// @param [in](uint8)gnss GNSS
// @param [in](uint8)ble_recv Bluetooth Low Energy受信
// @param [in](uint8)uvc カメラ
// @param [in](uint8)sio_recv シリアル受信
// @param [in](uint8)sio_send シリアル送信
// @param [in](uint8)ble_send Bluetooth Low Energy送信
// @param [in](uint8)vib 振動検出
// @param [in](uint8)lte_send LTEデータ送信
// @param [in](str)error_code エラーコード
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "oledAPI.h"
// @attention [NOT_FOR_USERS]直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
///
func OLED_DisplaySet(uint8 sync, int32 timeout, uint8 gnss, uint8 ble_recv, uint8 uvc, uint8 sio_recv, uint8 sio_send, uint8 ble_send, uint8 vib, uint8 lte_send, str error_code) {
    
}

///
// @brief ディスプレイに文字を表示するAPI ※直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
// @param [in](uint8)line 表示行(上下方向)設定 <0～18[pixel]>
// @param [in](uint8)offset 表示列(左右方向)設定 <0～15[文字]>
// @param [in](str)data 表示する文字データ
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "oledAPI.h"
// @attention [NOT_FOR_USERS]直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
///
func OLED_DisplayChar(uint8 line, uint8 offset, str data) {
    
}

///
// @brief ディスプレイに任意のピクセルを表示するAPI ※直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
// @param [in](uint8)line 表示行(上下方向)設定 <0～35[pixel]>
// @param [in](uint8)offset 表示列(左右方向)設定 <0～15[*8pixel]>
// @param [in](uint32)pixel_data0 表示するpixelデータ0
// @param [in](uint32)pixel_data1 表示するpixelデータ1
// @param [in](uint32)pixel_data2 表示するpixelデータ2
// @param [in](uint32)pixel_data3 表示するpixelデータ3
// @param [in](uint8)size 表示するデータサイズ <1～16で指定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "oledAPI.h"
// @attention [NOT_FOR_USERS]直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
///
func OLED_DisplayFree(uint8 line, uint8 offset, uint32 pixel_data0, uint32 pixel_data1, uint32 pixel_data2, uint32 pixel_data3, uint8 size) {
    
}

///
// @brief ディスプレイに任意の固定画面を表示するAPI ※直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
// @param [in](uint8)panel_id 表示する画面ID
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "oledAPI.h"
// @attention [NOT_FOR_USERS]直接利用禁止(ディスプレイ制御サブアプリAPIを利用すること)
///
func OLED_DisplayWhiteBlack(uint8 panel_id) {
    
}

///
// @brief 「動作の状況」を確認する画面の時刻表示を切り替えるためのAPI
// @param [in](uint8)ampm_flg 時刻の表示設定 <0:24h表示, 1:AM/PM表示>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "oledAPI.h"
// @note 本APIは必ずアプリケーションタスクの初期化処理event_init()内でのみ実行すること。
///
func OLED_DisplayTimeNotationChange(uint8 ampm_flg) {
    
}

//// ■ユーザーインターフェイスの制御ドライバ
///
// @brief ボタン押下時のイベント登録をするAPI
// @param [in](uint32)sense_min ボタン押下時間の最小値 [msec]
// @param [in](uint32)sense_max ボタン押下時間の最大値 [msec]
// @param [in](uint8)event_id ボタン押下時のイベントID <1～254>
// @return なし
// @detail 必要なヘッダinclude : "uicAPI.h"
// @note
//    4秒以上の長押しで端末自体の電源OFF処理が実行されるため、押下時間の設定はそれ未満とすること。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・取得値なし
///
func UIC_SenseButton(uint32 sense_min, uint32 sense_max, uint8 event_id) {
    
}

///
// @brief ボタン短押し(0.1～1秒押し)時のイベント登録をするAPI(ラッパー関数)
// @param [in](uint8)event_id ボタン押下時のイベントID <1～254>
// @return なし
// @detail 必要なヘッダinclude : "uicAPI.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はUIC_SenseButton(100, 1000, event_id)。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・取得値なし
///
func UIC_SenseButtonS(uint8 event_id) {
    
}

///
// @brief ボタン長押し(1～4秒押し)時のイベント登録をするAPI(ラッパー関数)
// @param [in](uint8)event_id ボタン押下時のイベントID <1～254>
// @return なし
// @detail 必要なヘッダinclude : "uicAPI.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はUIC_SenseButton(1000, 4000, event_id)。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・取得値なし
///
func UIC_SenseButtonM(uint8 event_id) {
    
}

///
// @brief LEDを制御するためのAPI(制御終了時のイベント通知なし) ※基本的には利用禁止
// @param [in](uint8)priority 要求の優先度設定、詳細は"olcAPI.h"の#define UIC_LED_PRI_XXX参照
// @param [in](uint32)led_color ON/OFFや要求する色の設定、詳細は"olcAPI.h"の#define UIC_LED_COLOR_参照
// @return なし
// @detail 必要なヘッダinclude : "uicAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func UIC_SetLED(uint8 priority, uint32 led_color) {
    
}

///
// @brief LEDを制御するためのAPI(制御終了時のイベント通知あり) ※直接利用禁止(LED制御サブアプリAPIを利用すること)
// @param [in](uint8)priority 要求の優先度設定、詳細は"olcAPI.h"の#define UIC_LED_PRI_XXX参照
// @param [in](uint8)led_color ON/OFFや要求する色の設定、詳細は"olcAPI.h"の#define UIC_LED_COLOR_参照
// @param [in](uint8)task_id 要求元のタスクID <rcplib_SV_Read(ENGINE_SVITEM_ID_TASKEVENTITEM_SENDER_ID)の利用を推奨>
// @return なし
// @detail 必要なヘッダinclude : "uicAPI.h"
// @attention [NOT_FOR_USERS]直接利用禁止(LED制御サブアプリAPIを利用すること)
///
func UIC_SetLEDwithID(uint8 priority, uint8 led_color, uint8 task_id) {
    
}

//// ■USBカメラドライバ
///
// @brief USBカメラを制御するためのAPI
// @param [in](uint8)start USBカメラの撮影開始/停止設定 <0:停止, 1:開始>
// @param [in](uint8)format USBカメラの画像形式設定 <UVC_STREAM_CODEC_MJPEG固定>
// @param [in](uint16)h_size 水平方向の解像度設定 <利用するUSBカメラスペックに合わせて利用>
// @param [in](uint16)v_size 垂直方向の解像度設定 <利用するUSBカメラスペックに合わせて利用>
// @param [in](uint16)fps USBカメラのfps設定 <[0.1fps]単位で利用可(例えば30.0fpsの場合は300、7.5fpsの場合は75を設定する)>
// @return 0:成功, 0以外:失敗
// @detail 必要なヘッダinclude : "uvcAPI.h"
// @note 解像度やfps設定を変更する際は、一度撮影停止してから行うこと。
//       撮影を開始していないタスクからの撮影中の本API実行はエラーとなる。
//       撮影開始設定後、最初の画像が得られるまでは5～10秒かかる。
///
func UVC_VideoStreamCtrl(uint8 start, uint8 format, uint16 h_size, uint16 v_size, uint16 fps) {
    
}

///
// @brief USBカメラの撮影画像をカメラバッファに記録する周期を設定するAPI
// @param [in](uint32)smp_rate カメラバッファに記録する周期設定 <0=fpsに従う、または1～60000[msec]>
// @return 0:成功, 0以外:失敗
// @detail 必要なヘッダinclude : "uvcAPI.h"
// @note 本APIは、撮影を開始したタスクからであればUSBカメラ撮影中でも実行可能。
//       撮影を開始していないタスクからの撮影中の本API実行はエラーとなる。
///
func UVC_BufCtrlSmpRate(uint32 smp_rate) {
    
}

///
// @brief USB制御ステータス変化通知のリスナー登録をするAPI
// @param [in](uint8)event_id ステータス変化通知のイベントID <1～254>
// @param [in](uint8)mode_sw リスナーの登録設定 <0:登録解除, 1:登録設定>
// @return UVC_RESULT_OK:成功, UVC_RESULT_ERROR:失敗
// @detail 必要なヘッダinclude : "uvcAPI.h"
// @note
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(uint8)result 通知する付加情報 ※"uvcAPI.h"の「ステータスリスナーCB返答値」参照
///
func UVC_RegistUsbVideoStatusListener(uint8 event_id, uint8 mode_sw) {
    
}

//// ■センサドライバ
///
// @brief 指定した秒数経過後に内蔵センサ(加速度センサおよびジャイロセンサ)の電源をOFFする。（センサを使用していない場合）
// @param [in](uint32)delay_time 秒数を指定[msec]
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @note
//    複数タスクから実行した場合は最後に設定したdelay_timeが採用される。
///
func SNS_SetDelayOffTime(uint32 delay_time) {
    
}

///
// @brief 加速度センサのパフォーマンスモードを変更する
// @param [in](int8)performance Highパフォーマンス（ACC_HIGH_PERF）、Lowパフォーマンス（ACC_LOW_PERF）
// @param [in](int8)odr 加速度センサの動作周波数の設定。設定値については、sensorAPI.hの"ODR周波数"を参照
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @note
//    加速度センサのAPIは複数のタスクから別々の要求が可能。
//    複数タスクから動作要求をした場合、以下優先順位に従って動作する
//    ・パフォーマンスモード(performance)：Highパフォーマンス設定を優先
//    ・動作周波数(odr)：高い周波数設定を優先
// 
//    // ODR周波数
//    #define ACC_ODR1_002Hz 1
//    #define ACC_ODR2_013Hz 2
//    #define ACC_ODR3_026Hz 3
//    #define ACC_ODR4_052Hz 4
//    #define ACC_ODR5_104Hz 5
//    #define ACC_ODR6_208Hz 6
//    // 加速度測定モード
//    #define ACC_LOW_PERF 0
//    #define ACC_HIGH_PERF 1
// @code
//    // ソース冒頭でヘッダをinclude
//    #include "sensorAPI.h"
//    // Lowパフォーマンスかつ2Hzで動作させたい場合
//    ACC_SetDeviceMeasure(ACC_LOW_PERF, ACC_ODR1_002Hz);
//    // Highパフォーマンスかつ208Hzで動作させたい場合
//    ACC_SetDeviceMeasure(ACC_HIGH_PERF, ACC_ODR6_208Hz);
///
func ACC_SetDeviceMeasure(int8 performance, int8 odr) {
    
}

///
// @brief 加速度センサのダイナミックレンジを変更するAPI
// @param [in](uint8)range ダイナミックレンジの種類。詳細はsensorAPI.hの加速度測定レンジを参照
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @note
// 内蔵センサ(加速度センサおよびジャイロセンサ)の電源がONになっている間は変更不可、内蔵センサの電源がOFFになっている間は変更可。
// 複数タスクから実行した場合は最後に設定したダイナミックレンジが採用される。
// 
// // 加速度センサ測定レンジ
// ACC_DRANGE_2  = 1  ： ±2[G]
// ACC_DRANGE_4  = 2  ： ±4[G]
// ACC_DRANGE_8  = 4  ： ±8[G]
// ACC_DRANGE_16 = 8  ： ±16[G]
// @code
//    // ソース冒頭でヘッダをinclude
//    #include "sensorAPI.h"
//    // 加速度センサで取得するデータのレンジを±2gに設定する場合
//    ACC_SetDeviceRange(ACC_DRANGE_2);
///
func ACC_SetDeviceRange(uint8 range) {
    
}

///
// @brief 加速度センサからデータを取得する
// @param [in](uint8)sync API実行方法 <同期実行の場合はEAPI_SYNC_RESULT、非同期実行の場合は1～254の任意のイベントID>
// @param [in](int32)timeout タイムアウト値[msec]
// @param [in](int32)interval インターバル秒数[msec]。何秒後にデータを取得するかを指定
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @note
//    加速度センサのAPIは複数のタスクから別々の要求が可能。
//    複数タスクから動作要求をした場合、以下優先順位に従って動作する。
//    ・パフォーマンスモード(performance)：Highパフォーマンス設定を優先
//    ・動作周波数(odr)：高い周波数設定を優先
//    ・ポーリング間隔(interval)：短い周期設定を優先
// 
//    ＜コールバックイベントでの(または同期実行後の)取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(int32)acc_x 加速度センサX軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(1)
//    　(int32)acc_y 加速度センサY軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(2)
//    　(int32)acc_z 加速度センサZ軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(3)
//    　(float)acc_x_f 加速度センサX軸のRead値[mG](-16000.0～+16000.0)
//    ・rcplib_TASK_GetArg(4)
//    　(float)acc_y_f 加速度センサY軸のRead値[mG](-16000.0～+16000.0)
//    ・rcplib_TASK_GetArg(5)
//    　(float)acc_z_f 加速度センサZ軸のRead値[mG](-16000.0～+16000.0)
// 
// @code
//    // ソース冒頭でヘッダをinclude
//    #include "sensorAPI.h"
//    --------
//    // SYNC_CALLを指定した場合
//    ACC_GetDataOneShot(SYNC_CALL, timeout_v, interval_v);
//    acc_x = rcplib_TASK_GetArg(0);
//    acc_y = rcplib_TASK_GetArg(1);
//    acc_z = rcplib_TASK_GetArg(2);
//    acc_f_x = rcplib_TASK_GetArg(3);
//    acc_f_y = rcplib_TASK_GetArg(4);
//    acc_f_z = rcplib_TASK_GetArg(5);
// 
//    str mess[100];
//    str tmp[40];
//    rcplib_FORMAT_String(mess, "notification_acc_oneshot() x:%.3f", acc_f_x);
//    rcplib_FORMAT_String(tmp, " y:%.3f", acc_f_y);
//    rcplib_STR_Cat(mess, tmp);
//    rcplib_FORMAT_String(tmp, " z:%.3f", acc_f_z);
//    rcplib_STR_Cat(mess, tmp);
//    rcplib_LOG_Print(mess);
//    --------
//    // EVENT_IDを指定し、timeoutを2秒、intervalを1秒に設定した場合
//    uint16 timeout = 2000;
//    uint16 interval = 1000;
//    ACC_GetDataOneShot(UNSYNC_EVENT_ACC_ONESHOT, timeout, interval);
// 
//    // EVENT_IDを登録
//    if(event_id == UNSYNC_EVENT_ACC_ONESHOT) {
//        notification_acc_oneshot(rcplib_TASK_GetArg(0), rcplib_TASK_GetArg(1),
//        rcplib_TASK_GetArg(2), rcplib_TASK_GetArg(3),
//        rcplib_TASK_GetArg(4), rcplib_TASK_GetArg(5));
//    }
// 
//    // 値を取得する関数
//    func notification_acc_oneshot(int16 acc_x, int16 acc_y, int16 acc_z,
//                             float acc_f_x, float acc_f_y, float acc_f_z) {
//        str mess[100];
//        str tmp[40];
//        int16 val;val=acc_x;val=acc_y;val=acc_z;
//        rcplib_FORMAT_String(mess, "ACC MAIN Oneshot x:%5.4f", acc_f_x);
//        rcplib_FORMAT_String(tmp, " y:%5.4f", acc_f_y);
//        rcplib_STR_Cat(mess, tmp);
//        rcplib_FORMAT_String(tmp, " z:%5.4f", acc_f_z);
//        rcplib_STR_Cat(mess, tmp);
//        rcplib_LOG_Print(mess);
//        return(0);
//    }
///
func ACC_GetDataOneShot(uint8 sync, int32 timeout, int32 interval) {
    
}

///
// @brief 加速度センサのポーリングを実施するAPI
// @param [in](int32)interval ポーリング間隔[msec] <0:ポーリング停止, 1[msec]以上:ポーリング要求>
// @param [in](uint8)notify_event_id 通知するイベントID <1～254>
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention
//    高速ポーリングを実行した場合はCPU処理負荷を著しく上げるため、
//    ポーリングのコールバックイベントでは極力少ない処理となるよう注意すること。
//    参考までに、加速度センサのポーリンングのみでCPU処理負荷が60%相当となる条件は以下の通り。
//    この設定より遅い周期で利用することを推奨する。
//    ・CPU High performance mode(473.6MHz駆動)では10[msec]
//    ・CPU通常時(96MHz駆動)では45[msec]
// @note
//    加速度センサのAPIは複数のタスクから別々の要求が可能。
//    複数タスクから動作要求をした場合、以下優先順位に従って動作する
//    ・パフォーマンスモード(performance)：Highパフォーマンス設定を優先
//    ・動作周波数(odr)：高い周波数設定を優先
//    ・ポーリング間隔(interval)：短い周期設定を優先
// 
//    ＜コールバックイベントでの(または同期実行後の)取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(int32)acc_x 加速度センサX軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(1)
//    　(int32)acc_y 加速度センサY軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(2)
//    　(int32)acc_z 加速度センサZ軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(3)
//    　(float)acc_x_f 加速度センサX軸のRead値[mG](-16000.0～+16000.0)
//    ・rcplib_TASK_GetArg(4)
//    　(float)acc_y_f 加速度センサY軸のRead値[mG](-16000.0～+16000.0)
//    ・rcplib_TASK_GetArg(5)
//    　(float)acc_z_f 加速度センサZ軸のRead値[mG](-16000.0～+16000.0)
// @code
// // ソース冒頭でヘッダをinclude
// #include "sensorAPI.h"
// // 1000ms間隔で加速度センサのポーリングを実施
// int32 interval; interval = 1000;
// ACC_StartPolling(interval, UNSYNC_EVENT_ACC_POLL);
// 
// // イベントIDの登録
// if(event_id == UNSYNC_EVENT_ACC_POLL) {
// notification_poll(rcplib_TASK_GetArg(0), rcplib_TASK_GetArg(1),
//                   rcplib_TASK_GetArg(2), rcplib_TASK_GetArg(3),
//                   rcplib_TASK_GetArg(4), rcplib_TASK_GetArg(5));
// }
// 
// // ポーリング関数
// func notification_poll(int16 acc_x, int16 acc_y, int16 acc_z,
//                        float acc_f_x, float acc_f_y, float acc_f_z) {
//     str mess[100];
//     str tmp[40];
//     rcplib_FORMAT_String(mess, "ACC MAIN ポーリング中 x: %d", acc_x);
//     rcplib_FORMAT_String(tmp, " y: %d", acc_y);
//     rcplib_STR_Cat(mess, tmp);
//     rcplib_FORMAT_String(tmp, " z: %d", acc_z);
//     rcplib_STR_Cat(mess, tmp);
//     rcplib_LOG_Print(mess);
//     rcplib_FORMAT_String(mess, "ACC MAIN ポーリング中 x: %5.4f", acc_f_x);
//     rcplib_FORMAT_String(tmp, " y: %5.4f", acc_f_y);
//     rcplib_STR_Cat(mess, tmp);
//     rcplib_FORMAT_String(tmp, " z: %5.4f", acc_f_z);
//     rcplib_STR_Cat(mess, tmp);
//     rcplib_LOG_Print(mess);
//     return(0);
// }
func ACC_StartPolling(int32 interval, uint8 notify_event_id) {
    
}

///
// @brief 振動検出の有効化無効化を設定
// @param [in](int8)sw 有効(ACC_VIB_ENABLE)、無効(ACC_VIB_DISABLE) 
// @param [in](uint8)notify_event_id 通知するイベントID <1～254>
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @note
//    加速度センサのAPIは複数のタスクから別々の要求が可能。
//    事前に加速度センサのODR(動作周波数)の設定変更APIであるACC_SetDeviceMeasure()の実行により
//    振動検出に関連する動作周期が変更できる。
//    複数タスクから動作要求をした場合、以下優先順位に従って動作する
//    ・パフォーマンスモード(performance)：Highパフォーマンス設定を優先
//    ・動作周波数(odr)：高い周波数設定を優先
//    ・ポーリング間隔(interval)：短い周期設定を優先
// 
//    初期設定の場合、加速度センサのダイナミックレンジは±8[G]、検出閾値は1LSbの設定なので
//    振動検出閾値は±0.03125[G]である。
// 
//    ダイナミックレンジ変更のAPIであるACC_SetDeviceRange()を実行することで
//    初期設定±8[G]から任意のダイナミックレンジに変更できる。
// 
//    sdev_sensor.krsの以下defineを変更することにより振動検出の検出閾値を変更できる。
//    #define ACC_WAKE_UP_THS  0x01 // 1LSb は ±ACC_DRANGE_X / 256 [G] に相当  ex) ACC_DRANGE_8 = ±8[G] -> ±0.03125[G]/LSb
//  
//    指定回数の振動検出時にイベント通知する振動検出機能を利用する場合は、
//    VIB_SetSenseMode()を利用すること。
// 
//    振動検出有効/無効
//    ACC_VIB_ENABLE=1
//    ACC_VIB_DISABLE=0
// 
//    ＜コールバックイベントでの(または同期実行後の)取得値の定義＞
//    ・取得値なし
///
func ACC_SetVibrationMode(int8 sw, uint8 notify_event_id) {
    
}

///
// @brief ジャイロセンサのパフォーマンスモードを変更する
// @param [in](int8)performance Highパフォーマンス(GYR_HIGH_PERF)、Lowパフォーマンス(GYR_LOW_PERF)
// @param [in](int8)odr ジャイロセンサの動作周波数の設定。設定値については、sensorAPI.hの"ODR周波数"を参照
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @note
//    ジャイロセンサのAPIは複数のタスクから別々の要求が可能。
//    複数タスクから動作要求をした場合、以下優先順位に従って動作する
//    ・パフォーマンスモード(performance)：Highパフォーマンス設定を優先
//    ・動作周波数(odr)：高い周波数設定を優先
// 
//    // ODR周波数
//    #define GYRO_ODR1_013Hz 7
//    #define GYRO_ODR2_026Hz 8
//    #define GYRO_ODR3_052Hz 9
//    #define GYRO_ODR4_104Hz 10
//    #define GYRO_ODR5_208Hz 11
//    // ジャイロ測定モード
//    #define GYR_LOW_PERF 4
//    #define GYR_HIGH_PERF 8
// @code
//    // ソース冒頭でヘッダをinclude
//    #include "sensorAPI.h"
//    // Lowパフォーマンスかつ13Hzで動作させたい場合
//    GYR_SetDeviceMeasure(GYR_LOW_PERF, GYRO_ODR1_013Hz);
//    // Highパフォーマンスかつ208Hzで動作させたい場合
//    GYR_SetDeviceMeasure(GYR_HIGH_PERF, GYRO_ODR5_208Hz);
///
func GYR_SetDeviceMeasure(int8 performance, int8 odr) {
    
}

///
// @brief ジャイロセンサのダイナミックレンジを変更するAPI
// @param [in](uint8)range ダイナミックレンジの種類、詳細はsensorAPI.hのジャイロ測定レンジを参照
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @note
// 内蔵センサ(加速度センサおよびジャイロセンサ)の電源がONになっている間は変更不可、内蔵センサの電源がOFFになっている間は変更可。
// 複数タスクから実行した場合は最後に設定したダイナミックレンジが採用される。
// 
// // ジャイロセンサ測定レンジ
// GYR_DRANGE_250  = 1  :  ±250[dps]
// GYR_DRANGE_500  = 2  :  ±500[dps]
// GYR_DRANGE_1000 = 4  : ±1000[dps]
// GYR_DRANGE_2000 = 8  : ±2000[dps]
// @code
//    // ソース冒頭でヘッダをinclude
//    #include "sensorAPI.h"
//    // ジャイロセンサで取得するデータのレンジを±250dpsに設定する場合
//    GYR_SetDeviceRange(GYR_DRANGE_250);
///
func GYR_SetDeviceRange(uint8 range) {
    
}

///
// @brief ジャイロセンサからデータを取得する
// @param [in](uint8)sync API実行方法 <同期実行の場合はEAPI_SYNC_RESULT、非同期実行の場合は1～254の任意のイベントID>
// @param [in](int32)timeout タイムアウト値[msec]
// @param [in](int32)interval インターバル秒数[msec]。何秒後にデータを取得するかを指定
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @note
//    ジャイロセンサのAPIは複数のタスクから別々の要求が可能。
//    複数タスクから動作要求をした場合、以下優先順位に従って動作する。
//    ・パフォーマンスモード(performance)：Highパフォーマンス設定を優先
//    ・動作周波数(odr)：高い周波数設定を優先
//    ・ポーリング間隔(interval)：短い周期設定を優先
// 
//    ＜コールバックイベントでの(または同期実行後の)取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(int32)gyro_x ジャイロセンサX軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(1)
//    　(int32)gyro_y ジャイロセンサY軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(2)
//    　(int32)gyro_z ジャイロセンサZ軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(3)
//    　(float)gyro_x_f ジャイロセンサX軸のRead値[dps](-2000.0～+2000.0)
//    ・rcplib_TASK_GetArg(4)
//    　(float)gyro_y_f ジャイロセンサY軸のRead値[dps](-2000.0～+2000.0)
//    ・rcplib_TASK_GetArg(5)
//    　(float)gyro_z_f ジャイロセンサZ軸のRead値[dps](-2000.0～+2000.0)
// @code
//    // ソース冒頭でヘッダをinclude
//    #include "sensorAPI.h"
//    // EVENT_IDを指定し、timeoutを2秒、intervalを1秒に設定した場合
//    uint16 timeout = 2000;
//    int32 interval = 1000;
//    GYR_GetDataOneshot(UNSYNC_EVENT_GYR_ONESHOT, timeout, interval);
// 
//    // EVENT_IDを登録
//    if(event_id == UNSYNC_EVENT_GYR_ONESHOT) {
//    notification_gyr_oneshot(rcplib_TASK_GetArg(0), rcplib_TASK_GetArg(1),
//                             rcplib_TASK_GetArg(2), rcplib_TASK_GetArg(3),
//                             rcplib_TASK_GetArg(4), rcplib_TASK_GetArg(5));
//    }
// 
//    // 値を取得する関数
//    func notification_gyr_oneshot(int16 gyr_x, int16 gyr_y, int16 gyr_z,
//                                  float gyr_f_x, float gyr_f_y, float gyr_f_z) {
//        str mess[100];
//        str tmp[40];
//        int16 val;val=gyr_x;val=gyr_y;val=gyr_z;
//        rcplib_FORMAT_String(mess, "GYR MAIN Oneshot x:%.3f", gyr_f_x);
//        rcplib_FORMAT_String(tmp, " y:%.3f", gyr_f_y);
//        rcplib_STR_Cat(mess, tmp);
//        rcplib_FORMAT_String(tmp, " z:%.3f", gyr_f_z);
//        rcplib_STR_Cat(mess, tmp);
//        rcplib_LOG_Print(mess);
//        return(0);
//    }
///
func GYR_GetDataOneshot(uint8 sync, int32 timeout, int32 interval) {
    
}

///
// @brief ジャイロセンサのポーリングを実施するAPI
// @param [in](int32)interval インターバル秒数[msec] <0:ポーリング停止, 1[msec]以上:ポーリング要求>
// @param [in](uint8)notify_event_id 通知するイベントid <1～254>
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention
//    高速ポーリングを実行した場合はCPU処理負荷を著しく上げるため、
//    ポーリングのコールバックイベントでは極力少ない処理となるよう注意すること。
//    参考までに、ジャイロセンサのポーリンングのみでCPU処理負荷が60%相当となる条件は以下の通り。
//    この設定より遅い周期で利用することを推奨する。
//    ・CPU High performance mode(473.6MHz駆動)では10[msec]
//    ・CPU通常時(96MHz駆動)では45[msec]
// @note
//    ジャイロセンサのAPIは複数のタスクから別々の要求が可能。
//    複数タスクから動作要求をした場合、以下優先順位に従って動作する。
//    ・パフォーマンスモード(performance)：Highパフォーマンス設定を優先
//    ・動作周波数(odr)：高い周波数設定を優先
//    ・ポーリング間隔(interval)：短い周期設定を優先
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(int32)gyro_x ジャイロセンサX軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(1)
//    　(int32)gyro_y ジャイロセンサY軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(2)
//    　(int32)gyro_z ジャイロセンサZ軸のレジスタRead値(-32768～+32767)
//    ・rcplib_TASK_GetArg(3)
//    　(float)gyro_x_f ジャイロセンサX軸のRead値[dps](-2000.0～+2000.0)
//    ・rcplib_TASK_GetArg(4)
//    　(float)gyro_y_f ジャイロセンサY軸のRead値[dps](-2000.0～+2000.0)
//    ・rcplib_TASK_GetArg(5)
//    　(float)gyro_z_f ジャイロセンサZ軸のRead値[dps](-2000.0～+2000.0)
// @code
//    // ソース冒頭でヘッダをinclude
//    #include "sensorAPI.h"
//    // 1000ms間隔でジャイロセンサのポーリングを実施
//    int32 interval; interval = 1000;
//    GYR_StartPolling(interval, UNSYNC_EVENT_GYR_POLL);
// 
//    //  イベントIDの登録
//    if(event_id == UNSYNC_EVENT_GYR_POLL) {
//    notification_poll(rcplib_TASK_GetArg(0), rcplib_TASK_GetArg(1),
//                      rcplib_TASK_GetArg(2), rcplib_TASK_GetArg(3),
//                      rcplib_TASK_GetArg(4), rcplib_TASK_GetArg(5));
//    }
// 
//    // ポーリング関数
//    func notification_poll(int16 gyr_x, int16 gyr_y, int16 gyr_z,
//                           float gyr_f_x, float gyr_f_y, float gyr_f_z) {
//        str mess[100];
//        str tmp[40];
//        rcplib_FORMAT_String(mess, "GYRO MAIN ポーリング中 x: %d", gyr_x);
//        rcplib_FORMAT_String(tmp, " y: %d", gyr_y);
//        rcplib_STR_Cat(mess, tmp);
//        rcplib_FORMAT_String(tmp, " z: %d", gyr_z);
//        rcplib_STR_Cat(mess, tmp);
//        rcplib_LOG_Print(mess);
//        rcplib_FORMAT_String(mess, "GYRO MAIN ポーリング中 x: %5.4f", gyr_f_x);
//        rcplib_FORMAT_String(tmp, " y: %5.4f", gyr_f_y);
//        rcplib_STR_Cat(mess, tmp);
//        rcplib_FORMAT_String(tmp, " z: %5.4f", gyr_f_z);
//        rcplib_STR_Cat(mess, tmp);
//        rcplib_LOG_Print(mess);
//        return(0);
//    }
///
func GYR_StartPolling(int32 interval, uint8 notify_event_id) {
    
}

///
// @brief 加速度センサのIDチェック用のAPI ※基本的には利用禁止
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func ACC_GYR_IdCheckInspect() {
    
}

///
// @brief 加速度ジャイロセンサ電源ONチェック用のAPI  ※基本的には利用禁止
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func ACC_GYR_OnInspect() {
    
}

///
// @brief 加速度ジャイロセンサ電源OFFチェック用のAPI  ※基本的には利用禁止
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func ACC_GYR_OffInspect() {
    
}

///
// @brief 加速度センサデータ取得チェック用のAPI  ※基本的には利用禁止
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func ACC_GetDataInspect() {
    
}

///
// @brief 加速度センサ動作チェック用のAPI  ※基本的には利用禁止
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func ACC_SelfTestInspect() {
    
}

///
// @brief ジャイロセンサデータ取得チェック用のAPI  ※基本的には利用禁止
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func GYR_GetDataInspect() {
    
}

///
// @brief ジャイロセンサ動作チェック用のAPI  ※基本的には利用禁止
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func GYR_SelfTestInspect() {
    
}

///
// @brief 加速度センサINT信号チェック用のAPI  ※基本的には利用禁止
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func ACC_GetIntStatusInspect() {
    
}

///
// @brief 加速度ジャイロセンサ電源制御確認用のAPI  ※基本的には利用禁止
// @return 0:成功
// @detail 必要なヘッダinclude : "sensorAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func ACC_GYR_SetPowerInspect() {
    
}

//////////////////////////////////////////////////////////////////
// ＜サブアプリケーションAPIの定義＞ //
//////////////////////////////////////////////////////////////////

///// ■サブアプリタスク■
//// ■接点入出力サブアプリ
///
// @brief GPIポートの状態変化を検知した際に、指定したイベントに通知を出すAPI
// @param [in](uint8)mode 有効化/無効化の設定 <有効化:NOTIFY_GPI_ENABLE, 無効化:NOTIFY_GPI_DISABLE>
// @param [in](uint8)port どのポートの状態変化を監視するか <GPI1:NOTIFY_GPI1, GPI2:NOTIFY_GPI2, GPI3:NOTIFY_GPI3>
// @param [in](uint8)state GPIポートがどの状態からどの状態へ変化した際に検知するか <HIGH->LOW:NOTIFY_GPI_L, LOW->HIGH:NOTIFY_GPI_H>
// @param [in](uint8)notify_event_id GPIポートの状態変化を検知した際に通知するイベントID <1～254>
// @return 0:成功
// @detail 必要なヘッダinclude : "gpiAPI.h"
// @note 本APIを使用する事によりGPIポートの状態を監視し、GPIポートの状態が変化した際に通知を受け取る事が可能。
//       監視できるGPIポート番号は"gpiAPI.h"に記載しているGPI1,GPI2,GPI3のみ。
//       本APIを使用すると1000ミリ秒間隔でGPIポートの状態をチェックする。
//       通知は自動で停止しないため、停止させたい際は無効化する。
//       GPIポートの状態をチェックする間隔を変更する場合は、api_SetCheckGpiInterval()を利用する。
// @code
//  // GPI1の状態がLOWからHIGH,HIGHからLOWに変化した際に通知を受け取る。
//  // それぞれ3回通知を受け取ったら通知を停止する。
//  // ソース冒頭でヘッダをinclude
//  #include "gpiAPI.h"
// 
//  #define LOW 1
//  #define HIGH 2
//  #define UNSYNC_EVENT_GPI1_LOW 1
//  #define UNSYNC_EVENT_GPI1_HIGH 2
// 
//  uint8 l_gpi1_low_detect;
//  uint8 l_gpi1_high_detect;
//  void main_loop(){
// 
//  //...基本処理省略...//
// 
//      else if (event_id == UNSYNC_EVENT_GPI1_LOW) {
//          GPI1(LOW);
//      }
//      else if (event_id == UNSYNC_EVENT_GPI1_HIGH) {
//          GPI1(HIGH);
//      }
//  }
// 
//  func event_init() {
//      l_gpi1_low_detect = 0;
//      l_gpi1_high_detect = 0;
//      GPI_SetNotifyPort(NOTIFY_GPI_ENABLE, NOTIFY_GPI1, NOTIFY_GPI_L, UNSYNC_EVENT_GPI1_LOW);
//      GPI_SetNotifyPort(NOTIFY_GPI_ENABLE, NOTIFY_GPI1, NOTIFY_GPI_H, UNSYNC_EVENT_GPI1_HIGH);
//      return(0);
//  }
//  func GPI1(uint8 LowHigh) {
//      if (LowHigh == LOW) {
//          rcplib_LOG_Print("Low Detect");
//          l_gpi1_low_detect = l_gpi1_low_detect + 1;
//          if (l_gpi1_low_detect == 3) {
//              GPI_SetNotifyPort(NOTIFY_GPI_DISABLE, NOTIFY_GPI1, NOTIFY_GPI_L, UNSYNC_EVENT_GPI1_LOW);
//          }
//      } else if (LowHigh == HIGH) {
//          rcplib_LOG_Print("High Detect");
//          l_gpi1_high_detect = l_gpi1_high_detect + 1;
//          if (l_gpi1_high_detect == 3) {
//              GPI_SetNotifyPort(NOTIFY_GPI_DISABLE, NOTIFY_GPI1, NOTIFY_GPI_H, UNSYNC_EVENT_GPI1_HIGH);
//          }
//      }
//  }
// 
///
func GPI_SetNotifyPort(uint8 mode, uint8 port, uint8 state, uint8 notify_event_id) {

}

///
// @brief GPIポートの状態を監視するポーリング間隔を設定するAPI
// @param [in](uint32)interval GPIポートの状態を監視するポーリング間隔<1～4294967295[msec]>
// @return 0:成功
// @detail 必要なヘッダinclude : "gpiAPI.h"
// @note 本APIを使用する事によりGPIポートの状態を監視するポーリング間隔を標準の1000ミリ秒から変更できる。
//       GPIポートの監視は全て同じインターバルで実施されているため、本APIでポーリング間隔を変更した場合、全てのGPIポートの状態を監視するポーリング間隔が変更される。
//       個別にポーリング間隔を設定する事はできない。
//       ポーリング中にポーリング間隔を再設定した場合、設定したタイミングで再度ポーリングが開始される。
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "gpiAPI.h"
//  // GPIポートを監視するポーリング間隔を3000[msec]へ変更する
//  api_SetCheckGpiInterval(3000);
//
///
func GPI_SetCheckGpiInterval(uint32 interval) {

}

//// ■シリアル制御サブアプリ
///
// @brief シリアル機能の開始とデータ受信時のイベント番号を登録するAPI
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 2:SIO_DEVICE_CAN, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint8)sw 登録/登録解除の指定 <0:SIO_RELEASE(登録解除), 1:SIO_BIND(登録)>
// @param [in](uint8)event_id データを受信した時のイベントID <1～254>
// @return 0:成功
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note 本APIでデータ受信時のコールバックイベントIDの登録および登録解除を行う。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(uint8)fifo_buff_id 受信データを格納したFIFOバッファID
//    ・rcplib_TASK_GetArg(1)
//    　(uint16)recived_can_id 受信したCAN識別ID(device_idにSIO_DEVICE_CANを指定した時のみ)
///
func SIO_Regist(uint8 device_id, uint8 sw, uint8 event_id) {
    
}

///
// @brief シリアル UART通信設定をするAPI
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint32)baudrate ボーレート設定[baud]
// @param [in](uint8)parity パリティ設定 <0:SIO_UART_PARITY_NONE, 1:SIO_UART_PARITY_EVEN, 2:SIO_UART_PARITY_ODD>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note RS485およびRS232の通信パラメーターを設定するAPI。
//       引数で変更可能なボーレート設定/パリティ設定以外のパラメーターは、sapp_serial.krs内でデフォルトのパラメーターを設定している。
//       ボーレート設定に関して、RS485は最大3Mbaud、RS232は最大230.4kbaudまで設定可能。
//       ボーレート設定を110,300,600[baud]に設定する場合は、API内rcplib_UART_Initの引数ClockPrescalerをUART_PRESCALER_DIV8に変更すること。
//       
//       機能部の有効化を行うAPIであるSIO_Regist()で登録設定した後、必要でに応じて本APIを実行し設定値を行うこと。
//       その後、SIO_Regist()を登録設定実行すると設定値は初期化されるため、注意すること。
///
func SIO_SetUartMode(uint8 device_id, uint32 baudrate, uint8 parity) {
    
}

///
// @brief シリアルデータを受信するサイズを登録するAPI
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint16)size 受信データサイズ[Byte]
// @return 0:成功
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note 本APIで登録したサイズのデータを受信すると、SIO_Regist()で登録したイベント番号でコールバックイベントが発生する。
//       対象はRS-485通信およびRS-232通信となっており、CAN通信は対象外。
//       SIO_SetSeparateModeCode()実行後、本APIを実行した場合、改行文字指定は無効、本APIによる設定が上書きされる。
///
func SIO_SetSeparateModeSize(uint8 device_id, uint16 size) {
    
}

///
// @brief シリアルデータを受信した時の区切り文字を登録するAPI
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint8)code 区切り文字コード
// @return 0:成功
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note 本APIで登録した区切り文字を受信すると、SIO_Regist()で登録したイベント番号でコールバックイベントが発生する。
//       対象はRS-485通信およびRS-232通信となっており、CAN通信は対象外。
//       
//       本APIを登録設定で実行した際、sapp_serial.krs内の処理でUARTの有効化とともにボーレートやパリティの設定値も初期値が設定される。
//       その場合、設定値変更のAPIであるSIO_SetUartMode()で設定変更を行っていた際は、再度設定値変更が必要となる。
//       
//       登録した区切り文字部分のデータは、文字列の終了を意味する0x00に自動的に置換される。
//       コールバックイベントで受信データを取得する際は注意すること。
///
func SIO_SetSeparateModeCode(uint8 device_id, uint8 code) {
    
}

///
// @brief シリアル RS-485/RS-485[2WIRE]/RS-232Cデータ送信API(ラッパー関数)
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint8[])data 送信データ
// @param [in](uint16)data_size 送信データサイズ
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "serialAPI.h"
// @attention SIO_DEVICE_RS485_2WIREの場合は、データ送信完了から受信許可となるまでの間に優先度が高いタスクが割り込まれると受信データを取り漏らす区間が発生することに注意。
//            データ送信完了から受信許可までの時間規定は使用条件により変わるため規定できないが、優先度が高いタスクが割り込まれない条件下における実測値は0[msec]。
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_UART_Transmit(device_id, data, data_size, SIO_SEND_DATA_TIMEOUT)。
//       device_idをSIO_DEVICE_RS485_2WIREとすると、データ送信中に受信の抑制制御を行い、送信データをエコーバック受信しないように回避が可能。(HWエコーキャンセル)
///
func SIO_SendDataSerial(uint32 device_id, uint8 data[], uint16 data_size) {
    
}

///
// @brief シリアル RS-485データ受信API ※システムで使用するAPIのため利用禁止
// @return なし
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note RS-485受信割込み発生時にsystem内部からcallされるAPI。
// @attention [NOT_FOR_USERS]システムで使用するAPIのため利用禁止
///
func SIO_NotifyRxRS485() {
    
}

///
// @brief シリアル RS-232データ受信API ※システムで使用するAPIのため利用禁止
// @return なし
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note RS-232受信割込み発生時にsystem内部からcallされるAPI。
// @attention [NOT_FOR_USERS]システムで使用するAPIのため利用禁止
///
func SIO_NotifyRxRS232() {
    
}

///
// @brief シリアル CANデータ受信API ※システムで使用するAPIのため利用禁止
// @param [in](uint32)identifier CAN識別ID
// @return なし
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note CAN受信割込み発生時にsystem内部からcallされるAPI。
// @attention [NOT_FOR_USERS]システムで使用するAPIのため利用禁止
///
func SIO_NotifyRxCAN(uint32 identifier) {
    
}

///
// @brief シリアル CAN通信設定のAPI
// @param [in](uint8)device_id シリアルデバイス識別ID <2:SIO_DEVICE_CAN固定>
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note CANの通信パラメーターを設定するAPI。
//       sapp_serial.krs内でデフォルトのパラメーターを設定している。
///
func SIO_SetCanMode(uint8 device_id) {
    
}

///
// @brief シリアル CANデータ送信API(ラッパー関数)
// @param [in](uint8[])data 送信データ
// @param [in](uint16)data_size 送信データサイズ
// @param [in](uint32)can_id CANの識別ID
// @return 0:成功, -1:失敗
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note 本APIはラッパー関数であり、実際に呼び出される処理はrcplib_CAN_Transmit(KRDEFINE_EXTDEV_CAN1, data, data_size, can_id)。
///
func SIO_SendDataCAN(uint8 data[], uint16 data_size, uint32 can_id) {
    
}

///
// @brief シリアル Modbus Echo制御、インターフェイス用バッファの登録をするAPI
// @param [in](uint8)echo エコーキャンセルモード<SIO_MODBUS_RS485_HW_ECHO_CANCEL:HWエコーキャンセル, SIO_MODBUS_RS485_SW_ECHO_CANCEL:SWエコーキャンセル>
// @param [in](uint8)fifoid 送受信データを格納するFIFOバッファID <0～31>
// @return 0:成功
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note Modbusインターフェイスの設定を行なう。
//       Modbus使用前にはSIO_Regist()/SIO_SetUartMode()によりシリアルインターフェイスの通信設定を行なっておくこと。
//       device_idをSIO_DEVICE_RS232/SIO_DEVICE_RS485_2WIREとして利用する場合は、SIO_MODBUS_RS485_HW_ECHO_CANCELに設定すること。
///
func SIO_ModbusInterfaceSettings(uint8 echo, uint8 fifoid) {
    
}

///
// @brief シリアル Modbus Discrete出力状態を読出すAPI (function code 01) 
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIREを指定可能>
// @param [in](uint8)server サーバーアドレス <1～247>
// @param [in](uint16)addr 読出し番地 (2byte)
// @param [in](uint16)bitqty 読出しビット数 (2byte)
// @return 
//    ・SIO_MODBUS_NO_ERROR 0                // エラーなし
//    ・SIO_MODBUS_ERROR_RCV_ECHO 1          // エコーバック内容違い
//    ・SIO_MODBUS_ERROR_RCV_HEAD 2          // 応答メッセージヘッダ違い
//    ・SIO_MODBUS_ERROR_RCV_CRC  3          // 応答CRC違い
//    ・SIO_MODBUS_ERROR_SND_CMD  4          // コマンド送信エラー
//    ・SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 5   // バッファ未設定
//    ・SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 6  // バッファへデータ設定エラー
//    ・SIO_MODBUS_ERROR_RCV_RESP 7          // エラーレスポンス受信
//    ・SIO_MODBUS_ERROR_RCV_TIMEOUT 200     // 受信タイムアウト
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note Modbusサーバーから DO(Discrete Output) のON/OFF状態を読出す。
//       本API実行前にSIO_ModbusInterfaceSettings()により受信データを格納するFIFOバッファIDを登録しておくこと。
///
func SIO_ModbusReadCoilStatus(uint8 device_id, uint8 server, uint16 addr, uint16 bitqty) {
    
}

///
// @brief シリアル Modbus Discrete入力状態を読出すAPI (function code 02) 
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIREを指定可能>
// @param [in](uint8)server サーバーアドレス <1～247>
// @param [in](uint16)addr 読出し番地 (2byte)
// @param [in](uint16)bitqty 読出しビット数 (2byte)
// @return 
//    ・SIO_MODBUS_NO_ERROR 0                // エラーなし
//    ・SIO_MODBUS_ERROR_RCV_ECHO 1          // エコーバック内容違い
//    ・SIO_MODBUS_ERROR_RCV_HEAD 2          // 応答メッセージヘッダ違い
//    ・SIO_MODBUS_ERROR_RCV_CRC  3          // 応答CRC違い
//    ・SIO_MODBUS_ERROR_SND_CMD  4          // コマンド送信エラー
//    ・SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 5   // バッファ未設定
//    ・SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 6  // バッファへデータ設定エラー
//    ・SIO_MODBUS_ERROR_RCV_RESP 7          // エラーレスポンス受信
//    ・SIO_MODBUS_ERROR_RCV_TIMEOUT 200     // 受信タイムアウト
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note Modbusサーバーから DI(Discrete Input) のON/OFF状態を読出す。
//       本API実行前にSIO_ModbusInterfaceSettings()により受信データを格納するFIFOバッファIDを登録しておくこと。
///
func SIO_ModbusReadInputStatus(uint8 device_id, uint8 server, uint16 addr, uint16 bitqty) {
    
}

///
// @brief シリアル Modbus 保持レジスタの内容を読出すAPI (function code 03) 
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint8)server サーバーアドレス <1～247>
// @param [in](uint16)addr 読出し番地 (2byte)
// @param [in](uint16)regqty 読出しレジスタ数 (2byte)
// @return 
//    ・SIO_MODBUS_NO_ERROR 0                // エラーなし
//    ・SIO_MODBUS_ERROR_RCV_ECHO 1          // エコーバック内容違い
//    ・SIO_MODBUS_ERROR_RCV_HEAD 2          // 応答メッセージヘッダ違い
//    ・SIO_MODBUS_ERROR_RCV_CRC  3          // 応答CRC違い
//    ・SIO_MODBUS_ERROR_SND_CMD  4          // コマンド送信エラー
//    ・SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 5   // バッファ未設定
//    ・SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 6  // バッファへデータ設定エラー
//    ・SIO_MODBUS_ERROR_RCV_RESP 7          // エラーレスポンス受信
//    ・SIO_MODBUS_ERROR_RCV_TIMEOUT 200     // 受信タイムアウト
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note Modbusサーバーの保持レジスタの内容を読出す。
//       本API実行前にSIO_ModbusInterfaceSettings()により受信データを格納するFIFOバッファIDを登録しておくこと。
///
func SIO_ModbusReadHoldingRegister(uint8 device_id, uint8 server, uint16 addr, uint16 regqty) {
    
}

///
// @brief シリアル Modbus 入力レジスタの内容を読出すAPI (function code 04) 
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint8)server サーバーアドレス <1～247>
// @param [in](uint16)addr 読出し番地 (2byte)
// @param [in](uint16)regqty 読出しレジスタ数 (2byte)
// @return 
//    ・SIO_MODBUS_NO_ERROR 0                // エラーなし
//    ・SIO_MODBUS_ERROR_RCV_ECHO 1          // エコーバック内容違い
//    ・SIO_MODBUS_ERROR_RCV_HEAD 2          // 応答メッセージヘッダ違い
//    ・SIO_MODBUS_ERROR_RCV_CRC  3          // 応答CRC違い
//    ・SIO_MODBUS_ERROR_SND_CMD  4          // コマンド送信エラー
//    ・SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 5   // バッファ未設定
//    ・SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 6  // バッファへデータ設定エラー
//    ・SIO_MODBUS_ERROR_RCV_RESP 7          // エラーレスポンス受信
//    ・SIO_MODBUS_ERROR_RCV_TIMEOUT 200     // 受信タイムアウト
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note Modbusサーバーの入力レジスタの内容を読出す。
//       本API実行前にSIO_ModbusInterfaceSettings()により受信データを格納するFIFOバッファIDを登録しておくこと。
///
func SIO_ModbusReadInputRegister(uint8 device_id, uint8 server, uint16 addr, uint16 regqty) {
    
}

///
// @brief シリアル Modbus Discrete出力のON/OFF変更をするAPI (function code 05)
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint8)server サーバーアドレス <0～247, 0はブロードキャスト>
// @param [in](uint16)addr 書換え番地 (2byte)
// @param [in](uint8)coil 書換えコイル (1 or 0)
// @return 
//    ・SIO_MODBUS_NO_ERROR 0                // エラーなし
//    ・SIO_MODBUS_ERROR_RCV_ECHO 1          // エコーバック内容違い
//    ・SIO_MODBUS_ERROR_RCV_HEAD 2          // 応答メッセージヘッダ違い
//    ・SIO_MODBUS_ERROR_RCV_CRC  3          // 応答CRC違い
//    ・SIO_MODBUS_ERROR_SND_CMD  4          // コマンド送信エラー
//    ・SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 5   // バッファ未設定
//    ・SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 6  // バッファへデータ設定エラー
//    ・SIO_MODBUS_ERROR_RCV_RESP 7          // エラーレスポンス受信
//    ・SIO_MODBUS_ERROR_RCV_TIMEOUT 200     // 受信タイムアウト
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note Modbusサーバーの DO(Discrete Output)の状態をON/OFFのいずれかに変更(書込み)する。
//       本API実行前にSIO_ModbusInterfaceSettings()により受信データを格納するFIFOバッファIDを登録しておくこと。
///
func SIO_ModbusForceSingleCoil(uint8 device_id, uint8 server, uint16 addr, uint8 coil) {
    
}

///
// @brief シリアル Modbus 保持レジスタの書込みをするAPI (function code 06)
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint8)server サーバーアドレス <0～247, 0はブロードキャスト>
// @param [in](uint16)addr 書換え番地 (2byte)
// @param [in](uint16)regval 書換えレジスタ値
// @return 
//    ・SIO_MODBUS_NO_ERROR 0                // エラーなし
//    ・SIO_MODBUS_ERROR_RCV_ECHO 1          // エコーバック内容違い
//    ・SIO_MODBUS_ERROR_RCV_HEAD 2          // 応答メッセージヘッダ違い
//    ・SIO_MODBUS_ERROR_RCV_CRC  3          // 応答CRC違い
//    ・SIO_MODBUS_ERROR_SND_CMD  4          // コマンド送信エラー
//    ・SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 5   // バッファ未設定
//    ・SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 6  // バッファへデータ設定エラー
//    ・SIO_MODBUS_ERROR_RCV_RESP 7          // エラーレスポンス受信
//    ・SIO_MODBUS_ERROR_RCV_TIMEOUT 200     // 受信タイムアウト
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note Modbusサーバーの保持レジスタの内容を変更(書込み)する。
//       本API実行前にSIO_ModbusInterfaceSettings()により受信データを格納するFIFOバッファIDを登録しておくこと。
///
func SIO_ModbusWriteSingleRegister(uint8 device_id, uint8 server, uint16 addr, uint16 regval) {
    
}

///
// @brief シリアル Modbus 診断用のAPI (function code 08) 
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint8)server サーバーアドレス <1～247>
// @param [in](uint16)subfunc Sub Function (2byte)
// @param [in](uint16)data Data (2byte)
// @return 
//    ・SIO_MODBUS_NO_ERROR 0                // エラーなし
//    ・SIO_MODBUS_ERROR_RCV_ECHO 1          // エコーバック内容違い
//    ・SIO_MODBUS_ERROR_RCV_HEAD 2          // 応答メッセージヘッダ違い
//    ・SIO_MODBUS_ERROR_RCV_CRC  3          // 応答CRC違い
//    ・SIO_MODBUS_ERROR_SND_CMD  4          // コマンド送信エラー
//    ・SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 5   // バッファ未設定
//    ・SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 6  // バッファへデータ設定エラー
//    ・SIO_MODBUS_ERROR_RCV_RESP 7          // エラーレスポンス受信
//    ・SIO_MODBUS_ERROR_RCV_TIMEOUT 200     // 受信タイムアウト
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note Modbusサーバーへ保守コマンド発行する。
//       本API実行前にSIO_ModbusInterfaceSettings()により受信データを格納するFIFOバッファIDを登録しておくこと。
///
func SIO_ModbusDiagnostics(uint8 device_id, uint8 server, uint16 subfunc, uint16 data) {
    
}

///
// @brief シリアル Modbus 複数の保持レジスタの書込みをするAPI (function code 16) 
// @param [in](uint8)device_id シリアルデバイス識別ID <0:SIO_DEVICE_RS485, 1:SIO_DEVICE_RS232, 5:SIO_DEVICE_RS485_2WIRE>
// @param [in](uint8)server サーバーアドレス <0～247, 0はブロードキャスト>
// @param [in](uint16)addr 開始アドレス
// @param [in](uint16)regqty レジスタ数
// @return 
//    ・SIO_MODBUS_NO_ERROR 0                // エラーなし
//    ・SIO_MODBUS_ERROR_RCV_ECHO 1          // エコーバック内容違い
//    ・SIO_MODBUS_ERROR_RCV_HEAD 2          // 応答メッセージヘッダ違い
//    ・SIO_MODBUS_ERROR_RCV_CRC  3          // 応答CRC違い
//    ・SIO_MODBUS_ERROR_SND_CMD  4          // コマンド送信エラー
//    ・SIO_MODBUS_ERROR_RCV_BUFF_NOTSET 5   // バッファ未設定
//    ・SIO_MODBUS_ERROR_RCV_BUFF_SETDATA 6  // バッファへデータ設定エラー
//    ・SIO_MODBUS_ERROR_RCV_RESP 7          // エラーレスポンス受信
//    ・SIO_MODBUS_ERROR_RCV_TIMEOUT 200     // 受信タイムアウト
// @detail 必要なヘッダinclude : "serialAPI.h"
// @note Modbusサーバーの複数の保持レジスタの内容を変更(書込み)する。
//       本API実行前にSIO_ModbusInterfaceSettings()により送受信データを格納するFIFOバッファIDを登録しておくこと。
///
func SIO_ModbusWriteMultipleRegisters(uint8 device_id, uint8 server, uint16 addr, uint16 regqty) {
    
}

//// ■ディスプレイ制御サブアプリ
///
// @brief ディスプレイに時計画面または状態画面を表示するAPI
// @param [in](uint8)id 画面の種類 <OLC_PICT_STATE:時計画面, OLC_PICT_SET:状態画面>
// @return なし
// @detail 必要なヘッダinclude : "olcAPI.h"
///
func OLC_DisplayPict(uint8 id) {
    
}

///
// @brief ディスプレイに文字を表示するAPI
// @param [in](uint8)priority 実行権限 <OLC_CHAR_USER:システム関連より弱い権限で表示, OLC_CHAR_FORCE:システム関連より強い権限で表示>
// @param [in](uint8)line 表示行(上下方向) <0～18[pixel]>
// @param [in](uint8)offset 表示列(左右方向) <0～15[文字]で指定>
// @param [in](str)disp_str 表示する文字データ <16文字以内かつ「"」以外の任意の文字列>
// @return なし
// @note disp_strには「"」を含む文字列(例えば元がjson変数の文字列など)は代入不可。
//       本APIを実行する度にディスプレイ表示は上書きされる。
// @detail 必要なヘッダinclude : "olcAPI.h"
///
func OLC_DisplayChar(uint8 priority, uint8 line, uint8 offset, str disp_str) {
    
}

///
// @brief ディスプレイに任意のピクセルを表示するAPI
// @param [in](uint8)priority 実行権限設定 <OLC_FREE_USER:システム関連より弱い権限で表示, OLC_FREE_FORCE:システム関連より強い権限で表示>
// @param [in](uint8)line 表示行(上下方向) <0～35[pixel]>
// @param [in](uint32)pixel_data0 表示するpixelデータ0
// @param [in](uint32)pixel_data1 表示するpixelデータ1
// @param [in](uint32)pixel_data2 表示するpixelデータ2
// @param [in](uint32)pixel_data3 表示するpixelデータ3
// @param [in](uint8)size 8pixel単位での左から表示するデータの個数 <1～16で指定>
// @return なし
// @note 本APIを実行する度にディスプレイ表示は上書きされる。
// @detail 必要なヘッダinclude : "olcAPI.h"
///
func OLC_DisplayFree(uint8 priority, uint8 line, uint32 pixel_data0, uint32 pixel_data1, uint32 pixel_data2, uint32 pixel_data3, uint8 size) {
    
}

///
// @brief ディスプレイに任意の固定画面を表示するAPI ※基本的には利用禁止
// @param [in](uint8)id 表示する画面設定、詳細は"olcAPI.h"の#define OLC_PANEL_XXX参照
// @return なし
// @detail 必要なヘッダinclude : "olcAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func OLC_DisplayPanel(uint8 id) {
    
}

///
// @brief ディスプレイに表示させる個別情報を設定するAPI ※基本的には利用禁止
// @param [in](uint8)device デバイス設定、詳細は"olcAPI.h"の#define OLC_DEVICE_XXX参照
// @param [in](uint8)event イベント設定、詳細は"olcAPI.h"の#define OLC_EVENT_XXX参照
// @return なし
// @detail 必要なヘッダinclude : "olcAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func OLC_ChangeStatus(uint8 device, uint8 event) {
    
}

///
// @brief ディスプレイに表示させるエラー情報を設定するAPI ※基本的には利用禁止
// @param [in](uint8)flag 要求/解除設定、詳細は"olcAPI.h"の#define OLC_ERRCD_XXX参照
// @param [in](str)errcd 設定するエラーコード文字列変数
// @return なし
// @detail 必要なヘッダinclude : "olcAPI.h"
// @attention [NOT_FOR_USERS]基本的には利用禁止
///
func OLC_SetErrCode(uint8 flag, str errcd) {
    
}

//// ■LEDサブアプリ
///
// @brief LEDを指定の色で点灯させるAPI
// @param [in](uint8)color 色指定 <0:LED_COLOR_RED（赤色）, 1:LED_COLOR_GREEN（緑色）, 2:LED_COLOR_ORANGE（橙色）, 3:LED_COLOR_STOP(消灯)>
// @param [in](uint32)time 点灯時間[msec](点灯したままにする場合は0を設定すること)
// @return 0:成功
// @detail 必要なヘッダinclude : "ledAPI.h"
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "ledAPI.h"
// 
//  // LED_ON(橙色のLEDを1秒間点灯する
//  LED_DoLightup(LED_COLOR_ORANGE, 1000);
///
func LED_DoLightup(uint8 color, uint32 time) {
    
}

///
// @brief LEDを指定した色と回数、間隔を指定して点滅させるAPI
// @param [in](uint8)color 色指定 <0:LED_COLOR_RED, 1:LED_COLOR_GREEN, 2:LED_COLOR_ORANGE, 3:LED_COLOR_STOPまたはそれ以上の値(点滅を停止し消灯する)>
// @param [in](uint16)count 点滅回数(LED_INTERVAL_LOW_REQ(x)/LED_INTERVAL_HIGH_REQ(x)のマクロを使用することで時間で指定することも可能)
// @param [in](uint32)interval 点滅間隔[msec]
// @return 0:成功
// @detail 必要なヘッダinclude : "ledAPI.h"
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "ledAPI.h"
// 
//  // 赤色LEDを30秒間点滅させる(LED_INTERVAL_HIGH=500[msec]間隔の点滅)
//  LED_DoBlink(LED_COLOR_RED, LED_INTERVAL_HIGH_REQ(30), LED_INTERVAL_HIGH);
///
func LED_DoBlink(uint8 color, uint16 count, uint32 interval) {
    
}

// @brief 起動時のLED点灯パターンを実行するAPI ※システムで使用するAPIのため利用禁止
// @param [in](uint8)mode 起動モード指定
// @param [in](uint8)event_id 点灯パターン終了時に発行されるイベントID <1～254>
// @return 0:成功
// @detail 必要なヘッダinclude : "ledAPI.h"
// @attention [NOT_FOR_USERS]システムで使用するAPIのため利用禁止
///
func LED_DoBootup(uint8 mode, uint8 event_id) {
    
}

///
// @brief シャットダウン時のLED点灯パターンを実行するAPI ※システムで使用するAPIのため利用禁止
// @param [in](uint8)event_id 点灯パターン終了時の発行されるイベントID <1～254>
// @return 0:成功
// @detail 必要なヘッダinclude : "ledAPI.h"
// @attention [NOT_FOR_USERS]システムで使用するAPIのため利用禁止
///
func LED_DoShutdown(uint8 event_id) {
    
}

///
// @brief エラー発生時のLED点灯パターンを実行するAPI ※システムで使用するAPIのため利用禁止
// @param [in](uint8)sw 要求詳細
// @return 0:成功
// @detail 必要なヘッダinclude : "ledAPI.h"
// @attention [NOT_FOR_USERS]システムで使用するAPIのため利用禁止
///
func LED_DoError(uint8 sw) {
    
}

///
// @brief ファームウェア更新中のLED点灯パターンを実行するAPI ※システムで使用するAPIのため利用禁止
// @param [in](uint8)sw 要求詳細
// @return 0:成功
// @detail 必要なヘッダinclude : "ledAPI.h"
// @attention [NOT_FOR_USERS]システムで使用するAPIのため利用禁止
///
func LED_DoFWupdate(uint8 sw) {
    
}

//// ■振動検出サブアプリ
///
// @brief 振動検出用の設定をするAPI
// @param [in](uint8)sw 有効/無効 <0:VIB_SENSE_DISABLE, 1:VIB_SENSE_ENABLE>
// @param [in](uint16)sens 振動検知回数
// @param [in](uint8)notify_event_id 振動検出イベントを受けるイベントID <1～254>
// @return 0:成功
// @detail 必要なヘッダinclude : "vibAPI.h"
// @note
//    加速度センサのダイナミックレンジを±8[G]で利用する場合の振動検出閾値は±0.03125[G]となる。
// 
//    事前に加速度センサのODR(動作周波数)の設定変更APIであるACC_SetDeviceMeasure()の実行により
//    振動検出に関連する動作周期が変更できる。
// 
//    ダイナミックレンジ変更のAPIであるACC_SetDeviceRange()を実行することで
//    初期設定±8[G]から任意のダイナミックレンジに変更できる。
// 
//    sdev_sensor.krsの以下defineを変更することにより振動検出の検出閾値を変更できる。
//    #define ACC_WAKE_UP_THS  0x01 // 1LSb は ±ACC_DRANGE_X / 256 [G] に相当  ex) ACC_DRANGE_8 = ±8[G] -> ±0.03125[G]/LSb
//  
//    本APIを利用した場合、振動検出する度に標準で10秒のインターバル内の次の振動を監視し、指定した回数の連続振動を検出した時にイベント通知する振動検出機能を利用できる。
//    振動検出時に毎回イベント通知する利用方法においてはACC_SetVibrationMode()を利用すること。
//    また、振動検出するインターバルを標準の10秒から変更する際は、VIB_SetCountInterval()を使用して変更すること。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・取得値なし
// @code
//  // ソース冒頭でヘッダをinclude
//  #include "vibAPI.h"
// 
//  // 内部非同期イベントIDを定義
//  #define UNSYNC_EVENT_VIB_NOTIFY 1
// 
//  // 振動検出を有効にする(10回振動を検知したらイベントID(UNSYNC_EVENT_VIB_NOTIFY)にイベント通知する)
//  VIB_SetSenseMode(VIB_SENSE_ENABLE, 10, UNSYNC_EVENT_VIB_NOTIFY);
// 
//  // 振動検出を無効にする
//  VIB_SetSenseMode(VIB_SENSE_DISABLE, 0, 0);
///
func VIB_SetSenseMode(uint8 sw, uint16 sens, uint8 notify_event_id) {
    
}

///
// @brief 振動検出のインターバル設定を行うAPI
// @param [in](uint32)interval インターバル間隔<1～4294967295[msec]>
// @return 0:成功
// @detail 必要なヘッダinclude : "vibAPI.h"
// @note
//    インターバルの初期秒数は10秒で設定されている。
///
func VIB_SetCountInterval(uint32 interval) {
    
}

//// ■モデム制御サブアプリ
///
// @brief プロトコル通信に利用する送信IDを登録するAPI
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8 (MSA_SEND_ID_01_LTE～MSA_SEND_ID_08_LTE)>
// @param [in](uint8)recv_mode 「送信結果イベント」と「データ受信イベント」のコールバック登録有効/無効設定 <MSA_SID_API_RECEIVE_DISABLE:コールバック登録なし, MSA_SID_API_RECEIVE_RESULT_ENABLE:送信結果イベントのみ登録, MSA_SID_API_RECEIVE_DATA_ENABLE:データ受信イベントのみ登録, MSA_SID_API_RECEIVE_ALL_ENABLE:送信結果とデータ受信の両イベントを登録>
// @param [in](uint8)send_res_event_id 送信結果のイベントを受けるイベントID <1～254, 使用しない場合は不問>
// @param [in](uint8)recv_data_event_id データ受信時にイベントを受けるイベントID <1～254, 使用しない場合は不問>
// @return 0(EAPI_NO_ERROR):成功, 0以外:失敗、詳細は以下備考を参照
// @detail 必要なヘッダinclude : 無し
// @note 
//    「モデム制御サブアプリ」を利用してプロトコル通信を行う場合は、
//    MMG_SetConnectParam()等の通信プロトコルAPIは利用禁止。
//    どちらか一方のみを利用すること。
// 
//    利用する通信プロトコルに応じて「recipe/inc/sappModem/msa_config_xxxxx.h」に設定を記述し
//    そこで設定した送信ID(MSA_SEND_ID_01_LTE～MSA_SEND_ID_08_LTE)を本APIにて登録実行する。
//    本APIはタスクの初期化処理内でのみ実行すること。送信IDの登録のみ可能で解除は非対応。
// 
//    returnの詳細は以下の通り
//      0(EAPI_NO_ERROR):成功
//      100(MSA_SID_API_ERR_NO_CONFIG) : 送信IDがmsa_config_xxxxx.h内のプロトコル設定で有効化されていない
//      101(MSA_SID_API_ERR_OUT_OF_RANGE) : 設定値が範囲外
//      102(MSA_SID_API_ERR_ALREADY_SET) : 登録済みの送信ID指定
//      103(MSA_SID_API_ERR_SBUF_CREATE) : 送信バッファの作成失敗
//      104(MSA_SID_API_ERR_RBUF_CREATE) : 受信バッファの作成失敗
// 
//    ＜送信結果のコールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(uint8)response_code 送信結果のレスポンスコード
//        送信結果のレスポンスコードの詳細は以下の通り
//          0(EAPI_NO_ERROR):成功
//          105(MSA_SID_API_ERR_NO_RECEPTION) : 圏外により送信せず
//          106(MSA_SID_API_ERR_LTE_SEND_FAIL) : LTEデータ送信成功数0
//    ・rcplib_TASK_GetArg(1)
//    　(uint16)send_success_num 送信成功数
// 
//    ＜データ受信時のコールバックイベントでの取得値の定義＞
//    ・rcplib_TASK_GetArg(0)
//    　(uint16)response_code 受信結果のレスポンスコード
//        HTTP以外利用時における受信結果のレスポンスコードの詳細は以下の通り
//          0(EAPI_NO_ERROR):成功
//          1～99:Warning ※詳細は"modemMgrTask.h"を参照
//          100～199:失敗 ※詳細は"modemMgrTask.h"を参照
//        HTTP利用時における受信結果のレスポンスコードは上記に加え、
//        HTTP通信実施時は200等のHTTPレスポンスコードを通知する
//    ・rcplib_TASK_GetArg(1)
//    　(uint8)rcv_datbuf_id 受信データを格納したFIFOバッファID
///
func MSA_SetLteSendId(uint8 send_id, uint8 recv_mode, uint8 send_res_event_id, uint8 recv_data_event_id) {
    
}

///
// @brief USBカメラの画像を送信するAPI
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8 (MSA_SEND_ID_01_LTE～MSA_SEND_ID_08_LTE)>
// @param [in](uint16)mov_target カメラの撮影画像送信時の対象指定 <0:最新の画像, 1～:最新から指定毎数分さかのぼった画像, 0xFFFF:一番古い画像>
// @return 0:成功
// @detail 必要なヘッダinclude : 無し
// @note
//    「モデム制御サブアプリ」を利用してプロトコル通信を行う場合は、
//    MMG_SetConnectParam()等の通信プロトコルAPIは利用禁止。
//    どちらか一方のみを利用すること。
// 
//    タスクの初期化処理内で「送信IDの登録APIであるMSA_SetLteSendId()」を予め実行し
//    その登録した送信IDを本APIのsend_idに指定してカメラバッファからの送信命令を行う。
//    sapp_modemを利用してUSBカメラの画像を送信する場合は、
//   「送信IDの登録APIであるMSA_SetLteSendId()」の実行では必ず
//    送信結果のコールバックイベントの登録を行うこと。
//    また、本APIによるUSBカメラの画像送信命令要求は必ず同時に1つのみとすること。
//    ＝一度の本API実行に対して、送信結果のコールバックイベントを待ってから次のAPI実行を行うこと。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・取得値なし
//      ※但し、MSA_SetLteSendId()で予め登録した送信結果のコールバックを利用し本APIの実行可否の判断を行うこと
///
func MSA_SendCameraImage(uint8 send_id, uint16 mov_target) {
    
}

///
// @brief 送信ID指定で常時セッション接続の登録/解除を行うAPI
// @param [in](uint8)event_id 本APIの実行結果受けるイベントID <1～254>
// @param [in](uint8)send_id 送信ID(接続や送受信の管理ID) <1～8 (MSA_SEND_ID_01_LTE～MSA_SEND_ID_08_LTE)>
// @param [in](uint8)regist 常時セッション接続の登録実行または登録解除設定 <MSA_ALWAYS_CONN_UNREGIST:登録解除, MSA_ALWAYS_CONN_REGIST:登録実行>
// @return 0:成功
// @detail 必要なヘッダinclude : 無し
// @note
//    「モデム制御サブアプリ」を利用してプロトコル通信を行う場合は、
//    MMG_SetConnectParam()等の通信プロトコルAPIは利用禁止。
//    どちらか一方のみを利用すること。
// 
//    タスクの初期化処理内で「送信IDの登録APIであるMSA_SetLteSendId()」を予め実行し
//    その登録した送信IDを本APIのsend_idに指定して常時セッション接続の登録/解除を行う。
//    また、本APIによる常時セッション接続の登録/解除要求は必ず同時に1つのみとすること。
//    ＝一度の本API実行に対して、本APIのコールバックイベントを待ってから次のAPI実行を行うこと。
// 
//    本APIは最後に実行された要求の設定値でその時の設定値を上書きし反映する。
//    複数タスクからの実行も可能だが、その場合においても上記の通り本APIの同時実行は避けること。
// 
//    ＜コールバックイベントでの取得値の定義＞
//    ・取得値なし
///
func MSA_SetAlwaysConnect(uint8 event_id, uint8 send_id, uint8 regist) {
    
}

#endif //_BASIC_INFORMATION_H_
